package Module::CPANTS;
use strict;
use vars qw($VERSION);
$VERSION = "0.20030725";

# This module is autogenerated!

sub new {
  my $class = shift;
  my $self = {};
  bless $self, $class;
}

sub data {
  my $self = shift;

  my $cpants = {'AA-0.03.tar.gz' => {'author' => 'RLZWART','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 275,'pod' => 83,'pod_errors' => 0,'total' => 358,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 12914,'unpacked' => 36350},'testers' => {},'uses' => ['Exporter','XSLoader','constant','strict','warnings']},'ABI-0.01.tar.gz' => {'author' => 'MALAY','description' => 'Perl module to parse chromatogram files generated by Applied Biosystems (ABI) automated DNA sequencing machine.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 400,'pod' => 86,'pod_errors' => 0,'total' => 486,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 12370,'unpacked' => 37542},'testers' => {'pass' => 4},'uses' => ['Carp','IO::File','strict']},'ACME-Error-0.03.tar.gz' => {'author' => 'CWEST','description' => 'Never have boring errors again!','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 58,'pod_errors' => 0,'total' => 147,'with_comments' => 16},'releases' => 3,'size' => {'packed' => 2233,'unpacked' => 4383},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'ACME-Error-31337-0.01.tar.gz' => {'author' => 'CWEST','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 29,'pod_errors' => 0,'total' => 49,'with_comments' => 0},'releases' => 1,'requires' => ['ACME-Error-0.03.tar.gz','Lingua-31337-0.02.tar.gz'],'requires_module' => {'ACME::Error' => '0.01','Lingua::31337' => '0.01'},'requires_recursive' => ['ACME-Error-0.03.tar.gz','Lingua-31337-0.02.tar.gz'],'size' => {'packed' => 1492,'unpacked' => 2036},'testers' => {'pass' => 3},'uses' => ['Lingua::31337','strict','vars']},'ACME-Error-Coy-0.01.tar.gz' => {'author' => 'CWEST','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 21,'pod' => 25,'pod_errors' => 0,'total' => 46,'with_comments' => 1},'releases' => 1,'requires' => ['Coy-0.05.tar.gz'],'requires_module' => {'Coy' => '0.01'},'requires_recursive' => ['Coy-0.05.tar.gz'],'size' => {'packed' => 1366,'unpacked' => 1901},'testers' => {'pass' => 3},'uses' => ['Coy','strict','vars']},'ACME-Error-HTML-0.01.tar.gz' => {'author' => 'CWEST','description' => 'ACME::Error Backend to Markup Errors with HTML','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 27,'pod_errors' => 0,'total' => 56,'with_comments' => 0},'releases' => 1,'requires' => ['HTML-FromText-1.005.tar.gz'],'requires_module' => {'HTML::FromText' => '0.01'},'requires_recursive' => ['HTML-FromText-1.005.tar.gz'],'size' => {'packed' => 1437,'unpacked' => 2245},'testers' => {'pass' => 3},'uses' => ['HTML::FromText','strict','vars']},'ACME-Error-IgpayAtinlay-0.01.tar.gz' => {'author' => 'CWEST','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 21,'pod' => 27,'pod_errors' => 0,'total' => 48,'with_comments' => 0},'releases' => 1,'requires' => ['Lingua-Atinlay-Igpay-0.03.tar.gz'],'requires_module' => {'Lingua::Atinlay::Igpay' => '0.01'},'requires_recursive' => ['Lingua-Atinlay-Igpay-0.03.tar.gz'],'size' => {'packed' => 1455,'unpacked' => 2207},'testers' => {'pass' => 3},'uses' => ['Lingua::Atinlay::Igpay','strict','vars']},'ACME-Error-Translate-0.01.tar.gz' => {'author' => 'CWEST','description' => 'Language Translating Backend for ACME::Error','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 25,'pod_errors' => 0,'total' => 56,'with_comments' => 0},'releases' => 1,'requires' => ['ACME-Error-0.03.tar.gz','Lingua-Translate-0.06.tar.gz'],'requires_module' => {'ACME::Error' => '0.01','Lingua::Translate' => '0.01'},'requires_recursive' => ['ACME-Error-0.03.tar.gz','Lingua-Translate-0.06.tar.gz'],'size' => {'packed' => 1464,'unpacked' => 2247},'testers' => {'fail' => 2},'uses' => ['Lingua::Translate','strict','vars']},'AFS-2.03.tar.gz' => {'author' => 'NOG','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1793,'pod' => 3454,'pod_errors' => 0,'total' => 5247,'with_comments' => 298},'releases' => 5,'size' => {'packed' => 90297,'unpacked' => 425849},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','vars']},'AI-Categorizer-0.06.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Automatic Text Categorization','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 3718,'pod' => 1761,'pod_errors' => 0,'total' => 5479,'with_comments' => 221},'releases' => 5,'requires' => ['Algorithm-NaiveBayes-0.02.tar.gz','Class-Container-0.10.tar.gz','File-Spec-0.82.tar.gz','Lingua-Stem-0.60.tar.gz','Params-Validate-0.64.tar.gz','Statistics-Contingency-0.06.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'Algorithm::NaiveBayes' => 0,'Class::Container' => '0.09','File::Spec' => 0,'Lingua::Stem' => '0.5','Params::Validate' => '0.18','Statistics::Contingency' => '0.06','Storable' => 0},'requires_recursive' => ['Algorithm-NaiveBayes-0.02.tar.gz','Attribute-Handlers-0.78.tar.gz','Class-Container-0.10.tar.gz','File-Spec-0.82.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','Params-Validate-0.64.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Statistics-Contingency-0.06.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-German-0.03.tar.gz'],'size' => {'packed' => 254644,'unpacked' => 415734},'testers' => {'pass' => 2},'uses' => ['AI::Categorizer::Category','AI::Categorizer::Collection','AI::Categorizer::Document','AI::Categorizer::FeatureSelector','AI::Categorizer::FeatureVector','AI::Categorizer::Hypothesis','AI::Categorizer::KnowledgeSet','AI::Categorizer::Learner','AI::Categorizer::ObjectSet','AI::Categorizer::Storable','AI::Categorizer::Util','AI::DecisionTree','Algorithm::NaiveBayes','Algorithm::SVM','Algorithm::SVM::DataSet','Carp','Class::Container','DBI','Exporter','File::Copy','File::Spec','Lingua::Stem','Params::Validate','Statistics::Contingency','Storable','Time::Progress','XML::SAX','XML::SAX::Base','integer','strict']},'AI-Categorizer-0.07.tar.gz' => {'author' => 'KWILLIAMS','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 3718,'pod' => 1761,'pod_errors' => 0,'total' => 5479,'with_comments' => 221},'releases' => 5,'requires' => ['Algorithm-NaiveBayes-0.02.tar.gz','Class-Container-0.10.tar.gz','File-Spec-0.82.tar.gz','Lingua-Stem-0.60.tar.gz','Params-Validate-0.64.tar.gz','Statistics-Contingency-0.06.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'Algorithm::NaiveBayes' => 0,'Class::Container' => '0.09','File::Spec' => 0,'Lingua::Stem' => '0.5','Params::Validate' => '0.18','Statistics::Contingency' => '0.06','Storable' => 0},'requires_recursive' => ['Algorithm-NaiveBayes-0.02.tar.gz','Attribute-Handlers-0.78.tar.gz','Class-Container-0.10.tar.gz','File-Spec-0.82.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','Params-Validate-0.64.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Statistics-Contingency-0.06.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-German-0.03.tar.gz'],'size' => {'packed' => 255814,'unpacked' => 419189},'testers' => {'pass' => 2},'uses' => ['AI::Categorizer::Learner::Boolean','AI::DecisionTree','Algorithm::NaiveBayes','Algorithm::SVM','Algorithm::SVM::DataSet','Carp','Class::Container','DBI','Exporter','File::Copy','File::Spec','Lingua::Stem','Params::Validate','Statistics::Contingency','Storable','Time::Progress','XML::SAX','XML::SAX::Base','integer','strict']},'AI-DecisionTree-0.08.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Automatically Learns Decision Trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 548,'pod' => 238,'pod_errors' => 0,'total' => 786,'with_comments' => 36},'releases' => 8,'size' => {'packed' => 25662,'unpacked' => 254179},'testers' => {'pass' => 2},'uses' => ['Carp','GraphViz','strict','vars']},'AI-ExpertSystem-Simple.1.1.tgz' => {'author' => 'PETERHI','description' => 'A simple expert system shell','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 686,'pod' => 642,'pod_errors' => 0,'total' => 1328,'with_comments' => 13},'releases' => 1,'requires' => ['XML-Twig-3.10.tar.gz'],'requires_module' => {'XML::Twig' => 0},'requires_recursive' => ['XML-Parser-2.31.tar.gz','XML-Twig-3.10.tar.gz'],'size' => {'packed' => 20215,'unpacked' => 151094},'testers' => {'pass' => 1},'uses' => ['XML::Twig','strict','warnings']},'AI-Fuzzy-0.01.tar.gz' => {'author' => 'SABREN','description' => 'Perl extension for Fuzzy Logic','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 94,'pod_errors' => 0,'total' => 299,'with_comments' => 24},'releases' => 3,'size' => {'packed' => 3717,'unpacked' => 7930},'testers' => {'pass' => 12},'uses' => ['AI::Fuzzy::Label','AI::Fuzzy::Set','strict','vars']},'AI-Fuzzy-0.05.tar.gz' => {'author' => 'TSCANLAN','description' => 'Perl extension for Fuzzy Logic','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 581,'pod' => 158,'pod_errors' => 0,'total' => 739,'with_comments' => 54},'releases' => 3,'size' => {'packed' => 8365,'unpacked' => 31684},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'AI-FuzzyInference-0.04.tar.gz' => {'author' => 'AQUMSIEH','description' => 'A module to implement a Fuzzy Inference System.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 891,'pod' => 257,'pod_errors' => 0,'total' => 1148,'with_comments' => 152},'releases' => 3,'size' => {'packed' => 9576,'unpacked' => 37602},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'AI-FuzzyLogic-0.04.tar.gz' => {'author' => 'SWALTERS','description' => 'Fuzzy Set Operations and Tools','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 1406,'pod' => 557,'pod_errors' => 0,'total' => 1963,'with_comments' => 287},'releases' => 2,'requires' => ['English-Reference-0.03.tgz','Scalar-List-Utils-1.11.tar.gz'],'requires_module' => {'English::Reference' => '0.01','Scalar::Util' => '1.11'},'requires_recursive' => ['English-Reference-0.03.tgz','Scalar-List-Utils-1.11.tar.gz'],'size' => {'packed' => 24556,'unpacked' => 72023},'testers' => {},'uses' => ['English::Reference','Nark','Scalar::Util','lib','strict','warnings']},'AI-Gene-Sequence-0.21.tar.gz' => {'author' => 'AJGOUGH','description' => 'Base class of mutation methods','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1263,'pod' => 442,'pod_errors' => 0,'total' => 1705,'with_comments' => 191},'releases' => 2,'size' => {'packed' => 16874,'unpacked' => 73949},'testers' => {'pass' => 12},'uses' => ['5.6.0','MIDI::Simple','strict','warnings']},'AI-LibNeural-0.02.tar.gz' => {'author' => 'RMCFARLA','description' => 'Perl extension libneural','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 100,'pod' => 114,'pod_errors' => 0,'total' => 214,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 14590,'unpacked' => 45559},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'AI-Menu-0.01.tar.gz' => {'author' => 'JSMITH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 309,'pod' => 173,'pod_errors' => 1,'total' => 482,'with_comments' => 0},'releases' => 1,'requires' => ['Class-MethodMaker-1.10.tar.gz','Graph-0.20101.tar.gz','Tree-Nary-1.21.tar.gz'],'requires_module' => {'Class::MethodMaker' => '1.02','Graph' => '0.201','Tree::Nary' => '1.21'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','Graph-0.20101.tar.gz','Heap-0.50.tar.gz','Tree-Nary-1.21.tar.gz'],'size' => {'packed' => 5587,'unpacked' => 19574},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['5.005_003','Graph::Directed','Tree::Nary','strict','vars']},'AI-NaiveBayes1-0.02.tar.gz' => {'author' => 'VLADO','description' => 'Bayesian prediction of categories','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 227,'pod' => 85,'pod_errors' => 0,'total' => 312,'with_comments' => 17},'releases' => 2,'size' => {'packed' => 5633,'unpacked' => 15414},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'AI-NeuralNet-BackProp-0.89.zip' => {'author' => 'JBRYAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1570,'pod' => 591,'pod_errors' => 0,'total' => 2161,'with_comments' => 329},'releases' => 4,'size' => {'packed' => 52051,'unpacked' => 168231},'testers' => {'pass' => 9,'tests' => '0','unknown' => 6},'uses' => ['Benchmark','strict']},'AI-NeuralNet-Kohonen-Demo-RGB-0.123.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 169,'pod' => 41,'pod_errors' => 0,'total' => 210,'with_comments' => 13},'releases' => 4,'requires' => ['Kohonen-SOM-0.133.tar.gz','Tk-800.024.tar.gz'],'requires_module' => {'AI::NeuralNet::Kohonen' => '0.11','Tk' => '0.1','Tk::Canvas' => '0.1','Tk::Label' => '0.1'},'requires_recursive' => ['Kohonen-SOM-0.133.tar.gz','Tk-800.024.tar.gz'],'size' => {'packed' => 3133,'unpacked' => 8097},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['AI::NeuralNet::Kohonen','Carp','Tk','Tk::Canvas','Tk::Label','strict','vars','warnings']},'AI-NeuralNet-Kohonen-Visual-0.2.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 291,'pod' => 133,'pod_errors' => 0,'total' => 424,'with_comments' => 12},'releases' => 1,'requires' => ['Kohonen-SOM-0.133.tar.gz'],'requires_module' => {'AI::NeuralNet::Kohonen' => '0.13'},'requires_recursive' => ['Kohonen-SOM-0.133.tar.gz'],'size' => {'packed' => 4906,'unpacked' => 13835},'testers' => {'pass' => 1},'uses' => ['AI::NeuralNet::Kohonen','Carp','Tk','Tk::Canvas','Tk::Label','strict','vars','warnings']},'AI-NeuralNet-Mesh-0.44.zip' => {'author' => 'JBRYAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1573,'pod' => 811,'pod_errors' => 1,'total' => 2384,'with_comments' => 210},'releases' => 4,'size' => {'packed' => 99886,'unpacked' => 284854},'testers' => {'pass' => 5,'tests' => '0','unknown' => 3},'uses' => ['Benchmark','Exporter','strict']},'AI-NeuralNet-SOM-0.02.tar.gz' => {'author' => 'VOISCHEV','description' => 'Kohonen Self-Organizing Maps','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1129,'pod' => 291,'pod_errors' => 0,'total' => 1420,'with_comments' => 141},'releases' => 2,'size' => {'packed' => 25753,'unpacked' => 44350},'testers' => {'pass' => 4},'uses' => ['5.005_62','AutoLoader','Carp','Exporter','POSIX','locale','strict','warnings']},'AI-Perceptron-0.01.tar.gz' => {'author' => 'SPURKIS','description' => 'An implementation of a Perceptron','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 70,'pod_errors' => 1,'total' => 231,'with_comments' => 51},'releases' => 1,'size' => {'packed' => 3545,'unpacked' => 7844},'testers' => {'pass' => 9},'uses' => ['strict','vars']},'AI-Proplog-0.04.tar.gz' => {'author' => 'TBONE','description' => 'Propositional logic engine','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 133,'pod_errors' => 0,'total' => 309,'with_comments' => 8},'releases' => 3,'size' => {'packed' => 3971,'unpacked' => 9974},'testers' => {'pass' => 4},'uses' => ['5.005_62','Exporter','strict','warnings']},'AI-jNeural-0.53.tar.gz' => {'author' => 'JETTERO','description' => 'The Jet\'s Neural Architecture base module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 495,'pod' => 344,'pod_errors' => 0,'total' => 839,'with_comments' => 23},'releases' => 6,'size' => {'packed' => 158454,'unpacked' => 622811},'testers' => {},'uses' => ['5.005_62','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'AIX-LPP-0.5.tar.gz' => {'author' => 'CRITTER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 199,'pod' => 72,'pod_errors' => 0,'total' => 271,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 5050,'unpacked' => 13337},'testers' => {'pass' => 4},'uses' => ['5.005_62','strict','warnings']},'AIX-SysInfo-1.0.tar.gz' => {'author' => 'SSKLAR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 352,'pod' => 102,'pod_errors' => 2,'total' => 454,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 5120,'unpacked' => 17114},'testers' => {},'uses' => ['Exporter','strict','vars']},'AKDB_Okewo_de_1.03.tar.gz' => {'author' => 'HORSHACK','description' => undef,'files' => [],'lines' => {'nonpod' => 1458,'pod' => 782,'pod_errors' => 3,'total' => 2240,'with_comments' => 144},'releases' => 1,'size' => {'packed' => 15312,'unpacked' => 56491},'testers' => {'fail' => 1},'uses' => ['Carp','DBD::Oracle','DBI','Date::Calc','Exporter','strict']},'ANSIColor-1.07.tar.gz' => {'author' => 'RRA','description' => 'Color output using ANSI escape sequences','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 300,'pod' => 169,'pod_errors' => 0,'total' => 469,'with_comments' => 65},'releases' => 7,'size' => {'packed' => 10921,'unpacked' => 30806},'testers' => {'pass' => 10},'uses' => ['5.001','Carp','strict','vars']},'AOL-TOC-0.340.tar.gz' => {'author' => 'JHARDING','description' => 'Perl extension for interfacing with AOL\'s AIM service','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 760,'pod' => 58,'pod_errors' => 0,'total' => 818,'with_comments' => 23},'releases' => 3,'size' => {'packed' => 7094,'unpacked' => 24502},'testers' => {'pass' => 4},'uses' => ['IO','IO::Select','Socket']},'ARSperl-1.74.tgz' => {'author' => 'JMURPHY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1471,'pod' => 0,'pod_errors' => 0,'total' => 1471,'with_comments' => 302},'releases' => 21,'size' => {'packed' => 184462,'unpacked' => 823768},'testers' => {},'uses' => ['5.004','ARSOOform','ARSOOmsgs','ARSOOsup','ARSar-h','ARSarerrno-h','ARSnparm','ARSnt-h','ARSnterrno-h','AutoLoader','Carp','Config','DynaLoader','Exporter','strict']},'ASF-Info-1.01.tar.gz' => {'author' => 'ALLENDAY','description' => 'ASF files for attributes like: -video codec -audio codec -frame height -frame width -frame count and more!','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 367,'pod' => 65,'pod_errors' => 0,'total' => 432,'with_comments' => 91},'releases' => 2,'size' => {'packed' => 59416,'unpacked' => 81150},'testers' => {'fail' => 2,'pass' => 1,'tests' => '20'},'uses' => ['5.005_62','Video::Info','constant','strict','vars','warnings']},'ASP-1.07.tar.gz' => {'author' => 'TIMMY','description' => 'Interface for ASP PerlScript and Apache::ASP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 308,'pod' => 214,'pod_errors' => 0,'total' => 522,'with_comments' => 34},'releases' => 2,'size' => {'packed' => 6436,'unpacked' => 20312},'testers' => {'pass' => 2,'tests' => '0','unknown' => 24},'uses' => ['5.005','CGI','Exporter','strict','vars']},'ASP-NextLink-0.11.tar.gz' => {'author' => 'TIMMY','description' => 'Perl implementation of the NextLink ASP component','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 153,'pod' => 99,'pod_errors' => 0,'total' => 252,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 2628,'unpacked' => 8623},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['CGI::Carp','strict','vars']},'AXF-0.8.1.tgz' => {'author' => 'SMCMURRAY','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 355,'pod' => 0,'pod_errors' => 0,'total' => 355,'with_comments' => 86},'releases' => 3,'requires' => ['Apache-Session-1.54.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'Apache::Session::Postgres' => '1.0','XML::LibXML' => '1.53','XML::LibXSLT' => '1.52','XML::Simple' => '2.0'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3238,'unpacked' => 9270},'testers' => {'fail' => 1,'tests' => '0','unknown' => 4},'uses' => ['Apache::Const','Apache::File','Apache::Session::Postgres','Apache::compat','CGI','CGI::Cookie','XML::LibXML','XML::LibXSLT','XML::Simple','mod','strict']},'AcePerl-1.82.tar.gz' => {'author' => 'LDS','description' => 'Object-Oriented Access to ACEDB Databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10094,'pod' => 4460,'pod_errors' => 0,'total' => 14554,'with_comments' => 1180},'releases' => 15,'requires' => ['Digest-MD5-2.26.tar.gz'],'requires_module' => {'Digest::MD5' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 293592,'unpacked' => 1028780},'testers' => {},'uses' => ['$safe','5.004','Ace','Ace::Browser::AceSubs','Ace::Browser::LocalSiteDefs','Ace::Iterator','Ace::Model','Ace::Object','Ace::Sequence','Ace::Sequence::FeatureList','Ace::Sequence::GappedAlignment','AutoLoader','CGI','CGI::Cookie','Carp','Digest::MD5','DynaLoader','Exporter','Fcntl','File::Path','GD','GFF','GFF::Filehandle','IO::Socket','IPC::Open2','Symbol','Text::Tabs','constant','overload','strict','vars']},'AcePerl-1.83.tar.gz' => {'author' => 'LDS','description' => 'Object-Oriented Access to ACEDB Databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10135,'pod' => 4464,'pod_errors' => 0,'total' => 14599,'with_comments' => 1182},'releases' => 15,'requires' => ['Digest-MD5-2.26.tar.gz'],'requires_module' => {'Digest::MD5' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 294151,'unpacked' => 1030144},'testers' => {'fail' => 2,'pass' => 2,'tests' => '130'},'uses' => ['$safe','5.004','Ace','Ace::Browser::AceSubs','Ace::Browser::LocalSiteDefs','Ace::Browser::SiteDefs','Ace::Graphics::Fk','Ace::Graphics::Glyph','Ace::Graphics::Glyph::segments','Ace::Graphics::GlyphFactory','Ace::Graphics::Track','Ace::Iterator','Ace::Model','Ace::Object','Ace::Sequence','Ace::Sequence::Feature','Ace::Sequence::FeatureList','Ace::Sequence::GappedAlignment','Ace::Sequence::Homol','Ace::Sequence::Transcript','AutoLoader','CGI','CGI::Cookie','Carp','Digest::MD5','DynaLoader','Exporter','Fcntl','File::Path','GD','GFF','GFF::Filehandle','IO::Socket','IPC::Open2','Symbol','Text::Tabs','constant','overload','strict','vars']},'AcePerl-1.86.tar.gz' => {'author' => 'LDS','description' => 'Object-Oriented Access to ACEDB Databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10164,'pod' => 4491,'pod_errors' => 0,'total' => 14655,'with_comments' => 1178},'releases' => 15,'requires' => ['Digest-MD5-2.26.tar.gz'],'requires_module' => {'Digest::MD5' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 294461,'unpacked' => 1033175},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['$safe','5.004','Ace::Browser::LocalSiteDefs','Ace::Browser::SiteDefs','Ace::Graphics::Fk','Ace::Graphics::Glyph','Ace::Graphics::Glyph::segments','Ace::Graphics::GlyphFactory','Ace::Graphics::Track','Ace::Sequence::Feature','Ace::Sequence::Homol','Ace::Sequence::Transcript','AutoLoader','CGI','CGI::Cookie','Carp','Digest::MD5','DynaLoader','Exporter','Fcntl','File::Path','GD','GFF','IO::Socket','IPC::Open2','Symbol','Text::Tabs','constant','overload','strict','vars']},'Acme-Bleach-1.12.tar.gz' => {'author' => 'DCONWAY','description' => 'For I<really> clean programs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 156,'pod_errors' => 0,'total' => 238,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 4299,'unpacked' => 11479},'testers' => {'pass' => 8},'uses' => ['Data::Dumper']},'Acme-Brainfuck-1.0.0.tar.gz' => {'author' => 'JALDHAR','description' => 'Embed Brainfuck in your perl code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 164,'pod_errors' => 0,'total' => 270,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 6260,'unpacked' => 15337},'testers' => {'pass' => 2},'uses' => ['Filter::Simple','strict','warnings']},'Acme-Buckaroo-1.02.tar.gz' => {'author' => 'KEVINRICE','description' => 'Buckaroo Banzai Characters Infest Your Code!','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 419,'pod' => 65,'pod_errors' => 0,'total' => 484,'with_comments' => 69},'releases' => 2,'size' => {'packed' => 11159,'unpacked' => 36636},'testers' => {'pass' => 12},'uses' => ['5.006','Data::Dumper','Exporter','strict','warnings']},'Acme-Buffy-1.3.tar.gz' => {'author' => 'LBROCARD','description' => 'An encoding scheme for Buffy fans','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 47,'pod' => 42,'pod_errors' => 0,'total' => 89,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 2381,'unpacked' => 5170},'testers' => {'pass' => 16},'uses' => []},'Acme-Bushisms-0.02.tar.gz' => {'author' => 'ACCARDO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 35,'pod_errors' => 0,'total' => 80,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2301,'unpacked' => 4029},'testers' => {'pass' => 1},'uses' => ['LWP::Simple']},'Acme-Chef-0.05.tar.gz' => {'author' => 'SMUELLER','description' => 'An interpreter for the Chef programming language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1483,'pod' => 307,'pod_errors' => 0,'total' => 1790,'with_comments' => 31},'releases' => 1,'requires' => ['File-Temp-0.12.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Temp' => '0.12','Test::More' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 16067,'unpacked' => 67570},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Data::Dumper','strict','vars','warnings']},'Acme-Code-FreedomFighter-3.1416.tar.gz' => {'author' => 'GMCCAR','description' => 'Defends our right to code in any style waiting for the right moment to strike back at the evil oppressors.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 27,'pod_errors' => 0,'total' => 106,'with_comments' => 19},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2179,'unpacked' => 6824},'testers' => {'pass' => 5},'uses' => []},'Acme-Code-Police-2.1828.tar.gz' => {'author' => 'OVID','description' => 'Enforce rigorous coding standards','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 22,'pod' => 40,'pod_errors' => 0,'total' => 62,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2093,'unpacked' => 3338},'testers' => {'pass' => 5},'uses' => []},'Acme-Colour-0.20.tar.gz' => {'author' => 'LBROCARD','description' => 'additive and subtractive human-readable colours','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 184,'pod' => 81,'pod_errors' => 0,'total' => 265,'with_comments' => 8},'releases' => 5,'requires' => ['Graphics-ColorNames-0.32.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Graphics::ColorNames' => 0,'List::Util' => 0,'Test::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Graphics-ColorNames-0.32.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3883,'unpacked' => 13078},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['Graphics::ColorNames','List::Util','strict','vars']},'Acme-ComeFrom-0.06.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Parallel goto-in-reverse','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 134,'pod' => 85,'pod_errors' => 0,'total' => 219,'with_comments' => 4},'releases' => 5,'requires' => ['Filter-Simple-0.78.tar.gz','Hook-LexWrap-0.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Filter::Simple' => '0.70','Hook::LexWrap' => '0.20','Test::More' => '0.11'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Hook-LexWrap-0.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 5453,'unpacked' => 14991},'testers' => {'fail' => 2,'pass' => 6,'tests' => '10'},'uses' => ['Filter::Simple','Hook::LexWrap','strict','vars']},'Acme-Comment-1.02.tar.gz' => {'author' => 'KANE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 332,'pod' => 268,'pod_errors' => 0,'total' => 600,'with_comments' => 34},'releases' => 3,'requires' => ['Filter-Simple-0.78.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Filter::Simple' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 7110,'unpacked' => 24788},'testers' => {'pass' => 3},'uses' => ['Data::Dumper','Filter::Simple','strict','vars']},'Acme-CramCode-0.01.tar.gz' => {'author' => 'XERN','description' => 'Compress your code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 16,'pod' => 20,'pod_errors' => 0,'total' => 36,'with_comments' => 1},'releases' => 1,'requires' => ['Compress-Zlib-1.22.tar.gz'],'requires_module' => {'Compress::Zlib' => '1.19'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz'],'size' => {'packed' => 1364,'unpacked' => 1955},'testers' => {'pass' => 9},'uses' => ['Compress::Zlib']},'Acme-Currency-0.01.tar.gz' => {'author' => 'SMUELLER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 37,'pod' => 53,'pod_errors' => 0,'total' => 90,'with_comments' => 0},'releases' => 1,'requires' => ['Filter-Simple-0.78.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Filter::Simple' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 2020,'unpacked' => 3955},'testers' => {'pass' => 4},'uses' => ['5.006','Filter::Simple','strict','vars','warnings']},'Acme-Current-20030724.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 19,'pod' => 46,'pod_errors' => 0,'total' => 65,'with_comments' => 0},'releases' => 13,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'testers' => {'pass' => 1},'uses' => ['strict','vars']},'Acme-Dahut-0.42.tar.gz' => {'author' => 'RBERJON','description' => 'A module for the Higher Circles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 55,'pod_errors' => 0,'total' => 133,'with_comments' => 25},'releases' => 1,'size' => {'packed' => 2316,'unpacked' => 5615},'testers' => {'pass' => 7},'uses' => ['strict','vars']},'Acme-Damn-0.02.tar.gz' => {'author' => 'IBB','description' => '\'Unbless\' Perl objects.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 49,'pod' => 88,'pod_errors' => 0,'total' => 137,'with_comments' => 1},'releases' => 2,'requires' => ['Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Exception' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4960,'unpacked' => 13809},'testers' => {'pass' => 1},'uses' => ['5.000','DynaLoader','Exporter','strict','vars']},'Acme-Device-Plot-0.01.tar.gz' => {'author' => 'PETDANCE','description' => 'Factory object for creating plot devices for TV & movies','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 72,'pod_errors' => 0,'total' => 145,'with_comments' => 0},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Builder' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2025,'unpacked' => 3497},'testers' => {'pass' => 5},'uses' => ['strict']},'Acme-Don-t-1.01.tar.gz' => {'author' => 'DCONWAY','description' => 'The opposite of C<do>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 30,'pod' => 81,'pod_errors' => 0,'total' => 111,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2659,'unpacked' => 5585},'testers' => {'pass' => 2},'uses' => []},'Acme-Dot-1.0.tar.gz' => {'author' => 'SIMON','description' => 'Call methods with the dot operator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 40,'pod_errors' => 0,'total' => 93,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 2508,'unpacked' => 4268},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['5.006','strict','warnings']},'Acme-DoubleHelix-0.01.tar.gz' => {'author' => 'XERN','description' => 'Double-helix programming','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 67,'pod' => 38,'pod_errors' => 0,'total' => 105,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2175,'unpacked' => 4884},'testers' => {'pass' => 3},'uses' => []},'Acme-EyeDrops-1.40.tar.gz' => {'author' => 'ASAVIGE','description' => 'Visual Programming in Perl','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 777,'pod' => 2030,'pod_errors' => 0,'total' => 2807,'with_comments' => 53},'releases' => 35,'size' => {'packed' => 69816,'unpacked' => 504771},'testers' => {'pass' => 1},'uses' => ['5.005','Exporter','strict','vars']},'Acme-Fitness-0.02.tar.gz' => {'author' => 'LARSGT','description' => 'Perl extension for calculating fitness results','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 117,'pod' => 41,'pod_errors' => 0,'total' => 158,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 2763,'unpacked' => 4893},'testers' => {'pass' => 9},'uses' => ['Carp','Exporter','strict','vars']},'Acme-Floral-1.00.tar.gz' => {'author' => 'JJORE','description' => 'Produces fragrant perl','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 441,'pod' => 27,'pod_errors' => 0,'total' => 468,'with_comments' => 0},'releases' => 1,'requires' => ['B-Deobfuscate-0.10.tar.gz'],'requires_module' => {'B::Deobfuscate' => '0.06'},'requires_recursive' => ['B-Deobfuscate-0.10.tar.gz','B-Keywords-0.05.tar.gz','YAML-0.35.tar.gz'],'size' => {'packed' => 4991,'unpacked' => 10459},'testers' => {'pass' => 1},'uses' => ['B::Deobfuscate','O']},'Acme-Hello-0.02.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Print a greeting message','files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 56,'pod_errors' => 0,'total' => 216,'with_comments' => 27},'releases' => 2,'requires' => ['Module-Build-0.19.tar.gz'],'requires_module' => {'Module::Build' => '0.11'},'requires_recursive' => ['Module-Build-0.19.tar.gz'],'size' => {'packed' => 12845,'unpacked' => 43534},'testers' => {'pass' => 3},'uses' => ['Exporter','File::Basename','File::Spec','Locale::Maketext','Locale::Maketext::Lexicon','Module::Build','strict','vars']},'Acme-Holy-0.03.tar.gz' => {'author' => 'IBB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 83,'pod_errors' => 0,'total' => 146,'with_comments' => 1},'releases' => 3,'requires' => ['Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Exception' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4513,'unpacked' => 12236},'testers' => {'pass' => 1},'uses' => ['5.000','DynaLoader','Exporter','strict','vars']},'Acme-Incorporated-0.10.tar.gz' => {'author' => 'CHROMATIC','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 128,'pod' => 49,'pod_errors' => 0,'total' => 177,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 11106,'unpacked' => 28242},'testers' => {'pass' => 1},'uses' => ['File::Spec','IO::File','strict','vars']},'Acme-Inline-PERL-0.01.tar.gz' => {'author' => 'JMCNAMARA','description' => 'Bring the power of PERL programming to your Perl programs.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 107,'pod' => 62,'pod_errors' => 0,'total' => 169,'with_comments' => 11},'releases' => 1,'requires' => ['Inline-0.44.tar.gz','Inline-Files-0.62.tar.gz'],'requires_module' => {'Inline' => 0,'Inline::Files' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Inline-0.44.tar.gz','Inline-Files-0.62.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3029,'unpacked' => 7829},'testers' => {'pass' => 6},'uses' => ['Carp','Inline','strict']},'Acme-Intraweb-1.01.tar.gz' => {'author' => 'KANE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 30,'pod' => 39,'pod_errors' => 0,'total' => 69,'with_comments' => 0},'releases' => 2,'requires' => ['CPANPLUS-0.042.tar.gz'],'requires_module' => {'CPANPLUS' => '0.036'},'requires_recursive' => ['CPANPLUS-0.042.tar.gz'],'size' => {'packed' => 7571,'unpacked' => 21787},'testers' => {'pass' => 4},'uses' => ['CPANPLUS','File::Spec']},'Acme-Licence-1.0.tar.gz' => {'author' => 'DCANTRELL','description' => 'A module to easily apply a licence to your code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 482,'pod' => 25,'pod_errors' => 0,'total' => 507,'with_comments' => 0},'releases' => 1,'requires' => ['Getopt-Declare-1.09.tar.gz'],'requires_module' => {'Getopt::Declare' => '1.09'},'requires_recursive' => ['Getopt-Declare-1.09.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 10486,'unpacked' => 27352},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['strict']},'Acme-LifeUniverseEverything-0.02.tar.gz' => {'author' => 'ROSULEK','description' => 'Revises your code based on The Ultimate Answer, as computed by the organic computer matrix "Earth"','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 66,'pod' => 54,'pod_errors' => 0,'total' => 120,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 2535,'unpacked' => 5673},'testers' => {'pass' => 1},'uses' => ['overload','strict']},'Acme-Lingua-Strine-Perl-0.54.tar.gz' => {'author' => 'SIMONW','description' => 'make Perl more like Damian','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 56,'pod_errors' => 0,'total' => 101,'with_comments' => 2},'releases' => 4,'requires' => ['Filter-Simple-0.78.tar.gz'],'requires_module' => {'Filter::Simple' => 0},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3163,'unpacked' => 6137},'testers' => {'pass' => 9},'uses' => ['5.005_62','AutoLoader','Exporter','strict','warnings']},'Acme-Magpie-0.05.tar.gz' => {'author' => 'RCLAMP','description' => 'steals shiny things','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 82,'pod_errors' => 0,'total' => 151,'with_comments' => 0},'releases' => 5,'requires' => ['Devel-Symdump-2.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Devel::Symdump' => 0,'Test::More' => 0},'requires_recursive' => ['Devel-Symdump-2.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2597,'unpacked' => 6341},'testers' => {'pass' => 4},'uses' => ['Devel::Symdump','constant','strict','vars']},'Acme-Mandlebrot-0.02.tar.gz' => {'author' => 'GMCCAR','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 30,'pod_errors' => 0,'total' => 103,'with_comments' => 0},'releases' => 2,'requires' => ['Class-MethodMaker-1.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::MethodMaker' => 0,'Test::More' => 0},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2139,'unpacked' => 5004},'testers' => {'pass' => 6},'uses' => ['strict','warnings']},'Acme-ManekiNeko-0.01.tar.gz' => {'author' => 'GMCCAR','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 37,'pod' => 28,'pod_errors' => 1,'total' => 65,'with_comments' => 0},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1718,'unpacked' => 3451},'testers' => {'pass' => 4},'uses' => []},'Acme-Meta-0.01.tar.gz' => {'author' => 'NWCLARK','description' => 'Enhances the Meta package','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 27,'pod_errors' => 0,'total' => 47,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1737,'unpacked' => 2859},'testers' => {'pass' => 2},'uses' => ['5.004','Exporter','strict','vars']},'Acme-Method-CaseInsensitive-0.04.tar.gz' => {'author' => 'MALTEU','description' => 'Perl module for case insensitive method invocation','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 37,'pod_errors' => 0,'total' => 94,'with_comments' => 0},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Simple' => '0.45'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1874,'unpacked' => 3156},'testers' => {'pass' => 2},'uses' => ['Carp','strict','warnings']},'Acme-Metification-1.00.tar.gz' => {'author' => 'SMUELLER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 101,'pod' => 103,'pod_errors' => 0,'total' => 204,'with_comments' => 11},'releases' => 1,'requires' => ['Filter-Simple-0.78.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Filter::Simple' => '0.78','Test::More' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3134,'unpacked' => 6989},'testers' => {'pass' => 2},'uses' => ['5.006','Filter::Simple','strict','vars','warnings']},'Acme-Module-Authors-0.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Thank you CPAN authors','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 65,'pod' => 28,'pod_errors' => 0,'total' => 93,'with_comments' => 2},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1724,'unpacked' => 2659},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['5.006','CPAN','strict']},'Acme-Morse-Audible-1.10.tar.gz' => {'author' => 'ITRIVIZKI','description' => 'Audio(Morse) Programming with Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 55,'pod_errors' => 0,'total' => 114,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2847,'unpacked' => 7263},'testers' => {'pass' => 6},'uses' => ['5.006','strict','warnings']},'Acme-No-0.03.tar.gz' => {'author' => 'GEOFF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 88,'pod' => 85,'pod_errors' => 0,'total' => 173,'with_comments' => 10},'releases' => 3,'requires' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','IO-1.20.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'File::Spec' => '0.8','Filter::Util::Call' => '1.06','IO::File' => 0,'Test::More' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4208,'unpacked' => 15062},'testers' => {'pass' => 6},'uses' => ['5.00503','Carp','Filter::Util::Call','strict']},'Acme-Octarine-0.01.tar.gz' => {'author' => 'NWCLARK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 66,'pod' => 36,'pod_errors' => 0,'total' => 102,'with_comments' => 9},'releases' => 1,'requires' => ['Acme-Colour-0.20.tar.gz','CPANPLUS-0.042.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Acme::Colour' => 0,'CPANPLUS' => '0.042','Test::Simple' => 0},'requires_recursive' => ['Acme-Colour-0.20.tar.gz','CPANPLUS-0.042.tar.gz','File-Spec-0.82.tar.gz','Graphics-ColorNames-0.32.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2521,'unpacked' => 4723},'testers' => {'pass' => 1},'uses' => ['5.005','Acme::Colour','B::Deparse','CPANPLUS::Backend','strict','vars']},'Acme-Ook-0.10.tar.gz' => {'author' => 'JHI','description' => 'the Ook! programming language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 99,'pod_errors' => 0,'total' => 204,'with_comments' => 4},'releases' => 10,'size' => {'packed' => 8573,'unpacked' => 271992},'testers' => {'pass' => 2},'uses' => ['bytes','strict','vars']},'Acme-Opish-0.03.1.tar.gz' => {'author' => 'GENE','description' => 'Prefix the audible vowels of words','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 208,'pod' => 94,'pod_errors' => 0,'total' => 302,'with_comments' => 53},'releases' => 8,'size' => {'packed' => 3935,'unpacked' => 10627},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','File::Basename','strict','vars']},'Acme-Orange-0.02.tar.gz' => {'author' => 'NWCLARK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 35,'pod' => 41,'pod_errors' => 0,'total' => 76,'with_comments' => 2},'releases' => 2,'requires' => ['Acme-Colour-0.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Acme::Colour' => 0,'Test::Simple' => 0},'requires_recursive' => ['Acme-Colour-0.20.tar.gz','File-Spec-0.82.tar.gz','Graphics-ColorNames-0.32.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2288,'unpacked' => 4401},'testers' => {'pass' => 1},'uses' => ['5.004','Acme::Colour','Exporter','strict','vars']},'Acme-PGPSign-0.01.tar.gz' => {'author' => 'UNDERMINE','description' => 'Perl extension for signed scripts','files' => [],'lines' => {'nonpod' => 81,'pod' => 52,'pod_errors' => 0,'total' => 133,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2607,'unpacked' => 5332},'testers' => {},'uses' => ['Crypt::OpenPGP','Crypt::OpenPGP::Armour','Data::Dumper','strict','warnings']},'Acme-POE-Knee-1.10.zip' => {'author' => 'KANE','description' => 'Time sliced pony race using the POE kernel.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 122,'pod' => 117,'pod_errors' => 0,'total' => 239,'with_comments' => 4},'releases' => 4,'size' => {'packed' => 6625,'unpacked' => 11356},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['POE','strict','vars']},'Acme-Palindrome-0.1.tar.gz' => {'author' => 'CWEST','description' => 'Programs are the same backward and forward','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 24,'pod' => 49,'pod_errors' => 1,'total' => 73,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 1629,'unpacked' => 3034},'testers' => {'pass' => 1},'uses' => ['strict','vars']},'Acme-Playmate-0.03.tar.gz' => {'author' => 'ODEZWART','description' => 'A object-oriented interface to playboy.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 40,'pod_errors' => 0,'total' => 103,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 2583,'unpacked' => 5050},'testers' => {'pass' => 2},'uses' => ['5.008','LWP::UserAgent','strict','warnings']},'Acme-Playwright-0.02.tar.gz' => {'author' => 'SIFUKURT','description' => 'Simple text obfuscation in the form of a play.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 378,'pod' => 30,'pod_errors' => 0,'total' => 408,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 8643,'unpacked' => 29029},'testers' => {'pass' => 9},'uses' => ['5.006','strict','vars','warnings']},'Acme-Pony-1.1.2.tar.gz' => {'author' => 'DCANTRELL','description' => 'An encoding scheme for Silly People','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 151,'pod' => 38,'pod_errors' => 0,'total' => 189,'with_comments' => 11},'releases' => 2,'size' => {'packed' => 5844,'unpacked' => 13161},'testers' => {'tests' => '0','unknown' => 24},'uses' => []},'Acme-Pr0n-0.03.tar.gz' => {'author' => 'CHROMATIC','description' => 'expose the naughty bits of modules to the world','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 47,'pod_errors' => 0,'total' => 123,'with_comments' => 0},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.45'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3593,'unpacked' => 7017},'testers' => {'pass' => 6},'uses' => ['Carp','strict','vars']},'Acme-Pr0n-Automate-0.06.tar.gz' => {'author' => 'CLAESJAC','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 702,'pod' => 106,'pod_errors' => 0,'total' => 808,'with_comments' => 30},'releases' => 5,'requires' => ['DB_File-1.806.tar.gz','HTML-Parser-3.28.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'DB_File' => '1.73','HTML::Parser' => '3.25','LWP::UserAgent' => '1.77'},'requires_recursive' => ['DB_File-1.806.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8549,'unpacked' => 23164},'testers' => {'pass' => 2},'uses' => ['$path::Fetcher::$_','5.006','AutoLoader','DB_File','Data::Dumper','Exporter','HTML::Parser','HTTP::Request','HTTP::Response','IO::File','LWP::UserAgent','constant','fields','strict','warnings']},'Acme-RTB-0.01.tar.gz' => {'author' => 'ANARION','description' => 'Perl extension for building realtimebattle bots','files' => [],'lines' => {'nonpod' => 420,'pod' => 274,'pod_errors' => 0,'total' => 694,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 6638,'unpacked' => 19907},'testers' => {'pass' => 3},'uses' => ['5.008','IO::Handle','IO::Select','strict','warnings']},'Acme-RedShirt-0.1.tar.gz' => {'author' => 'TMURRAY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 41,'pod' => 64,'pod_errors' => 0,'total' => 105,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 9395,'unpacked' => 24093},'testers' => {'tests' => '0','unknown' => 6},'uses' => []},'Acme-Ref-0.03.tar.gz' => {'author' => 'RLZWART','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 26,'pod' => 31,'pod_errors' => 0,'total' => 57,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 7854,'unpacked' => 18966},'testers' => {'pass' => 1},'uses' => ['Exporter','XSLoader','strict','warnings']},'Acme-Signum-0.01.tar.gz' => {'author' => 'RLZWART','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 38,'pod_errors' => 0,'total' => 114,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2229,'unpacked' => 3946},'testers' => {'pass' => 2},'uses' => ['Config','Exporter','strict','vars','warnings']},'Acme-Smirch-0.91.tar.gz' => {'author' => 'JNAGRA','description' => 'For I<really> dirty programs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 84,'pod_errors' => 0,'total' => 115,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 3777,'unpacked' => 14452},'testers' => {'pass' => 1,'tests' => '0','unknown' => 18},'uses' => []},'Acme-Snark-0.03.tar.gz' => {'author' => 'AJGOUGH','description' => 'What I tell you three times is true','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 39,'pod_errors' => 0,'total' => 118,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 1966,'unpacked' => 4134},'testers' => {'pass' => 8},'uses' => ['strict','vars']},'Acme-SoftwareUpdate-0.33.tar.gz' => {'author' => 'FOX','description' => undef,'files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 1603,'pod' => 78,'pod_errors' => 0,'total' => 1681,'with_comments' => 120},'releases' => 2,'size' => {'packed' => 25575,'unpacked' => 73757},'testers' => {'pass' => 1},'uses' => ['$self->{path}::$self->{dispatch}','CPAN','CPANPLUS','CPANPLUS::Backend','Carp','Config','Cwd','ExtUtils::MM_Unix','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Basename','File::Find','File::Path','File::Spec','FileHandle','IO::Socket','LWP::Simple','Module::Install','Module::Install::Base','Net::FTP','Socket','YAML','inc::Module::Install','strict','vars']},'Acme-Spider-0.01.tar.gz' => {'author' => 'KASEI','description' => 'frighten some other modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 65,'pod' => 33,'pod_errors' => 0,'total' => 98,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 1779,'unpacked' => 3423},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Carp','strict','warnings']},'Acme-Spinner-0.02.tar.gz' => {'author' => 'CFEDDE','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 54,'pod_errors' => 0,'total' => 118,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2561,'unpacked' => 4583},'testers' => {'pass' => 2},'uses' => ['5.008','strict','warnings']},'Acme-Stegano-0.02.1.tar.gz' => {'author' => 'ANARION','description' => 'Put some text inside another','files' => [],'lines' => {'nonpod' => 61,'pod' => 34,'pod_errors' => 0,'total' => 95,'with_comments' => 3},'releases' => 3,'size' => {'packed' => 2408,'unpacked' => 4694},'testers' => {'pass' => 3},'uses' => ['Carp','Tie::File','strict','vars','warnings']},'Acme-Tango-0.04.tar.gz' => {'author' => 'SARGIE','description' => 'Turn colours orange','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 24,'pod' => 30,'pod_errors' => 0,'total' => 54,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 2092,'unpacked' => 3533},'testers' => {'pass' => 3},'uses' => ['Graphics::RGBManipulate','strict']},'Acme-Tao-0.02.tar.gz' => {'author' => 'JSMITH','description' => 'enforce proper respect for the Tao','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 61,'pod_errors' => 0,'total' => 155,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 3051,'unpacked' => 7698},'testers' => {'pass' => 6},'uses' => ['strict','vars']},'Acme-Test-Buffy-0.01.tar.gz' => {'author' => 'MARKF','description' => 'example Test::Builder testing module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 115,'pod' => 36,'pod_errors' => 0,'total' => 151,'with_comments' => 52},'releases' => 1,'requires' => ['Test-Builder-Tester-0.09.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Builder' => '0.12','Test::Builder::Tester' => '0.09'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3700,'unpacked' => 8250},'testers' => {'pass' => 3},'uses' => ['strict','warnings']},'Acme-Test-Pr0n-0.01.tar.gz' => {'author' => 'LLAP','description' => 'Perl extension for wasteing your time.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 46,'pod_errors' => 0,'total' => 110,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2500,'unpacked' => 5474},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','strict','vars','warnings']},'Acme-Test-Weather-0.2.tar.gz' => {'author' => 'ASCOPE','description' => 'Test weather conditions on install','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 382,'pod' => 142,'pod_errors' => 0,'total' => 524,'with_comments' => 19},'releases' => 2,'requires' => ['Geography-Countries-1.4.tar.gz','Test-Simple-0.47.tar.gz','Weather-Underground-2.10.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Geography::Countries' => '0','Socket' => '0','Sys::Hostname' => '0','Test::Builder' => '0','Test::More' => '0','Weather::Underground' => '0'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Geography-Countries-1.4.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','Weather-Underground-2.10.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4716,'unpacked' => 12119},'testers' => {'fail' => 7,'tests' => '2'},'uses' => ['CAIDA::NetGeoClient','Cwd','Data::Denter','Exporter','File::Spec','Geography::Countries','Socket','Sys::Hostname','Test::Builder','Weather::Underground','strict']},'Acme-Tie-Eleet-0.32.tar.gz' => {'author' => 'JQUELIN','description' => 'Perl extension to 5pE4k 1Ik3 4n 3l337!','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 393,'pod' => 100,'pod_errors' => 0,'total' => 493,'with_comments' => 73},'releases' => 6,'size' => {'packed' => 7998,'unpacked' => 33554},'testers' => {'pass' => 2},'uses' => ['Carp','IO::Handle','strict','warnings']},'Acme-Time-Asparagus-1.10.tar.gz' => {'author' => 'RBOW','description' => 'Time on the vegetable clock','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 179,'pod' => 132,'pod_errors' => 0,'total' => 311,'with_comments' => 19},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 12132,'unpacked' => 33088},'testers' => {'pass' => 9},'uses' => ['strict','vars']},'Acme-Time-Baby-2.103.tar.gz' => {'author' => 'ABIGAIL','description' => '- Tell time little children can understand','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 240,'pod' => 161,'pod_errors' => 0,'total' => 401,'with_comments' => 74},'releases' => 11,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'warnings' => ''},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 7536,'unpacked' => 38861},'testers' => {'pass' => 12},'uses' => ['strict','vars','warnings']},'Acme-Turing-0.01.tar.gz' => {'author' => 'GROMMEL','description' => 'Turing machine emulation','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 116,'pod_errors' => 0,'total' => 338,'with_comments' => 16},'releases' => 1,'size' => {'packed' => 5494,'unpacked' => 12352},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','strict','vars']},'Acme-USIG-1.02.tar.gz' => {'author' => 'RCLAMP','description' => 'express the true nature of strict','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14,'pod' => 45,'pod_errors' => 0,'total' => 59,'with_comments' => 0},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1834,'unpacked' => 3685},'testers' => {'pass' => 6},'uses' => ['vars']},'Acme-Voodoo-0.2.tar.gz' => {'author' => 'ESUMMERS','description' => 'Do bad stuff to your objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 156,'pod' => 66,'pod_errors' => 0,'total' => 222,'with_comments' => 18},'releases' => 2,'size' => {'packed' => 3905,'unpacked' => 7987},'testers' => {'pass' => 10},'uses' => ['Carp','strict','warnings']},'Acme-YBFOD-0.11.tar.gz' => {'author' => 'INGY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8,'pod' => 35,'pod_errors' => 0,'total' => 43,'with_comments' => 0},'releases' => 2,'requires' => ['Acme-Buffy-1.3.tar.gz'],'requires_module' => {'Acme::Buffy' => '1.2'},'requires_recursive' => ['Acme-Buffy-1.3.tar.gz'],'size' => {'packed' => 2669,'unpacked' => 9427},'testers' => {'pass' => 3},'uses' => ['Acme::Buffy']},'Acme-Yoda-0.02.tar.gz' => {'author' => 'GREP','description' => '','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 179,'pod' => 74,'pod_errors' => 0,'total' => 253,'with_comments' => 9},'releases' => 1,'requires' => ['Lingua-LinkParser1.08.tar.gz'],'requires_module' => {'Lingua::LinkParser' => 0},'requires_recursive' => ['Lingua-LinkParser1.08.tar.gz'],'size' => {'packed' => 10474,'unpacked' => 28235},'testers' => {},'uses' => ['Lingua::LinkParser','strict','vars']},'Acme-Your-0.01.tar.gz' => {'author' => 'RCLAMP','description' => 'not our variables, your variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 66,'pod_errors' => 0,'total' => 201,'with_comments' => 6},'releases' => 1,'requires' => ['Filter-Simple-0.78.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Filter::Simple' => '0.77','Parse::RecDescent' => '1.80','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3942,'unpacked' => 10188},'testers' => {'pass' => 6},'uses' => ['Filter::Simple','Parse::RecDescent','strict','v5.6','vars','warnings']},'Acme-emcA-0.03.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Acme::emcA','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 507,'pod' => 45,'pod_errors' => 0,'total' => 552,'with_comments' => 39},'releases' => 1,'size' => {'packed' => 6579,'unpacked' => 17534},'testers' => {'pass' => 2},'uses' => ['$self->{path}::$self->{dispatch}','ExtUtils::MM_Unix','File::Find','File::Path','Module::Install','Module::Install::Base','YAML','inc::Module::Install','strict','vars']},'Acme-landmine-0.01.tar.gz' => {'author' => 'DAVIDNICO','description' => 'variables that explode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 46,'pod' => 31,'pod_errors' => 0,'total' => 77,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1797,'unpacked' => 2863},'testers' => {'pass' => 4},'uses' => ['5.000','Carp','strict','vars']},'Acme-use-strict-with-pride-0.02.tar.gz' => {'author' => 'NWCLARK','description' => 'enforce bondage and discipline on very naughty modules.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 93,'pod' => 44,'pod_errors' => 0,'total' => 137,'with_comments' => 14},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.41'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3793,'unpacked' => 7527},'testers' => {'pass' => 4},'uses' => ['5.006','strict','warnings']},'ActionExporter-0.02.tar.gz' => {'author' => 'ADZZ','description' => 'Extends Exporter with the export_action() function, for use with the GCT::XSP::ActionTaglib module.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 67,'pod_errors' => 0,'total' => 112,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 2342,'unpacked' => 4839},'testers' => {'pass' => 3},'uses' => ['5.006','Exporter','strict','warnings']},'AddressBook-0.16.tar.gz' => {'author' => 'DLEIGH','description' => 'Abstract class for using AddressBooks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2322,'pod' => 1006,'pod_errors' => 0,'total' => 3328,'with_comments' => 163},'releases' => 3,'size' => {'packed' => 32634,'unpacked' => 124575},'testers' => {'fail' => 2,'tests' => '7'},'uses' => ['AddressBook','CGI','Carp','DBI','Date::Manip','File::Basename','IO::File','Net::LDAP','Net::LDAP::Entry','Net::LDAP::LDIF','Net::LDAP::Util','PDA::Pilot','XML::DOM','strict','vars']},'Affix-Infix2Postfix-0.03.tar.gz' => {'author' => 'ADDI','description' => 'Perl extension for converting from infix notation to postfix notation.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 190,'pod' => 37,'pod_errors' => 0,'total' => 227,'with_comments' => 48},'releases' => 1,'size' => {'packed' => 3827,'unpacked' => 8273},'testers' => {'pass' => 11},'uses' => ['AutoLoader','Data::Dumper','Exporter','strict','vars']},'Agent-3.20.tar.gz' => {'author' => 'SPURKIS','description' => 'the Transportable Agent Perl module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 675,'pod' => 340,'pod_errors' => 0,'total' => 1015,'with_comments' => 107},'releases' => 3,'size' => {'packed' => 20261,'unpacked' => 57706},'testers' => {'fail' => 2},'uses' => ['Class::Tom','Data::Dumper','IO::Socket','Thread','UNIVERSAL','strict','vars']},'AlarmCall-1.1.tar.gz' => {'author' => 'JACKS','description' => 'Timeout on any sub. Allows nested alarms','files' => [],'lines' => {'nonpod' => 153,'pod' => 149,'pod_errors' => 0,'total' => 302,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 3858,'unpacked' => 9430},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','Exporter']},'Algorithm-Bucketizer-0.10.tar.gz' => {'author' => 'MSCHILLI','description' => 'Distribute sized items to buckets with limited size','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 348,'pod' => 207,'pod_errors' => 0,'total' => 555,'with_comments' => 49},'releases' => 3,'size' => {'packed' => 7554,'unpacked' => 30367},'testers' => {'pass' => 3},'uses' => ['5.006','Algorithm::Permute','strict','warnings']},'Algorithm-ChooseSubsets-0.01.tar.gz' => {'author' => 'BDUGGAN','description' => 'OO interface to iterate through subsets of a list.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 91,'pod' => 73,'pod_errors' => 0,'total' => 164,'with_comments' => 28},'releases' => 1,'size' => {'packed' => 2785,'unpacked' => 5775},'testers' => {'pass' => 6},'uses' => ['Carp','strict','warnings']},'Algorithm-Cluster-1.22.tar.gz' => {'author' => 'MDEHOON','description' => 'Perl extension for the C clustering library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 564,'pod' => 39,'pod_errors' => 0,'total' => 603,'with_comments' => 140},'releases' => 7,'size' => {'packed' => 63214,'unpacked' => 293844},'testers' => {'pass' => 1},'uses' => ['DynaLoader','Exporter','strict','vars','warnings::register']},'Algorithm-Dependency-0.4.tar.gz' => {'author' => 'ADAMK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 626,'pod' => 393,'pod_errors' => 0,'total' => 1019,'with_comments' => 114},'releases' => 4,'requires' => ['File-Spec-0.82.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Spec' => '0.82','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 23656,'unpacked' => 85009},'testers' => {'pass' => 2},'uses' => ['UNIVERSAL','strict','vars']},'Algorithm-Diff-1.15.tar.gz' => {'author' => 'NEDKONZ','description' => 'Compute `intelligent\' differences between two files / lists','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 806,'pod' => 349,'pod_errors' => 0,'total' => 1155,'with_comments' => 138},'releases' => 10,'size' => {'packed' => 23234,'unpacked' => 81846},'testers' => {'pass' => 45},'uses' => ['integer','strict','vars']},'Algorithm-Diff-Apply-0.2.1.zip' => {'author' => 'ANDREWC','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 530,'pod' => 173,'pod_errors' => 0,'total' => 703,'with_comments' => 58},'releases' => 4,'requires' => ['Algorithm-Diff-1.15.tar.gz'],'requires_module' => {'Algorithm::Diff' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz'],'size' => {'packed' => 14039,'unpacked' => 27842},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','strict','vars']},'Algorithm-Evolutionary-0.53.tar.gz' => {'author' => 'JMERELO','description' => 'Perl extension for performing paradigm-free evolutionary algorithms.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3216,'pod' => 2061,'pod_errors' => 1,'total' => 5277,'with_comments' => 214},'releases' => 4,'requires' => ['Algorithm-Permute-0.06.tar.gz','Math-Random-0.67.tar.gz','Test-Simple-0.47.tar.gz','Tree-DAG_Node-1.04.tar.gz','XML-Parser-EasyTree-0.01.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Algorithm::Permute' => '0.01','B::Deparse' => '0.56','Math::Random' => '0.63','Test::Simple' => '0.44','Tree::DAG_Node' => '1.04','XML::Parser::EasyTree' => '0.01'},'requires_recursive' => ['Algorithm-Permute-0.06.tar.gz','File-Spec-0.82.tar.gz','Math-Random-0.67.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tree-DAG_Node-1.04.tar.gz','XML-Parser-EasyTree-0.01.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 46965,'unpacked' => 209188},'testers' => {'fail' => 11,'tests' => '102'},'uses' => ['Algorithm::Permute','B::Deparse','Carp','Exporter','Math::Random','Tree::DAG_Node','XML::Parser','XML::Parser::EasyTree','lib','strict','warnings']},'Algorithm-Evolve-0.03.tar.gz' => {'author' => 'ROSULEK','description' => 'An extensible and generic framework for executing evolutionary algorithms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 901,'pod' => 482,'pod_errors' => 0,'total' => 1383,'with_comments' => 41},'releases' => 3,'requires' => ['Scalar-List-Utils-1.11.tar.gz'],'requires_module' => {'List::Util' => '0.1'},'requires_recursive' => ['Scalar-List-Utils-1.11.tar.gz'],'size' => {'packed' => 15687,'unpacked' => 53655},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','List::Util','strict']},'Algorithm-FastPermute-0.05.tar.gz' => {'author' => 'ROBIN','description' => 'Rapid generation of permutations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 45,'pod_errors' => 0,'total' => 88,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 5384,'unpacked' => 11890},'testers' => {'fail' => 1,'pass' => 8},'uses' => ['DynaLoader','Exporter','strict','vars']},'Algorithm-Huffman-0.09.tar.gz' => {'author' => 'BIGJ','description' => 'Perl extension that implements the Huffman algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 297,'pod' => 211,'pod_errors' => 0,'total' => 508,'with_comments' => 0},'releases' => 9,'requires' => ['Data-Dumper-2.101.tar.gz','Heap-0.50.tar.gz','Scalar-List-Utils-1.11.tar.gz','String-Random-0.198.tar.gz','Test-Exception-0.15.tar.gz','Test-ManyParams-0.10.tar.gz','Test-Simple-0.47.tar.gz','Tree-DAG_Node-1.04.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => 0,'Heap' => 0,'Heap::Elem' => 0,'Heap::Fibonacci' => 0,'List::Util' => 0,'String::Random' => 0,'Test::Exception' => 0,'Test::ManyParams' => '0.04','Test::More' => 0,'Tree::DAG_Node' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Heap-0.50.tar.gz','Scalar-List-Utils-1.11.tar.gz','Set-CrossProduct-1.4.tar.gz','String-Random-0.198.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-ManyParams-0.10.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz','Tree-DAG_Node-1.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7963,'unpacked' => 24860},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','Heap::Elem','Heap::Fibonacci','List::Util','Tree::DAG_Node','strict','warnings']},'Algorithm-InversionList-0.03.tar.gz' => {'author' => 'TEODOR','description' => 'Perl extension for generating an inversion list from a bit sequence.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 38,'pod_errors' => 0,'total' => 133,'with_comments' => 10},'releases' => 3,'size' => {'packed' => 2939,'unpacked' => 5628},'testers' => {'pass' => 3},'uses' => ['5.006','Exporter','strict','warnings']},'Algorithm-LUHN-1.00.tar.gz' => {'author' => 'TAYERS','description' => 'Calculate mod 10 Double Add Double checksum','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 103,'pod' => 68,'pod_errors' => 0,'total' => 171,'with_comments' => 2},'releases' => 4,'requires' => ['Test-1.24.tar.gz'],'requires_module' => {'Test' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 3748,'unpacked' => 9267},'testers' => {'pass' => 14},'uses' => ['Exporter','strict','vars']},'Algorithm-MDiff-0.94.tar.gz' => {'author' => 'JETTERO','description' => 'Perl extension for m-differece detection.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 27,'pod_errors' => 0,'total' => 70,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 2959,'unpacked' => 5916},'testers' => {'pass' => 10},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Algorithm-MarkovChain-0.05.tar.gz' => {'author' => 'RCLAMP','description' => 'Object oriented Markov chain generator','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 242,'pod' => 103,'pod_errors' => 0,'total' => 345,'with_comments' => 8},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4487,'unpacked' => 11290},'testers' => {'pass' => 8},'uses' => ['Carp','fields','strict','v5.6','warnings']},'Algorithm-MarkovChain-GHash-0.01.tar.gz' => {'author' => 'RCLAMP','description' => 'Object oriented Markov chain generator, glib/C storage','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 31,'pod_errors' => 0,'total' => 63,'with_comments' => 1},'releases' => 1,'requires' => ['Algorithm-MarkovChain-0.05.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Algorithm::MarkovChain' => '0.05','Test::More' => 0},'requires_recursive' => ['Algorithm-MarkovChain-0.05.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3007,'unpacked' => 7305},'testers' => {'pass' => 4},'uses' => ['Algorithm::MarkovChain','Algorithm::MarkovChain::Base','DynaLoader','fields','strict','vars']},'Algorithm-Merge-0.03.tar.gz' => {'author' => 'JSMITH','description' => 'Implements 3-way merge and diff algorithms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 473,'pod' => 185,'pod_errors' => 1,'total' => 658,'with_comments' => 118},'releases' => 3,'requires' => ['Algorithm-Diff-1.15.tar.gz'],'requires_module' => {'Algorithm::Diff' => 1},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz'],'size' => {'packed' => 9345,'unpacked' => 38794},'testers' => {'pass' => 5},'uses' => ['Carp','Data::Dumper','constant','strict','vars']},'Algorithm-MinMax-0.01.tar.gz' => {'author' => 'DETZOLD','description' => 'Finding the minimum and maximum of an array with at most 3n/2 - 2 comparisons.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 88,'pod' => 28,'pod_errors' => 0,'total' => 116,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 2144,'unpacked' => 4075},'testers' => {'pass' => 2},'uses' => ['5.6.1','Exporter','strict','warnings']},'Algorithm-NaiveBayes-0.02.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Bayesian prediction of categories','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 208,'pod' => 121,'pod_errors' => 0,'total' => 329,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 6603,'unpacked' => 19404},'testers' => {'pass' => 3},'uses' => ['strict']},'Algorithm-PageRank-0.02.tar.gz' => {'author' => 'XERN','description' => 'Calculating PageRank','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 48,'pod_errors' => 0,'total' => 168,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 3837,'unpacked' => 9076},'testers' => {'fail' => 1,'pass' => 2,'tests' => '3'},'uses' => ['5.006','List::Util','XSLoader','strict']},'Algorithm-Permute-0.06.tar.gz' => {'author' => 'EDPRATOMO','description' => 'Handy and fast permutation with OO interface','files' => ['Makefile.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 122,'pod' => 122,'pod_errors' => 0,'total' => 244,'with_comments' => 15},'releases' => 6,'size' => {'packed' => 9976,'unpacked' => 25247},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Algorithm-Points-MinimumDistance-0.01.tar.gz' => {'author' => 'KAKE','description' => 'Works out the distance from each point to its nearest neighbour. Kinda.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 172,'pod' => 92,'pod_errors' => 0,'total' => 264,'with_comments' => 23},'releases' => 1,'size' => {'packed' => 4254,'unpacked' => 14158},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Algorithm-SISort-0.14.tar.gz' => {'author' => 'HRAFNKELL','description' => 'Select And Insert sorting algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 143,'pod' => 43,'pod_errors' => 0,'total' => 186,'with_comments' => 0},'releases' => 5,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.40'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3918,'unpacked' => 8880},'testers' => {'pass' => 6},'uses' => ['5.005_62','Exporter','Inline','strict','warnings']},'Algorithm-SVM-0.06.tar.gz' => {'author' => 'CSPENCER','description' => 'Perl bindings for the libsvm Support Vector Machine library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 327,'pod' => 183,'pod_errors' => 0,'total' => 510,'with_comments' => 14},'releases' => 5,'size' => {'packed' => 44703,'unpacked' => 138752},'testers' => {'pass' => 6},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Algorithm-SetCovering-0.03.tar.gz' => {'author' => 'MSCHILLI','description' => 'Algorithms to solve the "set covering problem"','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 259,'pod' => 120,'pod_errors' => 0,'total' => 379,'with_comments' => 44},'releases' => 2,'requires' => ['Log-Log4perl-0.35.tar.gz'],'requires_module' => {'Log::Log4perl' => '0.27'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Log-Log4perl-0.35.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5562,'unpacked' => 19170},'testers' => {'pass' => 2},'uses' => ['Log::Log4perl','strict','warnings']},'Algorithm-Tree-NCA-0.01.tar.gz' => {'author' => 'MATKIN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 354,'pod' => 210,'pod_errors' => 0,'total' => 564,'with_comments' => 50},'releases' => 1,'size' => {'packed' => 9881,'unpacked' => 35090},'testers' => {'pass' => 2},'uses' => ['5.006','Exporter','fields','strict','warnings']},'Alias-2.32.tar.gz' => {'author' => 'GSAR','description' => 'Convenient access to data/code via aliases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 240,'pod_errors' => 0,'total' => 370,'with_comments' => 10},'releases' => 8,'size' => {'packed' => 9659,'unpacked' => 24753},'testers' => {'pass' => 16},'uses' => ['5.004','Carp','DynaLoader','Exporter']},'AltaVista-PerlSDK-3.02.tar.gz' => {'author' => 'BWILLIAM','description' => 'Utilize the AltaVista Search Developer\'s Kit','files' => ['Makefile.PL'],'lines' => {'nonpod' => 189,'pod' => 189,'pod_errors' => 0,'total' => 378,'with_comments' => 25},'releases' => 1,'size' => {'packed' => 8246,'unpacked' => 37322},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'AltaVista-SDKLinguistics-3.02.tar.gz' => {'author' => 'BWILLIAM','description' => 'Perl extension for AltaVista SDK Linguistics functionality','files' => ['Makefile.PL'],'lines' => {'nonpod' => 75,'pod' => 34,'pod_errors' => 0,'total' => 109,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 4274,'unpacked' => 18345},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Alzabo-0.72.tar.gz' => {'author' => 'DROLSKY','description' => 'A data modelling tool and RDBMS-OO mapper','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 16584,'pod' => 6545,'pod_errors' => 0,'total' => 23129,'with_comments' => 336},'releases' => 38,'size' => {'packed' => 203294,'unpacked' => 868543},'testers' => {'fail' => 1,'pass' => 1,'tests' => '3643'},'uses' => ['','5.005','Alzabo::Config','Alzabo::Docs','Alzabo::DocumentationContainer','BerkeleyDB','Cache::Mmap','Carp','Class::Factory::Util','Cwd','DBD::Pg','DBD::mysql','DBI','DB_File','Data::Dumper','Fcntl','File::Basename','File::Copy','File::Path','File::Spec','HTML::Entities','IPC::Shareable','MIME::Base64','Module::Build','Params::Validate','SDBM_File','Storable','Tie::IxHash','Time::HiRes','strict','vars']},'Amethyst-1.00.tar.gz' => {'author' => 'SHEVEK','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4756,'pod' => 75,'pod_errors' => 0,'total' => 4831,'with_comments' => 245},'releases' => 1,'requires' => ['Math-BaseCalc-1.011.tar.gz','Net-DNS-0.38.tar.gz','POE-0.26.tar.gz','POE-Component-Client-DNS-0.95.tar.gz','POE-Component-Client-UserAgent-0.05.tar.gz','ParseLex-2.15.tar.gz','Text-Soundex-3.02.tar.gz','URI-1.24.tar.gz','WWW-Search-2.41.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'HTTP::Request' => '1.3','HTTP::Response' => '1.36','Math::BaseCalc' => '1.011','Math::Trig' => 1,'Net::DNS' => '0.31','POE' => '0.23','POE::Component::Client::DNS' => '0.94','POE::Component::Client::UserAgent' => '0.04','Parse::Lex' => '2.15','Text::Soundex' => 1,'URI' => '1.22','WWW::Search' => '2.36'},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','Math-BaseCalc-1.011.tar.gz','Net-DNS-0.38.tar.gz','POE-0.26.tar.gz','POE-Component-Client-DNS-0.95.tar.gz','POE-Component-Client-UserAgent-0.05.tar.gz','ParallelUserAgent-2.56.tar.gz','ParseLex-2.15.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Text-Soundex-3.02.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 1818167,'unpacked' => 5821937},'testers' => {'fail' => 1},'uses' => ['Acme::Time::Baby','Algorithm::MarkovChain','Carp','Chatbot::Eliza','Data::Dumper','Date::Format','Exporter','Fcntl','HTTP::Request::Common','HTTP::Response','LWP::UserAgent','MLDBM','Math::BaseCalc','Math::Trig','POE','POE::Component::Client::DNS','POE::Component::Client::UserAgent','POE::Component::IRC','Parse::Lex','Socket','Text::Soundex','URI','WWW::Search','WWW::SearchResult','strict','vars','warnings']},'Ananke-SqlLink-1.1.2.tgz' => {'author' => 'NATTIS','description' => 'Front-end module to MySQL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 112,'pod_errors' => 0,'total' => 250,'with_comments' => 24},'releases' => 4,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'DBD::mysql' => '2.1017','DBI' => '1.3'},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz'],'size' => {'packed' => 8743,'unpacked' => 24480},'testers' => {'pass' => 3},'uses' => ['DBI','strict','vars']},'Ananke-Template-1.4.tgz' => {'author' => 'NATTIS','description' => 'Front-end module to the Ananke::Template','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 427,'pod' => 137,'pod_errors' => 0,'total' => 564,'with_comments' => 78},'releases' => 5,'size' => {'packed' => 11115,'unpacked' => 32067},'testers' => {'pass' => 2},'uses' => ['strict']},'Ananke-Utils-1.0.2.tgz' => {'author' => 'NATTIS','description' => 'Utility functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 159,'pod' => 77,'pod_errors' => 0,'total' => 236,'with_comments' => 30},'releases' => 3,'size' => {'packed' => 9842,'unpacked' => 26180},'testers' => {'pass' => 3},'uses' => ['strict']},'Anarres-Mud-Driver-0.18.tar.gz' => {'author' => 'SHEVEK','description' => 'A game driver for LP Muds.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9603,'pod' => 46,'pod_errors' => 0,'total' => 9649,'with_comments' => 1123},'releases' => 4,'requires' => ['Parse-Yapp-1.05.tar.gz','Storable-2.07.tar.gz','String-Escape-2002.001.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Basename' => 0,'Parse::Yapp::Driver' => '1.05','Storable' => '1.014','String::Escape' => '2002.001','Time::HiRes' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Parse-Yapp-1.05.tar.gz','Storable-2.07.tar.gz','String-Escape-2002.001.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 149401,'unpacked' => 1014801},'testers' => {'pass' => 3},'uses' => ['Anarres::Mud::Driver','Anarres::Mud::Driver::Compiler','Anarres::Mud::Driver::Program','Anarres::Mud::Driver::Program::Efun','Anarres::Mud::Driver::Program::Method','Anarres::Mud::Driver::Program::Type','Anarres::Mud::Driver::Program::Variable','Carp','Data::Dumper','Exporter','Fcntl','File::Basename','IO::Handle','IPC::Open3','Parse::Yapp::Driver','Storable','String::Escape','Symbol','strict','vars','warnings']},'Anarres-Mud-Driver-0.23.tar.gz' => {'author' => 'SHEVEK','description' => 'A game driver for LP Muds.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3439,'pod' => 46,'pod_errors' => 0,'total' => 3485,'with_comments' => 360},'releases' => 4,'requires' => ['Parse-Yapp-1.05.tar.gz','Storable-2.07.tar.gz','String-Escape-2002.001.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Basename' => 0,'Parse::Yapp::Driver' => '1.05','Storable' => '1.014','String::Escape' => '2002.001','Time::HiRes' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Parse-Yapp-1.05.tar.gz','Storable-2.07.tar.gz','String-Escape-2002.001.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 66189,'unpacked' => 245971},'testers' => {'fail' => 1},'uses' => ['Anarres::Mud::Driver::Compiler::Dump','Anarres::Mud::Driver::Compiler::Method','Carp','Data::Dumper','DynaLoader','Exporter','Fcntl','File::Basename','String::Escape','strict','vars','warnings']},'AnyData-0.04.tar.gz' => {'author' => 'JZUCKER','description' => '- easy access to data in many formats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3627,'pod' => 1104,'pod_errors' => 1,'total' => 4731,'with_comments' => 601},'releases' => 2,'size' => {'packed' => 41627,'unpacked' => 159917},'testers' => {'fail' => 1},'uses' => ['AnyData','AnyData::Format::Base','AnyData::Format::CSV','AnyData::Storage::File','AnyData::Storage::FileSys','AnyData::Storage::TiedHash','CGI','Data::Dumper','Exporter','Fcntl','File::Basename','File::DosGlob','File::Find','HTML::TableExtract','IO::File','LWP::UserAgent','XML::Twig','strict','vars']},'AnyData-0.05.tar.gz' => {'author' => 'JZUCKER','description' => '- easy access to data in many formats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3558,'pod' => 1191,'pod_errors' => 1,'total' => 4749,'with_comments' => 543},'releases' => 2,'size' => {'packed' => 43411,'unpacked' => 162112},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['AnyData::Storage::RAM','CGI','Data::Dumper','Exporter','Fcntl','File::Basename','File::DosGlob','File::Find','HTML::TableExtract','IO::File','LWP::UserAgent','XML::Twig','strict','vars']},'AnyLoader-0.04.tar.gz' => {'author' => 'MSCHWERN','description' => 'Automagically loads modules for fully qualified functions','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 69,'pod_errors' => 0,'total' => 207,'with_comments' => 9},'releases' => 2,'requires' => ['Class-ISA-0.32.tar.gz'],'requires_module' => {'Class::ISA' => '0.31'},'requires_recursive' => ['Class-ISA-0.32.tar.gz'],'size' => {'packed' => 3990,'unpacked' => 11987},'testers' => {'pass' => 7},'uses' => ['Carp','Class::ISA','strict','vars']},'Apache-ACEProxy-0.04.tar.gz' => {'author' => 'MIYAGAWA','description' => 'IDN compatible ACE proxy server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 160,'pod_errors' => 0,'total' => 337,'with_comments' => 7},'releases' => 4,'requires' => ['Convert-RACE-0.07.tar.gz','URI-1.24.tar.gz','Unicode-String-2.07.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Convert::RACE' => '0.06','LWP::UserAgent' => '1.8','URI' => '1.15','Unicode::String' => '2.06','mod_perl' => '1.21'},'requires_recursive' => ['Convert-Base32-0.02.tar.gz','Convert-RACE-0.07.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','Unicode-String-2.07.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3867,'unpacked' => 11311},'testers' => {'pass' => 5},'uses' => ['Apache::Constants','Apache::Log','Convert::RACE','LWP::UserAgent','URI','Unicode::String','strict','vars']},'Apache-ASP-2.53.tar.gz' => {'author' => 'CHAMAS','description' => 'Active Server Pages for Apache with mod_perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8035,'pod' => 5299,'pod_errors' => 1,'total' => 13334,'with_comments' => 1029},'releases' => 42,'requires' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','MLDBM-2.01.tar.gz','MLDBM-Sync-0.30.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Class::Struct' => 0,'Data::Dumper' => 0,'Digest::MD5' => 0,'Fcntl' => 0,'File::Basename' => 0,'MLDBM' => 0,'MLDBM::Sync' => 0,'SDBM_File' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','MLDBM-2.01.tar.gz','MLDBM-Sync-0.30.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 509507,'unpacked' => 1583792},'testers' => {'pass' => 3},'uses' => ['5.002','Apache::ASP::Error','Apache::ASP::Share::CORE','Apache::ASP::StatINC','Apache::ASP::StateManager','CGI','Carp','Class::Struct','Cwd','Data::Dumper','Digest::MD5','Exporter','Fcntl','File::Basename','Image::Size','MLDBM','MLDBM::Sync','MLDBM::Sync::SDBM_File','SDBM_File','integer','lib','strict','vars']},'Apache-Access-Headers-0.01.tar.gz' => {'author' => 'JEFFO','description' => 'mod_perl HTTP header authorization module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 308,'pod' => 191,'pod_errors' => 1,'total' => 499,'with_comments' => 68},'releases' => 1,'requires' => ['Data-Dumper-2.101.tar.gz','XML-Simple-2.08.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '0.1','Data::Dumper' => '0.1','XML::Simple' => '0.1'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 7792,'unpacked' => 25038},'testers' => {'pass' => 2},'uses' => ['Apache','Apache::Constants','Apache::Log','Data::Dumper','XML::Simple','XML::XPath','strict']},'Apache-AddHostPath-0.02.tar.gz' => {'author' => 'RJENKS','description' => 'Prepends parts of hostname to URI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 99,'pod_errors' => 0,'total' => 189,'with_comments' => 21},'releases' => 1,'size' => {'packed' => 3641,'unpacked' => 11210},'testers' => {'fail' => 1,'pass' => 6},'uses' => ['Apache::Constants','vars']},'Apache-Admin-Config-0.91.tar.gz' => {'author' => 'RSOLIV','description' => 'A module to read/write Apache like configuration files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1295,'pod' => 567,'pod_errors' => 0,'total' => 1862,'with_comments' => 66},'releases' => 24,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'FileHandle' => 2},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 28168,'unpacked' => 89840},'testers' => {'pass' => 6},'uses' => ['5.005','Carp','Data::Dumper','FileHandle','strict']},'Apache-Album-0.95.tar.gz' => {'author' => 'WOODY','description' => 'Simple mod_perl Photo Album','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 934,'pod' => 195,'pod_errors' => 0,'total' => 1129,'with_comments' => 101},'releases' => 6,'requires' => ['PerlMagick-5.56.tar.gz','libapreq-1.2.tar.gz'],'requires_module' => {'Apache::Request' => '0.31','Image::Magick' => '1.45'},'requires_recursive' => ['PerlMagick-5.56.tar.gz','libapreq-1.2.tar.gz'],'size' => {'packed' => 13647,'unpacked' => 46249},'testers' => {},'uses' => ['Apache::Constants','Apache::Request','strict','vars']},'Apache-AntiSpam-0.05.tar.gz' => {'author' => 'MIYAGAWA','description' => 'AntiSpam filter for web pages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 207,'pod' => 205,'pod_errors' => 0,'total' => 412,'with_comments' => 8},'releases' => 5,'requires' => ['Email-Find-0.09.tar.gz','HTML-Parser-3.28.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Email::Find' => '0.04','HTML::Entities' => 0,'mod_perl' => '1.21'},'requires_recursive' => ['Email-Find-0.09.tar.gz','Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 4469,'unpacked' => 13878},'testers' => {'pass' => 6},'uses' => ['Apache::Constants','Apache::File','Email::Find','HTML::Entities','strict','vars']},'Apache-AntiSpam-SpamTrap-0.01.tar.gz' => {'author' => 'APLEINER','description' => 'Add SpamTrap suffix to local-part in Email','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 66,'pod_errors' => 0,'total' => 125,'with_comments' => 2},'releases' => 1,'requires' => ['Apache-AntiSpam-0.05.tar.gz','Crypt-Blowfish-2.09.tar.gz'],'requires_module' => {'Apache::AntiSpam' => '0.05','Crypt::Blowfish' => 2},'requires_recursive' => ['Apache-AntiSpam-0.05.tar.gz','Crypt-Blowfish-2.09.tar.gz','Email-Find-0.09.tar.gz','Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 2926,'unpacked' => 6784},'testers' => {},'uses' => ['Apache::AntiSpam','Apache::Constants','Crypt::Blowfish','strict','vars']},'Apache-App-Mercury-0.80.tar.gz' => {'author' => 'ADIRAJ','description' => 'Internal web messaging for Apache mod_perl (1.x)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2985,'pod' => 349,'pod_errors' => 0,'total' => 3334,'with_comments' => 163},'releases' => 1,'size' => {'packed' => 38372,'unpacked' => 135091},'testers' => {'tests' => '0','unknown' => 1},'uses' => ['','5.004','Apache','Apache::Constants','CGI','DBI','MIME::Lite','POSIX','Storable','Text::Wrap','URI::Escape','constant','strict','vars']},'Apache-AppCluster-0.02.tar.gz' => {'author' => 'MAUNDER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1913,'pod' => 562,'pod_errors' => 0,'total' => 2475,'with_comments' => 69},'releases' => 1,'requires' => ['Digest-MD5-2.26.tar.gz','Storable-2.07.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Digest::MD5' => 0,'Storable' => 0,'Time::HiRes' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 23995,'unpacked' => 74471},'testers' => {},'uses' => ['Apache','Apache::Constants','Carp','Digest::MD5','IO::Socket','POSIX','Storable','Time::HiRes','constant','lib','strict','vars']},'Apache-Archive-0.1.tar.gz' => {'author' => 'JPETERSON','description' => 'Make linked contents pages of .tar(.gz)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 360,'pod' => 168,'pod_errors' => 1,'total' => 528,'with_comments' => 78},'releases' => 1,'requires' => ['Archive-Tar-1.03.tar.gz','Compress-Zlib-1.22.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '1.2','Archive::Tar' => '0.2','Compress::Zlib' => 0},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','Compress-Zlib-1.22.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 6559,'unpacked' => 16011},'testers' => {'pass' => 5},'uses' => ['Apache::Constants','Apache::Log','Apache::Status','Apache::Util','Archive::Tar','Exporter','strict','vars']},'Apache-AuthChecker-0.20.tar.gz' => {'author' => 'SWAMPFOX','description' => 'Apache module to prevent password attacks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 277,'pod' => 84,'pod_errors' => 0,'total' => 361,'with_comments' => 13},'releases' => 2,'requires' => ['IPC-Shareable-0.60.tar.gz'],'requires_module' => {'IPC::Shareable' => '0.6'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IPC-Shareable-0.60.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 11623,'unpacked' => 33372},'testers' => {},'uses' => ['Apache::Access','Apache::CmdParms','Apache::Connection','Apache::Const','Apache::Constants','Apache::Log','Apache::Module','Apache::ModuleConfig','Apache::RequestRec','Apache::RequestUtil','Apache::SubRequest','IPC::Shareable','IPC::SysV','Symbol','mod','vars']},'Apache-AuthCookie-1.4.tar.gz' => {'author' => 'BARTLEY','description' => 'Perl Authentication and Authorization via cookies','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 418,'pod' => 173,'pod_errors' => 0,'total' => 591,'with_comments' => 72},'releases' => 18,'size' => {'packed' => 9987,'unpacked' => 34800},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Apache','Apache::AuthCookie','Apache::Constants','strict','vars']},'Apache-AuthCookie-3.04.tar.gz' => {'author' => 'MSCHOUT','description' => 'Authen + Authz via cookies','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1326,'pod' => 481,'pod_errors' => 0,'total' => 1807,'with_comments' => 132},'releases' => 18,'size' => {'packed' => 29851,'unpacked' => 102774},'testers' => {'fail' => 3},'uses' => ['Apache::Constants','Apache::Util','Carp','strict','vars']},'Apache-AuthCookieDBI-1.19.tar.gz' => {'author' => 'CROMIS','description' => 'An AuthCookie module backed by a DBI database.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 604,'pod' => 188,'pod_errors' => 0,'total' => 792,'with_comments' => 116},'releases' => 2,'size' => {'packed' => 20699,'unpacked' => 64106},'testers' => {'fail' => 5},'uses' => ['5.004','Apache','Apache::AuthCookie','Apache::Constants','Apache::DBI','Apache::File','Date::Calc','Digest::MD5','strict','vars']},'Apache-AuthCookieDBIRadius-1.19.tar.gz' => {'author' => 'BARRACODE','description' => 'Perl Authentication and Authorization via cookies','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1337,'pod' => 512,'pod_errors' => 0,'total' => 1849,'with_comments' => 290},'releases' => 2,'size' => {'packed' => 34717,'unpacked' => 109998},'testers' => {'fail' => 3},'uses' => ['5.004','Apache','Apache::AuthCookie','Apache::Constants','Apache::DBI','Apache::File','Authen::Radius','Carp','Date::Calc','Digest::MD5','Tie::IxHash','strict','vars']},'Apache-AuthCookieLDAP-0.03.tar.gz' => {'author' => 'BJORNARDO','description' => 'An AuthCookie module backed by LDAP database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 640,'pod' => 158,'pod_errors' => 0,'total' => 798,'with_comments' => 121},'releases' => 3,'requires' => ['Apache-AuthCookie-3.04.tar.gz'],'requires_module' => {'Apache::AuthCookie' => '0'},'requires_recursive' => ['Apache-AuthCookie-3.04.tar.gz'],'size' => {'packed' => 17660,'unpacked' => 54751},'testers' => {},'uses' => ['5.004','Apache','Apache::AuthCookie','Apache::Constants','Apache::File','Date::Calc','Digest::MD5','strict','vars']},'Apache-AuthCookieURL-1.003.tar.gz' => {'author' => 'HANK','description' => 'Perl Authentication and Authorization or session management via cookies or URL munging','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 731,'pod' => 261,'pod_errors' => 0,'total' => 992,'with_comments' => 116},'releases' => 1,'requires' => ['libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Cookie' => 0,'Apache::URI' => 0},'requires_recursive' => ['libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 10441,'unpacked' => 31829},'testers' => {'pass' => 1},'uses' => ['Apache::Constants','Apache::Cookie','constant','strict','vars']},'Apache-AuthDigest-0.022.tar.gz' => {'author' => 'GEOFF','description' => 'reimplementation of mod_digest.c in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1580,'pod' => 527,'pod_errors' => 1,'total' => 2107,'with_comments' => 204},'releases' => 4,'requires' => ['Digest-MD5-2.26.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Digest::MD5' => '2.13','HTTP::Headers::Util' => '1.09','mod_perl' => '1.26'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 20112,'unpacked' => 80270},'testers' => {},'uses' => ['5.006','Apache','Apache::Constants','Apache::File','Apache::Log','Apache::ModuleConfig','Carp','Digest::MD5','DynaLoader','HTTP::Headers::Util','IPC::SysV','strict']},'Apache-AuthExpire-0.36.tar.gz' => {'author' => 'JJHORNER','description' => 'PerlAuthenHandler to implement time limits','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 100,'pod' => 56,'pod_errors' => 0,'total' => 156,'with_comments' => 24},'releases' => 6,'size' => {'packed' => 4651,'unpacked' => 10324},'testers' => {'pass' => 5},'uses' => ['Apache::Constants','Apache::Log','Carp','strict']},'Apache-AuthLDAP-0.21.tar.gz' => {'author' => 'CDONLEY','description' => 'LDAP authentication module','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 49,'pod_errors' => 0,'total' => 187,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2400,'unpacked' => 5697},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Apache::Constants','Net::LDAPapi','strict']},'Apache-AuthNetLDAP-0.25.tar.gz' => {'author' => 'SPEEVES','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 125,'pod_errors' => 0,'total' => 272,'with_comments' => 16},'releases' => 7,'size' => {'packed' => 5276,'unpacked' => 13274},'testers' => {'pass' => 1},'uses' => ['Apache::Access','Apache::Connection','Apache::Constants','Apache::Log','Apache::RequestRec','Apache::RequestUtil','Exporter','Net::LDAP','mod','strict','vars']},'Apache-AuthPAM-0.01.tar.gz' => {'author' => 'HDANIEL','description' => 'Authenticate apache request using PAM services','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 145,'pod' => 59,'pod_errors' => 0,'total' => 204,'with_comments' => 29},'releases' => 1,'requires' => ['Authen-PAM-0.14.tar.gz'],'requires_module' => {'Authen::PAM' => '0.13'},'requires_recursive' => ['Authen-PAM-0.14.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3599,'unpacked' => 8045},'testers' => {'pass' => 1},'uses' => ['5.006','Apache::Constants','Apache::Log','Authen::PAM','Exporter','strict','warnings']},'Apache-AuthPerLDAP-0.5.tar.gz' => {'author' => 'HENRIK','description' => 'LDAP authentication module (PerLDAP)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 76,'pod_errors' => 0,'total' => 170,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 2800,'unpacked' => 6845},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Apache::Constants','Mozilla::LDAP::Conn','mod','strict']},'Apache-AuthTicket-0.31.tar.gz' => {'author' => 'MSCHOUT','description' => 'Cookie based access module.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 845,'pod' => 325,'pod_errors' => 0,'total' => 1170,'with_comments' => 83},'releases' => 3,'size' => {'packed' => 11958,'unpacked' => 39626},'testers' => {'pass' => 1},'uses' => ['Apache::Constants','Data::Dumper','Digest::MD5','constant','strict','vars']},'Apache-Authen-Program-0.92.tar.gz' => {'author' => 'MLFISHER','description' => 'mod_perl external program authentication module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 165,'pod' => 60,'pod_errors' => 0,'total' => 225,'with_comments' => 34},'releases' => 2,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => 0},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 5219,'unpacked' => 13612},'testers' => {'pass' => 2},'uses' => ['Apache::Constants','File::Temp','strict']},'Apache-AuthenCache-0.05.tar.gz' => {'author' => 'JBODNAR','description' => 'Cache authentication credentials','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 255,'pod' => 81,'pod_errors' => 0,'total' => 336,'with_comments' => 103},'releases' => 7,'requires' => ['IPC-Cache-0.02.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '1.11','IPC::Cache' => '0.02'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IPC-Cache-0.02.tar.gz','IPC-ShareLite-0.09.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 4686,'unpacked' => 12727},'testers' => {'pass' => 3},'uses' => ['Apache::Constants','IPC::Cache','strict']},'Apache-AuthenLDAP-1.00.tar.gz' => {'author' => 'CGILMORE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 494,'pod' => 103,'pod_errors' => 0,'total' => 597,'with_comments' => 324},'releases' => 6,'requires' => ['Data-Dumper-2.101.tar.gz','mod_perl-1.28.tar.gz','perl-ldap-0.29.tar.gz'],'requires_module' => {'Apache' => '1.24','Data::Dumper' => '2.101','Net::LDAP' => '0.19'},'requires_recursive' => ['Convert-ASN1-0.17.tar.gz','Data-Dumper-2.101.tar.gz','mod_perl-1.28.tar.gz','perl-ldap-0.29.tar.gz'],'size' => {'packed' => 8782,'unpacked' => 24706},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','Apache::Log','Date::Calc','Net::LDAP','strict']},'Apache-AuthenN2-0.05.tar.gz' => {'author' => 'VALERIE','description' => 'Authenticate into the NT and NIS+ domains','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 219,'pod' => 68,'pod_errors' => 0,'total' => 287,'with_comments' => 25},'releases' => 5,'size' => {'packed' => 5035,'unpacked' => 15845},'testers' => {},'uses' => ['Apache::Constants','Authen::Smb','Net::NISPlus::Table','strict','vars']},'Apache-AuthenNIS-0.10.tar.gz' => {'author' => 'DEP','description' => 'NIS authentication','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 51,'pod_errors' => 0,'total' => 120,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2550,'unpacked' => 6591},'testers' => {},'uses' => ['Apache::Constants','Net::NIS','strict']},'Apache-AuthenNISPlus-0.06.tar.gz' => {'author' => 'VALERIE','description' => 'Authenticate into a NIS+ domain','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 136,'pod' => 36,'pod_errors' => 0,'total' => 172,'with_comments' => 17},'releases' => 4,'size' => {'packed' => 2594,'unpacked' => 6153},'testers' => {},'uses' => ['Apache::Constants','Net::NISPlus::Table','strict','vars']},'Apache-AuthenNTLM-0.23.tar.gz' => {'author' => 'GRICHTER','description' => 'Perform Microsoft NTLM and Basic User Authentication','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 813,'pod' => 211,'pod_errors' => 0,'total' => 1024,'with_comments' => 54},'releases' => 9,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::Base64' => 0},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 49682,'unpacked' => 191282},'testers' => {'pass' => 2},'uses' => ['Apache::Constants','Authen::Smb','AutoLoader','Carp','DynaLoader','Exporter','IPC::Semaphore','IPC::SysV','Socket','strict','vars']},'Apache-AuthenPasswd-0.12.tar.gz' => {'author' => 'SPEEVES','description' => 'Authenticate against /etc/passwd','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 72,'pod_errors' => 0,'total' => 151,'with_comments' => 4},'releases' => 3,'size' => {'packed' => 4511,'unpacked' => 13383},'testers' => {'pass' => 1},'uses' => ['Apache::Access','Apache::Connection','Apache::Constants','Apache::Log','Apache::RequestRec','Apache::RequestUtil','mod','strict']},'Apache-AuthenPasswdSrv-0.01.tar.gz' => {'author' => 'JEFFH','description' => 'External authentication server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 96,'pod' => 49,'pod_errors' => 0,'total' => 145,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 4584,'unpacked' => 10515},'testers' => {'fail' => 5},'uses' => ['Apache::Constants','Socket','strict']},'Apache-AuthenProgram-0.90.tar.gz' => {'author' => 'MLFISHER','description' => 'mod_perl external program authentication module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 159,'pod' => 56,'pod_errors' => 0,'total' => 215,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 4695,'unpacked' => 12667},'testers' => {},'uses' => ['Apache::Constants','File::Temp','strict']},'Apache-AuthenRadius-0.3.tar.gz' => {'author' => 'DANIEL','description' => 'Authentication via a Radius server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 84,'pod' => 87,'pod_errors' => 1,'total' => 171,'with_comments' => 11},'releases' => 2,'requires' => ['RadiusPerl-0.09.tar.gz'],'requires_module' => {'Authen::Radius' => '0.05'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Data-HexDump-0.02.tar.gz','Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz','RadiusPerl-0.09.tar.gz'],'size' => {'packed' => 2774,'unpacked' => 5726},'testers' => {'fail' => 1},'uses' => ['Apache::Constants','Authen::Radius','strict','vars']},'Apache-AuthenSecurID-0.4.tar.gz' => {'author' => 'FLIPKIN','description' => 'Authentication via a SecurID server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 673,'pod' => 195,'pod_errors' => 2,'total' => 868,'with_comments' => 17},'releases' => 4,'requires' => ['Authen-ACE-0.90.tar.gz','Config-General-2.21.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz'],'requires_module' => {'Authen::ACE' => '0.9','Config::General' => '1.2','Crypt::Blowfish' => '2.06','Crypt::CBC' => '1.25'},'requires_recursive' => ['Authen-ACE-0.90.tar.gz','Config-General-2.21.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 26715,'unpacked' => 130090},'testers' => {},'uses' => ['Apache','Apache::Constants','Apache::Cookie','Apache::Log','Apache::Registry','CGI::Carp','Crypt::CBC','IO::Socket::INET','strict','vars']},'Apache-AuthenSmb-0.60.tar.gz' => {'author' => 'PARKER','description' => 'Authenticate against NT server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 88,'pod' => 46,'pod_errors' => 0,'total' => 134,'with_comments' => 3},'releases' => 4,'size' => {'packed' => 2753,'unpacked' => 6412},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','Authen::Smb','strict']},'Apache-AuthenURL-0.8.tar.gz' => {'author' => 'JGROENVEL','description' => 'Authenticate via another URL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 40,'pod_errors' => 0,'total' => 119,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 2516,'unpacked' => 5072},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Apache::Constants','LWP::UserAgent','strict','vars']},'Apache-AuthzCache-1.01.tar.gz' => {'author' => 'CGILMORE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 658,'pod' => 75,'pod_errors' => 0,'total' => 733,'with_comments' => 401},'releases' => 7,'requires' => ['Cache-Cache-1.02.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache' => '1.24','Apache::Log' => '1.01','Cache::Cache' => '1.01','Text::ParseWords' => '3.2'},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10208,'unpacked' => 32686},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','Apache::Log','Cache::FileCache','Text::ParseWords','Time::Object','strict']},'Apache-AuthzLDAP-1.00.tar.gz' => {'author' => 'CGILMORE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 669,'pod' => 130,'pod_errors' => 0,'total' => 799,'with_comments' => 377},'releases' => 5,'requires' => ['mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz','perl-ldap-0.29.tar.gz'],'requires_module' => {'Apache' => '1.26','Apache::Log' => '1.01','Net::LDAP' => '0.25','Text::ParseWords' => '3.2'},'requires_recursive' => ['Convert-ASN1-0.17.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz','perl-ldap-0.29.tar.gz'],'size' => {'packed' => 10907,'unpacked' => 33306},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','Net::LDAP','strict']},'Apache-AuthzNIS-0.10.tar.gz' => {'author' => 'DEP','description' => 'NIS authorization','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 54,'pod_errors' => 0,'total' => 131,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2887,'unpacked' => 7675},'testers' => {},'uses' => ['Apache::Constants','Net::NIS','strict']},'Apache-AuthzNetLDAP-0.07.tar.gz' => {'author' => 'SPEEVES','description' => 'Apache-Perl module that enables you to authorize a user for Website based on LDAP attributes.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 344,'pod' => 89,'pod_errors' => 0,'total' => 433,'with_comments' => 46},'releases' => 4,'size' => {'packed' => 6107,'unpacked' => 18579},'testers' => {'pass' => 1},'uses' => ['Apache::Access','Apache::Connection','Apache::Constants','Apache::Log','Apache::RequestRec','Apache::RequestUtil','AutoLoader','Carp','DynaLoader','Exporter','Net::LDAP','URI','URI::ldap','mod','strict','vars']},'Apache-AuthzPasswd-0.11.tar.gz' => {'author' => 'SPEEVES','description' => 'Authorize against /etc/passwd','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 62,'pod_errors' => 0,'total' => 157,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 4508,'unpacked' => 12237},'testers' => {'pass' => 1},'uses' => ['Apache::Access','Apache::Connection','Apache::Constants','Apache::Log','Apache::RequestRec','Apache::RequestUtil','mod','strict']},'Apache-AuthzUserDir-0.92.tar.gz' => {'author' => 'NINJAZ','description' => 'mod_perl UserDir authorization module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 67,'pod' => 32,'pod_errors' => 0,'total' => 99,'with_comments' => 6},'releases' => 3,'size' => {'packed' => 2202,'unpacked' => 4748},'testers' => {'pass' => 2},'uses' => ['Apache::Constants','strict']},'Apache-AutoIndex-0.08.tar.gz' => {'author' => 'GOZER','description' => 'Lists directory content','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 864,'pod' => 218,'pod_errors' => 0,'total' => 1082,'with_comments' => 46},'releases' => 6,'requires' => ['Apache-Icon-0.02.tar.gz','Apache-Language-0.14.tar.gz','HTML-Parser-3.28.tar.gz','Storable-2.07.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 0,'Apache::Icon' => '0.02','Apache::Language' => 0,'Apache::Status' => 0,'HTML::HeadParser' => 0,'Storable' => 0},'requires_recursive' => ['Apache-Icon-0.02.tar.gz','Apache-Language-0.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','I18N-LangTags-0.28.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 12110,'unpacked' => 38619},'testers' => {'pass' => 5},'uses' => ['Apache::Constants','Apache::Icon','Apache::Language','Apache::ModuleConfig','Apache::Util','Data::Dumper','HTML::HeadParser','Storable','constant','strict','vars']},'Apache-AxKit-Language-Svg2AnyFormat-0.02.tar.gz' => {'author' => 'TOMSON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 339,'pod' => 210,'pod_errors' => 0,'total' => 549,'with_comments' => 6},'releases' => 2,'requires' => ['AxKit-1.6.1.tar.gz','PerlMagick-5.56.tar.gz'],'requires_module' => {'AxKit' => '1.6.1','Image::Magick' => '5.55'},'requires_recursive' => ['AxKit-1.6.1.tar.gz','PerlMagick-5.56.tar.gz'],'size' => {'packed' => 53832,'unpacked' => 179558},'testers' => {},'uses' => ['Apache','Apache::Constants','Apache::Request','Cwd','Image::Magick','strict']},'Apache-AxKit-Language-XSP-ObjectTaglib-0.01.tar.gz' => {'author' => 'SIMON','description' => 'Helper for OO Taglibs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 157,'pod' => 135,'pod_errors' => 0,'total' => 292,'with_comments' => 0},'releases' => 1,'requires' => ['AxKit-1.6.1.tar.gz'],'requires_module' => {'Apache::AxKit::Language::XSP' => 0},'requires_recursive' => ['AxKit-1.6.1.tar.gz'],'size' => {'packed' => 4421,'unpacked' => 11907},'testers' => {'pass' => 1},'uses' => ['Apache::AxKit::Language::XSP','Exporter','strict','vars']},'Apache-AxKit-Plugin-AddXSLParams-Request-1.01.tar.gz' => {'author' => 'KHAMPTON','description' => 'Provides a way to pass info from the Apache::Request to XSLT params','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 183,'pod_errors' => 0,'total' => 273,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 4754,'unpacked' => 17512},'testers' => {'fail' => 5,'tests' => '1'},'uses' => ['Apache::Constants','Apache::Cookie','Apache::Request','Apache::URI','strict','vars']},'Apache-AxKit-Plugin-Session-0.93.tar.gz' => {'author' => 'JWALT','description' => 'flexible session management for AxKit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1947,'pod' => 594,'pod_errors' => 0,'total' => 2541,'with_comments' => 217},'releases' => 4,'requires' => ['Apache-RequestNotes-0.06.tar.gz','Apache-Session-1.54.tar.gz','AxKit-1.6.1.tar.gz'],'requires_module' => {'Apache::RequestNotes' => 0,'Apache::Session' => 0,'AxKit' => '1.6'},'requires_recursive' => ['Apache-RequestNotes-0.06.tar.gz','Apache-Session-1.54.tar.gz','AxKit-1.6.1.tar.gz','libapreq-1.2.tar.gz'],'size' => {'packed' => 24731,'unpacked' => 90359},'testers' => {'pass' => 1},'uses' => ['Apache::AxKit::Language::XSP::SimpleTaglib','Apache::Constants','Apache::Cookie','Apache::RequestNotes','Apache::Session::File','Apache::Table','Crypt::GeneratePassword','Time::Piece','URI','URI::Escape','strict','vars']},'Apache-AxKit-Provider-DOM-0.01.tar.gz' => {'author' => 'PHISH','description' => 'Base Class For Parsed XML Providers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 70,'pod' => 44,'pod_errors' => 0,'total' => 114,'with_comments' => 14},'releases' => 1,'requires' => ['AxKit-1.6.1.tar.gz'],'requires_module' => {'AxKit' => '1.6'},'requires_recursive' => ['AxKit-1.6.1.tar.gz'],'size' => {'packed' => 2323,'unpacked' => 5229},'testers' => {},'uses' => ['Apache::AxKit::Exception','Apache::AxKit::Provider','strict','vars']},'Apache-AxKit-Provider-OpenOffice-1.02.tar.gz' => {'author' => 'MSERGEANT','description' => 'OpenOffice package file provider','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 154,'pod' => 45,'pod_errors' => 0,'total' => 199,'with_comments' => 11},'releases' => 1,'requires' => ['Archive-Zip-1.06.tar.gz','AxKit-1.6.1.tar.gz','libapreq-1.2.tar.gz'],'requires_module' => {'Apache::Request' => 1,'Archive::Zip' => '1.01','AxKit' => '1.6'},'requires_recursive' => ['Archive-Zip-1.06.tar.gz','AxKit-1.6.1.tar.gz','Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Time-Local-1.07.tar.gz','libapreq-1.2.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 61288,'unpacked' => 298287},'testers' => {},'uses' => ['Apache::AxKit::Provider::File','Apache::Constants','Apache::Request','Archive::Zip','AxKit','IO::File','strict','vars']},'Apache-AxKit-Provider-PodSAX-1.00.tar.gz' => {'author' => 'MSERGEANT','description' => 'Dynamically Serve POD Files as XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 25,'pod_errors' => 0,'total' => 101,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 2443,'unpacked' => 4486},'testers' => {'fail' => 3,'tests' => '1'},'uses' => ['Apache::AxKit::Provider::File','Pod::SAX','XML::SAX::Writer','strict','vars']},'Apache-AxKit-RayApp-0.44.tar.gz' => {'author' => 'JANPAZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 456,'pod' => 144,'pod_errors' => 2,'total' => 600,'with_comments' => 25},'releases' => 1,'requires' => ['AxKit-1.6.1.tar.gz','Unicode-Map8-0.12.tar.gz','Unicode-String-2.07.tar.gz','XML-LibXSLT-1.53.tar.gz'],'requires_module' => {'AxKit' => '1.3','Unicode::Map8' => 0,'Unicode::String' => 0,'XML::LibXSLT' => 0},'requires_recursive' => ['AxKit-1.6.1.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','MIME-Base64-2.20.tar.gz','Unicode-Map8-0.12.tar.gz','Unicode-String-2.07.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15156,'unpacked' => 51675},'testers' => {},'uses' => ['Apache::AxKit::ConfigReader','Apache::AxKit::Language::XPathScript','Apache::AxKit::Provider::File','Apache::Constants','Apache::Request','Cwd','DBI','Data::Dumper','Unicode::Map8','Unicode::String','strict','vars']},'Apache-Backhand-0.02.tar.gz' => {'author' => 'DLOWE','description' => 'Bridge between mod_backhand + mod_perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 128,'pod_errors' => 0,'total' => 197,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 9530,'unpacked' => 26357},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict']},'Apache-Blog-0.03.tar.gz' => {'author' => 'GARDNER','description' => 'mod_perl weblog handler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 326,'pod' => 56,'pod_errors' => 0,'total' => 382,'with_comments' => 75},'releases' => 2,'requires' => ['DateManip-5.42a.tar.gz','HTML-Template-2.6.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => 0,'Apache::Request' => 0,'Date::Manip' => 0,'HTML::Template' => 0},'requires_recursive' => ['DateManip-5.42a.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7438,'unpacked' => 19622},'testers' => {},'uses' => ['Apache::Constants','Apache::File','Apache::Request','Date::Manip','File::Basename','HTML::Template','strict','vars']},'Apache-CIPP-0.13.tar.gz' => {'author' => 'JRED','description' => 'Use CIPP embedded HTML Pages with mod_perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 594,'pod' => 120,'pod_errors' => 0,'total' => 714,'with_comments' => 27},'releases' => 3,'requires' => ['CIPP-2.40.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 0,'CIPP' => '2.13'},'requires_recursive' => ['CIPP-2.40.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 7803,'unpacked' => 23355},'testers' => {'pass' => 3},'uses' => ['Apache::Constants','CIPP','Config','File::Path','FileHandle','strict']},'Apache-CPANTS-XML-1.4.tar.gz' => {'author' => 'CWEST','description' => 'XML Web Service for CPANTS metrics','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 38,'pod_errors' => 0,'total' => 95,'with_comments' => 2},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 0,'Test::More' => 0,'XML::Simple' => '2.05'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 1708,'unpacked' => 3225},'testers' => {},'uses' => ['Apache','Apache::Constants','Module::CPANTS','XML::Simple','strict','vars']},'Apache-CVS-0.08.tar.gz' => {'author' => 'BARBEE','description' => 'method handler provide a web interface to CVS repositories','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1865,'pod' => 681,'pod_errors' => 1,'total' => 2546,'with_comments' => 42},'releases' => 8,'size' => {'packed' => 14772,'unpacked' => 64301},'testers' => {'pass' => 2},'uses' => ['strict']},'Apache-Cache-0.05.tar.gz' => {'author' => 'RSOLIV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 418,'pod' => 280,'pod_errors' => 0,'total' => 698,'with_comments' => 12},'releases' => 5,'requires' => ['Apache-SharedMem-0.09.tar.gz','Time-modules-2003.0211.tar.gz'],'requires_module' => {'Apache::SharedMem' => '0.08','Time::ParseDate' => '100.01_03_01'},'requires_recursive' => ['Apache-SharedMem-0.09.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IPC-ShareLite-0.09.tar.gz','IPC-SysV-1.03.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz'],'size' => {'packed' => 8501,'unpacked' => 31643},'testers' => {},'uses' => ['5.005','Apache::SharedMem','Carp','Exporter','Time::ParseDate','constant','strict']},'Apache-CacheContent-0.12.tar.gz' => {'author' => 'LINDNER','description' => 'PerlFixupHandler class that caches dynamic content','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 202,'pod' => 116,'pod_errors' => 1,'total' => 318,'with_comments' => 23},'releases' => 1,'size' => {'packed' => 4244,'unpacked' => 9137},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Apache','Apache::Constants','strict']},'Apache-Centipaid-1.3.1.tar.gz' => {'author' => 'AELFAKIH','description' => 'mod_perl AuthenHandler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 335,'pod' => 247,'pod_errors' => 1,'total' => 582,'with_comments' => 52},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','IO-1.20.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache' => '1.02','Apache::File' => '1.01','CGI::Cookie' => '1.21','DBD::mysql' => '2.0419','DBI' => '1.21','IO::Socket' => '1.26','Net::hostent' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 310563,'unpacked' => 353148},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['Apache::Constants','Apache::File','CGI::Cookie','DBI','IO::Socket','Net::hostent','strict']},'Apache-Chameleon-0.02.tar.gz' => {'author' => 'IDORU','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2776,'pod' => 977,'pod_errors' => 0,'total' => 3753,'with_comments' => 256},'releases' => 1,'requires' => ['CGI-Untaint-0.90.tar.gz','CGI-Untaint-date-0.03.tar.gz','CGI-Untaint-email-0.03.tar.gz','Class-DBI-0.93.tar.gz','Class-DBI-FromCGI-0.92.tar.gz','Class-DBI-mysql-0.15.tar.gz','Digest-MD5-2.26.tar.gz','MailTools-1.58.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => undef,'Apache::Cookie' => undef,'Apache::FakeRequest' => undef,'Apache::Log' => undef,'Apache::Request' => undef,'Apache::libapreq' => undef,'CGI::Untaint' => '0.83','CGI::Untaint::date' => '0.03','CGI::Untaint::email' => '0.03','Class::DBI' => '0.36','Class::DBI::FromCGI' => '0.9','Class::DBI::mysql' => '0.13','Digest::MD5' => undef,'Mail::Send' => undef,'Template' => '2.06','Test::Simple' => '0.42'},'requires_recursive' => ['CGI-Untaint-0.90.tar.gz','CGI-Untaint-date-0.03.tar.gz','CGI-Untaint-email-0.03.tar.gz','Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-DBI-FromCGI-0.92.tar.gz','Class-DBI-mysql-0.15.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Date-Simple-1.03.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','Email-Valid-0.14.tar.gz','Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','MailTools-1.58.tar.gz','Storable-2.07.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 34887,'unpacked' => 147527},'testers' => {},'uses' => ['','Apache::Constants','Apache::Cookie','Apache::Log','CGI::Untaint','Class::DBI','Class::DBI::FromCGI','Class::DBI::mysql::FullTextSearch','Digest::MD5','Mail::Send','Template','Template::Context','Template::Plugin','Template::Plugins','Template::Provider','Template::Service','strict','warnings']},'Apache-ChooseLanguage-1.02.tar.gz' => {'author' => 'BILL','description' => 'Perl extension for accessing different versions of a website based on the user preferred language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 112,'pod' => 62,'pod_errors' => 0,'total' => 174,'with_comments' => 10},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'CGI::Cookie' => 0,'mod_perl' => 1},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 3359,'unpacked' => 7401},'testers' => {'pass' => 2},'uses' => ['Apache::Constants','strict']},'Apache-Clickable-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Make URLs and Emails in HTML clickable','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 194,'pod' => 80,'pod_errors' => 0,'total' => 274,'with_comments' => 8},'releases' => 2,'requires' => ['Apache-Filter-1.022.tar.gz','Email-Find-0.09.tar.gz','HTML-Parser-3.28.tar.gz','URI-Find-0.13.tar.gz'],'requires_module' => {'Apache::Filter' => 0,'Email::Find' => '0.06','HTML::Parser' => 0,'URI::Find' => 0},'requires_recursive' => ['Apache-Filter-1.022.tar.gz','Email-Find-0.09.tar.gz','Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','URI-Find-0.13.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 3513,'unpacked' => 9630},'testers' => {},'uses' => ['Apache::Constants','Apache::File','Email::Find','HTML::Parser','URI::Find','strict','vars']},'Apache-CodeRed-1.07.tar.gz' => {'author' => 'REUVEN','description' => 'Responds to CodeRed worm attacks with e-mail warnings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 271,'pod' => 47,'pod_errors' => 0,'total' => 318,'with_comments' => 66},'releases' => 1,'requires' => ['Cache-Cache-1.02.tar.gz','Mail-Sendmail-0.79.tar.gz','Net-DNS-0.38.tar.gz','TimeDate-1.16.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => '1.09','Cache::Cache' => '0.08','Mail::Sendmail' => '0.78','Net::DNS' => '0.12','Time::Zone' => '2.2'},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Mail-Sendmail-0.79.tar.gz','Net-DNS-0.38.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 5360,'unpacked' => 12836},'testers' => {'pass' => 2},'uses' => ['Apache::Constants','Cache::FileCache','Mail::Sendmail','Net::DNS','Time::Zone','strict','vars','warnings']},'Apache-Compress-1.003.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Compress content on the fly','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 654,'pod' => 168,'pod_errors' => 0,'total' => 822,'with_comments' => 62},'releases' => 2,'requires' => ['Compress-Zlib-1.22.tar.gz'],'requires_module' => {'Compress::Zlib' => '1.08'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz'],'size' => {'packed' => 11028,'unpacked' => 27369},'testers' => {},'uses' => ['Apache::Constants','Apache::File','Compress::Zlib','strict','vars']},'Apache-CompressClientFixup-0.07.tar.gz' => {'author' => 'SLAVA','description' => 'Perl extension for Apache-1.3.X to avoid C<gzip> compression for some buggy browsers.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 124,'pod' => 191,'pod_errors' => 0,'total' => 315,'with_comments' => 19},'releases' => 6,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => '0','Apache::Log' => '0','Apache::URI' => '0'},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 5729,'unpacked' => 20415},'testers' => {'pass' => 1},'uses' => ['5.004','Apache::Constants','strict','vars']},'Apache-ConfigFile-0.14.tar.gz' => {'author' => 'NWIGER','description' => 'Parse an Apache style httpd.conf config file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 511,'pod' => 365,'pod_errors' => 0,'total' => 876,'with_comments' => 106},'releases' => 2,'size' => {'packed' => 12801,'unpacked' => 45940},'testers' => {'pass' => 5},'uses' => ['Carp','Data::Dumper','strict','vars']},'Apache-ConfigParser-0.06.tar.gz' => {'author' => 'BZAJAC','description' => 'Load Apache configuration files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2962,'pod' => 1254,'pod_errors' => 0,'total' => 4216,'with_comments' => 290},'releases' => 6,'requires' => ['Tree-DAG_Node-1.04.tar.gz'],'requires_module' => {'Tree::DAG_Node' => '1.04'},'requires_recursive' => ['Tree-DAG_Node-1.04.tar.gz'],'size' => {'packed' => 156148,'unpacked' => 1702555},'testers' => {'pass' => 2},'uses' => ['5.004_05','Carp','Exporter','File::Spec','Symbol','Tree::DAG_Node','strict','vars']},'Apache-ContentHandler-1.3.3.tar.gz' => {'author' => 'ZENSPIDER','description' => 'mod_perl extension for uniform application generation.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 455,'pod' => 163,'pod_errors' => 0,'total' => 618,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 5715,'unpacked' => 14784},'testers' => {'pass' => 3},'uses' => ['Apache::Constants','CGI','Mail::Mailer','strict','vars']},'Apache-CookieToQuery-1.04.tar.gz' => {'author' => 'ALEXP','description' => 'Rewrite query string by adding cookie information','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 49,'pod' => 80,'pod_errors' => 0,'total' => 129,'with_comments' => 5},'releases' => 4,'requires' => ['libapreq-1.2.tar.gz'],'requires_module' => {'Apache::Cookie' => '0'},'requires_recursive' => ['libapreq-1.2.tar.gz'],'size' => {'packed' => 9922,'unpacked' => 27369},'testers' => {'fail' => 1},'uses' => ['Apache','Apache::Constants','Apache::Cookie','CGI','constant','strict','vars']},'Apache-CryptHash-3.02.tar.gz' => {'author' => 'MIKER','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 185,'pod' => 104,'pod_errors' => 0,'total' => 289,'with_comments' => 43},'releases' => 3,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::Base64' => '2.11'},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 13607,'unpacked' => 36674},'testers' => {'fail' => 2,'tests' => '13'},'uses' => ['5.005_62','Apache','Crypt::CapnMidNite','MIME::Base64','Sys::Hostname','strict','vars','warnings']},'Apache-CustomKeywords-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Customizable toolbar for MSIE','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 117,'pod' => 78,'pod_errors' => 0,'total' => 195,'with_comments' => 0},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Test::More' => '0.32','mod_perl' => '1.2'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 3200,'unpacked' => 8179},'testers' => {},'uses' => ['Apache::Constants','Apache::ModuleConfig','Apache::Util','strict','vars']},'Apache-DAV-0.13.tar.gz' => {'author' => 'GRICHTER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1053,'pod' => 0,'pod_errors' => 0,'total' => 1053,'with_comments' => 326},'releases' => 1,'size' => {'packed' => 43788,'unpacked' => 423586},'testers' => {},'uses' => ['DynaLoader','strict','vars']},'Apache-DB-0.06.tar.gz' => {'author' => 'DOUGM','description' => 'Hook Perl interactive DB into mod_perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 350,'pod' => 156,'pod_errors' => 0,'total' => 506,'with_comments' => 7},'releases' => 3,'size' => {'packed' => 6510,'unpacked' => 16102},'testers' => {'pass' => 3,'tests' => '0','unknown' => 15},'uses' => ['5.005','Devel::DProf','File::Basename','Time::HiRes','strict','vars']},'Apache-DBI-0.91.tar.gz' => {'author' => 'ABH','description' => 'Initiate a persistent database connection','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1156,'pod' => 358,'pod_errors' => 2,'total' => 1514,'with_comments' => 209},'releases' => 2,'requires' => ['DBI-1.37.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DBI' => 1,'Test::More' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 26739,'unpacked' => 97388},'testers' => {'fail' => 2,'pass' => 9,'tests' => '7'},'uses' => ['Apache::Constants','Carp','IPC::SysV','strict']},'Apache-DBILogConfig-0.02.tar.gz' => {'author' => 'JBODNAR','description' => 'Custom format logging via DBI for mod_perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 124,'pod' => 162,'pod_errors' => 0,'total' => 286,'with_comments' => 44},'releases' => 2,'size' => {'packed' => 5335,'unpacked' => 16537},'testers' => {'fail' => 4,'pass' => 1},'uses' => ['5.004','Apache::Constants','DBI','Date::Format','strict']},'Apache-DBILogger-0.93.tar.gz' => {'author' => 'ABH','description' => 'Logging via DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 132,'pod_errors' => 0,'total' => 293,'with_comments' => 5},'releases' => 10,'size' => {'packed' => 9702,'unpacked' => 28081},'testers' => {'fail' => 4,'pass' => 1},'uses' => ['5.004','Apache::Constants','DBI','Date::Format','strict']},'Apache-DBILogin-2.0.tar.gz' => {'author' => 'JGROENVEL','description' => 'Authenticate/authorize to backend database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 83,'pod_errors' => 0,'total' => 257,'with_comments' => 4},'releases' => 7,'size' => {'packed' => 3447,'unpacked' => 8985},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Apache::Constants','DBI','strict','vars']},'Apache-DebugInfo-0.05.tar.gz' => {'author' => 'GEOFF','description' => 'Per-request data logging','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 772,'pod' => 176,'pod_errors' => 0,'total' => 948,'with_comments' => 96},'releases' => 1,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'mod_perl' => '1.2401'},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 9882,'unpacked' => 38811},'testers' => {'pass' => 4},'uses' => ['5.005','Apache::Constants','Apache::File','Apache::Log','Data::Dumper','strict']},'Apache-DefaultCharset-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'AddDefaultCharset configuration from mod_perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 49,'pod_errors' => 0,'total' => 128,'with_comments' => 0},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Test::More' => '0.32','mod_perl' => '1.2'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 3358,'unpacked' => 7857},'testers' => {},'uses' => ['DynaLoader','strict','vars']},'Apache-Dispatch-0.09.tar.gz' => {'author' => 'GEOFF','description' => 'call PerlHandlers with the ease of Registry scripts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 749,'pod' => 260,'pod_errors' => 0,'total' => 1009,'with_comments' => 96},'releases' => 9,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'mod_perl' => '1.2401'},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 15436,'unpacked' => 50410},'testers' => {'fail' => 1,'pass' => 3,'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','Apache::Log','Apache::ModuleConfig','strict']},'Apache-DnsZone-0.1.tar.gz' => {'author' => 'THOMAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5664,'pod' => 0,'pod_errors' => 0,'total' => 5664,'with_comments' => 225},'releases' => 2,'requires' => ['Apache-AuthCookie-3.04.tar.gz','Apache-AuthTicket-0.31.tar.gz','CGI-FastTemplate-1.09.tar.gz','DBI-1.37.tar.gz','Email-Valid-0.14.tar.gz','MLDBM-2.01.tar.gz','Net-DNS-0.38.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache::AuthCookie' => 0,'Apache::AuthTicket' => 0,'Apache::Request' => '0.3103','CGI::FastTemplate' => '1.09','DBI' => '1.13','Email::Valid' => 0,'GDBM_File' => 0,'MLDBM' => 0,'Net::DNS' => '0.12','mod_perl' => '1.24'},'requires_recursive' => ['Apache-AuthCookie-3.04.tar.gz','Apache-AuthTicket-0.31.tar.gz','CGI-FastTemplate-1.09.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MLDBM-2.01.tar.gz','MailTools-1.58.tar.gz','Net-DNS-0.38.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 39963,'unpacked' => 295326},'testers' => {},'uses' => ['Apache::Constants','Apache::DnsZone','Apache::DnsZone::AuthCookie','Apache::DnsZone::Config','Apache::DnsZone::DB','Apache::DnsZone::Language','Apache::DnsZone::Resolver','CGI::FastTemplate','DBI','Data::Dumper','Digest::MD5','Email::Valid','Exporter','Fcntl','HTML::Entities','MLDBM','Net::DNS','strict','vars']},'Apache-DnsZone-0.2.tar.gz' => {'author' => 'THOMAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7047,'pod' => 0,'pod_errors' => 0,'total' => 7047,'with_comments' => 265},'releases' => 2,'requires' => ['Apache-AuthCookie-3.04.tar.gz','Apache-AuthTicket-0.31.tar.gz','CGI-FastTemplate-1.09.tar.gz','DBI-1.37.tar.gz','Email-Valid-0.14.tar.gz','MLDBM-2.01.tar.gz','Net-DNS-0.38.tar.gz','Net-IP-1.20.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache::AuthCookie' => 0,'Apache::AuthTicket' => 0,'Apache::Request' => '0.3103','CGI::FastTemplate' => '1.09','DBI' => '1.13','Email::Valid' => 0,'GDBM_File' => 0,'MLDBM' => 0,'Net::DNS' => '0.12','Net::IP' => 0,'mod_perl' => '1.24'},'requires_recursive' => ['Apache-AuthCookie-3.04.tar.gz','Apache-AuthTicket-0.31.tar.gz','CGI-FastTemplate-1.09.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MLDBM-2.01.tar.gz','MailTools-1.58.tar.gz','Net-DNS-0.38.tar.gz','Net-IP-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 47032,'unpacked' => 374993},'testers' => {},'uses' => ['Apache::Constants','CGI::FastTemplate','DBI','Data::Dumper','Digest::MD5','Email::Valid','Exporter','Fcntl','HTML::Entities','MLDBM','Net::DNS','Net::IP','strict','vars']},'Apache-DoCoMoProxy-0.01.tar.gz' => {'author' => 'KOBAYASI','description' => 'NTT DoCoMo HTTP gateway clone for mod_proxy','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 33,'pod_errors' => 0,'total' => 130,'with_comments' => 0},'releases' => 1,'requires' => ['URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'LWP::UserAgent' => '1.8','URI' => '1.15','mod_perl' => '1.21'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2314,'unpacked' => 4651},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','Apache::Request','URI','strict','vars']},'Apache-DumpHeaders-0.94.tar.gz' => {'author' => 'ABH','description' => 'Watch HTTP transaction via headers','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 113,'pod' => 97,'pod_errors' => 0,'total' => 210,'with_comments' => 2},'releases' => 7,'size' => {'packed' => 3372,'unpacked' => 7617},'testers' => {'fail' => 1,'pass' => 6},'uses' => ['Apache','Apache::Constants','strict','vars']},'Apache-Dynagzip-0.11.tar.gz' => {'author' => 'SLAVA','description' => 'dynamic gzip compression of outbound stream','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1583,'pod' => 870,'pod_errors' => 0,'total' => 2453,'with_comments' => 339},'releases' => 8,'requires' => ['Compress-LeadingBlankSpaces-0.01.tar.gz','Compress-Zlib-1.22.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache::Constants' => '0','Apache::File' => '0','Apache::Log' => '0','Apache::URI' => '0','Apache::Util' => '0','Compress::LeadingBlankSpaces' => '0','Compress::Zlib' => '1.16','Fcntl' => '0','FileHandle' => '0'},'requires_recursive' => ['Compress-LeadingBlankSpaces-0.01.tar.gz','Compress-Zlib-1.22.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 31136,'unpacked' => 142657},'testers' => {'pass' => 1},'uses' => ['5.004','Apache::Constants','Apache::File','Apache::Util','Compress::LeadingBlankSpaces','Compress::Zlib','Fcntl','FileHandle','constant','strict','vars']},'Apache-EmbperlChain-0.04.tar.gz' => {'author' => 'CHOLET','description' => 'Feed handler output to Embperl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 58,'pod_errors' => 0,'total' => 148,'with_comments' => 11},'releases' => 3,'requires' => ['Apache-OutputChain-0.11.tar.gz','Embperl-2.0b9.tar.gz'],'requires_module' => {'Apache::OutputChain' => 0,'HTML::Embperl' => 1},'requires_recursive' => ['Apache-OutputChain-0.11.tar.gz','Embperl-2.0b9.tar.gz','File-Spec-0.82.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 2917,'unpacked' => 7438},'testers' => {},'uses' => ['Apache::OutputChain','Apache::Util','strict','vars']},'Apache-Fake-0.9.tar.gz' => {'author' => 'JWALT','description' => 'fake a mod_perl request object','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 983,'pod' => 125,'pod_errors' => 0,'total' => 1108,'with_comments' => 85},'releases' => 2,'size' => {'packed' => 9887,'unpacked' => 34067},'testers' => {'fail' => 2},'uses' => ['5.6.0','Apache::ConfigFile','Apache::Constants','CGI','CGI::Carp','HTTP::Status','IO::Handle','Socket','constant','strict','vars']},'Apache-FakeCookie-0.07.tar.gz' => {'author' => 'MIKER','description' => 'fake request object for debugging','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 235,'pod' => 119,'pod_errors' => 0,'total' => 354,'with_comments' => 43},'releases' => 1,'size' => {'packed' => 16003,'unpacked' => 44931},'testers' => {'pass' => 1},'uses' => ['strict','vars']},'Apache-File-Resumable-1.1.1.1.tar.gz' => {'author' => 'TBONE','description' => 'example of how to serve resumable files under modperl','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 193,'pod' => 35,'pod_errors' => 0,'total' => 228,'with_comments' => 33},'releases' => 1,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => 1},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 3605,'unpacked' => 7209},'testers' => {'pass' => 3},'uses' => ['5.005_62','Apache::Constants','Exporter','strict','warnings']},'Apache-FileManager-0.19.tar.gz' => {'author' => 'PMC','description' => 'Apache mod_perl File Manager','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1214,'pod' => 178,'pod_errors' => 0,'total' => 1392,'with_comments' => 106},'releases' => 8,'requires' => ['Archive-Any-0.03.tar.gz','CGI.pm-2.98.tar.gz','File-NCopy0.32.tar.gz','File-Remove0.20.tar.gz','IO-1.20.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache::Constants' => '1.09','Apache::File' => '1.01','Apache::Request' => 0,'Apache::Util' => 0,'Archive::Any' => '0.03','CGI::Cookie' => '1.2','File::Copy' => '2.03','File::NCopy' => '0.32','File::Remove' => '0.2','File::stat' => 0,'IO::File' => 0,'POSIX' => '1.03'},'requires_recursive' => ['Archive-Any-0.03.tar.gz','Archive-Tar-1.03.tar.gz','Archive-Zip-1.06.tar.gz','CGI.pm-2.98.tar.gz','Carp-Assert-0.17.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-ISA-0.32.tar.gz','Class-Virtual-0.03.tar.gz','Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','File-NCopy0.32.tar.gz','File-Remove0.20.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12485,'unpacked' => 42379},'testers' => {},'uses' => ['5.005_62','Apache::Constants','Apache::File','Apache::Request','Apache::Util','Archive::Any','CGI::Cookie','Data::Dumper','File::Copy','File::NCopy','File::Remove','File::stat','IO::File','POSIX','strict','warnings']},'Apache-Filter-1.022.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Alter the output of previous handlers','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 1303,'pod' => 432,'pod_errors' => 0,'total' => 1735,'with_comments' => 126},'releases' => 30,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'mod_perl' => '1.24_01'},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 26259,'unpacked' => 74887},'testers' => {},'uses' => ['Apache','Apache::Constants','Apache::PerlRun','Apache::RegistryNG','Symbol','strict','vars']},'Apache-Filter-HanConvert-0.02.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Filter between Chinese variant and encodings','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 172,'pod' => 58,'pod_errors' => 0,'total' => 230,'with_comments' => 2},'releases' => 2,'requires' => ['Encode-1.97.tar.gz','Encode-HanConvert-0.26.tar.gz'],'requires_module' => {'Encode' => 0,'Encode::HanConvert' => '0.1'},'requires_recursive' => ['Encode-1.97.tar.gz','Encode-HanConvert-0.26.tar.gz'],'size' => {'packed' => 4593,'unpacked' => 11034},'testers' => {'fail' => 1,'tests' => '2'},'uses' => ['strict','warnings']},'Apache-FilteringProxy-0.1.tar.gz' => {'author' => 'DCASTRO','description' => 'A configurable rewriting proxy module for HTTP servers in mod_perl.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1155,'pod' => 172,'pod_errors' => 0,'total' => 1327,'with_comments' => 286},'releases' => 1,'requires' => ['XML-EasyOBJ-1.12.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::UserAgent' => 0,'XML::EasyOBJ' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-EasyOBJ-1.12.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19984,'unpacked' => 71427},'testers' => {'fail' => 1},'uses' => ['Apache::URI','DBI','LWP::UserAgent','XML::EasyOBJ','diagnostics','strict','vars']},'Apache-ForwardedFor-0.5.tar.gz' => {'author' => 'JLAWRENC','description' => 'Updates the remote ip for proxied requests','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 98,'pod' => 106,'pod_errors' => 0,'total' => 204,'with_comments' => 13},'releases' => 2,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'mod_perl' => undef},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 11020,'unpacked' => 28861},'testers' => {'pass' => 4},'uses' => ['Apache::Constants','strict','vars']},'Apache-GD-Thumbnail-0.03.tar.gz' => {'author' => 'ISAAC','description' => 'Apache module which generates on-the-fly thumbnails using GD and libjpeg','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 56,'pod_errors' => 0,'total' => 133,'with_comments' => 10},'releases' => 3,'requires' => ['GD-2.07.tar.gz','Image-GD-Thumbnail-0.02.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::File' => '1.01','GD' => '1.38','Image::GD::Thumbnail' => '0.02'},'requires_recursive' => ['GD-2.07.tar.gz','Image-GD-Thumbnail-0.02.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2589,'unpacked' => 5093},'testers' => {'pass' => 2},'uses' => ['Apache::Constants','Apache::File','GD','Image::GD::Thumbnail','strict','vars','warnings']},'Apache-GDGraph-0.96.tar.gz' => {'author' => 'RKITOVER','description' => 'Generate Graphs in an Apache handler.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 651,'pod' => 292,'pod_errors' => 1,'total' => 943,'with_comments' => 73},'releases' => 16,'requires' => ['File-Cache-0.16.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'File::Cache' => 0,'GD::Graph' => 0,'GD::Text::Align' => 0,'LWP::Simple' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Cache-0.16.tar.gz','File-Spec-0.82.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18744,'unpacked' => 48394},'testers' => {'fail' => 1,'pass' => 2,'tests' => '2'},'uses' => ['Apache','Apache::Constants','Data::Dumper','File::Cache','GD','GD::Graph','GD::Graph::$type','GD::Graph::colour','GD::Text','HTTP::Date','LWP::Simple','constant','strict']},'Apache-GTopLimit-1.02.tar.gz' => {'author' => 'STAS','description' => 'Child exit on small shared or large mem','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 219,'pod' => 118,'pod_errors' => 0,'total' => 337,'with_comments' => 27},'releases' => 5,'size' => {'packed' => 5956,'unpacked' => 20779},'testers' => {},'uses' => ['Apache::Constants','strict']},'Apache-Gallery-0.6.tar.gz' => {'author' => 'LEGART','description' => 'mod_perl handler to create an image gallery','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1113,'pod' => 169,'pod_errors' => 0,'total' => 1282,'with_comments' => 37},'releases' => 9,'requires' => ['CGI-FastTemplate-1.09.tar.gz','File-Spec-0.82.tar.gz','Image-Info-1.12.tar.gz','Image-Size-2.992.tar.gz','Inline-0.44.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Request' => 0,'CGI::FastTemplate' => 0,'File::Spec' => 0,'Image::Info' => 0,'Image::Size' => 0,'Inline' => 0,'Test::More' => 0,'URI::Escape' => 0,'mod_perl' => 0},'requires_recursive' => ['CGI-FastTemplate-1.09.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Image-Info-1.12.tar.gz','Image-Size-2.992.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','URI-1.24.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 66429,'unpacked' => 111336},'testers' => {'pass' => 1},'uses' => ['Apache::Constants','CGI::FastTemplate','File::Spec','File::stat','Image::Info','Image::Size','Inline','POSIX','URI::Escape','strict','vars']},'Apache-Gateway-1.01.tar.gz' => {'author' => 'CCWF','description' => 'A multiplexing gateway','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 672,'pod' => 233,'pod_errors' => 0,'total' => 905,'with_comments' => 114},'releases' => 2,'size' => {'packed' => 14863,'unpacked' => 42188},'testers' => {'fail' => 5},'uses' => ['Apache::Constants','strict','vars']},'Apache-GeoIP-1.13.tar.gz' => {'author' => 'RKOBES','description' => 'Look up country by IP Address','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1696,'pod' => 837,'pod_errors' => 0,'total' => 2533,'with_comments' => 22},'releases' => 3,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'mod_perl' => undef},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 335595,'unpacked' => 703885},'testers' => {},'uses' => ['APR::Table','APR::URI','Apache','Apache::Constants','Apache::Log','Apache::RequestRec','Apache::RequestUtil','Apache::URI','DynaLoader','POSIX','strict','vars']},'Apache-GuessCharset-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'adds HTTP charset by guessing file\'s encoding','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 46,'pod_errors' => 0,'total' => 119,'with_comments' => 3},'releases' => 2,'requires' => ['Encode-1.97.tar.gz','I18N-Charset-1.24.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::File' => 0,'Encode::Guess' => 0,'I18N::Charset' => '1.16','Test::More' => '0.32'},'requires_recursive' => ['App-Info-0.23.tar.gz','Encode-1.97.tar.gz','File-Spec-0.82.tar.gz','I18N-Charset-1.24.tar.gz','IO-String-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 2867,'unpacked' => 7058},'testers' => {'pass' => 1},'uses' => ['Apache::Constants','Apache::File','Encode::Guess','I18N::Charset','strict']},'Apache-GzipChain-1.14.tar.gz' => {'author' => 'ANDK','description' => 'Compress files on the fly','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 79,'pod_errors' => 0,'total' => 204,'with_comments' => 1},'releases' => 5,'requires' => ['Apache-OutputChain-0.11.tar.gz','Compress-Zlib-1.22.tar.gz'],'requires_module' => {'Apache::OutputChain' => '0.04','Compress::Zlib' => 1},'requires_recursive' => ['Apache-OutputChain-0.11.tar.gz','Compress-Zlib-1.22.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 4243,'unpacked' => 10041},'testers' => {'pass' => 6},'uses' => ['Apache::Constants','Apache::OutputChain','Compress::Zlib','Encode','FileHandle','HTTP::Date','strict','vars']},'Apache-HTMLView-0.91.tar.gz' => {'author' => 'BJORNARDO','description' => 'A mod_perl module for compiled HTMLView page','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 217,'pod' => 37,'pod_errors' => 0,'total' => 254,'with_comments' => 45},'releases' => 2,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '0'},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 13477,'unpacked' => 36509},'testers' => {'fail' => 7},'uses' => ['Apache::Constants','Apache::DBI','CGI','DBI','vars']},'Apache-Handlers-0.02.tar.gz' => {'author' => 'JSMITH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 308,'pod' => 226,'pod_errors' => 3,'total' => 534,'with_comments' => 5},'releases' => 2,'requires' => ['Perl-WhichPhase-0.01.tar.gz'],'requires_module' => {'Perl::WhichPhase' => '0.01'},'requires_recursive' => ['Perl-WhichPhase-0.01.tar.gz'],'size' => {'packed' => 6720,'unpacked' => 23238},'testers' => {'fail' => 1,'pass' => 1,'tests' => '13'},'uses' => ['Apache::Constants','Attribute::Handlers','Carp','Data::Dumper','Perl::WhichPhase','strict','vars']},'Apache-HeavyCGI-0.0133.tar.gz' => {'author' => 'ANDK','description' => 'Framework to run complex CGI tasks on an Apache server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1255,'pod' => 422,'pod_errors' => 0,'total' => 1677,'with_comments' => 56},'releases' => 7,'size' => {'packed' => 25970,'unpacked' => 75804},'testers' => {'pass' => 3,'tests' => '0','unknown' => 3},'uses' => ['5.005','Apache::Constants','Apache::Request','Carp','Class::Singleton','Compress::Zlib','Data::Dumper','URI::Escape','URI::URL','constant','fields','overload','strict','vars']},'Apache-Htgroup-1.22.tar.gz' => {'author' => 'RBOW','description' => 'Manage Apache authentication group files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 180,'pod' => 110,'pod_errors' => 0,'total' => 290,'with_comments' => 23},'releases' => 9,'size' => {'packed' => 13239,'unpacked' => 36661},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Apache-Htpasswd-1.5.5.tar.gz' => {'author' => 'KMELTZ','description' => 'Manage Unix crypt-style password file.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 530,'pod' => 185,'pod_errors' => 0,'total' => 715,'with_comments' => 43},'releases' => 11,'size' => {'packed' => 6648,'unpacked' => 23395},'testers' => {'pass' => 7},'uses' => ['Carp','Fcntl','POSIX','strict','vars']},'Apache-Htpasswd-Perishable-1.00.tar.gz' => {'author' => 'ALLENDAY','description' => 'Perl extension for expiring htaccess entries','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 31,'pod_errors' => 0,'total' => 110,'with_comments' => 4},'releases' => 1,'requires' => ['Apache-Htpasswd-1.5.5.tar.gz','Date-Simple-1.03.tar.gz'],'requires_module' => {'Apache::Htpasswd' => '','Date::Simple' => '2.02'},'requires_recursive' => ['Apache-Htpasswd-1.5.5.tar.gz','Date-Simple-1.03.tar.gz'],'size' => {'packed' => 2430,'unpacked' => 4646},'testers' => {'pass' => 2},'uses' => ['Apache::Htpasswd','Date::Simple','strict','warnings']},'Apache-Icon-0.02.tar.gz' => {'author' => 'DOUGM','description' => 'Access to AddIcon* configuration','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 33,'pod' => 84,'pod_errors' => 0,'total' => 117,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 6097,'unpacked' => 17469},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['strict']},'Apache-ImageMagick-2.0b7.tar.gz' => {'author' => 'GRICHTER','description' => 'Convert and manipulate images on the fly','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 677,'pod' => 233,'pod_errors' => 0,'total' => 910,'with_comments' => 52},'releases' => 1,'size' => {'packed' => 25457,'unpacked' => 69039},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Apache::Constants','Digest::MD5','File::Basename','IO::File','Text::ParseWords','constant','strict','vars']},'Apache-JAF-0.06.tar.gz' => {'author' => 'GRISHACE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1038,'pod' => 300,'pod_errors' => 0,'total' => 1338,'with_comments' => 117},'releases' => 4,'requires' => ['Data-Dumper-2.101.tar.gz','Template-Toolkit-2.10.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache' => 0,'Apache::Request' => 0,'Data::Dumper' => 0,'DirHandle' => 0,'Template' => '2.08'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Template-Toolkit-2.10.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18520,'unpacked' => 56139},'testers' => {},'uses' => ['5.6.0','Apache','Apache::Constants','Data::Dumper','strict']},'Apache-JumpByReferer-0.01.tar.gz' => {'author' => 'TANIGUCHI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 168,'pod' => 87,'pod_errors' => 0,'total' => 255,'with_comments' => 4},'releases' => 1,'requires' => ['mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache::Constants' => 0,'Apache::Log' => 0,'Text::ParseWords' => 0,'mod_perl' => 0},'requires_recursive' => ['mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3824,'unpacked' => 8742},'testers' => {'pass' => 1},'uses' => ['Apache::Constants','Text::ParseWords','strict','vars']},'Apache-Keywords-0.1.tar.gz' => {'author' => 'MAGNUS','description' => 'Store keywords as a personal profile in a cookie.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 294,'pod' => 112,'pod_errors' => 0,'total' => 406,'with_comments' => 38},'releases' => 1,'size' => {'packed' => 4330,'unpacked' => 14647},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Apache::Constants','Apache::Cookie','AutoLoader','Exporter','vars']},'Apache-Language-0.07.tar.gz' => {'author' => 'GOZER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1138,'pod' => 539,'pod_errors' => 0,'total' => 1677,'with_comments' => 115},'releases' => 12,'requires' => ['I18N-LangTags-0.28.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 0,'I18N::LangTags' => '0.11'},'requires_recursive' => ['I18N-LangTags-0.28.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 20266,'unpacked' => 78500},'testers' => {},'uses' => ['Apache::Constants','Apache::Language::Constants','Apache::ModuleConfig','DBI','Data::Dumper','Exporter','I18N::LangTags','IO::File','constant','strict','vars']},'Apache-Language-0.14.tar.gz' => {'author' => 'GOZER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 978,'pod' => 479,'pod_errors' => 0,'total' => 1457,'with_comments' => 66},'releases' => 12,'requires' => ['I18N-LangTags-0.28.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 0,'I18N::LangTags' => '0.11'},'requires_recursive' => ['I18N-LangTags-0.28.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 15726,'unpacked' => 50832},'testers' => {'fail' => 2,'pass' => 3,'tests' => '3'},'uses' => ['Apache::Constants','Apache::ModuleConfig','DBI','Data::Dumper','Exporter','I18N::LangTags','IO::File','constant','strict','vars']},'Apache-Layer-1.07.tar.gz' => {'author' => 'SAM','description' => 'Layer content tree over one or more','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 107,'pod' => 48,'pod_errors' => 0,'total' => 155,'with_comments' => 27},'releases' => 1,'size' => {'packed' => 3146,'unpacked' => 6532},'testers' => {'pass' => 4},'uses' => ['Apache::Constants','strict','vars']},'Apache-Lint-0.02.tar.gz' => {'author' => 'PETDANCE','description' => 'HTML validation filter using HTML::Lint','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 56,'pod_errors' => 0,'total' => 134,'with_comments' => 1},'releases' => 2,'requires' => ['HTML-Lint-1.22.tar.gz'],'requires_module' => {'HTML::Lint' => '0.94'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Lint-1.22.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2131,'unpacked' => 3740},'testers' => {'fail' => 1,'pass' => 6,'tests' => '1'},'uses' => ['Apache','Apache::Constants','Apache::File','Apache::Log','HTML::Lint','strict','warnings']},'Apache-Log-Spread-1.0.3.tar.gz' => {'author' => 'GSCHLOSS','description' => 'Perl implementation of mod_log_spread for multicasting access logs.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 156,'pod' => 53,'pod_errors' => 0,'total' => 209,'with_comments' => 10},'releases' => 4,'requires' => ['Spread-3.14-1.03.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => 0,'Apache::ExtUtils' => 0,'Apache::ModuleConfig' => 0,'Apache::Util' => 0,'Spread' => 0},'requires_recursive' => ['Spread-3.14-1.03.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 3437,'unpacked' => 8114},'testers' => {},'uses' => ['5.005_62','Apache::Constants','Apache::Util','English','POSIX','Spread','strict','vars','warnings']},'Apache-LogFile-0.12.tar.gz' => {'author' => 'DOUGM','description' => 'Interface to Apache\'s piped logs, etc.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 47,'pod_errors' => 0,'total' => 139,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 5118,'unpacked' => 11829},'testers' => {'fail' => 2,'tests' => '0','unknown' => 3},'uses' => ['strict','vars']},'Apache-LogIgnore-0.03.tar.gz' => {'author' => 'BEATNIK','description' => 'mod_perl log handler to ignore connections','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 151,'pod_errors' => 0,'total' => 256,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 2879,'unpacked' => 8570},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.006','Apache::Constants','strict']},'Apache-MIMEMapper-0.10.tar.gz' => {'author' => 'GEOFF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 128,'pod' => 69,'pod_errors' => 0,'total' => 197,'with_comments' => 11},'releases' => 1,'requires' => ['MIME-Types-1.06.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'MIME::Types' => 0,'mod_perl' => '1.26'},'requires_recursive' => ['MIME-Types-1.06.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 2955,'unpacked' => 9177},'testers' => {},'uses' => ['5.006','Apache::Constants','MIME::Types','strict']},'Apache-MP3-3.01.tar.gz' => {'author' => 'LDS','description' => 'Generate streamable directories of MP3 and Ogg Vorbis files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5395,'pod' => 1260,'pod_errors' => 0,'total' => 6655,'with_comments' => 1077},'releases' => 23,'requires' => ['Audio-Wav-0.02.tar.gz','Locale-Maketext-1.06.tar.gz','MP3-Info-1.02.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '1.14','Audio::Wav' => '0.02','Locale::Maketext' => '1.03','MP3::Info' => '0.8'},'requires_recursive' => ['Audio-Wav-0.02.tar.gz','File-Spec-0.82.tar.gz','I18N-LangTags-0.28.tar.gz','Locale-Maketext-1.06.tar.gz','MP3-Info-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 322331,'unpacked' => 483178},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','Apache::MP3','Apache::MP3::L10N','Apache::MP3::L10N::Aliases','Apache::MP3::L10N::RightToLeft','Apache::MP3::L10N::hr','Apache::MP3::L10N::nb','Apache::MP3::L10N::nl','Apache::MP3::L10N::nn','Apache::MP3::L10N::no','Apache::MP3::Playlist','Apache::MP3::Sorted','Audio::Wav','CGI','CGI::Cookie','File::Basename','File::Path','IO::File','Locale::Maketext','MP3::Info','Ogg::Vorbis','Socket','UNIVERSAL','constant','strict','vars']},'Apache-MP3-3.03.tar.gz' => {'author' => 'LDS','description' => 'Generate streamable directories of MP3 and Ogg Vorbis files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5616,'pod' => 1279,'pod_errors' => 0,'total' => 6895,'with_comments' => 1086},'releases' => 23,'requires' => ['Audio-Wav-0.02.tar.gz','Locale-Maketext-1.06.tar.gz','MP3-Info-1.02.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '1.14','Audio::Wav' => '0.02','Locale::Maketext' => '1.03','MP3::Info' => '0.8'},'requires_recursive' => ['Audio-Wav-0.02.tar.gz','File-Spec-0.82.tar.gz','I18N-LangTags-0.28.tar.gz','Locale-Maketext-1.06.tar.gz','MP3-Info-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 323869,'unpacked' => 489850},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Apache::Constants','Apache::MP3::L10N','Apache::MP3::L10N::Aliases','Apache::MP3::L10N::RightToLeft','Apache::MP3::L10N::hr','Apache::MP3::L10N::nb','Apache::MP3::L10N::nl','Apache::MP3::Playlist','Apache::MP3::Sorted','Audio::Wav','CGI','CGI::Cookie','File::Basename','File::Path','IO::File','Locale::Maketext','MP3::Info','Ogg::Vorbis','Socket','UNIVERSAL','constant','strict','vars']},'Apache-MP3-3.04.tar.gz' => {'author' => 'LDS','description' => 'Generate streamable directories of MP3 and Ogg Vorbis files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5993,'pod' => 1286,'pod_errors' => 0,'total' => 7279,'with_comments' => 1150},'releases' => 23,'requires' => ['Audio-Wav-0.02.tar.gz','Locale-Maketext-1.06.tar.gz','MP3-Info-1.02.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '1.14','Audio::Wav' => '0.02','Locale::Maketext' => '1.03','MP3::Info' => '0.8'},'requires_recursive' => ['Audio-Wav-0.02.tar.gz','File-Spec-0.82.tar.gz','I18N-LangTags-0.28.tar.gz','Locale-Maketext-1.06.tar.gz','MP3-Info-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 329226,'unpacked' => 506365},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Apache','Apache::Constants','Apache::MP3','Apache::MP3::L10N::nn','Apache::MP3::L10N::no','Audio::Wav','CGI','CGI::Carp','CGI::Cookie','File::Basename','File::Path','IO::File','Locale::Maketext','MP3::Info','Ogg::Vorbis','Socket','UNIVERSAL','constant','mod_perl','strict','vars']},'Apache-MP3-Skin-0.91.tar.gz' => {'author' => 'RGRAFF','description' => 'Enables use of skin files with Apache::MP3','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 791,'pod' => 567,'pod_errors' => 0,'total' => 1358,'with_comments' => 28},'releases' => 1,'requires' => ['Apache-MP3-3.03.tar.gz','HTML-Template-2.6.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '1.14','Apache::MP3' => '2.12','HTML::Template' => 2},'requires_recursive' => ['Apache-MP3-3.03.tar.gz','Audio-Wav-0.02.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','I18N-LangTags-0.28.tar.gz','Locale-Maketext-1.06.tar.gz','MP3-Info-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18167,'unpacked' => 64649},'testers' => {'fail' => 3,'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','Apache::MP3::Playlist','CGI','File::Basename','HTML::Template','constant','strict','vars']},'Apache-MSIISProbes-1.08.tar.gz' => {'author' => 'TONKIN','description' => 'Responds to worm attacks on Microsoft Internet Information Servers with e-mail warnings.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 334,'pod' => 159,'pod_errors' => 0,'total' => 493,'with_comments' => 82},'releases' => 1,'size' => {'packed' => 6980,'unpacked' => 18260},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Apache::Constants','Cache::FileCache','Mail::Sendmail','Net::DNS','Time::Zone','strict','vars']},'Apache-Mailtrack-0.03.tar.gz' => {'author' => 'FLORIAN','description' => 'keep track of views of HTML newsletters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 195,'pod' => 149,'pod_errors' => 0,'total' => 344,'with_comments' => 40},'releases' => 3,'requires' => ['DBI-1.37.tar.gz','Data-Serializer-0.17.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Request' => 1,'DBI' => '1.21','Data::Serializer' => '0.17','mod_perl' => '1.26'},'requires_recursive' => ['DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Data-Serializer-0.17.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 4459,'unpacked' => 10515},'testers' => {},'uses' => ['5.006','Apache::Constants','Apache::Request','DBI','Data::Serializer','strict','warnings']},'Apache-MiniWiki-0.83.tar.gz' => {'author' => 'KERW','description' => 'Miniature Wiki for Apache','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1067,'pod' => 198,'pod_errors' => 0,'total' => 1265,'with_comments' => 131},'releases' => 7,'requires' => ['Apache-Htpasswd-1.5.5.tar.gz','CGI.pm-2.98.tar.gz','DateManip-5.42a.tar.gz','HTML-FromText-1.005.tar.gz','HTML-Template-2.6.tar.gz','PerlMagick-5.56.tar.gz','Rcs-1.04.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => 0,'Apache::Htpasswd' => 0,'CGI' => 0,'Date::Manip' => 0,'HTML::FromText' => 0,'HTML::Template' => 0,'Image::Magick' => 1,'Rcs' => '1.04'},'requires_recursive' => ['Apache-Htpasswd-1.5.5.tar.gz','CGI.pm-2.98.tar.gz','DateManip-5.42a.tar.gz','File-Spec-0.82.tar.gz','HTML-FromText-1.005.tar.gz','HTML-Template-2.6.tar.gz','PerlMagick-5.56.tar.gz','Rcs-1.04.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 28043,'unpacked' => 79463},'testers' => {'pass' => 1},'uses' => ['5.006','Apache::Constants','Apache::File','Apache::Htpasswd','CGI','Carp','Date::Manip','File::stat','HTML::FromText','HTML::Template','Image::Magick','Rcs','strict']},'Apache-Mmap-0.05.tar.gz' => {'author' => 'FLETCH','description' => 'Share data via Mmap module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 414,'pod' => 153,'pod_errors' => 0,'total' => 567,'with_comments' => 84},'releases' => 3,'size' => {'packed' => 18470,'unpacked' => 52020},'testers' => {'fail' => 2},'uses' => ['5.004','Apache','Apache::Constants','AutoLoader','Carp','DynaLoader','Exporter','FileHandle','Mmap','Symbol','strict','vars']},'Apache-Module-0.11.tar.gz' => {'author' => 'DOUGM','description' => 'Self documentation for Apache C modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 510,'pod' => 123,'pod_errors' => 0,'total' => 633,'with_comments' => 19},'releases' => 4,'size' => {'packed' => 9000,'unpacked' => 26696},'testers' => {'pass' => 2,'tests' => '0','unknown' => 6},'uses' => ['Apache::Constants','Apache::Util','File::Basename','strict','vars']},'Apache-Motd-1.00.tar.gz' => {'author' => 'CRAMIREZ','description' => 'Add motd functionality to Apache webserver','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 189,'pod' => 167,'pod_errors' => 0,'total' => 356,'with_comments' => 19},'releases' => 5,'requires' => ['libapreq-1.2.tar.gz'],'requires_module' => {'Apache::Cookie' => '0'},'requires_recursive' => ['libapreq-1.2.tar.gz'],'size' => {'packed' => 6386,'unpacked' => 14884},'testers' => {'pass' => 3},'uses' => ['Apache','Apache::Constants','Apache::Cookie','strict','vars']},'Apache-MultiAuth-0.06.tar.gz' => {'author' => 'DARREN','description' => 'Choose from a number of authentication modules at runtime','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 56,'pod_errors' => 0,'total' => 191,'with_comments' => 18},'releases' => 3,'size' => {'packed' => 3159,'unpacked' => 9142},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','DynaLoader','strict','vars']},'Apache-NNTPGateway-0.9.tar.gz' => {'author' => 'BOUBAKER','description' => 'A Web based NNTP (usenet) interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1805,'pod' => 306,'pod_errors' => 0,'total' => 2111,'with_comments' => 426},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','MailTools-1.58.tar.gz','libapreq-1.2.tar.gz','libnet-1.16.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '1.2','Apache::Constants' => 1,'Apache::Log' => 1,'Apache::Request' => '0.3','Apache::URI' => 1,'CGI::Cookie' => '1.1','File::Spec' => '0.8','Mail::Address' => '1.1','Net::Cmd' => 2,'Net::Config' => '1.1','Net::Domain' => 2,'Net::NNTP' => 2},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MailTools-1.58.tar.gz','libapreq-1.2.tar.gz','libnet-1.16.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21146,'unpacked' => 76144},'testers' => {'pass' => 4},'uses' => ['5.00502','Apache::Constants','Apache::Log','Apache::Request','Apache::URI','CGI','CGI::Cookie','File::Spec','HTML::Template','IO::Socket','Mail::Address','Net::Cmd','Net::Config','Net::Domain','Net::NNTP','strict','vars','warnings']},'Apache-NavBarDD-0.75.tar.gz' => {'author' => 'LOURIDAS','description' => 'A dynamic double-decker (two level) Navigation Bar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 464,'pod' => 267,'pod_errors' => 0,'total' => 731,'with_comments' => 81},'releases' => 6,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => '1.09','Apache::File' => '1.01','Apache::URI' => '1.00'},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 7579,'unpacked' => 24243},'testers' => {'pass' => 2},'uses' => ['5.0006','Apache::Constants','strict']},'Apache-No404Proxy-0.05.tar.gz' => {'author' => 'MIYAGAWA','description' => '404 free Proxy','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 56,'pod_errors' => 0,'total' => 161,'with_comments' => 2},'releases' => 5,'requires' => ['SOAP-Lite-0.55.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'LWP::UserAgent' => '1.8','SOAP::Lite' => 0,'URI' => '1.15','mod_perl' => '1.21'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','SOAP-Lite-0.55.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2576,'unpacked' => 5636},'testers' => {'pass' => 2},'uses' => ['Apache::Constants','Apache::Log','LWP::UserAgent','SOAP::Lite','URI','strict','vars']},'Apache-OWA-0.7.tar.gz' => {'author' => 'SVINTO','description' => 'Runs Oracle PL/SQL Web Toolkit apps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 587,'pod' => 79,'pod_errors' => 0,'total' => 666,'with_comments' => 82},'releases' => 3,'size' => {'packed' => 14268,'unpacked' => 41478},'testers' => {'pass' => 4},'uses' => ['Apache::Constants','Apache::DBI','DBI','Data::Dumper','strict','vars']},'Apache-OutputChain-0.11.tar.gz' => {'author' => 'JANPAZ','description' => 'SSI on other modules output','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 235,'pod' => 181,'pod_errors' => 0,'total' => 416,'with_comments' => 3},'releases' => 10,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => 0},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 5321,'unpacked' => 13089},'testers' => {'pass' => 6},'uses' => ['5.004','Apache::Constants','Apache::SSI','FileHandle','strict','vars']},'Apache-PAR-0.21.tar.gz' => {'author' => 'NBYRD','description' => 'Perl extension for including Perl ARchive files in a mod_perl (1.x or 2.x) environment.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 811,'pod' => 678,'pod_errors' => 0,'total' => 1489,'with_comments' => 35},'releases' => 8,'requires' => ['Apache-Test-1.03.tar.gz','Archive-Zip-1.06.tar.gz','MIME-Types-1.06.tar.gz','PAR-0.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Test' => '1.01','Archive::Zip' => '1.05','MIME::Types' => '1.004','PAR' => '0.49','mod_perl' => '1.26'},'requires_recursive' => ['Apache-Test-1.03.tar.gz','Archive-Zip-1.06.tar.gz','Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Types-1.06.tar.gz','PAR-0.69.tar.gz','Time-Local-1.07.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21218,'unpacked' => 74967},'testers' => {},'uses' => ['5.005','APR::Table','Apache','Apache::Const','Apache::Constants','Apache::File','Apache::Log','Apache::PerlRun','Apache::RegistryNG','Apache::RequestIO','Apache::RequestRec','Apache::RequestUtil','Apache::Response','Apache::Server','Apache::ServerUtil','Archive::Zip','Exporter','ModPerl::RegistryCooker','PAR','mod_perl','strict','vars','warnings']},'Apache-PHLogin-0.5.tar.gz' => {'author' => 'JGROENVEL','description' => 'Authenticate via a PH database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 36,'pod_errors' => 0,'total' => 105,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2030,'unpacked' => 3910},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Apache::Constants','Net::PH','strict','vars']},'Apache-PSP-0.81.tgz' => {'author' => 'RADCLIFF','description' => 'mod_perl interface to Perl Server Pages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 961,'pod' => 51,'pod_errors' => 0,'total' => 1012,'with_comments' => 136},'releases' => 5,'requires' => ['CGI-Minimal-1.10.tar.gz','DBI-1.37.tar.gz','HTML-Parser-3.28.tar.gz','IO-stringy-2.108.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => '0.1','CGI::Minimal' => '0.1','DBI' => 1,'HTML::Parser' => '0.1','IO::Scalar' => '2.1'},'requires_recursive' => ['CGI-Minimal-1.10.tar.gz','DBI-1.37.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-stringy-2.108.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 11013,'unpacked' => 32527},'testers' => {'pass' => 1},'uses' => ['5.005','Apache::Constants','CGI::Minimal','Carp','DBI','HTML::Parser','IO::Scalar','strict','vars']},'Apache-PageKit-1.11.tar.gz' => {'author' => 'BORISZ','description' => 'MVCC web framework using mod_perl, XML and HTML::Template','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4027,'pod' => 674,'pod_errors' => 0,'total' => 4701,'with_comments' => 479},'releases' => 28,'requires' => ['Apache-SessionX-2.00b5.tar.gz','Compress-Zlib-1.22.tar.gz','Data-FormValidator-3.12.tar.gz','HTML-Clean-0.8.tar.gz','HTML-FillInForm-1.02.tar.gz','HTML-Template-2.6.tar.gz','HTML-Template-XPath-0.10.tar.gz','Text-Iconv-1.2.tar.gz','XML-LibXML-1.54.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Cookie' => 0,'Apache::Request' => 0,'Apache::SessionX' => 0,'Apache::URI' => 0,'Apache::Util' => 0,'Compress::Zlib' => 0,'Data::FormValidator' => 0,'HTML::Clean' => 0,'HTML::FillInForm' => '0.12','HTML::Template' => '2.2','HTML::Template::XPath' => '0.1','Text::Iconv' => 0,'XML::LibXML' => '1.31','mod_perl' => '1.2401'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','Apache-SessionX-2.00b5.tar.gz','Compress-Zlib-1.22.tar.gz','Data-FormValidator-3.12.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Clean-0.8.tar.gz','HTML-FillInForm-1.02.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Template-2.6.tar.gz','HTML-Template-XPath-0.10.tar.gz','IO-1.20.tar.gz','Text-Iconv-1.2.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 114628,'unpacked' => 411877},'testers' => {'fail' => 1},'uses' => ['Apache::Constants','Apache::Session','Carp','DBI','Data::FormValidator','MIME::Types','Mail::Mailer','MyPageKit::MyModel','XML::LibXML','XML::LibXSLT','bytes','integer','strict','vars']},'Apache-ParseControl-0.1.2.tar.gz' => {'author' => 'DAPATRICK','description' => 'control the parsing of server-side scripts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 50,'pod_errors' => 0,'total' => 119,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 3104,'unpacked' => 5421},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['5.005_62','Apache::Constants','Apache::File','strict','warnings']},'Apache-ParseFormData-0.04.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 317,'pod' => 186,'pod_errors' => 0,'total' => 503,'with_comments' => 10},'releases' => 6,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'mod_perl' => '1.9908'},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'testers' => {},'uses' => ['5','APR::Table','Apache::Log','Exporter','IO::File','POSIX','constant','strict']},'Apache-ParseLog-1.02.tar.gz' => {'author' => 'AKIRA','description' => 'OO interface to Apache log files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2206,'pod' => 1078,'pod_errors' => 8,'total' => 3284,'with_comments' => 319},'releases' => 3,'size' => {'packed' => 37836,'unpacked' => 160386},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['5.004','Carp','Exporter','vars']},'Apache-Peek-1.01.tar.gz' => {'author' => 'STAS','description' => 'Devel::Peek for mod_perl','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 53,'pod_errors' => 0,'total' => 128,'with_comments' => 1},'releases' => 4,'size' => {'packed' => 26295,'unpacked' => 99023},'testers' => {'pass' => 1},'uses' => ['Devel::Peek','Exporter','mod','strict','warnings']},'Apache-PerlVINC-0.03.tar.gz' => {'author' => 'DAVEM','description' => 'Allows versioning of modules among directories or v-hosts.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 121,'pod' => 93,'pod_errors' => 0,'total' => 214,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 2888,'unpacked' => 6037},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','strict']},'Apache-Perldoc-1.11.tar.gz' => {'author' => 'RBOW','description' => 'mod_perl handler to spooge out HTML perldocs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 79,'pod_errors' => 0,'total' => 164,'with_comments' => 6},'releases' => 6,'size' => {'packed' => 3587,'unpacked' => 9860},'testers' => {'pass' => 2},'uses' => ['vars']},'Apache-Pod-0.02.tar.gz' => {'author' => 'PETDANCE','description' => 'base class for converting Pod files to prettier forms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 122,'pod' => 119,'pod_errors' => 0,'total' => 241,'with_comments' => 4},'releases' => 1,'requires' => ['Pod-Simple-0.96.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Pod::Simple' => '0.93','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 3148,'unpacked' => 7218},'testers' => {'pass' => 4},'uses' => ['Pod::Find','Pod::Simple::HTML','Pod::Simple::Text','strict','vars']},'Apache-Precompress-0.1.tar.gz' => {'author' => 'SPROCTOR','description' => 'Deliver already compressed files or decompress on the fly','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 114,'pod' => 85,'pod_errors' => 0,'total' => 199,'with_comments' => 2},'releases' => 1,'requires' => ['Compress-Zlib-1.22.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-MockObject-0.12.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache::Constants' => 0,'Apache::Log' => 0,'Compress::Zlib' => 1,'Cwd' => 0,'File::Spec' => 0,'File::Temp' => 0,'Test::MockObject' => 0},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4201,'unpacked' => 11555},'testers' => {'pass' => 2},'uses' => ['5.006','Apache::Constants','Apache::Log','Compress::Zlib','strict','vars','warnings']},'Apache-PrettyPerl-1.00.tar.gz' => {'author' => 'RA','description' => 'Syntax highlighting for Perl files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 61,'pod_errors' => 0,'total' => 237,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 4474,'unpacked' => 9411},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Apache','Apache::Constants','Apache::File','CGI','DynaLoader','strict','sys::syscall.ph','vars']},'Apache-Proxy-0.02.tar.gz' => {'author' => 'XFIRE','description' => 'Perl interface to mod_proxy','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 18,'pod' => 22,'pod_errors' => 0,'total' => 40,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2018,'unpacked' => 3578},'testers' => {},'uses' => ['strict','vars']},'Apache-Proxy-Info-0.01.tar.gz' => {'author' => 'GOZER','description' => 'Small backend to get information from doc server to mod_perl server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 49,'pod' => 40,'pod_errors' => 0,'total' => 89,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 4542,'unpacked' => 11220},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Apache::Constants','strict','vars']},'Apache-ProxyPass-0.06.tar.gz' => {'author' => 'MJS','description' => 'Perl implementation of ProxyPass','files' => ['Makefile.PL'],'lines' => {'nonpod' => 80,'pod' => 25,'pod_errors' => 0,'total' => 105,'with_comments' => 2},'releases' => 4,'size' => {'packed' => 1452,'unpacked' => 2465},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Apache::Constants','strict']},'Apache-ProxyRewrite-0.17.tar.gz' => {'author' => 'CGILMORE','description' => 'mod_perl URL-rewriting proxy','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 835,'pod' => 119,'pod_errors' => 0,'total' => 954,'with_comments' => 364},'releases' => 8,'requires' => ['URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '1.24','Apache::Log' => '0','LWP' => '5.43','URI' => '1.0'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12407,'unpacked' => 37861},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Apache','Apache::Constants','Apache::Log','Apache::URI','LWP::UserAgent','Socket','URI::Escape','strict']},'Apache-ProxyScan-0.31.tar.gz' => {'author' => 'PSTADT','description' => 'proxy module to integrate content scanners','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 296,'pod' => 108,'pod_errors' => 0,'total' => 404,'with_comments' => 28},'releases' => 5,'requires' => ['File-MMagic-1.19.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => '0','File::MMagic' => '0','LWP::UserAgent' => '0','URI::URL' => '0'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-MMagic-1.19.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9754,'unpacked' => 26690},'testers' => {},'uses' => ['Apache::Constants','File::MMagic','URI::URL','strict','vars']},'Apache-ProxyStuff-0.10.tar.gz' => {'author' => 'JBODNAR','description' => 'mod_perl header/footer/proxy module','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 378,'pod' => 97,'pod_errors' => 0,'total' => 475,'with_comments' => 110},'releases' => 5,'size' => {'packed' => 6232,'unpacked' => 18743},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Apache::Constants','Apache::Log','Apache::Table','Data::Dumper','HTML::TokeParser','LWP::UserAgent','strict','vars']},'Apache-Queue-0.3.tar.gz' => {'author' => 'PSYON','description' => 'An HTTP file queueing system.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 288,'pod' => 52,'pod_errors' => 0,'total' => 340,'with_comments' => 16},'releases' => 3,'requires' => ['DB_File-1.806.tar.gz','Template-Toolkit-2.10.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache::Constants' => '0','Apache::File' => '0','Apache::Log' => '0','DB_File' => '0','Fcntl' => '0','Template' => '0'},'requires_recursive' => ['DB_File-1.806.tar.gz','Template-Toolkit-2.10.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3938,'unpacked' => 9976},'testers' => {'pass' => 1},'uses' => ['Apache::Constants','Apache::File','Apache::Log','DB_File','Fcntl','Template','strict','vars']},'Apache-RSS-0.05.tar.gz' => {'author' => 'IKEBE','description' => 'generate RSS output for directory Index.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 313,'pod' => 135,'pod_errors' => 0,'total' => 448,'with_comments' => 21},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz','XML-RSS-1.02.tar.gz'],'requires_module' => {'Test::More' => '0.32','Time::Piece' => '1.01','XML::RSS' => '0.97'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-RSS-1.02.tar.gz'],'size' => {'packed' => 5828,'unpacked' => 21321},'testers' => {'fail' => 1},'uses' => ['Apache::Constants','Apache::ModuleConfig','Apache::Util','Carp','DirHandle','Jcode','Time::Piece','URI','XML::RSS','strict','vars']},'Apache-RandomLocation-0.5.tar.gz' => {'author' => 'RKOBES','description' => 'Random image display','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 405,'pod' => 105,'pod_errors' => 0,'total' => 510,'with_comments' => 47},'releases' => 3,'requires' => ['CGI.pm-2.98.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => '1.00','CGI' => '2.38'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 7502,'unpacked' => 22761},'testers' => {'pass' => 6},'uses' => ['Apache::Constants','CGI','strict','vars']},'Apache-Recorder-0.07.tar.gz' => {'author' => 'CBROOKS','description' => 'mod_perl handler to record HTTP sessions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 158,'pod' => 54,'pod_errors' => 0,'total' => 212,'with_comments' => 7},'releases' => 5,'requires' => ['CGI.pm-2.98.tar.gz','Storable-2.07.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => 0,'Apache::URI' => 0,'CGI::Cookie' => '1.21','Storable' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 6898,'unpacked' => 18785},'testers' => {'pass' => 3},'uses' => ['Apache::Constants','Apache::File','Apache::URI','CGI::Cookie','Storable','constant','strict','vars']},'Apache-RefererBlock-0.03.tar.gz' => {'author' => 'CHOLET','description' => 'Block based on MIME type + Referer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 39,'pod_errors' => 0,'total' => 117,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 2685,'unpacked' => 6781},'testers' => {'pass' => 3},'uses' => ['Apache::Constants','strict','vars']},'Apache-Reload-0.07.tar.gz' => {'author' => 'MSERGEANT','description' => 'Reload changed modules (extending StatINC)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 84,'pod_errors' => 0,'total' => 251,'with_comments' => 5},'releases' => 7,'size' => {'packed' => 3266,'unpacked' => 10379},'testers' => {'pass' => 3,'tests' => '0','unknown' => 15},'uses' => ['strict','vars']},'Apache-Request-Redirect-0.02.tar.gz' => {'author' => 'EBRUNI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 265,'pod' => 177,'pod_errors' => 0,'total' => 442,'with_comments' => 21},'releases' => 2,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request' => 'HTTP::Headers','HTTP::Response' => 'URI'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6047,'unpacked' => 14815},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','Exporter','HTTP::Headers','HTTP::Request','HTTP::Response','LWP::UserAgent','Log::FileSimple','URI','strict','vars','warnings']},'Apache-RequestNotes-0.06.tar.gz' => {'author' => 'GEOFF','description' => 'Pass cookie & form data around pnotes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 168,'pod' => 89,'pod_errors' => 0,'total' => 257,'with_comments' => 43},'releases' => 1,'requires' => ['libapreq-1.2.tar.gz'],'requires_module' => {'Apache::Cookie' => 0,'Apache::Request' => '0.3103'},'requires_recursive' => ['libapreq-1.2.tar.gz'],'size' => {'packed' => 4800,'unpacked' => 16296},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.004','Apache::Constants','Apache::Cookie','Apache::Log','Apache::Request','strict']},'Apache-ReverseProxy-0.06.tar.gz' => {'author' => 'CLINTDW','description' => 'An Apache mod_perl reverse proxy','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 243,'pod' => 71,'pod_errors' => 0,'total' => 314,'with_comments' => 46},'releases' => 6,'size' => {'packed' => 5454,'unpacked' => 15657},'testers' => {'fail' => 1,'pass' => 3,'tests' => '1'},'uses' => ['Apache::Constants','CGI','LWP','Symbol','strict','vars']},'Apache-RewritingProxy-0.4.tar.gz' => {'author' => 'HAGANK','description' => 'proxy that works by rewriting requested documents with no client proxy config needed.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 364,'pod' => 54,'pod_errors' => 0,'total' => 418,'with_comments' => 80},'releases' => 3,'size' => {'packed' => 5409,'unpacked' => 14909},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','HTML::TokeParser','HTTP::Cookies','LWP::UserAgent','strict','vars']},'Apache-RewritingProxy-0.7.tar.gz' => {'author' => 'HAGANK','description' => 'proxy that works by rewriting requested documents with no client proxy config needed.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 656,'pod' => 68,'pod_errors' => 0,'total' => 724,'with_comments' => 132},'releases' => 3,'size' => {'packed' => 10290,'unpacked' => 29692},'testers' => {'pass' => 1,'tests' => '0','unknown' => 3},'uses' => ['Apache::Constants','Apache::RewritingProxy','Apache::Util','CGI','HTML::TokeParser','HTTP::Cookies','LWP::UserAgent','strict','vars']},'Apache-Roaming-0.1003.tar.gz' => {'author' => 'JWIED','description' => 'A mod_perl handler for Roaming Profiles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 605,'pod' => 397,'pod_errors' => 0,'total' => 1002,'with_comments' => 86},'releases' => 4,'size' => {'packed' => 13898,'unpacked' => 57981},'testers' => {},'uses' => ['5.004','strict']},'Apache-SSI-2.17.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Implement server-side includes in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1182,'pod' => 344,'pod_errors' => 0,'total' => 1526,'with_comments' => 103},'releases' => 26,'requires' => ['HTML-SimpleParse-0.12.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => '1.00','HTML::SimpleParse' => '0.06'},'requires_recursive' => ['HTML-SimpleParse-0.12.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 25819,'unpacked' => 72164},'testers' => {'pass' => 1},'uses' => ['Apache::Constants','File::Basename','HTML::SimpleParse','POSIX','Symbol','strict','vars']},'Apache-Sandwich-2.05.tar.gz' => {'author' => 'VKHERA','description' => 'Layered document (sandwich) maker','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 112,'pod_errors' => 0,'total' => 231,'with_comments' => 23},'releases' => 6,'size' => {'packed' => 5016,'unpacked' => 14142},'testers' => {'fail' => 2,'pass' => 6},'uses' => ['5.004','Apache::Constants','strict','vars']},'Apache-Scoreboard-0.10.tar.gz' => {'author' => 'DOUGM','description' => 'Perl interface to the Apache scoreboard structure','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 312,'pod' => 208,'pod_errors' => 0,'total' => 520,'with_comments' => 1},'releases' => 9,'size' => {'packed' => 9115,'unpacked' => 28650},'testers' => {'fail' => 1,'pass' => 1,'tests' => '0','unknown' => 6},'uses' => ['GTop','LWP::UserAgent','constant','strict']},'Apache-SearchEngineLog-0.51.tar.gz' => {'author' => 'OCTO','description' => 'Logging of terms used in search engines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 379,'pod' => 56,'pod_errors' => 0,'total' => 435,'with_comments' => 96},'releases' => 8,'requires' => ['DBI-1.37.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 0,'DBI' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 14972,'unpacked' => 45354},'testers' => {'pass' => 3},'uses' => ['Apache','Apache::Log','DBI','strict','vars','warnings']},'Apache-SecSess-0.09.tgz' => {'author' => 'PLIAM','description' => 'Secure Apache session management library','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1832,'pod' => 343,'pod_errors' => 0,'total' => 2175,'with_comments' => 327},'releases' => 1,'requires' => ['Crypt-Rijndael-0.05.tar.gz','DBD-Pg-1.22.tar.gz','DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'Crypt::Rijndael' => '0.04','DBD::Pg' => 0,'DBI' => 0,'Digest::MD5' => 0,'IO::File' => 0,'MIME::Base64' => 0},'requires_recursive' => ['Crypt-Rijndael-0.05.tar.gz','DBD-Pg-1.22.tar.gz','DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 100281,'unpacked' => 315349},'testers' => {'pass' => 1},'uses' => ['Apache::Constants','Apache::Log','Apache::URI','Crypt::Rijndael','DBI','Digest::MD5','IO::File','MIME::Base64','strict','vars']},'Apache-Session-0.17.1.tar.gz' => {'author' => 'JBAKER','description' => 'Maintain session state across HTTP requests','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1627,'pod' => 437,'pod_errors' => 0,'total' => 2064,'with_comments' => 102},'releases' => 21,'requires' => ['MD5-2.02.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache' => 0,'MD5' => 0,'Tie::Hash' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','MD5-2.02.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18297,'unpacked' => 67266},'testers' => {'pass' => 1},'uses' => ['Apache::Session','Carp','DBI','FreezeThaw','IO::Select','IO::Socket','IPC::Shareable','MD5','POSIX','Storable','constant','strict','vars']},'Apache-Session-1.03.tar.gz' => {'author' => 'JBAKER','description' => 'A persistence framework for session data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1998,'pod' => 424,'pod_errors' => 0,'total' => 2422,'with_comments' => 183},'releases' => 21,'requires' => ['MD5-2.02.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'MD5' => 0,'Storable' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','MD5-2.02.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 17135,'unpacked' => 65131},'testers' => {'pass' => 5},'uses' => ['Apache::Session','Carp','DBI','Fcntl','File::CounterFile','File::Path','IO::Select','IO::Socket','IPC::Semaphore','IPC::SysV','MD5','POSIX','Storable','Symbol','strict','vars']},'Apache-Session-1.54.tar.gz' => {'author' => 'JBAKER','description' => 'A persistence framework for session data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2339,'pod' => 1220,'pod_errors' => 0,'total' => 3559,'with_comments' => 293},'releases' => 21,'size' => {'packed' => 27355,'unpacked' => 127605},'testers' => {'fail' => 10,'pass' => 17,'tests' => '100'},'uses' => ['Apache','CGI::Cookie','Carp','Config','DBI','DB_File','Digest::MD5','Fcntl','IPC::Semaphore','IPC::SysV','MIME::Base64','Storable','Symbol','strict','vars']},'Apache-Session-CacheAny-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'use Cache::* for Apache::Session storage','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 107,'pod_errors' => 0,'total' => 223,'with_comments' => 3},'releases' => 1,'requires' => ['Apache-Session-1.54.tar.gz','Cache-Cache-1.02.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Apache::Session' => '1.53','Cache::Cache' => '0.08','Test::More' => '0.18'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','Cache-Cache-1.02.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3316,'unpacked' => 9960},'testers' => {'pass' => 3},'uses' => ['Apache::Session','Apache::Session::Generate::MD5','Apache::Session::Lock::Null','Apache::Session::Serialize::Storable','strict','vars']},'Apache-Session-Counted-1.118.tar.gz' => {'author' => 'ANDK','description' => 'Session management via a File::CounterFile','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 373,'pod' => 117,'pod_errors' => 0,'total' => 490,'with_comments' => 29},'releases' => 7,'requires' => ['Apache-Session-1.54.tar.gz','File-CounterFile-1.00.tar.gz'],'requires_module' => {'Apache::Session' => '1.5','File::CounterFile' => 0},'requires_recursive' => ['Apache-Session-1.54.tar.gz','File-CounterFile-1.00.tar.gz'],'size' => {'packed' => 8366,'unpacked' => 21282},'testers' => {'pass' => 1},'uses' => ['Apache::Session','Apache::Session::Serialize::Storable','Dumpvalue','File::Basename','File::CounterFile','File::Path','HTTP::Request::Common','LWP::UserAgent','Symbol','strict','vars']},'Apache-Session-Generate-AutoIncrement-0.9.tar.gz' => {'author' => 'PFLEURY','description' => 'Use monotonically increasing IDs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 81,'pod' => 35,'pod_errors' => 0,'total' => 116,'with_comments' => 15},'releases' => 1,'requires' => ['Apache-Session-1.54.tar.gz','File-CounterFile-1.00.tar.gz'],'requires_module' => {'Apache::Session' => '1.54','File::CounterFile' => '0.12'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','File-CounterFile-1.00.tar.gz'],'size' => {'packed' => 2718,'unpacked' => 7414},'testers' => {'pass' => 3},'uses' => ['Carp','File::CounterFile','strict','vars']},'Apache-Session-Generate-ModUniqueId-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'use mod_unique_id for session ID generation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 28,'pod' => 30,'pod_errors' => 0,'total' => 58,'with_comments' => 0},'releases' => 2,'requires' => ['Apache-Session-1.54.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Apache::Session' => '1.53','Test::More' => 0},'requires_recursive' => ['Apache-Session-1.54.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1912,'unpacked' => 3916},'testers' => {'pass' => 5},'uses' => ['Carp','strict','vars']},'Apache-Session-Generate-ModUsertrack-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'uses mod_usertrack for session ID generation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 49,'pod_errors' => 0,'total' => 102,'with_comments' => 3},'releases' => 2,'requires' => ['Apache-Session-1.54.tar.gz','CGI.pm-2.98.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Apache::Session' => '1.53','CGI::Cookie' => 0,'Test::More' => '0.18'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2751,'unpacked' => 6654},'testers' => {'pass' => 6},'uses' => ['Apache','CGI::Cookie','Carp','strict','vars']},'Apache-Session-Lazy-0.05.tar.gz' => {'author' => 'GKAPUR','description' => 'Perl extension for opening Apache::Sessions on first read/write access.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 74,'pod_errors' => 0,'total' => 168,'with_comments' => 15},'releases' => 5,'requires' => ['Apache-Session-1.54.tar.gz'],'requires_module' => {'Apache::Session' => '0'},'requires_recursive' => ['Apache-Session-1.54.tar.gz'],'size' => {'packed' => 3292,'unpacked' => 7543},'testers' => {'pass' => 7},'uses' => ['5.006','strict','warnings']},'Apache-Session-Manager-0.03.tar.gz' => {'author' => 'DRTECH','description' => 'Perl wrapper around Apache::Session, to provide short term session management and long term user tracking, by cookie or URL.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 997,'pod' => 781,'pod_errors' => 0,'total' => 1778,'with_comments' => 289},'releases' => 2,'requires' => ['Apache-Session-1.54.tar.gz','Digest-MD5-2.26.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Cookie' => '1.0','Apache::Request' => '1.0','Apache::Session' => '1.54','Digest::MD5' => '2.20','mod_perl' => '1.27'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','Digest-MD5-2.26.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 20144,'unpacked' => 69977},'testers' => {'fail' => 1},'uses' => ['5.005','Data::Dumper','Digest::MD5','constant','strict','warnings','warnings::register']},'Apache-Session-PHP-0.04.tar.gz' => {'author' => 'MIYAGAWA','description' => 'glues Apache::Session with PHP::Session','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 131,'pod' => 92,'pod_errors' => 0,'total' => 223,'with_comments' => 0},'releases' => 3,'requires' => ['Apache-Session-1.54.tar.gz','PHP-Session-0.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Apache::Session' => '1.52','PHP::Session' => '0.06','Test::More' => '0.32'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','PHP-Session-0.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'size' => {'packed' => 2980,'unpacked' => 8519},'testers' => {'pass' => 3},'uses' => ['Apache::Session','Apache::Session::File','Apache::Session::Generate::MD5','Apache::Session::Lock::Null','Fcntl','IO::File','PHP::Session::Serializer::PHP','strict','vars']},'Apache-Session-SQLite-0.21.tar.gz' => {'author' => 'KOBAYASI','description' => 'use DBD::SQLite for Apache::Session storage','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 33,'pod_errors' => 0,'total' => 65,'with_comments' => 0},'releases' => 3,'requires' => ['Apache-Session-1.54.tar.gz','DBD-SQLite-0.25.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Apache::Session' => '1.53','DBD::SQLite' => '0.15','Test::More' => '0.32'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','DBD-SQLite-0.25.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1718,'unpacked' => 3099},'testers' => {'pass' => 4},'uses' => ['Apache::Session','Apache::Session::Generate::MD5','Apache::Session::Lock::Null','Apache::Session::Serialize::Base64','Apache::Session::Store::MySQL','strict','vars']},'Apache-Session-Serialize-Dumper-0.90.tar.gz' => {'author' => 'PFLEURY','description' => 'Use Data::Dumper to zip up persistent data','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 40,'pod' => 24,'pod_errors' => 0,'total' => 64,'with_comments' => 8},'releases' => 1,'requires' => ['Apache-Session-1.54.tar.gz','Data-Dumper-2.101.tar.gz'],'requires_module' => {'Apache::Session' => '1.54','Data::Dumper' => '2.101'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 1738,'unpacked' => 3537},'testers' => {'pass' => 2},'uses' => ['Data::Dumper','strict','vars']},'Apache-Session-Serialize-SOAPEnvelope-0.01.tar.gz' => {'author' => 'IKEBE','description' => 'serialize as SOAPEnvelope','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 30,'pod_errors' => 0,'total' => 59,'with_comments' => 0},'releases' => 1,'requires' => ['Apache-Session-1.54.tar.gz','SOAP-Lite-0.55.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Apache::Session' => '1.54','SOAP::Lite' => '0.55','Test::More' => '0.32'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','File-Spec-0.82.tar.gz','SOAP-Lite-0.55.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1506,'unpacked' => 2670},'testers' => {'fail' => 1,'pass' => 1,'tests' => '4'},'uses' => ['strict','vars']},'Apache-Session-Serialize-YAML-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'use YAML for serialization','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 28,'pod' => 32,'pod_errors' => 0,'total' => 60,'with_comments' => 0},'releases' => 2,'requires' => ['Apache-Session-1.54.tar.gz','Test-Simple-0.47.tar.gz','YAML-0.35.tar.gz'],'requires_module' => {'Apache::Session::Flex' => '1.01','Test::More' => '0.32','YAML' => '0.35'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','YAML-0.35.tar.gz'],'size' => {'packed' => 1594,'unpacked' => 2683},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Apache-Session-SharedMem-0.41.tar.gz' => {'author' => 'SIMONW','description' => 'Session management via shared memory','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 157,'pod' => 84,'pod_errors' => 0,'total' => 241,'with_comments' => 8},'releases' => 4,'requires' => ['Apache-Session-1.54.tar.gz','IPC-Cache-0.02.tar.gz'],'requires_module' => {'Apache::Session' => 0,'IPC::Cache' => 0},'requires_recursive' => ['Apache-Session-1.54.tar.gz','File-Spec-0.82.tar.gz','IPC-Cache-0.02.tar.gz','IPC-ShareLite-0.09.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3721,'unpacked' => 9500},'testers' => {'pass' => 5},'uses' => ['Apache::Session','Apache::Session::Generate::MD5','Apache::Session::Lock::Null','Apache::Session::Serialize::Storable','IPC::Cache','strict','vars']},'Apache-SessionManager-0.05.tar.gz' => {'author' => 'ENRYS','description' => 'Manage sessions over HTTP requests','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 696,'pod' => 1350,'pod_errors' => 0,'total' => 2046,'with_comments' => 55},'releases' => 5,'requires' => ['Apache-Session-1.54.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Session' => '1.54','mod_perl' => '1.24'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 20891,'unpacked' => 77596},'testers' => {'fail' => 1},'uses' => ['5.005','Apache::Constants','Apache::Cookie','Apache::Session::Flex','CGI::Cookie','strict','vars']},'Apache-SessionX-2.00b5.tar.gz' => {'author' => 'GRICHTER','description' => 'An extented persistence framework for session data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 789,'pod' => 157,'pod_errors' => 0,'total' => 946,'with_comments' => 81},'releases' => 1,'requires' => ['Apache-Session-1.54.tar.gz'],'requires_module' => {'Apache::Session' => '1.53'},'requires_recursive' => ['Apache-Session-1.54.tar.gz'],'size' => {'packed' => 11981,'unpacked' => 49184},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Apache::Session','Apache::Session::Store::File','Apache::SessionX::Config','Symbol','strict','vars']},'Apache-SetWWWTheme-1.06.tar.gz' => {'author' => 'CHOGAN','description' => 'Standard theme generation, including sidebars and navigation bars','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 832,'pod' => 280,'pod_errors' => 1,'total' => 1112,'with_comments' => 201},'releases' => 7,'requires' => ['HTML-WWWTheme-1.06.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => '0','HTML::WWWTheme' => '1.06'},'requires_recursive' => ['HTML-WWWTheme-1.06.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 25799,'unpacked' => 82074},'testers' => {'pass' => 1},'uses' => ['Apache::Constants','Carp','HTML::WWWTheme','strict','vars']},'Apache-SharedMem-0.09.tar.gz' => {'author' => 'RSOLIV','description' => 'Share data between Apache children prcesses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1167,'pod' => 347,'pod_errors' => 0,'total' => 1514,'with_comments' => 55},'releases' => 8,'requires' => ['Data-Dumper-2.101.tar.gz','IPC-ShareLite-0.09.tar.gz','IPC-SysV-1.03.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'Data::Dumper' => '2.101','IPC::ShareLite' => '0.06','IPC::SysV' => '1.03','Storable' => '1.006'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IPC-ShareLite-0.09.tar.gz','IPC-SysV-1.03.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 16546,'unpacked' => 67514},'testers' => {'fail' => 1,'pass' => 1,'tests' => '40'},'uses' => ['5.005','Apache','Carp','Data::Dumper','Exporter','IPC::ShareLite','IPC::SysV','Storable','constant','strict']},'Apache-SimpleReplace-0.06.tar.gz' => {'author' => 'GEOFF','description' => 'Simple replacement template tool','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 154,'pod' => 93,'pod_errors' => 0,'total' => 247,'with_comments' => 34},'releases' => 2,'size' => {'packed' => 3628,'unpacked' => 12299},'testers' => {'pass' => 5,'tests' => '0','unknown' => 3},'uses' => ['5.004','Apache::Constants','Apache::File','Apache::Log','strict']},'Apache-SimpleTemplate-0.05.tar.gz' => {'author' => 'FORTY','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 615,'pod' => 423,'pod_errors' => 0,'total' => 1038,'with_comments' => 110},'releases' => 5,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 1},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 10317,'unpacked' => 32131},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['strict']},'Apache-Singleton-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Singleton class for mod_perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 153,'pod' => 116,'pod_errors' => 0,'total' => 269,'with_comments' => 5},'releases' => 6,'requires' => ['Cache-Cache-1.02.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Cache::Cache' => '0.99','Test::More' => '0.32','mod_perl' => 0},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 3415,'unpacked' => 12016},'testers' => {},'uses' => ['Apache','Apache::Singleton','Apache::Singleton::Process','Apache::Singleton::Request','Cache::SharedMemoryCache','strict','vars']},'Apache-Singleton-0.06.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Singleton class for mod_perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 110,'pod' => 91,'pod_errors' => 0,'total' => 201,'with_comments' => 1},'releases' => 6,'requires' => ['Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Test::More' => '0.32','mod_perl' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 2935,'unpacked' => 9763},'testers' => {'pass' => 2},'uses' => ['Apache','strict','vars']},'Apache-Stage-1.20.tar.gz' => {'author' => 'ANDK','description' => 'Manage a document staging directory','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 79,'pod_errors' => 0,'total' => 143,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 3363,'unpacked' => 9405},'testers' => {'fail' => 2,'pass' => 6},'uses' => ['Apache::Constants','URI::URL','strict','vars']},'Apache-StickyQuery-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'rewrites links using sticky query','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 54,'pod_errors' => 0,'total' => 126,'with_comments' => 2},'releases' => 2,'requires' => ['Apache-Filter-1.022.tar.gz','HTML-StickyQuery-0.11.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Filter' => 0,'HTML::StickyQuery' => '0.03','Test::More' => 0,'mod_perl' => '1.21'},'requires_recursive' => ['Apache-Filter-1.022.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-StickyQuery-0.11.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 2328,'unpacked' => 5511},'testers' => {},'uses' => ['Apache::Constants','Apache::File','HTML::StickyQuery','strict','vars']},'Apache-Storage-1.1.tar.gz' => {'author' => 'KROW','description' => 'Storing data in Apache.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 113,'pod_errors' => 0,'total' => 233,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 4148,'unpacked' => 11036},'testers' => {'pass' => 4},'uses' => ['Apache::Constants','Apache::ModuleConfig','AutoLoader','DynaLoader','Exporter','strict','vars']},'Apache-SubProcess-0.03.tar.gz' => {'author' => 'DOUGM','description' => 'Interface to Apache subprocess API','files' => ['Makefile.PL'],'lines' => {'nonpod' => 54,'pod' => 0,'pod_errors' => 0,'total' => 54,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 2675,'unpacked' => 5378},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['strict']},'Apache-Sybase-CTlib-1.02.tar.gz' => {'author' => 'MDOWNING','description' => 'Persistent CTlib connection mgmt for Apache','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 37,'pod_errors' => 0,'total' => 94,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 1945,'unpacked' => 3502},'testers' => {'pass' => 5},'uses' => ['Exporter','Sybase::CTlib','strict','vars']},'Apache-Sybase-ConPool-1.00.tar.gz' => {'author' => 'MEWP','description' => 'A Sybase connection pooling module for Apache/mod_perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 265,'pod' => 65,'pod_errors' => 0,'total' => 330,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 4185,'unpacked' => 9972},'testers' => {},'uses' => ['Carp','IPC::Semaphore','IPC::SysV','Sybase::CTlib','Sys::Hostname','strict','vars']},'Apache-TaintRequest-0.10.tar.gz' => {'author' => 'LINDNER','description' => 'HTML Escape tainted data to prevent CSS Attacks','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 62,'pod' => 64,'pod_errors' => 0,'total' => 126,'with_comments' => 2},'releases' => 1,'requires' => ['Taint-0.09.tar.gz'],'requires_module' => {'Taint' => '0.09'},'requires_recursive' => ['Taint-0.09.tar.gz'],'size' => {'packed' => 2056,'unpacked' => 3629},'testers' => {'fail' => 1},'uses' => ['Apache','Apache::Util','Taint','strict','warnings']},'Apache-TempFile-0.05.tar.gz' => {'author' => 'TOMHUGHES','description' => 'Manage temporary files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 68,'pod' => 36,'pod_errors' => 0,'total' => 104,'with_comments' => 7},'releases' => 3,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 0},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 2038,'unpacked' => 4125},'testers' => {'pass' => 3},'uses' => ['Apache','Carp','Exporter','strict']},'Apache-Template-0.06.tar.gz' => {'author' => 'ABW','description' => 'Apache interface to the Template Toolkit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 908,'pod' => 363,'pod_errors' => 0,'total' => 1271,'with_comments' => 252},'releases' => 3,'requires' => ['Digest-MD5-2.26.tar.gz','Template-Toolkit-2.10.tar.gz'],'requires_module' => {'Digest::MD5' => '2.09','Template' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','Template-Toolkit-2.10.tar.gz'],'size' => {'packed' => 16454,'unpacked' => 63482},'testers' => {'pass' => 1},'uses' => ['','5.004','Apache::Constants','Apache::Request','Apache::Util','Digest::MD5','Template::Config','Template::Constants','Template::Exception','Template::Service','strict','vars']},'Apache-Test-1.01.tar.gz' => {'author' => 'STAS','description' => 'Test.pm wrapper with helpers for testing Apache','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 8642,'pod' => 775,'pod_errors' => 1,'total' => 9417,'with_comments' => 671},'releases' => 3,'size' => {'packed' => 75870,'unpacked' => 247566},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['$_::apache_test_config','APR::Pool','APR::UUID','Apache2','Apache::Build','Apache::RequestRec','Apache::Test','Apache::TestClient','Apache::TestConfig','Apache::TestRequest','Apache::TestTrace','Apache::TestUtil','Carp','Config','Cwd','Data::Dumper','Digest::MD5','Exporter','File::Basename','File::Copy','File::Find','File::Path','File::Spec::Functions','FindBin','Getopt::Long','HTTP::Request::Common','IO::Socket','Inline','LWP::Debug','LWP::Protocol::http','LWP::Protocol::https','LWP::UserAgent','Net::SSL','POSIX','Test','Win32::Process','blib','constant','lib','strict','subs','vars','warnings']},'Apache-Test-1.03.tar.gz' => {'author' => 'STAS','description' => undef,'files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 8746,'pod' => 820,'pod_errors' => 1,'total' => 9566,'with_comments' => 684},'releases' => 3,'size' => {'packed' => 80048,'unpacked' => 259278},'testers' => {'fail' => 3,'pass' => 1},'uses' => ['$_::apache_test_config','APR::Pool','APR::UUID','Apache2','Apache::Build','Apache::RequestRec','Apache::TestSSLCA','Carp','Config','Cwd','Data::Dumper','Digest::MD5','Exporter','File::Basename','File::Copy','File::Find','File::Path','File::Spec::Functions','FindBin','Getopt::Long','HTTP::Request::Common','IO::Socket','Inline','LWP::Debug','LWP::Protocol::http','LWP::Protocol::https','LWP::UserAgent','Net::SSL','POSIX','Test','Win32::Process','blib','constant','lib','strict','subs','vars','warnings']},'Apache-Throttle-0.03.tar.gz' => {'author' => 'DONS','description' => 'Apache/Perl module for speed-based content negotiation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 311,'pod' => 133,'pod_errors' => 0,'total' => 444,'with_comments' => 6},'releases' => 3,'requires' => ['IPC-Shareable-0.60.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '0','IPC::Shareable' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IPC-Shareable-0.60.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 8375,'unpacked' => 22791},'testers' => {'pass' => 2},'uses' => ['Apache','Apache::Constants','Apache::URI','IPC::Shareable','Time::HiRes','strict','vars']},'Apache-TimedRedirect-0.13.tar.gz' => {'author' => 'PETERM','description' => 'Redirect urls for a given time period','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 68,'pod' => 52,'pod_errors' => 0,'total' => 120,'with_comments' => 12},'releases' => 2,'requires' => ['Period-1.20.tar.gz'],'requires_module' => {'Time::Period' => '1.20'},'requires_recursive' => ['Period-1.20.tar.gz'],'size' => {'packed' => 2949,'unpacked' => 5771},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['Apache::Constants','Exporter','Time::Period','strict','vars']},'Apache-Traffic-1.02.tar.gz' => {'author' => 'MAURICE','description' => 'Logs bytes transferred, per-user basis','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 266,'pod' => 221,'pod_errors' => 0,'total' => 487,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 9570,'unpacked' => 25265},'testers' => {'fail' => 2},'uses' => ['5.004','Apache::Constants','AutoLoader','DB_File','Exporter','IPC::Shareable','IPC::SysV','Storable','Time::Local','constant','strict','vars']},'Apache-TransLDAP-0.20.tar.gz' => {'author' => 'CDONLEY','description' => 'Translate URIs to LDAP queries','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 113,'pod' => 33,'pod_errors' => 0,'total' => 146,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 2424,'unpacked' => 5133},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Apache::Constants','AutoLoader','Exporter','Net::LDAPapi','strict','vars']},'Apache-UploadMeter-0.22.tar.gz' => {'author' => 'ISAAC','description' => 'Provides GUI progress meter for HTTP uploads','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 348,'pod' => 63,'pod_errors' => 0,'total' => 411,'with_comments' => 40},'releases' => 3,'requires' => ['Apache-SSI-2.17.tar.gz','Cache-Cache-1.02.tar.gz','Number-Format-1.45.tar.gz','TimeDate-1.16.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '0.01','Apache::Request' => '0.33','Apache::SSI' => '2.16','Cache::Cache' => '0.09','Date::Format' => '0.01','Number::Format' => '0.01'},'requires_recursive' => ['Apache-SSI-2.17.tar.gz','Cache-Cache-1.02.tar.gz','HTML-SimpleParse-0.12.tar.gz','Number-Format-1.45.tar.gz','TimeDate-1.16.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 7318,'unpacked' => 19528},'testers' => {},'uses' => ['Apache::Constants','Apache::Request','Apache::SSI','Apache::Util','Cache::FileCache','Digest::MD5','strict','vars','warnings']},'Apache-UploadSvr-1.024.tar.gz' => {'author' => 'ANDK','description' => 'A Lightweight Publishing System for Apache','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1247,'pod' => 133,'pod_errors' => 0,'total' => 1380,'with_comments' => 59},'releases' => 2,'requires' => ['Apache-Stage-1.20.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Apache::Stage' => 0,'LWP' => 0},'requires_recursive' => ['Apache-Stage-1.20.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18988,'unpacked' => 54947},'testers' => {'pass' => 5},'uses' => ['Apache::Constants','CGI','Cwd','DBI','Data::Dumper','DirHandle','ExtUtils::Manifest','File::Basename','File::Find','File::Path','HTML::LinkExtor','HTML::Parse','HTTP::Date','IO::File','Image::Magick','Mail::Send','URI::URL','strict','vars']},'Apache-Usertrack-0.03.tar.gz' => {'author' => 'ABH','description' => 'Perl version of mod_usertrack','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 49,'pod' => 37,'pod_errors' => 0,'total' => 86,'with_comments' => 1},'releases' => 2,'requires' => ['Time-HiRes-1.49.tar.gz'],'requires_module' => {'Time::HiRes' => 0},'requires_recursive' => ['Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 2144,'unpacked' => 3678},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['Apache::Constants','Time::HiRes','integer','strict']},'Apache-VMonitor-0.8.tar.gz' => {'author' => 'STAS','description' => 'Visual System and Processes Monitor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1295,'pod' => 269,'pod_errors' => 0,'total' => 1564,'with_comments' => 215},'releases' => 8,'size' => {'packed' => 18209,'unpacked' => 64373},'testers' => {},'uses' => ['Apache::Constants','Data::Dumper','constant','strict']},'Apache-WAP-AutoIndex-0.01.tar.gz' => {'author' => 'DBRIAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 37,'pod' => 0,'pod_errors' => 0,'total' => 37,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 7150,'unpacked' => 20096},'testers' => {'fail' => 2},'uses' => ['Apache::Constants','CGI::WML','strict']},'Apache-WAP-MailPeek-0.01.tar.gz' => {'author' => 'DBRIAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 58,'pod' => 0,'pod_errors' => 0,'total' => 58,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 7889,'unpacked' => 21808},'testers' => {'fail' => 2},'uses' => ['Apache::Constants','Mail::Cclient','strict']},'Apache-Watchdog-RunAway-0.3.tar.gz' => {'author' => 'STAS','description' => 'RunAway processes watchdog/terminator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 288,'pod' => 180,'pod_errors' => 0,'total' => 468,'with_comments' => 46},'releases' => 2,'size' => {'packed' => 7722,'unpacked' => 24981},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['strict','subs']},'Apache-WebSNMP-0.11.tar.gz' => {'author' => 'RIGBYC','description' => 'Allows for SNMP calls to be embedded in HTML','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 336,'pod' => 255,'pod_errors' => 0,'total' => 591,'with_comments' => 57},'releases' => 1,'size' => {'packed' => 6268,'unpacked' => 24412},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Apache::Constants','SNMP','strict']},'Apache-WinBitHack-0.01.tar.gz' => {'author' => 'RKOBES','description' => 'An Apache module to emulate XBitHack on Win32','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 72,'pod_errors' => 0,'total' => 202,'with_comments' => 16},'releases' => 1,'requires' => ['mod_perl-1.28.tar.gz'],'requires_module' => {'mod_perl' => '1.2601'},'requires_recursive' => ['mod_perl-1.28.tar.gz'],'size' => {'packed' => 3823,'unpacked' => 10618},'testers' => {},'uses' => ['5.006','Apache::Constants','Apache::File','Apache::ModuleConfig','DynaLoader','Win32::File','strict']},'Apache-Wombat-0.5.1.tar.gz' => {'author' => 'IX','description' => 'embed Wombat within an Apache/mod_perl server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1569,'pod' => 918,'pod_errors' => 0,'total' => 2487,'with_comments' => 62},'releases' => 1,'requires' => ['Cache-Cache-1.02.tar.gz','IPC-ShareLite-0.09.tar.gz','Wombat-0.7.1.tar.gz','libapreq-1.2.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 0,'Apache::Request' => 0,'Apache::Util' => 0,'Cache::SharedMemoryCache' => 0,'IPC::ShareLite' => 0,'Wombat' => '0.7.1'},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Devel-StackTrace-1.03.tar.gz','Digest-1.02.tar.gz','Digest-MD5-2.26.tar.gz','Exception-Class-1.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IPC-ShareLite-0.09.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','Wombat-0.7.1.tar.gz','XML-Parser-2.31.tar.gz','libapreq-1.2.tar.gz','libnet-1.16.tar.gz','libservlet-0.9.2.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 23425,'unpacked' => 102139},'testers' => {},'uses' => ['Wombat','Wombat::Connector','Wombat::Connector::HttpRequestBase','Wombat::Connector::HttpResponseBase','Wombat::Logger::LoggerBase','fields','strict','warnings']},'Apache-XBEL-1.2.1.tar.gz' => {'author' => 'ASCOPE','description' => 'mod_perl to transform XBEL into exciting and fooy HTML documents.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 473,'pod' => 78,'pod_errors' => 0,'total' => 551,'with_comments' => 66},'releases' => 1,'requires' => ['Digest-MD5-2.26.tar.gz','XML-Generator-0.93.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-XPath-1.13.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache' => '1.26','Cwd' => 0,'Digest::MD5' => '1.0','File::Basename' => 0,'XML::Generator' => '0.91','XML::LibXML' => '1.51','XML::LibXSLT' => '1.31','XML::XPath' => '1.12'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-Generator-0.93.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-SAX-0.12.tar.gz','XML-XPath-1.13.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8465,'unpacked' => 27760},'testers' => {},'uses' => ['Apache::Constants','Apache::File','Apache::Log','Apache::URI','Digest::MD5','File::Basename','FileHandle','XML::Generator','XML::LibXML','XML::LibXSLT','XML::XPath','strict']},'Apache-XPP-2.02.tar.gz' => {'author' => 'CNATION','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1760,'pod' => 1067,'pod_errors' => 0,'total' => 2827,'with_comments' => 191},'releases' => 3,'requires' => ['libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 0,'HTTP::Request' => 0,'LWP' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 33164,'unpacked' => 102860},'testers' => {'pass' => 3},'uses' => ['Apache::Constants','Carp','Data::Dumper','File::stat','FileHandle','Filter::Util::Call','HTTP::Request','LWP::UserAgent','strict','vars']},'Apache-iNcom-0.09.tar.gz' => {'author' => 'FRAJULAC','description' => 'An e-commerce framework.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5143,'pod' => 1994,'pod_errors' => 0,'total' => 7137,'with_comments' => 568},'releases' => 2,'requires' => ['Apache-Session-1.54.tar.gz','DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','Embperl-2.0b9.tar.gz','Storable-2.07.tar.gz','libapreq-1.2.tar.gz'],'requires_module' => {'Apache::Request' => 0,'Apache::Session' => '1.03','DBI' => '1.13','Digest::MD5' => 0,'HTML::Embperl' => '1.2','Storable' => 0},'requires_recursive' => ['Apache-Session-1.54.tar.gz','DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','Embperl-2.0b9.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','libapreq-1.2.tar.gz'],'size' => {'packed' => 65775,'unpacked' => 235728},'testers' => {},'uses' => ['5.005','Apache','Apache::Constants','Apache::Cookie','Apache::File','Apache::Log','Apache::Request','Apache::Session','Apache::Util','Carp','DBI','Digest::MD5','Exporter','File::Basename','HTML::Embperl','I18N::LangTags','MIME::Base64','Storable','Symbol','constant','strict','vars']},'Apache-iTunes-0.06.tar.gz' => {'author' => 'BDFOY','description' => 'mod_perl interface to iTunes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 105,'pod_errors' => 0,'total' => 200,'with_comments' => 3},'releases' => 2,'requires' => ['File-Find-Rule-0.10.tar.gz','Mac-AppleScript-0.04.tar.gz','Mac-iTunes-0.82.tar.gz','Test-Data-0.92.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Template-1.44.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => '0','Apache::FakeRequest' => '0','Apache::Util' => '0','File::Find::Rule' => '0','Mac::AppleScript' => '0','Mac::iTunes' => '0','Test::Data' => '0','Test::More' => '0','Test::Pod' => '0','Test::Prereq' => '0.05','Text::Template' => '0'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MP3-Info-1.02.tar.gz','Mac-AppleScript-0.04.tar.gz','Mac-Path-Util-0.09.tar.gz','Mac-PropertyList-0.1.tar.gz','Mac-iTunes-0.82.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Data-0.92.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Text-Template-1.44.tar.gz','Time-HiRes-1.49.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3776,'unpacked' => 8668},'testers' => {},'uses' => ['Apache::Constants','Apache::Util','Mac::iTunes','Text::Template','strict','vars']},'Apache-mod_perl_guide-1.31.tar.gz' => {'author' => 'STAS','description' => 'The mod_perl Guide','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13679,'pod' => 22250,'pod_errors' => 54,'total' => 35929,'with_comments' => 369},'releases' => 12,'size' => {'packed' => 472182,'unpacked' => 1365317},'testers' => {'fail' => 2,'tests' => '0','unknown' => 6},'uses' => ['5.004','Carp','DBI','Fcntl','constant','strict','vars']},'ApacheBench-0.62.tar.gz' => {'author' => 'ADIRAJ','description' => 'Perl API for Apache benchmarking and regression testing.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 842,'pod' => 669,'pod_errors' => 0,'total' => 1511,'with_comments' => 42},'releases' => 6,'size' => {'packed' => 61627,'unpacked' => 237874},'testers' => {'fail' => 2,'pass' => 2,'tests' => '39'},'uses' => ['DynaLoader','HTTPD::Bench::ApacheBench::Regression','HTTPD::Bench::ApacheBench::Run','strict','vars']},'ApacheCookieEncrypted-0.03.tar.gz' => {'author' => 'JKRASNOO','description' => 'Cookies with value auto encrypted/decrypted','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 207,'pod' => 136,'pod_errors' => 0,'total' => 343,'with_comments' => 14},'releases' => 2,'requires' => ['Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','libapreq-1.2.tar.gz'],'requires_module' => {'Apache::Cookie' => '0.01','Crypt::Blowfish' => '2.06','Crypt::CBC' => '1.25'},'requires_recursive' => ['Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Digest-MD5-2.26.tar.gz','libapreq-1.2.tar.gz'],'size' => {'packed' => 3813,'unpacked' => 9675},'testers' => {'pass' => 2,'tests' => '0','unknown' => 6},'uses' => ['Apache','Apache::Cookie','Carp','Crypt::CBC','strict','vars','warnings']},'ApacheMysql-0.3.tar.gz' => {'author' => 'NJENSEN','description' => 'Persistent connection mgmt. for Mysql','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 29,'pod_errors' => 0,'total' => 72,'with_comments' => 3},'releases' => 4,'size' => {'packed' => 1934,'unpacked' => 3714},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['strict']},'App-Context-0.01.tar.gz' => {'author' => 'SPADKINS','description' => 'Backplane for core App services','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5088,'pod' => 5049,'pod_errors' => 0,'total' => 10137,'with_comments' => 978},'releases' => 1,'requires' => ['Class-Data-Inheritable-0.02.tar.gz','Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','Devel-StackTrace-1.03.tar.gz','Exception-Class-1.14.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz','TimeDate-1.16.tar.gz'],'requires_module' => {'Class::Data::Inheritable' => 0,'Compress::Zlib' => 0,'Data::Dumper' => 0,'Date::Format' => 0,'Date::Parse' => 0,'Devel::StackTrace' => 0,'Exception::Class' => 0,'MIME::Base64' => '2.1','Storable' => 0},'requires_recursive' => ['Class-Data-Inheritable-0.02.tar.gz','Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','Devel-StackTrace-1.03.tar.gz','Exception-Class-1.14.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz'],'size' => {'packed' => 76622,'unpacked' => 317558},'testers' => {'fail' => 1},'uses' => ['App::UserAgent','Compress::Zlib','Crypt::CBC','Data::Dumper','Date::Format','Digest::HMAC_MD5','Exception::Class','MIME::Base64','Storable','XML::Dumper','XML::Parser','XML::Simple','strict','vars']},'App-Control-1.01.tar.gz' => {'author' => 'AWRIGLEY','description' => 'Perl module for apachectl style control of another script or executable','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 251,'pod' => 125,'pod_errors' => 0,'total' => 376,'with_comments' => 1},'releases' => 4,'size' => {'packed' => 4553,'unpacked' => 13580},'testers' => {'pass' => 6},'uses' => ['File::Basename','File::Path','strict','vars','warnings']},'App-Info-0.23.tar.gz' => {'author' => 'DWHEELER','description' => 'Information about software packages on a system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3336,'pod' => 3131,'pod_errors' => 0,'total' => 6467,'with_comments' => 345},'releases' => 11,'requires' => ['File-Spec-0.82.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Spec' => 0,'Test::Simple' => '0.17'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 50602,'unpacked' => 243893},'testers' => {'pass' => 17},'uses' => ['Config','strict','vars']},'App-Manager-0.03.tar.gz' => {'author' => 'MLEHMANN','description' => 'Installing/Managing/Uninstalling Software','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 382,'pod' => 21,'pod_errors' => 0,'total' => 403,'with_comments' => 12},'releases' => 3,'requires' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'File::Spec' => '0.7','Storable' => '0.6'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 16951,'unpacked' => 46034},'testers' => {'fail' => 3,'pass' => 1},'uses' => ['Carp','Cwd','DynaLoader','Exporter','Fcntl','File::Basename','File::Compare','File::Copy','File::Spec','IO::Socket::UNIX','POSIX','Storable','strict','subs']},'App-Packer-0.12.tar.gz' => {'author' => 'MBARBON','description' => 'pack applications in a single executable file','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 998,'pod' => 250,'pod_errors' => 0,'total' => 1248,'with_comments' => 93},'releases' => 9,'requires' => ['Config-IniFiles-2.38.tar.gz','Memoize-1.01.tar.gz','Module-Info-0.20.tar.gz','Test-Harness-2.29.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Config::IniFiles' => 2,'File::Spec::Functions' => '0.01','Memoize' => '0.01','Module::Info' => '0.15','Test::Harness::Straps' => '0.14'},'requires_recursive' => ['Config-IniFiles-2.38.tar.gz','File-Spec-0.82.tar.gz','Memoize-1.01.tar.gz','Module-Info-0.20.tar.gz','Test-Harness-2.29.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 24974,'unpacked' => 83376},'testers' => {'pass' => 4},'uses' => ['5.006','Compress::Zlib','Config','Config::IniFiles','Fcntl','File::Basename','File::Copy','File::Path','File::Spec::Functions','File::stat','Memoize','Module::Info','strict','vars']},'AppConfig-1.55.tar.gz' => {'author' => 'ABW','description' => 'Perl5 module for reading configuration files and parsing command line arguments.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2701,'pod' => 1501,'pod_errors' => 0,'total' => 4202,'with_comments' => 833},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 45687,'unpacked' => 177267},'testers' => {'pass' => 5},'uses' => ['','5.004','5.005','Exporter','Getopt::Long','constant','strict','vars']},'AppConfig-MyFile-0.00.tar.gz' => {'author' => 'ABW','description' => 'Perl5 module for reading configuration files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 203,'pod' => 47,'pod_errors' => 0,'total' => 250,'with_comments' => 83},'releases' => 1,'requires' => ['AppConfig-1.55.tar.gz'],'requires_module' => {'AppConfig' => '1.52'},'requires_recursive' => ['AppConfig-1.55.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2996,'unpacked' => 7670},'testers' => {'pass' => 3},'uses' => ['5.004','AppConfig','AppConfig::State','strict','vars']},'AppConfig-Std-1.07.tar.gz' => {'author' => 'NEILB','description' => 'Provides standard configuration options','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 141,'pod_errors' => 0,'total' => 379,'with_comments' => 89},'releases' => 5,'requires' => ['AppConfig-1.55.tar.gz','PodParser-1.23.tar.gz'],'requires_module' => {'AppConfig' => '1.52','Pod::Usage' => '1.14'},'requires_recursive' => ['AppConfig-1.55.tar.gz','File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6140,'unpacked' => 21916},'testers' => {'pass' => 13},'uses' => ['AppConfig','strict']},'Ar-0.2alpha.tar.gz' => {'author' => 'RIK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 336,'pod' => 258,'pod_errors' => 1,'total' => 594,'with_comments' => 27},'releases' => 1,'size' => {'packed' => 7772,'unpacked' => 30989},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter']},'Archive-Any-0.03.tar.gz' => {'author' => 'MSCHWERN','description' => 'Single interface to deal with zips and tarballs','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 120,'pod_errors' => 0,'total' => 325,'with_comments' => 7},'releases' => 2,'requires' => ['Archive-Tar-1.03.tar.gz','Archive-Zip-1.06.tar.gz','Class-Virtual-0.03.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Archive::Tar' => '0.22','Archive::Zip' => '0.11','Class::Virtually::Abstract' => '0.02','Cwd' => 0,'File::Spec::Functions' => 0,'Test::More' => '0.11'},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','Archive-Zip-1.06.tar.gz','Carp-Assert-0.17.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-ISA-0.32.tar.gz','Class-Virtual-0.03.tar.gz','Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 53482,'unpacked' => 60637},'testers' => {'fail' => 1,'pass' => 8,'tests' => '49'},'uses' => ['Archive::Tar','Archive::Zip','Class::Virtually::Abstract','Cwd','File::Spec::Functions','strict','vars']},'Archive-Builder-0.8.tar.gz' => {'author' => 'ADAMK','description' => 'File generation and archiving framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1164,'pod' => 501,'pod_errors' => 0,'total' => 1665,'with_comments' => 192},'releases' => 6,'requires' => ['Class-Autouse-0.7.tar.gz','Class-Handle-0.4.tar.gz','Class-Inspector-1.tar.gz','File-Flat-0.8.tar.gz','File-Spec-0.82.tar.gz','IO-Zlib-1.01.tar.gz','IO-stringy-2.108.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Autouse' => '0.7','Class::Handle' => 0,'Class::Inspector' => 1,'File::Flat' => '0.6','File::Spec' => '0.83','IO::Scalar' => '2.104','IO::Zlib' => 0,'List::Util' => 0,'Scalar::Util' => '1.11','Test::More' => 0},'requires_recursive' => ['Class-Autouse-0.7.tar.gz','Class-Handle-0.4.tar.gz','Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','Compress-Zlib-1.22.tar.gz','File-Flat-0.8.tar.gz','File-NCopy0.32.tar.gz','File-Remove0.20.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','IO-Zlib-1.01.tar.gz','IO-stringy-2.108.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 33163,'unpacked' => 121802},'testers' => {},'uses' => ['5.005','Class::Autouse','Scalar::Util','UNIVERSAL','strict','vars']},'Archive-Ipkg-0.02.tar.gz' => {'author' => 'CRENZ','description' => 'Module for manipulation of iPKG archives','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 475,'pod' => 192,'pod_errors' => 0,'total' => 667,'with_comments' => 19},'releases' => 2,'requires' => ['Archive-Tar-1.03.tar.gz','Compress-Zlib-1.22.tar.gz'],'requires_module' => {'Archive::Tar' => '0.072','Compress::Zlib' => 0},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','Compress-Zlib-1.22.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7320,'unpacked' => 24710},'testers' => {'pass' => 3},'uses' => ['Archive::Tar','Carp','Compress::Zlib','lib','strict','warnings']},'Archive-Par-1.01.tar.gz' => {'author' => 'FLUFFY','description' => 'use & manipulate par files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1172,'pod' => 760,'pod_errors' => 0,'total' => 1932,'with_comments' => 158},'releases' => 2,'size' => {'packed' => 241775,'unpacked' => 688328},'testers' => {},'uses' => ['','5.005_62','Carp','Class::MethodMaker','Config','Env','Exporter','ExtUtils::MakeMaker','Fatal','Fcntl','File::Basename','File::Compare','File::Path','File::Spec::Functions','File::Temp','FindBin','IPC::Run','Log::Info','Test','constant','happy','strict','warnings']},'Archive-Parity-0.06.tar.gz' => {'author' => 'FGLOCK','description' => 'makes parity file, recover files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 38,'pod_errors' => 0,'total' => 176,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 2643,'unpacked' => 6725},'testers' => {'pass' => 10},'uses' => ['Exporter','strict','vars']},'Archive-Rar-1.9.tar.gz' => {'author' => 'JMBO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 561,'pod' => 99,'pod_errors' => 0,'total' => 660,'with_comments' => 96},'releases' => 1,'size' => {'packed' => 7438,'unpacked' => 22271},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['5.002','Cwd','Data::Dumper','Exporter','File::Path','Win32::Registry']},'Archive-Tar-0.23.tgz' => {'author' => 'KANE','description' => 'module for manipulation of tar archives.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1682,'pod' => 351,'pod_errors' => 0,'total' => 2033,'with_comments' => 202},'releases' => 11,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 17614,'unpacked' => 59512},'testers' => {'pass' => 13},'uses' => ['Carp','Compress::Zlib','Cwd','Exporter','Fcntl','File::Basename','Symbol','strict','vars']},'Archive-Tar-1.03.tar.gz' => {'author' => 'KANE','description' => 'Read, write and manipulate tar files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1277,'pod' => 418,'pod_errors' => 0,'total' => 1695,'with_comments' => 121},'releases' => 11,'requires' => ['File-Spec-0.82.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Spec' => '0.82','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 20993,'unpacked' => 84321},'testers' => {'pass' => 4},'uses' => ['5.005_03','Carp','Cwd','Exporter','FileHandle','IO::File','constant','strict','vars']},'Archive-Zip-1.06.tar.gz' => {'author' => 'NEDKONZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3928,'pod' => 1196,'pod_errors' => 0,'total' => 5124,'with_comments' => 543},'releases' => 16,'requires' => ['Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Compress::Zlib' => '1.14','Data::Dumper' => 0,'File::Basename' => 0,'File::Copy' => 0,'File::Find' => 0,'File::Path' => 0,'File::Spec' => '0.8','Getopt::Std' => 0,'IO::File' => 0,'IO::Handle' => 0,'IO::Seekable' => 0,'Time::Local' => 0},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 74587,'unpacked' => 271515},'testers' => {'pass' => 3},'uses' => ['5.003_96','Carp','Compress::Zlib','Cwd','File::Basename','File::Path','IO::File','constant','strict','vars']},'Arguments-0.2.tar.gz' => {'author' => 'BINKLEY','description' => 'Perl subroutine type-checking','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 292,'pod' => 151,'pod_errors' => 0,'total' => 443,'with_comments' => 39},'releases' => 1,'size' => {'packed' => 6488,'unpacked' => 18849},'testers' => {'pass' => 2},'uses' => ['constant','strict','vars','warnings']},'Argv-1.10.tar.gz' => {'author' => 'DSB','description' => 'Provide an OO interface to an ARGV','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1234,'pod' => 499,'pod_errors' => 0,'total' => 1733,'with_comments' => 112},'releases' => 28,'requires' => ['Getopt-Long-2.33.tar.gz'],'requires_module' => {'Getopt::Long' => '2.23'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 34713,'unpacked' => 102483},'testers' => {'pass' => 1},'uses' => ['Carp','Data::Dumper','Exporter','Getopt::Long','Storable','strict','vars']},'Array-Autojoin-0.02.tar.gz' => {'author' => 'SBURKE','description' => '- arrayrefs that stringify as join(", ", @$it)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 88,'pod_errors' => 0,'total' => 152,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 4061,'unpacked' => 8747},'testers' => {'pass' => 7},'uses' => ['5','Exporter','strict','vars']},'Array-Compare-1.03.tar.gz' => {'author' => 'DAVECROSS','description' => 'Class to compare two arrays','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 350,'pod' => 135,'pod_errors' => 0,'total' => 485,'with_comments' => 152},'releases' => 4,'size' => {'packed' => 7426,'unpacked' => 20378},'testers' => {'pass' => 37},'uses' => ['Carp','Exporter','strict','vars']},'Array-Dissect-1.00.tar.gz' => {'author' => 'KILINRAX','description' => 'Convert an array into N-sized array of arrays','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 44,'pod' => 29,'pod_errors' => 0,'total' => 73,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 2103,'unpacked' => 3538},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','strict','vars']},'Array-FileReader-0.01.tar.gz' => {'author' => 'SIMON','description' => 'Lazily tie files to arrays for reading','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 80,'pod' => 35,'pod_errors' => 0,'total' => 115,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 2172,'unpacked' => 3845},'testers' => {'pass' => 10},'uses' => ['Carp','DynaLoader','Exporter','IO::File','Tie::Array','strict','vars']},'Array-IntSpan-1.01.tar.gz' => {'author' => 'TEVERETT','description' => 'a Module for handling arrays using IntSpan techniques','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 275,'pod' => 113,'pod_errors' => 0,'total' => 388,'with_comments' => 50},'releases' => 1,'size' => {'packed' => 5420,'unpacked' => 16713},'testers' => {'pass' => 15},'uses' => ['Carp','strict','vars']},'Array-Lookup-2.1.tar.gz' => {'author' => 'AKSTE','description' => 'Lookup strings in arrays or hash tables with abbreviation.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 84,'pod' => 96,'pod_errors' => 0,'total' => 180,'with_comments' => 15},'releases' => 3,'size' => {'packed' => 13449,'unpacked' => 58179},'testers' => {'fail' => 5,'pass' => 1},'uses' => ['Array::PrintCols','Carp']},'Array-PatternMatcher-0.04.tar.gz' => {'author' => 'TBONE','description' => 'Pattern matching for arrays.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 412,'pod' => 314,'pod_errors' => 0,'total' => 726,'with_comments' => 20},'releases' => 4,'requires' => ['Carp-Datum-0.1.3.tar.gz'],'requires_module' => {'Carp::Datum' => '0.1'},'requires_recursive' => ['Carp-Datum-0.1.3.tar.gz','Getargs-Long-0.1.3.tar.gz','Log-Agent-0.304.tar.gz'],'size' => {'packed' => 6240,'unpacked' => 23963},'testers' => {'pass' => 3},'uses' => ['5.005_62','Carp::Datum','Data::Dumper','Exporter','Storable','diagnostics','strict','warnings']},'Array-PrintCols-2.1.tar.gz' => {'author' => 'AKSTE','description' => 'Print elements in vertically sorted columns','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 143,'pod' => 66,'pod_errors' => 0,'total' => 209,'with_comments' => 52},'releases' => 4,'size' => {'packed' => 14926,'unpacked' => 48581},'testers' => {'pass' => 12},'uses' => ['5.001','Exporter']},'Array-RefElem-0.02.tar.gz' => {'author' => 'GAAS','description' => 'Set up array elements as aliases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 26,'pod' => 41,'pod_errors' => 0,'total' => 67,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1961,'unpacked' => 3944},'testers' => {'pass' => 26},'uses' => ['DynaLoader','Exporter','strict','vars']},'Array-Reform-1.03.tar.gz' => {'author' => 'TBONE','description' => 'Convert an array into N-sized array of array','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 54,'pod' => 57,'pod_errors' => 1,'total' => 111,'with_comments' => 6},'releases' => 4,'size' => {'packed' => 2340,'unpacked' => 4447},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','strict','vars']},'Array-Unique-0.03.tar.gz' => {'author' => 'SZABGAB','description' => 'Tieable array that allows only unique values','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 275,'pod' => 188,'pod_errors' => 0,'total' => 463,'with_comments' => 37},'releases' => 3,'requires' => ['Tie-IxHash-1.21.tar.gz'],'requires_module' => {'Tie::IxHash' => '1.21'},'requires_recursive' => ['Tie-IxHash-1.21.tar.gz'],'size' => {'packed' => 5654,'unpacked' => 15233},'testers' => {'pass' => 5},'uses' => ['5.006','Array::Unique::Quick','Carp','Tie::Array','Tie::IxHash','Tie::StdArray','strict','warnings']},'Array-Window-0.1.tar.gz' => {'author' => 'ADAMK','description' => 'Calculate windows/subsets/pages of arrays.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 268,'pod' => 152,'pod_errors' => 0,'total' => 420,'with_comments' => 49},'releases' => 1,'requires' => ['Class-Inspector-1.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Inspector' => 0,'Test::Simple' => 0},'requires_recursive' => ['Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 12969,'unpacked' => 40905},'testers' => {'pass' => 2},'uses' => ['UNIVERSAL','strict','vars']},'ArrayGenerator_1.0.1.tar.gz' => {'author' => 'KOTOTAMA','description' => 'Easy generation of a HTML array','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 136,'pod' => 54,'pod_errors' => 0,'total' => 190,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 2519,'unpacked' => 5760},'testers' => {'pass' => 2},'uses' => ['HTML::Stream','strict','warnings']},'ArrayHashMonster-0.02.tar.gz' => {'author' => 'MJD','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 67,'pod' => 0,'pod_errors' => 0,'total' => 67,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 2203,'unpacked' => 4488},'testers' => {'fail' => 1,'pass' => 8},'uses' => []},'AsciiDB-TagFile-1.06.tar.gz' => {'author' => 'JOSERODR','description' => 'Tie class for a simple ASCII database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 375,'pod' => 176,'pod_errors' => 0,'total' => 551,'with_comments' => 19},'releases' => 6,'size' => {'packed' => 7446,'unpacked' => 20301},'testers' => {'pass' => 16},'uses' => ['Carp','Cwd','Tie::Hash','vars']},'Aspect-0.08.tar.gz' => {'author' => 'MARCEL','description' => 'Even more rope to hang yourself','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1752,'pod' => 1782,'pod_errors' => 0,'total' => 3534,'with_comments' => 323},'releases' => 4,'requires' => ['Class-MethodMaker-1.10.tar.gz','Hook-LexWrap-0.20.tar.gz','IO-stringy-2.108.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::MethodMaker' => '1.02','Hook::LexWrap' => '0.2','IO::Scalar' => '1.125','Test::More' => '0.45'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','File-Spec-0.82.tar.gz','Hook-LexWrap-0.20.tar.gz','IO-stringy-2.108.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 43081,'unpacked' => 146513},'testers' => {'pass' => 3},'uses' => ['Attribute::Handlers','Benchmark::Timer','Class::MethodMaker','Exporter','Hook::LexWrap','strict','warnings']},'AssistantFrames-0.1.tar.gz' => {'author' => 'GBAUER','description' => 'GUI-Class to build an assistant-like line of frames resembles the standard OS assistants/wizards.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 670,'pod' => 224,'pod_errors' => 0,'total' => 894,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 6748,'unpacked' => 32435},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.004','Mac::Controls','Mac::Dialogs','Mac::Events','Mac::Windows','strict']},'Astro-0.62.tar.gz' => {'author' => 'CPHIL','description' => 'Miscellaneous astronomical routines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3035,'pod' => 938,'pod_errors' => 3,'total' => 3973,'with_comments' => 715},'releases' => 4,'size' => {'packed' => 32542,'unpacked' => 118136},'testers' => {'pass' => 8,'tests' => '0','unknown' => 3},'uses' => ['Carp','POSIX','constant','integer','strict','vars']},'Astro-ADS-1.20.7.tar.gz' => {'author' => 'AALLAN','description' => 'An object orientated interface to NASA\'s ADS database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1819,'pod' => 644,'pod_errors' => 0,'total' => 2463,'with_comments' => 377},'releases' => 9,'requires' => ['PodParser-1.23.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.53','Net::Domain' => '2.13','Pod::Usage' => '1.14'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 27940,'unpacked' => 106284},'testers' => {'pass' => 3},'uses' => ['Carp','LWP::UserAgent','Net::Domain','overload','strict','vars']},'Astro-Aladin-2.0.1.tar.gz' => {'author' => 'AALLAN','description' => 'Perl class giving access to images and catalogues','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 554,'pod' => 237,'pod_errors' => 0,'total' => 791,'with_comments' => 108},'releases' => 2,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'threads' => '','threads::shared' => '0.9'},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 14090,'unpacked' => 41757},'testers' => {'fail' => 5,'tests' => '2'},'uses' => ['Carp','Config','Errno','File::Spec','POSIX','strict','threads','threads::shared','vars']},'Astro-Catalog-2.1.2.tar.gz' => {'author' => 'AALLAN','description' => 'A generic API for stellar catalogues','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2753,'pod' => 845,'pod_errors' => 0,'total' => 3598,'with_comments' => 502},'releases' => 5,'requires' => ['PodParser-1.23.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.53','Net::Domain' => '2.13','Pod::Usage' => '1.14'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 71483,'unpacked' => 238028},'testers' => {'pass' => 1},'uses' => ['Astro::Aladin','Carp','File::Spec','LWP::UserAgent','Math::Libm','Net::Domain','strict','vars']},'Astro-Catalog-2.1.3.tar.gz' => {'author' => 'AALLAN','description' => 'A generic API for stellar catalogues','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 2774,'pod' => 855,'pod_errors' => 0,'total' => 3629,'with_comments' => 503},'releases' => 5,'requires' => ['PodParser-1.23.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.53','Net::Domain' => '2.13','Pod::Usage' => '1.14'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 72121,'unpacked' => 239468},'testers' => {'pass' => 1},'uses' => ['Astro::Aladin','Astro::Catalog','Carp','File::Spec','LWP::UserAgent','Math::Libm','Net::Domain','strict','vars']},'Astro-Constants-0.09.tar.gz' => {'author' => 'DUFFEE','description' => 'Physical constants used in Astronomy','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 127,'pod_errors' => 0,'total' => 209,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 12034,'unpacked' => 32607},'testers' => {'pass' => 3},'uses' => ['Astro::Constants::CGS']},'Astro-Coords-0.03.tar.gz' => {'author' => 'TJENNESS','description' => 'Class for handling astronomical coordinates','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1184,'pod' => 824,'pod_errors' => 0,'total' => 2008,'with_comments' => 63},'releases' => 2,'requires' => ['Astro-SLA-0.96.tar.gz','Astro-Telescope-0.50.tar.gz','Time-Piece-1.08.tar.gz'],'requires_module' => {'Astro::SLA' => '0.95','Astro::Telescope' => '0.50','Time::Piece' => '1.02'},'requires_recursive' => ['Astro-SLA-0.96.tar.gz','Astro-Telescope-0.50.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Time-Piece-1.08.tar.gz'],'size' => {'packed' => 13047,'unpacked' => 50029},'testers' => {},'uses' => ['','5.006','Carp','Time::Piece','overload','strict','warnings']},'Astro-Cosmology-0.90.tar.gz' => {'author' => 'DJBURKE','description' => 'Calculate cosmological distance/volume/times','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 506,'pod' => 391,'pod_errors' => 0,'total' => 897,'with_comments' => 90},'releases' => 3,'requires' => ['PDL-2.4.0.tar.gz'],'requires_module' => {'PDL' => 0},'requires_recursive' => ['PDL-2.4.0.tar.gz'],'size' => {'packed' => 20082,'unpacked' => 75263},'testers' => {'pass' => 1},'uses' => ['Astro::Cosmology::Internal','Carp','constant','vars']},'Astro-DSS-1.6.1.tar.gz' => {'author' => 'AALLAN','description' => 'An Object Orientated interface to the Digital Sky Survey','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 490,'pod' => 186,'pod_errors' => 0,'total' => 676,'with_comments' => 77},'releases' => 3,'requires' => ['PodParser-1.23.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.53','Net::Domain' => '2.13','Pod::Usage' => '1.14'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12569,'unpacked' => 35413},'testers' => {'pass' => 4},'uses' => ['Carp','File::Spec','LWP::UserAgent','Net::Domain','strict','vars']},'Astro-FITS-CFITSIO-1.01.tar.gz' => {'author' => 'PRATZLAFF','description' => 'Perl extension for using the cfitsio library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 915,'pod' => 155,'pod_errors' => 0,'total' => 1070,'with_comments' => 34},'releases' => 2,'size' => {'packed' => 186357,'unpacked' => 698759},'testers' => {'pass' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Astro-FITS-Header-1.9.tar.gz' => {'author' => 'AALLAN','description' => 'interface to FITS headers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1451,'pod' => 443,'pod_errors' => 0,'total' => 1894,'with_comments' => 311},'releases' => 9,'size' => {'packed' => 46785,'unpacked' => 149990},'testers' => {'pass' => 8},'uses' => ['','Astro::FITS::Header::Item','CFITSIO','Carp','NDF','overload','strict','vars']},'Astro-FITS-Header-2.1.tar.gz' => {'author' => 'AALLAN','description' => 'A FITS header','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1579,'pod' => 546,'pod_errors' => 0,'total' => 2125,'with_comments' => 339},'releases' => 9,'size' => {'packed' => 49896,'unpacked' => 161445},'testers' => {'pass' => 5},'uses' => ['','Astro::FITS::Header','CFITSIO','Carp','NDF','overload','strict','vars']},'Astro-FITS-Header-2.7.1.tar.gz' => {'author' => 'AALLAN','description' => 'Object Orientated interface to FITS HDUs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2046,'pod' => 672,'pod_errors' => 0,'total' => 2718,'with_comments' => 437},'releases' => 9,'size' => {'packed' => 72821,'unpacked' => 217300},'testers' => {'pass' => 1},'uses' => ['','Astro::FITS::CFITSIO','Astro::FITS::Header','Astro::FITS::Header::Item','Carp','GSD','NDF','overload','strict','vars']},'Astro-Funtools-Parse-0.04.tar.gz' => {'author' => 'DJERIUS','description' => 'routines to parse the output of Funtools programs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 333,'pod' => 188,'pod_errors' => 0,'total' => 521,'with_comments' => 25},'releases' => 1,'requires' => ['Data-Dumper-2.101.tar.gz','Data-LineBuffer-0.01.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Data::LineBuffer' => '0.01','Test::More' => '0.42'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Data-LineBuffer-0.01.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 34550,'unpacked' => 338665},'testers' => {'pass' => 4},'uses' => ['Astro::Parse::Funtools','Carp','Data::LineBuffer','Exporter','IO::File','strict','warnings']},'Astro-IRAF-CL-0.2.0.tar.gz' => {'author' => 'SJQUINNEY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1077,'pod' => 232,'pod_errors' => 0,'total' => 1309,'with_comments' => 93},'releases' => 4,'requires' => ['Expect-1.15.tar.gz','IO-Tty-1.02.tar.gz'],'requires_module' => {'Expect' => '1.15','IO::Pty' => 1,'IO::Tty' => 1},'requires_recursive' => ['Expect-1.15.tar.gz','IO-Tty-1.02.tar.gz'],'size' => {'packed' => 19661,'unpacked' => 58247},'testers' => {'pass' => 3},'uses' => ['Cwd','Env','Expect','Fcntl','strict','vars','warnings']},'Astro-MoonPhase-0.10.tar.gz' => {'author' => 'RPIKKARA','description' => 'Information about the phase of the Moon.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 485,'pod' => 156,'pod_errors' => 0,'total' => 641,'with_comments' => 122},'releases' => 1,'size' => {'packed' => 7387,'unpacked' => 19139},'testers' => {'pass' => 12},'uses' => ['Exporter','Time::Local','integer','strict','vars']},'Astro-NED-Query-0.02.tar.gz' => {'author' => 'DJERIUS','description' => 'base class for NED queries','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 996,'pod' => 874,'pod_errors' => 0,'total' => 1870,'with_comments' => 49},'releases' => 2,'requires' => ['Class-Accessor-0.18.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableParser-0.34.tar.gz','Test-Simple-0.47.tar.gz','WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'Class::Accessor' => '0.17','HTML::LinkExtor' => '1.31','HTML::TableParser' => '0.32','Test::More' => '0.47','WWW::Mechanize' => '0.35'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableParser-0.34.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','WWW-Mechanize-0.56.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17918,'unpacked' => 65221},'testers' => {'pass' => 5},'uses' => ['','5.006','Carp','Class::Accessor','Class::Accessor::Fast','HTML::LinkExtor','HTML::Parser','HTML::TableParser','WWW::Mechanize','autouse','constant','strict','warnings']},'Astro-SIMBAD-1.9.5.tar.gz' => {'author' => 'AALLAN','description' => 'An object orientated interface to CDS\' SIMBAD database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1206,'pod' => 431,'pod_errors' => 0,'total' => 1637,'with_comments' => 208},'releases' => 4,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.53'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18936,'unpacked' => 71728},'testers' => {'pass' => 1},'uses' => ['Carp','LWP::UserAgent','Net::Domain','strict','vars']},'Astro-SLA-0.96.tar.gz' => {'author' => 'TJENNESS','description' => 'Interface to SLALIB positional astronomy lib','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 321,'pod' => 168,'pod_errors' => 0,'total' => 489,'with_comments' => 45},'releases' => 7,'requires' => ['Test-1.24.tar.gz'],'requires_module' => {'Test' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 26791,'unpacked' => 102598},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','aliasing','strict','vars']},'Astro-STSDAS-Table-0.13.tar.gz' => {'author' => 'DJERIUS','description' => 'Base class for STSDAS Tables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1519,'pod' => 928,'pod_errors' => 1,'total' => 2447,'with_comments' => 117},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.42'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 41472,'unpacked' => 125186},'testers' => {'fail' => 1,'pass' => 4,'tests' => '261'},'uses' => ['5.005_62','Carp','Config','Exporter','FileHandle','IO::File','POSIX','constant','integer','strict','warnings']},'Astro-SkyCat-0.01.tar.gz' => {'author' => 'TJENNESS','description' => 'Interface to ESO SkyCat library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 41,'pod_errors' => 0,'total' => 77,'with_comments' => 0},'releases' => 1,'requires' => ['Test-1.24.tar.gz'],'requires_module' => {'Test' => undef},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 5420,'unpacked' => 15187},'testers' => {'fail' => 2},'uses' => ['','Astro::SkyCat::WorldOrImageCoords','Carp','DynaLoader','Exporter','strict','vars']},'Astro-SunTime-0.01.tar.gz' => {'author' => 'ROBF','description' => 'Calculate sun rise/set times','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 114,'pod' => 0,'pod_errors' => 0,'total' => 114,'with_comments' => 23},'releases' => 1,'requires' => ['Time-modules-2003.0211.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'POSIX' => 0,'Time::ParseDate' => 0},'requires_recursive' => ['Time-modules-2003.0211.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2260,'unpacked' => 4080},'testers' => {'pass' => 13},'uses' => ['POSIX','Time::ParseDate','strict','vars']},'Astro-Sunrise-0.8.tar.gz' => {'author' => 'RKHILL','description' => 'Computes sunrise/sunset for a given day','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 534,'pod' => 193,'pod_errors' => 0,'total' => 727,'with_comments' => 179},'releases' => 8,'requires' => ['Time-Piece-1.08.tar.gz'],'requires_module' => {'Time::Piece' => '1.08'},'requires_recursive' => ['Time-Piece-1.08.tar.gz'],'size' => {'packed' => 8499,'unpacked' => 31512},'testers' => {'pass' => 9},'uses' => ['Carp','Exporter','Math::Trig','POSIX','Time::Piece','Time::Seconds','integer','strict','vars','warnings']},'Astro-Time-HJD-0.02.tar.gz' => {'author' => 'RCREAGER','description' => 'Perl extension for calculating heliocentric julian date adjustment.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 293,'pod' => 39,'pod_errors' => 0,'total' => 332,'with_comments' => 9},'releases' => 1,'requires' => ['Time-modules-2003.0211.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Math::Trig' => 0,'Time::JulianDay' => 0},'requires_recursive' => ['Time-modules-2003.0211.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4634,'unpacked' => 12391},'testers' => {'pass' => 6},'uses' => ['5.006','AutoLoader','Exporter','Math::Trig','Time::JulianDay','strict','warnings']},'Astro-WaveBand-0.04.tar.gz' => {'author' => 'TJENNESS','description' => 'Transparently work in waveband, wavelength or filter','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 663,'pod' => 147,'pod_errors' => 0,'total' => 810,'with_comments' => 75},'releases' => 2,'size' => {'packed' => 7768,'unpacked' => 24398},'testers' => {'pass' => 5},'uses' => ['5.006','Carp','constant','overload','strict','warnings','warnings::register']},'Async-0.10.tar.gz' => {'author' => 'MJD','description' => 'Asynchronous evaluation of Perl code (with optional timeouts)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 172,'pod' => 100,'pod_errors' => 0,'total' => 272,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 3253,'unpacked' => 7646},'testers' => {'tests' => '0','unknown' => 24},'uses' => ['Storable']},'Async-Callback-1.00.02.tar.gz' => {'author' => 'DMLLOYD','description' => 'Perl extension for adding asynchronous C callbacks.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 105,'pod_errors' => 0,'total' => 168,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 5317,'unpacked' => 17372},'testers' => {'fail' => 1},'uses' => ['5.006','Callback','DynaLoader','Exporter','strict','warnings']},'Async-Group-0.3.tar.gz' => {'author' => 'DDUMONT','description' => 'Deal with simultaneous asynchronous calls','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 146,'pod' => 91,'pod_errors' => 0,'total' => 237,'with_comments' => 29},'releases' => 3,'size' => {'packed' => 3717,'unpacked' => 10123},'testers' => {'pass' => 9},'uses' => ['AutoLoader','Carp','strict','vars']},'AtExit-2.01.tar.gz' => {'author' => 'BRADAPP','description' => 'atexit() function to register exit-callbacks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 313,'pod' => 105,'pod_errors' => 0,'total' => 418,'with_comments' => 37},'releases' => 3,'size' => {'packed' => 8081,'unpacked' => 24780},'testers' => {'pass' => 8},'uses' => ['5.002','Exporter','diagnostics','strict','vars']},'Attribute-Abstract-0.01.tar.gz' => {'author' => 'MARCEL','description' => 'implement abstract methods with attributes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 28,'pod' => 37,'pod_errors' => 0,'total' => 65,'with_comments' => 0},'releases' => 1,'requires' => ['Attribute-Handlers-0.78.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.61'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz'],'size' => {'packed' => 2086,'unpacked' => 4360},'testers' => {'pass' => 14},'uses' => ['Attribute::Handlers','strict','warnings']},'Attribute-Constructor-0.04.tar.gz' => {'author' => 'FIDUS','description' => 'implementing constructors with attributes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 68,'pod_errors' => 0,'total' => 111,'with_comments' => 3},'releases' => 1,'requires' => ['Attribute-Handlers-0.78.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.78'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz'],'size' => {'packed' => 3000,'unpacked' => 7084},'testers' => {'pass' => 3},'uses' => ['5.006','Attribute::Handlers','strict','warnings']},'Attribute-Curried-0.01.tgz' => {'author' => 'SEANO','description' => '- Functional goodness for Perl.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 49,'pod' => 51,'pod_errors' => 0,'total' => 100,'with_comments' => 1},'releases' => 1,'requires' => ['Attribute-Handlers-0.78.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.01'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz'],'size' => {'packed' => 2106,'unpacked' => 3871},'testers' => {'pass' => 5},'uses' => ['5.006','Attribute::Handlers','strict','warnings']},'Attribute-Default-1.31.tar.gz' => {'author' => 'STEPHEN','description' => 'Perl extension to assign default values to subroutine arguments','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 496,'pod' => 204,'pod_errors' => 0,'total' => 700,'with_comments' => 151},'releases' => 3,'requires' => ['Attribute-Handlers-0.78.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => 0,'Test::More' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 9256,'unpacked' => 28116},'testers' => {'pass' => 6},'uses' => ['5.006','Attribute::Handlers','Carp','Exporter','Symbol','attributes','strict','warnings']},'Attribute-Deprecated-1.04.tar.gz' => {'author' => 'KASEI','description' => 'Mark deprecated methods','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 40,'pod' => 30,'pod_errors' => 0,'total' => 70,'with_comments' => 0},'releases' => 2,'requires' => ['Attribute-Handlers-0.78.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.70'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz'],'size' => {'packed' => 1613,'unpacked' => 2517},'testers' => {'pass' => 10},'uses' => ['Attribute::Handlers','strict','v5.6','warnings']},'Attribute-Handlers-0.76.tar.gz' => {'author' => 'DCONWAY','description' => 'Simpler definition of attribute handlers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 427,'pod' => 517,'pod_errors' => 0,'total' => 944,'with_comments' => 22},'releases' => 9,'size' => {'packed' => 12858,'unpacked' => 41468},'testers' => {'fail' => 1,'pass' => 11,'tests' => '20'},'uses' => ['5.006','Attribute::Handlers','Carp','Data::Dumper','warnings']},'Attribute-Handlers-0.78.tar.gz' => {'author' => 'ABERGMAN','description' => 'Simpler definition of attribute handlers','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 461,'pod' => 523,'pod_errors' => 0,'total' => 984,'with_comments' => 26},'releases' => 9,'size' => {'packed' => 15392,'unpacked' => 47224},'testers' => {'pass' => 30},'uses' => ['5.006','Carp','Data::Dumper','warnings']},'Attribute-Handlers-Prospective-0.01.tar.gz' => {'author' => 'DCONWAY','description' => 'Richer semantics for attribute handlers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 562,'pod' => 438,'pod_errors' => 0,'total' => 1000,'with_comments' => 16},'releases' => 1,'requires' => ['Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Filter::Simple' => 0,'Text::Balanced' => 0},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 13730,'unpacked' => 39853},'testers' => {'fail' => 2,'pass' => 6,'tests' => '31'},'uses' => ['Carp','Data::Dumper','Filter::Simple','Text::Balanced']},'Attribute-Memoize-0.01.tar.gz' => {'author' => 'MARCEL','description' => 'Attribute interface to Memoize.pm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 51,'pod_errors' => 0,'total' => 80,'with_comments' => 0},'releases' => 1,'requires' => ['Memoize-1.01.tar.gz'],'requires_module' => {'Memoize' => 0},'requires_recursive' => ['Memoize-1.01.tar.gz'],'size' => {'packed' => 2101,'unpacked' => 4358},'testers' => {'fail' => 2,'pass' => 13},'uses' => ['Attribute::Handlers','Memoize','strict','warnings']},'Attribute-Overload-0.02.tar.gz' => {'author' => 'MARCEL','description' => 'Attribute that makes overloading easier','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 67,'pod' => 36,'pod_errors' => 0,'total' => 103,'with_comments' => 10},'releases' => 1,'requires' => ['Attribute-Handlers-0.78.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.61'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz'],'size' => {'packed' => 2841,'unpacked' => 5920},'testers' => {'pass' => 7},'uses' => ['Attribute::Handlers','strict','warnings']},'Attribute-Persistent-1.0.tar.gz' => {'author' => 'SIMON','description' => 'Really lazy persistence','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 60,'pod' => 39,'pod_errors' => 0,'total' => 99,'with_comments' => 2},'releases' => 1,'requires' => ['Attribute-Handlers-Prospective-0.01.tar.gz','Digest-MD5-2.26.tar.gz','MLDBM-2.01.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'AnyDBM_File' => 0,'Attribute::Handlers::Prospective' => 0,'Digest::MD5' => 0,'MLDBM' => 0},'requires_recursive' => ['Attribute-Handlers-Prospective-0.01.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','MLDBM-2.01.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2232,'unpacked' => 3773},'testers' => {'fail' => 1,'pass' => 3,'tests' => '3'},'uses' => ['AnyDBM_File','Attribute::Handlers::Prospective','Carp','Digest::MD5','File::Spec::Functions','MLDBM','strict']},'Attribute-Profiled-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Profiles specific methods in class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 54,'pod' => 36,'pod_errors' => 0,'total' => 90,'with_comments' => 0},'releases' => 3,'requires' => ['Attribute-Handlers-0.78.tar.gz','Benchmark-Timer-0.5.tar.gz','Hook-LexWrap-0.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.7','Benchmark::Timer' => '0.5','Hook::LexWrap' => '0.01','Test::More' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Benchmark-Timer-0.5.tar.gz','File-Spec-0.82.tar.gz','Hook-LexWrap-0.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 2226,'unpacked' => 4701},'testers' => {'pass' => 3},'uses' => ['5.006','Attribute::Handlers','Benchmark::Timer','Hook::LexWrap','strict','warnings']},'Attribute-Property-1.04.tar.gz' => {'author' => 'JUERD','description' => 'Lvalue methods with value validation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1703,'pod' => 1069,'pod_errors' => 0,'total' => 2772,'with_comments' => 72},'releases' => 5,'requires' => ['Attribute-Handlers-0.78.tar.gz'],'requires_module' => {'Attribute::Handlers' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz'],'size' => {'packed' => 24467,'unpacked' => 77756},'testers' => {'fail' => 1,'pass' => 4,'tests' => '176'},'uses' => ['5.006','Attribute::Handlers','Carp','Want']},'Attribute-Protected-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'implementing proctected methods with attributes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 82,'pod_errors' => 0,'total' => 135,'with_comments' => 1},'releases' => 3,'requires' => ['Attribute-Handlers-0.78.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.7','Test::More' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2346,'unpacked' => 6464},'testers' => {'pass' => 5},'uses' => ['5.006','Attribute::Handlers','Carp','strict','warnings']},'Attribute-Signature-1.02.tar.gz' => {'author' => 'JDUNCAN','description' => 'Signatures on methods and subroutines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 216,'pod' => 84,'pod_errors' => 1,'total' => 300,'with_comments' => 11},'releases' => 3,'requires' => ['Attribute-Handlers-0.78.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.7','Scalar::Util' => '0.01','Test::Simple' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5109,'unpacked' => 18720},'testers' => {'fail' => 1,'pass' => 8},'uses' => ['Attribute::Handlers','Carp','Data::Dumper','Scalar::Util','strict','warnings::register']},'Attribute-TieClasses-0.01.tar.gz' => {'author' => 'MARCEL','description' => 'attribute wrappers for CPAN Tie classes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 128,'pod_errors' => 0,'total' => 295,'with_comments' => 13},'releases' => 1,'requires' => ['Attribute-Handlers-0.78.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.61'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz'],'size' => {'packed' => 5149,'unpacked' => 17724},'testers' => {'pass' => 8},'uses' => ['Attribute::Handlers','strict','warnings']},'Attribute-Types-0.10.tar.gz' => {'author' => 'DCONWAY','description' => 'Attributes that confer type on variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 244,'pod' => 178,'pod_errors' => 0,'total' => 422,'with_comments' => 0},'releases' => 1,'requires' => ['Attribute-Handlers-0.78.tar.gz'],'requires_module' => {'Attribute::Handlers' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz'],'size' => {'packed' => 6254,'unpacked' => 28400},'testers' => {'pass' => 9},'uses' => ['Attribute::Handlers','Carp','warnings']},'Attribute-Unimplemented-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'mark unimplemented methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 33,'pod_errors' => 0,'total' => 67,'with_comments' => 0},'releases' => 2,'requires' => ['Attribute-Handlers-0.78.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.7','Test::More' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1718,'unpacked' => 3297},'testers' => {'pass' => 4},'uses' => ['5.006','Attribute::Handlers','Carp','strict','warnings']},'Attribute-Util-0.02.tar.gz' => {'author' => 'MARCEL','description' => 'A selection of general-utility attributes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 94,'pod_errors' => 0,'total' => 166,'with_comments' => 0},'releases' => 1,'requires' => ['Attribute-Handlers-0.78.tar.gz','Memoize-1.01.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.61','Memoize' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Memoize-1.01.tar.gz'],'size' => {'packed' => 4037,'unpacked' => 11789},'testers' => {'fail' => 1,'pass' => 5,'tests' => '19'},'uses' => ['Attribute::Handlers','Memoize','strict','warnings']},'Audio-1.000.tar.gz' => {'author' => 'NI-S','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 845,'pod' => 289,'pod_errors' => 3,'total' => 1134,'with_comments' => 37},'releases' => 4,'requires' => ['Math-GSL-0.01.tar.gz'],'requires_module' => {'Math::GSL' => 0},'requires_recursive' => ['Math-GSL-0.01.tar.gz'],'size' => {'packed' => 78996,'unpacked' => 266570},'testers' => {},'uses' => ['Audio::Filter::AllPole','Audio::Filter::FIR','Audio::Play::$^O','AutoLoader','Data::Dumper','DynaLoader','File::Temp','Tk','Tk::Canvas','Tk::Derived','Tk::widgets','overload','strict']},'Audio-Ao-0.01.tar.gz' => {'author' => 'DBP','description' => 'A Perl wrapper for the Ao audio library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 219,'pod' => 86,'pod_errors' => 0,'total' => 305,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 3925,'unpacked' => 9540},'testers' => {},'uses' => ['5.006','Carp','Exporter','Inline','strict','warnings']},'Audio-Beep-0.10.tar.gz' => {'author' => 'GIULIENK','description' => 'a module to use your computer beeper in fancy ways','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 428,'pod' => 354,'pod_errors' => 0,'total' => 782,'with_comments' => 7},'releases' => 8,'size' => {'packed' => 27999,'unpacked' => 66584},'testers' => {'fail' => 1,'pass' => 3,'tests' => '3'},'uses' => ['Carp','Exporter','IO::File','Win32::API','constant','strict','vars']},'Audio-CD-0.04.tar.gz' => {'author' => 'DOUGM','description' => 'Perl interface to libcdaudio (cd + cddb)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 244,'pod_errors' => 1,'total' => 264,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 6539,'unpacked' => 23395},'testers' => {},'uses' => ['strict']},'Audio-CoolEdit-0.01.tar.gz' => {'author' => 'NPESKETT','description' => 'Modules for reading & writing Syntrillium CoolEdit Pro .ses files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1189,'pod' => 220,'pod_errors' => 0,'total' => 1409,'with_comments' => 155},'releases' => 1,'size' => {'packed' => 11143,'unpacked' => 44614},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Audio::Tools::ByteOrder','Audio::Wav','Cwd','FileHandle','strict','vars']},'Audio-DSP-0.02.tar.gz' => {'author' => 'SETHJ','description' => 'Perl interface to *NIX digital audio device.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 180,'pod' => 402,'pod_errors' => 0,'total' => 582,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 28446,'unpacked' => 82675},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Audio-Daemon-0.99Beta.tar.gz' => {'author' => 'JAYJ','description' => 'UDP Daemon for various Sound Players','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1528,'pod' => 577,'pod_errors' => 9,'total' => 2105,'with_comments' => 133},'releases' => 1,'size' => {'packed' => 15745,'unpacked' => 63593},'testers' => {'pass' => 5},'uses' => ['IO::Select','IO::Socket','IO::Socket::INET','MP3::Info','Shout','strict','vars']},'Audio-Daemon-MPG123-0.9Beta.tar.gz' => {'author' => 'JAYJ','description' => 'UDP Daemon wrapper around Audio::Play::MPG123','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 801,'pod' => 335,'pod_errors' => 5,'total' => 1136,'with_comments' => 47},'releases' => 1,'size' => {'packed' => 10920,'unpacked' => 35186},'testers' => {'pass' => 5},'uses' => ['Audio::Daemon::MPG123','IO::Select','IO::Socket','IO::Socket::INET','strict','vars']},'Audio-ESD-0.02.tar.gz' => {'author' => 'DJHD','description' => 'Perl extension for talking to the Enlightened Sound Daemon','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 229,'pod' => 205,'pod_errors' => 0,'total' => 434,'with_comments' => 22},'releases' => 2,'size' => {'packed' => 6450,'unpacked' => 19634},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','IO::Socket','strict','vars']},'Audio-Ecasound-0.2.tar.gz' => {'author' => 'BOWMANBS','description' => 'ecasound bindings, sound and fx processing','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 321,'pod' => 205,'pod_errors' => 0,'total' => 526,'with_comments' => 39},'releases' => 1,'size' => {'packed' => 9068,'unpacked' => 26826},'testers' => {},'uses' => ['5.005_62','Carp','DynaLoader','Exporter','strict','vars']},'Audio-MPEG-0.04.tar.gz' => {'author' => 'PTIMOF','description' => 'Encode/Decode MPEG Audio (MP3)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 328,'pod' => 589,'pod_errors' => 1,'total' => 917,'with_comments' => 30},'releases' => 1,'size' => {'packed' => 58460,'unpacked' => 151643},'testers' => {},'uses' => ['Carp','DynaLoader','strict','vars']},'Audio-Mad-0.4.tar.gz' => {'author' => 'MISCHKE','description' => 'Perl interface to the mad MPEG decoder library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 266,'pod' => 628,'pod_errors' => 0,'total' => 894,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 127832,'unpacked' => 182099},'testers' => {},'uses' => ['5.6.0','Carp','DynaLoader','Exporter','overload','strict','warnings']},'Audio-MikMod-0.5.tar.gz' => {'author' => 'DANIEL','description' => 'Perl extension for libmikmod.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 327,'pod' => 42,'pod_errors' => 0,'total' => 369,'with_comments' => 150},'releases' => 1,'requires' => ['Time-HiRes-1.49.tar.gz'],'requires_module' => {'Time::HiRes' => '1.2'},'requires_recursive' => ['Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 507936,'unpacked' => 732624},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','constant','strict','vars']},'Audio-Mix-0.01.tar.gz' => {'author' => 'NPESKETT','description' => 'Module for fading cross-fading wav audio files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1729,'pod' => 197,'pod_errors' => 0,'total' => 1926,'with_comments' => 61},'releases' => 1,'size' => {'packed' => 16154,'unpacked' => 63186},'testers' => {'fail' => 3},'uses' => ['Audio::CoolEdit','Audio::Tools::Fades','Audio::Tools::Time','Audio::Wav','DirHandle','File::Basename','FileHandle','strict','vars']},'Audio-Mixer-0.7.tar.gz' => {'author' => 'SERGEY','description' => 'Sound mixer control using ioctl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 57,'pod_errors' => 0,'total' => 195,'with_comments' => 22},'releases' => 5,'size' => {'packed' => 6709,'unpacked' => 19350},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Audio-OSS-0.0501.tar.gz' => {'author' => 'DJHD','description' => 'Interface to Open Sound System audio devices','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 215,'pod' => 296,'pod_errors' => 0,'total' => 511,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 8823,'unpacked' => 25549},'testers' => {'fail' => 1,'pass' => 6},'uses' => ['Audio::OSS::Constants','Exporter','constant','strict','vars']},'Audio-Play-MPG123-0.62.tar.gz' => {'author' => 'MLEHMANN','description' => 'Generic frontend for MPG123','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 237,'pod' => 108,'pod_errors' => 0,'total' => 345,'with_comments' => 4},'releases' => 8,'size' => {'packed' => 225913,'unpacked' => 867436},'testers' => {'pass' => 10},'uses' => ['Carp','Cwd','Errno','Exporter','Fcntl','File::Spec','IPC::Open3','strict']},'Audio-RaveMP-0.04.tar.gz' => {'author' => 'DOUGM','description' => 'Perl interface to Sensory Science RaveMP player','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 382,'pod' => 182,'pod_errors' => 0,'total' => 564,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 25288,'unpacked' => 162591},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Xmms','constant','strict','subs']},'Audio-SID-3.02.tgz' => {'author' => 'LALA','description' => 'Perl module to handle SID files (Commodore-64 music files).','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1289,'pod' => 301,'pod_errors' => 0,'total' => 1590,'with_comments' => 109},'releases' => 3,'size' => {'packed' => 20389,'unpacked' => 70293},'testers' => {'pass' => 5},'uses' => ['5','Carp','Digest::MD5','FileHandle','strict','vars']},'Audio-SoundFile-0.15.tar.gz' => {'author' => 'TAIY','description' => 'Perl interface to libsndfile, a sound I/O library','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 236,'pod' => 261,'pod_errors' => 0,'total' => 497,'with_comments' => 16},'releases' => 2,'requires' => ['PDL-2.1.1.tar.gz','PDL-2.3.2.tar.gz'],'requires_module' => {'PDL::Core' => 0,'PDL::Core::Dev' => 0},'requires_recursive' => ['ExtUtils-F77-1.14.tar.gz','File-Spec-0.82.tar.gz','PDL-2.1.1.tar.gz','PDL-2.3.2.tar.gz'],'size' => {'packed' => 12931,'unpacked' => 93433},'testers' => {'fail' => 1},'uses' => ['DynaLoader','Exporter','PDL::Core','strict','vars']},'Audio-Tools-0.01.tar.gz' => {'author' => 'NPESKETT','description' => 'Common Tools for Audio::Wav, Audio::Mix & Audio::CoolEdit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 351,'pod' => 273,'pod_errors' => 0,'total' => 624,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 6078,'unpacked' => 24670},'testers' => {'pass' => 4},'uses' => ['FileHandle','strict','vars']},'Audio-Wav-0.02.tar.gz' => {'author' => 'NPESKETT','description' => 'Modules for reading & writing Microsoft WAV files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1223,'pod' => 388,'pod_errors' => 0,'total' => 1611,'with_comments' => 43},'releases' => 2,'size' => {'packed' => 15827,'unpacked' => 59573},'testers' => {'fail' => 8,'pass' => 4},'uses' => ['FileHandle','strict','vars']},'AudioCD-0.20.tar.gz' => {'author' => 'CNANDOR','description' => 'Extension for controlling Audio CDs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 36,'pod_errors' => 0,'total' => 67,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2998,'unpacked' => 6165},'testers' => {'pass' => 6},'uses' => ['AudioCD::Mac','Exporter','strict','vars']},'AudioCD-Mac-0.25.tar.gz' => {'author' => 'CNANDOR','description' => 'Extension for controlling Audio CDs on MacOS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 208,'pod' => 171,'pod_errors' => 0,'total' => 379,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 14873,'unpacked' => 35090},'testers' => {},'uses' => ['DynaLoader','Exporter','Mac::Files','strict','vars']},'Authen-ACE-0.90.tar.gz' => {'author' => 'DCARRIGAN','description' => 'Interface to Security Dynamics ACE (SecurID)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 159,'pod' => 112,'pod_errors' => 0,'total' => 271,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 9768,'unpacked' => 27207},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Authen-ACE4-1.1.tar.gz' => {'author' => 'MIKEM','description' => 'Perl extension for accessing a SecurID ACE s','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 198,'pod' => 231,'pod_errors' => 0,'total' => 429,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 8625,'unpacked' => 27449},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Authen-Challenge-Basic-0.1.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'A Basic challenge/response authentication scheme.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 179,'pod' => 104,'pod_errors' => 0,'total' => 283,'with_comments' => 25},'releases' => 1,'size' => {'packed' => 4535,'unpacked' => 11057},'testers' => {'pass' => 3},'uses' => ['5.000','MD5']},'Authen-CyrusSASL-0.01.tar.gz' => {'author' => 'MAKLER','description' => 'Cyrus-sasl pwcheck/saslauthd authentication.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 126,'pod' => 49,'pod_errors' => 0,'total' => 175,'with_comments' => 17},'releases' => 1,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO' => '1.12'},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 4113,'unpacked' => 9029},'testers' => {'fail' => 3},'uses' => ['AutoLoader','Exporter','IO::Select','IO::Socket','vars']},'Authen-Krb5-Admin-0.04.tar.gz' => {'author' => 'KORTY','description' => 'Perl extension for MIT Kerberos 5 admin interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 228,'pod' => 297,'pod_errors' => 0,'total' => 525,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 19497,'unpacked' => 81433},'testers' => {},'uses' => ['5.004','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Authen-Krb5-Easy-0.90.tar.gz' => {'author' => 'SCHALLEE','description' => 'Easy krb5 client interface using krb libs.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 61,'pod' => 74,'pod_errors' => 0,'total' => 135,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 4163,'unpacked' => 12947},'testers' => {},'uses' => ['5.005_62','DynaLoader','Exporter','strict','warnings']},'Authen-Krb5-KDB-0.09.tar.gz' => {'author' => 'DKS','description' => 'Parse Kerberos V5 database dumps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1346,'pod' => 895,'pod_errors' => 0,'total' => 2241,'with_comments' => 96},'releases' => 5,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'POSIX' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 21172,'unpacked' => 102453},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','POSIX','strict','vars']},'Authen-Krb5-Simple-0.31.tar.gz' => {'author' => 'DSTUART','description' => 'Basic user authentication using Kerberos 5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 101,'pod_errors' => 0,'total' => 231,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 6069,'unpacked' => 18140},'testers' => {},'uses' => ['5.006','Carp','DynaLoader','strict','warnings']},'Authen-Libwrap-0.10.tar.gz' => {'author' => 'JFITZ','description' => 'access to Wietse Venema\'s TCP Wrappers library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 61,'pod' => 55,'pod_errors' => 0,'total' => 116,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 4002,'unpacked' => 8560},'testers' => {'pass' => 3},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Authen-NTLM-0.30.tar.gz' => {'author' => 'UMVUE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 882,'pod' => 172,'pod_errors' => 0,'total' => 1054,'with_comments' => 206},'releases' => 3,'requires' => ['Crypt-DES_PP-1.00.tar.gz','Digest-Perl-MD4-1.3.tar.gz'],'requires_module' => {'Crypt::DES_PP' => 1,'Digest::Perl::MD4' => 1},'requires_recursive' => ['Crypt-DES_PP-1.00.tar.gz','Digest-Perl-MD4-1.3.tar.gz'],'size' => {'packed' => 11795,'unpacked' => 55602},'testers' => {'pass' => 6},'uses' => ['Carp','Crypt::DES','Crypt::DES_PP','Digest::MD4','Digest::Perl::MD4','DynaLoader','Exporter','MIME::Base64','POSIX','constant','strict','vars']},'Authen-OPIE-1.00.tar.gz' => {'author' => 'EESTABROO','description' => 'Perl module for opie (onetime password in everything)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 56,'pod' => 32,'pod_errors' => 0,'total' => 88,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 3129,'unpacked' => 6117},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Authen-PAM-0.14.tar.gz' => {'author' => 'NIKIP','description' => 'Interface to PAM library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 96,'pod' => 252,'pod_errors' => 0,'total' => 348,'with_comments' => 2},'releases' => 13,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'POSIX' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 43455,'unpacked' => 186872},'testers' => {'fail' => 3,'pass' => 1},'uses' => []},'Authen-PIN-1.10.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Create and verify strong PIN numbers','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 158,'pod' => 70,'pod_errors' => 0,'total' => 228,'with_comments' => 0},'releases' => 2,'requires' => ['Business-CreditCard-0.27.tar.gz','Digest-MD5-2.26.tar.gz','Number-Encode-1.00.tar.gz'],'requires_module' => {'Business::CreditCard' => 0,'Digest::MD5' => 0,'Number::Encode' => 0},'requires_recursive' => ['Business-CreditCard-0.27.tar.gz','Digest-MD5-2.26.tar.gz','Number-Encode-1.00.tar.gz'],'size' => {'packed' => 3183,'unpacked' => 6687},'testers' => {'pass' => 6},'uses' => ['Business::CreditCard','Carp','Digest::MD5','Number::Encode','strict','vars']},'Authen-Perl-NTLM-0.12.tar.gz' => {'author' => 'UMVUE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 554,'pod' => 64,'pod_errors' => 0,'total' => 618,'with_comments' => 123},'releases' => 7,'requires' => ['Crypt-DES_PP-1.00.tar.gz','Digest-Perl-MD4-1.3.tar.gz'],'requires_module' => {'Crypt::DES_PP' => 1,'Digest::Perl::MD4' => 1},'requires_recursive' => ['Crypt-DES_PP-1.00.tar.gz','Digest-Perl-MD4-1.3.tar.gz'],'size' => {'packed' => 7713,'unpacked' => 31677},'testers' => {'pass' => 3},'uses' => ['Carp','Crypt::DES','Crypt::DES_PP','Digest::MD4','Digest::Perl::MD4','DynaLoader','Exporter','POSIX','constant','strict','vars']},'Authen-Prot-1.08.tar.gz' => {'author' => 'PAULG','description' => 'Perl extension for accessing protected password database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 99,'pod' => 113,'pod_errors' => 0,'total' => 212,'with_comments' => 17},'releases' => 2,'size' => {'packed' => 9362,'unpacked' => 28572},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Authen-SASL-2.04.tar.gz' => {'author' => 'GBARR','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 554,'pod' => 175,'pod_errors' => 0,'total' => 729,'with_comments' => 47},'releases' => 5,'size' => {'packed' => 7501,'unpacked' => 25252},'testers' => {'pass' => 2},'uses' => ['Carp','Digest::HMAC_MD5','Digest::MD5','strict','vars']},'Authen-SASL-Cyrus-0.07.tar.gz' => {'author' => 'ADAMSON','description' => 'XS Interface to Cyrus SASL','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 120,'pod_errors' => 1,'total' => 296,'with_comments' => 21},'releases' => 7,'size' => {'packed' => 9467,'unpacked' => 30974},'testers' => {},'uses' => ['DynaLoader']},'Authen-SimplePam-0.1.24.tar.gz' => {'author' => 'RSD','description' => 'Simple interface to PAM authentication','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 790,'pod' => 192,'pod_errors' => 0,'total' => 982,'with_comments' => 128},'releases' => 1,'requires' => ['Authen-PAM-0.14.tar.gz'],'requires_module' => {'Authen::PAM' => '0.13'},'requires_recursive' => ['Authen-PAM-0.14.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13604,'unpacked' => 43699},'testers' => {'pass' => 2},'uses' => ['Authen::PAM','strict','warnings']},'Authen-Smb-0.91.tar.gz' => {'author' => 'PMKANE','description' => 'Perl extension to authenticate against an SMB server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 45,'pod_errors' => 0,'total' => 122,'with_comments' => 12},'releases' => 8,'size' => {'packed' => 38710,'unpacked' => 151639},'testers' => {'pass' => 5},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Authen-Ticket-0.02.tar.gz' => {'author' => 'JSMITH','description' => 'Perl extension for implementing ticket authentication','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1282,'pod' => 447,'pod_errors' => 2,'total' => 1729,'with_comments' => 198},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz','MIME-Base64-2.20.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '1.26','Apache::Constants' => '1.09','Apache::URI' => '1.00','Apache::Util' => '1.01','CGI' => '2.46','CGI::Cookie' => '1.06','MIME::Base64' => '2.11'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 14456,'unpacked' => 56318},'testers' => {'pass' => 7},'uses' => ['Apache::Constants','Carp','MIME::Base64','OpenSSL','strict','vars']},'AutoLoader-Register-0.01.tar.gz' => {'author' => 'VPARSEVAL','description' => 'A smart autoloader to be inherited by your classes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 131,'pod' => 221,'pod_errors' => 0,'total' => 352,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 6696,'unpacked' => 17186},'testers' => {'pass' => 5},'uses' => ['5.006','Carp','strict','warnings']},'Autodia-1.7.tar.gz' => {'author' => 'TEEJAY','description' => 'The configuration and Utility perl module for AutoDia.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5198,'pod' => 503,'pod_errors' => 4,'total' => 5701,'with_comments' => 746},'releases' => 4,'requires' => ['Data-Dumper-2.101.tar.gz','GraphViz-1.8.tar.gz','Inline-0.44.tar.gz','Inline-Java-0.41.tar.gz','Template-Toolkit-2.10.tar.gz','VCG-0.5.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'File::Find' => 0,'Getopt::Std' => 0,'GraphViz' => 0,'Inline' => 0,'Inline::Java' => 0,'Template' => 0,'VCG' => '0.4','XML::Simple' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','Heap-0.50.tar.gz','IPC-Run-0.75.tar.gz','Inline-0.44.tar.gz','Inline-Java-0.41.tar.gz','Math-Bezier-0.01.tar.gz','Parse-RecDescent-1.94.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','VCG-0.5.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 47778,'unpacked' => 212047},'testers' => {'pass' => 2},'uses' => ['DBI','Data::Dumper','Exporter','GraphViz','Inline::Java','Template','VCG','XML::Simple','strict','vars']},'Aviation-Report-1.02.tar.gz' => {'author' => 'JBRIGGS','description' => 'Perl extension for translating U.S. METAR, TAF and PIREP textual reports into plain English.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 516,'pod' => 27,'pod_errors' => 0,'total' => 543,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 7362,'unpacked' => 21702},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'Aw-0.16.7.tar.gz' => {'author' => 'DYACOB','description' => 'Perl extension for the ActiveWorks C Application Development Kit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2387,'pod' => 472,'pod_errors' => 0,'total' => 2859,'with_comments' => 165},'releases' => 23,'requires' => ['CORBA-ORBit-0.4.3.tar.gz'],'requires_module' => {'CORBA::LongLong' => 0},'requires_recursive' => ['CORBA-ORBit-0.4.3.tar.gz'],'size' => {'packed' => 131505,'unpacked' => 775062},'testers' => {},'uses' => ['Apache::Constants','Apache::Request','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'AxKit-1.5.2.tar.gz' => {'author' => 'MSERGEANT','description' => 'an XML Application Server for Apache','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7063,'pod' => 1613,'pod_errors' => 0,'total' => 8676,'with_comments' => 545},'releases' => 16,'size' => {'packed' => 273641,'unpacked' => 751381},'testers' => {'fail' => 2,'tests' => '113'},'uses' => ['5.006','Apache','Apache::AxKit::Cache','Apache::AxKit::CharsetConv','Apache::AxKit::ConfigReader','Apache::AxKit::Exception','Apache::AxKit::Language::LibXSLT','Apache::AxKit::Language::XPathScript','Apache::AxKit::Language::XSP','Apache::AxKit::Language::XSP::SimpleTaglib','Apache::AxKit::Provider','Apache::AxKit::Provider::File','Apache::AxKit::Provider::Scalar','Apache::Constants','Apache::Cookie','Apache::File','Apache::Log','Apache::Peek','Apache::Request','Apache::URI','AxKit','Compress::Zlib','Cwd','DBI','Data::Dumper','DynaLoader','Error','Exporter','Fcntl','File::Basename','File::Spec','HTTP::GHTTP','IPC::Run','LWP::Simple','Time::HiRes','Time::Piece','XML::DOM','XML::Handler::AxPoint','XML::LibXML','XML::LibXSLT','XML::Parser','XML::SAX','XML::SAX::Writer','XML::XPath','XML::XPath::Node','XML::XPath::NodeSet','XML::XPath::Parser','XML::XPath::XMLParser','XMLNews::HTMLTemplate','attributes','constant','overload','strict','vars']},'AxKit-1.6.1.tar.gz' => {'author' => 'MSERGEANT','description' => 'an XML Application Server for Apache','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9032,'pod' => 2283,'pod_errors' => 0,'total' => 11315,'with_comments' => 711},'releases' => 16,'size' => {'packed' => 300610,'unpacked' => 844024},'testers' => {},'uses' => ['5.006','Apache','Apache::AxKit::Language','Apache::Constants','Apache::Cookie','Apache::File','Apache::Log','Apache::Peek','Apache::Request','Apache::URI','CPAN','CPANPLUS::Backend','CPANPLUS::Shell::Default','Carp','Compress::Zlib','Cwd','DBI','Data::Dumper','DynaLoader','Error','Exporter','ExtUtils::Manifest','Fcntl','File::Basename','File::Spec','HTTP::GHTTP','IPC::Run','LWP::Simple','Perl::Tidy','Socket','Time::HiRes','Time::Piece','WeakRef','XML::DOM','XML::Handler::AxPoint','XML::LibXML','XML::LibXML::SAX::Builder','XML::LibXSLT','XML::Parser','XML::SAX','XML::SAX::Machines','XML::SAX::Writer','XML::XPath','XML::XPath::Node','XML::XPath::NodeSet','XML::XPath::Parser','XML::XPath::XMLParser','XMLNews::HTMLTemplate','attributes','constant','overload','strict','vars']},'AxKit-1.6.tar.gz' => {'author' => 'MSERGEANT','description' => 'an XML Application Server for Apache','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7492,'pod' => 1720,'pod_errors' => 0,'total' => 9212,'with_comments' => 575},'releases' => 16,'size' => {'packed' => 278788,'unpacked' => 768773},'testers' => {},'uses' => ['5.006','Apache','Apache::AxKit::Cache','Apache::AxKit::CharsetConv','Apache::AxKit::ConfigReader','Apache::AxKit::Exception','Apache::AxKit::Language','Apache::AxKit::Language::LibXSLT','Apache::AxKit::Language::XPathScript','Apache::AxKit::Language::XSP','Apache::AxKit::Language::XSP::SimpleTaglib','Apache::AxKit::Provider','Apache::AxKit::Provider::File','Apache::AxKit::Provider::Scalar','Apache::Constants','Apache::Cookie','Apache::File','Apache::Log','Apache::Peek','Apache::Request','Apache::URI','AxKit','Compress::Zlib','Cwd','DBI','Data::Dumper','DynaLoader','Error','Exporter','Fcntl','File::Basename','HTTP::GHTTP','IPC::Run','LWP::Simple','Time::HiRes','Time::Piece','XML::DOM','XML::Handler::AxPoint','XML::LibXML','XML::LibXML::SAX::Builder','XML::LibXSLT','XML::Parser','XML::SAX','XML::SAX::Machines','XML::SAX::Writer','XML::XPath','XML::XPath::Node','XML::XPath::NodeSet','XML::XPath::Parser','XML::XPath::XMLParser','XMLNews::HTMLTemplate','attributes','constant','overload','strict','vars']},'AxKit-App-Gallery-0.4.tar.gz' => {'author' => 'NIKC','description' => 'web based image galleries using AxKit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 545,'pod' => 602,'pod_errors' => 0,'total' => 1147,'with_comments' => 185},'releases' => 1,'requires' => ['AxKit-1.6.1.tar.gz','Data-Page-0.18.tar.gz','Image-Info-1.12.tar.gz','Imager-0.41.tar.gz','URI-1.24.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'AxKit' => '1.61','Data::Page' => '0.15','Image::Info' => '1.08','Imager' => '0.41','URI' => '1.23','XML::LibXML' => '1.52','XML::LibXSLT' => '1.53','XML::Simple' => '1.08'},'requires_recursive' => ['AxKit-1.6.1.tar.gz','Data-Page-0.18.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Image-Info-1.12.tar.gz','Imager-0.41.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18326,'unpacked' => 77179},'testers' => {},'uses' => ['Apache::AxKit::Exception','Apache::AxKit::Provider::File','Apache::Constants','Apache::Request','Data::Dumper','File::Path','Image::Info','Imager','URI','URI::Escape','strict','vars']},'AxKit-Plugin-DisableXSLTParams-0.01.tar.gz' => {'author' => 'RBERJON','description' => 'Disable XSLT Params','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 41,'pod' => 30,'pod_errors' => 0,'total' => 71,'with_comments' => 13},'releases' => 1,'requires' => ['AxKit-1.6.1.tar.gz'],'requires_module' => {'AxKit' => '1.5'},'requires_recursive' => ['AxKit-1.6.1.tar.gz'],'size' => {'packed' => 1589,'unpacked' => 3363},'testers' => {},'uses' => ['strict','vars']},'AxKit-Provider-HTML-1.0.tar.gz' => {'author' => 'MSERGEANT','description' => 'AxKit Provider Module for HTML files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 23,'pod_errors' => 0,'total' => 52,'with_comments' => 1},'releases' => 1,'requires' => ['AxKit-1.6.1.tar.gz','XML-LibXML-1.54.tar.gz'],'requires_module' => {'AxKit' => '1.5','XML::LibXML' => '1.50'},'requires_recursive' => ['AxKit-1.6.1.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 1891,'unpacked' => 3463},'testers' => {'fail' => 1,'tests' => '4'},'uses' => ['Apache::AxKit::Exception','Apache::AxKit::Provider::File','XML::LibXML','strict']},'AxKit-XSP-AttrParam-0.01.tar.gz' => {'author' => 'RBERJON','description' => 'XSP taglib for HTTP request parameters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 58,'pod_errors' => 0,'total' => 140,'with_comments' => 8},'releases' => 1,'requires' => ['AxKit-1.6.1.tar.gz'],'requires_module' => {'AxKit' => '1.3_95'},'requires_recursive' => ['AxKit-1.6.1.tar.gz'],'size' => {'packed' => 2706,'unpacked' => 5441},'testers' => {'pass' => 1},'uses' => ['Apache::AxKit::Language::XSP','strict','vars']},'AxKit-XSP-BasicSession-0.15.tar.gz' => {'author' => 'NACHBAUR','description' => 'Session wrapper tag library for AxKit eXtesible Server Pages.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 304,'pod' => 233,'pod_errors' => 0,'total' => 537,'with_comments' => 16},'releases' => 3,'requires' => ['Apache-Session-1.54.tar.gz','AxKit-1.5.2.tar.gz','AxKit-1.6.1.tar.gz','TimeDate-1.16.tar.gz','libapreq-1.2.tar.gz'],'requires_module' => {'Apache::AxKit::Language::XSP::TaglibHelper' => 0,'Apache::Cookie' => 0,'Apache::Session::Flex' => 0,'AxKit' => '1.6','Date::Format' => 0},'requires_recursive' => ['Apache-Session-1.54.tar.gz','AxKit-1.5.2.tar.gz','AxKit-1.6.1.tar.gz','TimeDate-1.16.tar.gz','libapreq-1.2.tar.gz'],'size' => {'packed' => 8024,'unpacked' => 21917},'testers' => {'fail' => 1},'uses' => ['Apache','Apache::AxKit::Language::XSP::TaglibHelper','Apache::Constants','Apache::Cookie','Apache::Request','Apache::Session','Apache::Session::Flex','Apache::URI','Date::Format','constant','lib','strict','vars']},'AxKit-XSP-Blog-0.01.tar.gz' => {'author' => 'DRRHO','description' => 'XSP taglib to include Blogs (weblogs)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 101,'pod' => 120,'pod_errors' => 0,'total' => 221,'with_comments' => 8},'releases' => 1,'requires' => ['AxKit-1.6.1.tar.gz','DBI-1.37.tar.gz','Getopt-Long-2.33.tar.gz','IO-1.20.tar.gz','Net-Blogger-0.86.tar.gz','PodParser-1.23.tar.gz','Time-Local-1.07.tar.gz','TimeDate-1.16.tar.gz','XML-Writer-0.4.tar.gz','XML-XPath-1.13.tar.gz'],'requires_module' => {'Apache::AxKit::Language::XSP::SimpleTaglib' => '0.1','AxKit' => '1.6','DBI' => '1.21','Date::Format' => '2.22','Getopt::Long' => '2.32','IO' => '1.2','IO::Handle' => '1.21','Net::Blogger' => '','Pod::Usage' => '1.14','Time::Local' => undef,'XML::Writer' => '0.4','XML::XPath' => '1.12'},'requires_recursive' => ['AxKit-1.6.1.tar.gz','CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-Blogger-0.86.tar.gz','PodParser-1.23.tar.gz','SOAP-Lite-0.55.tar.gz','TermReadKey-2.21.tar.gz','Time-Local-1.07.tar.gz','TimeDate-1.16.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz','XML-XPath-1.13.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18948,'unpacked' => 66772},'testers' => {},'uses' => ['Apache::AxKit::Language::XSP::SimpleTaglib','DBI','Data::Dumper','LWP::Simple','strict']},'AxKit-XSP-CharsetConv-0.02.tar.gz' => {'author' => 'RBERJON','description' => 'AxKit XSP taglib for charset conversion','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 36,'pod_errors' => 0,'total' => 130,'with_comments' => 15},'releases' => 2,'requires' => ['AxKit-1.6.1.tar.gz'],'requires_module' => {'AxKit' => '1.4'},'requires_recursive' => ['AxKit-1.6.1.tar.gz'],'size' => {'packed' => 2413,'unpacked' => 5138},'testers' => {},'uses' => ['Apache::AxKit::CharsetConv','Apache::AxKit::Language::XSP','strict','vars']},'AxKit-XSP-Cookie-1.41.tar.gz' => {'author' => 'MSERGEANT','description' => 'An XSP library for setting and getting HTTP cookies.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 144,'pod_errors' => 0,'total' => 318,'with_comments' => 6},'releases' => 3,'requires' => ['AxKit-1.6.1.tar.gz','libapreq-1.2.tar.gz'],'requires_module' => {'Apache::Cookie' => 0,'AxKit' => '1.4'},'requires_recursive' => ['AxKit-1.6.1.tar.gz','libapreq-1.2.tar.gz'],'size' => {'packed' => 3803,'unpacked' => 11936},'testers' => {'pass' => 1},'uses' => ['Apache::AxKit::Language::XSP','Apache::Cookie','strict','vars']},'AxKit-XSP-ESQL-1.4.tar.gz' => {'author' => 'MSERGEANT','description' => 'An Extended SQL taglib for AxKit eXtensible Server Pages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 539,'pod' => 247,'pod_errors' => 0,'total' => 786,'with_comments' => 16},'releases' => 3,'requires' => ['AxKit-1.6.1.tar.gz','AxKit-XSP-Util-1.6.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'AxKit' => '1.4','AxKit::XSP::Util' => 1,'DBI' => 1},'requires_recursive' => ['AxKit-1.6.1.tar.gz','AxKit-XSP-Util-1.6.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTTP-GHTTP-1.07.tar.gz','Time-Piece-1.08.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6564,'unpacked' => 23711},'testers' => {'pass' => 1},'uses' => ['Apache::AxKit::Language::XSP','AxKit::XSP::Util','DBI','strict','vars']},'AxKit-XSP-Exception-1.6.tar.gz' => {'author' => 'MSERGEANT','description' => 'Exceptions taglib for eXtensible Server Pages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 109,'pod' => 50,'pod_errors' => 0,'total' => 159,'with_comments' => 8},'releases' => 3,'requires' => ['AxKit-1.6.1.tar.gz'],'requires_module' => {'AxKit' => '1.4'},'requires_recursive' => ['AxKit-1.6.1.tar.gz'],'size' => {'packed' => 2612,'unpacked' => 5560},'testers' => {'pass' => 1},'uses' => ['Apache::AxKit::Language::XSP','strict','vars']},'AxKit-XSP-IfParam-1.4.tar.gz' => {'author' => 'MSERGEANT','description' => 'Equivalent of XSP Param taglib, but conditional.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 54,'pod_errors' => 0,'total' => 85,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 1439,'unpacked' => 2118},'testers' => {'fail' => 3,'pass' => 1,'tests' => '2'},'uses' => ['Apache::AxKit::Language::XSP','strict','vars']},'AxKit-XSP-LDAP-0.1.tar.gz' => {'author' => 'CTHOM','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 237,'pod_errors' => 0,'total' => 357,'with_comments' => 7},'releases' => 1,'requires' => ['perl-ldap-0.29.tar.gz'],'requires_module' => {'Net::LDAP' => '0.25'},'requires_recursive' => ['Convert-ASN1-0.17.tar.gz','perl-ldap-0.29.tar.gz'],'size' => {'packed' => 4408,'unpacked' => 11425},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Apache::AxKit::Language::XSP::TaglibHelper','AxKit','AxKit::XSP::WebUtils','Net::LDAP','strict']},'AxKit-XSP-MD5-0.01.tar.gz' => {'author' => 'RBERJON','description' => 'AxKit XSP taglib for MD5 digests','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 84,'pod' => 34,'pod_errors' => 0,'total' => 118,'with_comments' => 14},'releases' => 1,'requires' => ['AxKit-1.6.1.tar.gz','Digest-MD5-2.26.tar.gz'],'requires_module' => {'AxKit' => '1.4','Digest::MD5' => '0'},'requires_recursive' => ['AxKit-1.6.1.tar.gz','Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 2083,'unpacked' => 4093},'testers' => {'pass' => 1},'uses' => ['Apache::AxKit::Language::XSP','Digest::MD5','strict','vars']},'AxKit-XSP-Minisession-1.02.tar.gz' => {'author' => 'SIMON','description' => 'Yet Another Session Handling Library','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 141,'pod' => 42,'pod_errors' => 0,'total' => 183,'with_comments' => 5},'releases' => 3,'size' => {'packed' => 3791,'unpacked' => 8907},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['Apache::Cookie','Apache::Log','Apache::Session::File','strict','vars']},'AxKit-XSP-Param-1.4.tar.gz' => {'author' => 'MSERGEANT','description' => 'A namespace wrapper for accessing HTTP request paramaters.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 77,'pod_errors' => 0,'total' => 130,'with_comments' => 9},'releases' => 2,'requires' => ['AxKit-1.6.1.tar.gz'],'requires_module' => {'AxKit' => '1.4'},'requires_recursive' => ['AxKit-1.6.1.tar.gz'],'size' => {'packed' => 2573,'unpacked' => 5700},'testers' => {},'uses' => ['Apache::AxKit::Language::XSP','strict','vars']},'AxKit-XSP-PerForm-1.8.2.tar.gz' => {'author' => 'MSERGEANT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 915,'pod' => 625,'pod_errors' => 0,'total' => 1540,'with_comments' => 28},'releases' => 6,'requires' => ['AxKit-1.6.1.tar.gz','AxKit-XSP-WebUtils-1.6.tar.gz'],'requires_module' => {'AxKit' => '1.4','AxKit::XSP::WebUtils' => '1.5'},'requires_recursive' => ['AxKit-1.6.1.tar.gz','AxKit-XSP-WebUtils-1.6.tar.gz'],'size' => {'packed' => 13241,'unpacked' => 54608},'testers' => {},'uses' => ['Apache','Apache::AxKit::Language::XSP::TaglibHelper','AxKit','AxKit::XSP::WebUtils','strict','vars']},'AxKit-XSP-Sendmail-1.4.tar.gz' => {'author' => 'MSERGEANT','description' => 'Simple SMTP mailer tag library for AxKit eXtesible Server Pages.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 97,'pod_errors' => 0,'total' => 273,'with_comments' => 13},'releases' => 2,'requires' => ['AxKit-1.6.1.tar.gz','Email-Valid-0.14.tar.gz','Mail-Sendmail-0.79.tar.gz'],'requires_module' => {'AxKit' => '1.4','Email::Valid' => 0,'Mail::Sendmail' => 0},'requires_recursive' => ['AxKit-1.6.1.tar.gz','Email-Valid-0.14.tar.gz','Mail-Sendmail-0.79.tar.gz','MailTools-1.58.tar.gz'],'size' => {'packed' => 3683,'unpacked' => 8760},'testers' => {},'uses' => ['Apache::AxKit::CharsetConv','Apache::AxKit::Language::XSP','Carp','Email::Valid','Mail::Sendmail','strict','vars']},'AxKit-XSP-Session-0.11.tar.gz' => {'author' => 'NACHBAUR','description' => 'Session wrapper tag library for AxKit eXtesible Server Pages.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 407,'pod' => 184,'pod_errors' => 0,'total' => 591,'with_comments' => 30},'releases' => 2,'requires' => ['Apache-Session-1.54.tar.gz'],'requires_module' => {'Apache::Session::Flex' => 0},'requires_recursive' => ['Apache-Session-1.54.tar.gz'],'size' => {'packed' => 6727,'unpacked' => 18774},'testers' => {'fail' => 3,'pass' => 1,'tests' => '1'},'uses' => ['Apache','Apache::AxKit::Language::XSP','Apache::Request','Apache::Session','Apache::Session::Flex','Carp','Date::Format','constant','lib','strict','vars']},'AxKit-XSP-Swish-0.2a.tar.gz' => {'author' => 'FMACHABEE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 91,'pod' => 117,'pod_errors' => 0,'total' => 208,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 3071,'unpacked' => 5978},'testers' => {'fail' => 5},'uses' => ['Apache::AxKit::Language::XSP::TaglibHelper','SWISHE','strict','vars']},'AxKit-XSP-Util-1.6.tar.gz' => {'author' => 'MSERGEANT','description' => 'XSP util: taglib.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 73,'pod_errors' => 0,'total' => 295,'with_comments' => 17},'releases' => 4,'requires' => ['AxKit-1.6.1.tar.gz','HTTP-GHTTP-1.07.tar.gz','Time-Piece-1.08.tar.gz','XML-LibXML-1.54.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::File' => 0,'AxKit' => '1.5','HTTP::GHTTP' => 1,'Time::Piece' => 1,'XML::LibXML' => '1.31'},'requires_recursive' => ['AxKit-1.6.1.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTTP-GHTTP-1.07.tar.gz','Time-Piece-1.08.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3513,'unpacked' => 8997},'testers' => {'pass' => 1},'uses' => ['Apache::AxKit::Language::XSP','Apache::File','HTTP::GHTTP','Time::Piece','XML::LibXML','strict','vars']},'AxKit-XSP-WebUtils-1.6.tar.gz' => {'author' => 'MSERGEANT','description' => 'Utilities for building XSP web apps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 331,'pod' => 285,'pod_errors' => 0,'total' => 616,'with_comments' => 14},'releases' => 3,'requires' => ['AxKit-1.6.1.tar.gz'],'requires_module' => {'AxKit' => '1.4'},'requires_recursive' => ['AxKit-1.6.1.tar.gz'],'size' => {'packed' => 5347,'unpacked' => 15043},'testers' => {},'uses' => ['Apache','Apache::AxKit::Language::XSP::TaglibHelper','Apache::Constants','Apache::Request','Apache::URI','Apache::Util','AxKit','strict']},'AxKit-XSP-Wiki-0.06.tar.gz' => {'author' => 'MSERGEANT','description' => 'An AxKit XSP based Wiki clone','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 422,'pod' => 25,'pod_errors' => 0,'total' => 447,'with_comments' => 16},'releases' => 6,'requires' => ['AxKit-1.6.1.tar.gz','DBD-SQLite-0.25.tar.gz','Pod-SAX-0.14.tar.gz','Text-WikiFormat-SAX-0.03.tar.gz','XML-LibXML-1.54.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'AxKit' => '1.52','DBD::SQLite' => 0,'Pod::SAX' => '0.04','Text::WikiFormat::SAX' => 0,'XML::LibXML' => '1.52','XML::SAX::Writer' => 0},'requires_recursive' => ['AxKit-1.6.1.tar.gz','DBD-SQLite-0.25.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Pod-SAX-0.14.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','Text-WikiFormat-SAX-0.03.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9115,'unpacked' => 31704},'testers' => {},'uses' => ['Apache::AxKit::Language::XSP::TaglibHelper','DBI','Fatal','Pod::SAX','Text::WikiFormat::SAX','XML::LibXML::SAX::Parser','XML::SAX::Writer','strict','vars']},'B-Deobfuscate-0.10.tar.gz' => {'author' => 'JJORE','description' => 'Deobfuscation support utility','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 946,'pod' => 153,'pod_errors' => 0,'total' => 1099,'with_comments' => 21},'releases' => 7,'requires' => ['B-Keywords-0.05.tar.gz','YAML-0.35.tar.gz'],'requires_module' => {'B::Keywords' => '0.03','YAML' => '0'},'requires_recursive' => ['B-Keywords-0.05.tar.gz','YAML-0.35.tar.gz'],'size' => {'packed' => 12563,'unpacked' => 29058},'testers' => {'pass' => 1},'uses' => ['B::Deparse','Carp','YAML','strict','warnings']},'B-Fathom-0.07.tar.gz' => {'author' => 'KSTAR','description' => 'Estimate the readability of Perl code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 341,'pod' => 60,'pod_errors' => 0,'total' => 401,'with_comments' => 61},'releases' => 7,'size' => {'packed' => 5641,'unpacked' => 14193},'testers' => {'pass' => 12},'uses' => ['B','strict','vars']},'B-Flags-0.01.tar.gz' => {'author' => 'SIMON','description' => 'Friendlier flags for B','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 30,'pod_errors' => 0,'total' => 59,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 4329,'unpacked' => 16590},'testers' => {'pass' => 3},'uses' => ['5.005_62','B','DynaLoader','strict','warnings']},'B-Generate-1.06.tar.gz' => {'author' => 'ABERGMAN','description' => 'Create your own op trees.','files' => ['Makefile.PL','Build.PL','MANIFEST'],'lines' => {'nonpod' => 145,'pod' => 116,'pod_errors' => 0,'total' => 261,'with_comments' => 5},'releases' => 12,'size' => {'packed' => 12379,'unpacked' => 43479},'testers' => {'fail' => 3,'pass' => 5},'uses' => ['5.005_62','B','DynaLoader','constant','strict','warnings']},'B-Graph-0.51.tar.gz' => {'author' => 'SMCCAM','description' => 'Perl Compiler backend to diagram OP trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1003,'pod' => 130,'pod_errors' => 0,'total' => 1133,'with_comments' => 15},'releases' => 4,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'B' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 12505,'unpacked' => 38377},'testers' => {'pass' => 11},'uses' => ['5.004','B','B::Asmdata','strict','vars']},'B-JVM-Jasmin-0.01.tar.gz' => {'author' => 'BJEPS','description' => 'Jasmin backend for the Perl compiler.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 371,'pod' => 27,'pod_errors' => 0,'total' => 398,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 3942,'unpacked' => 10687},'testers' => {'pass' => 2},'uses' => ['B','B::Asmdata','strict','vars']},'B-JVM-Jasmin-0.02.tar.gz' => {'author' => 'BKUHN','description' => 'Perl Backend module for generating JVM code via Jasmin Assembler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2405,'pod' => 969,'pod_errors' => 0,'total' => 3374,'with_comments' => 235},'releases' => 2,'size' => {'packed' => 44224,'unpacked' => 185954},'testers' => {'fail' => 1},'uses' => ['5.000562','AutoLoader','B','Carp','Exporter','File::Spec::Functions','IO::File','strict','vars','warnings']},'B-Keywords-0.05.tar.gz' => {'author' => 'JJORE','description' => 'Lists of reserved barewords and symbol names','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 350,'pod' => 35,'pod_errors' => 0,'total' => 385,'with_comments' => 1},'releases' => 5,'size' => {'packed' => 3754,'unpacked' => 7479},'testers' => {'pass' => 3},'uses' => ['5.006','strict','vars','warnings']},'B-LexInfo-0.02.tar.gz' => {'author' => 'DOUGM','description' => 'Show info about subroutine lexical variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 274,'pod' => 137,'pod_errors' => 0,'total' => 411,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 4939,'unpacked' => 13987},'testers' => {'pass' => 1,'tests' => '0','unknown' => 21},'uses' => ['B::Asmdata','Data::Dumper','Tie::IxHash','strict','vars']},'B-More-1.01.tar.gz' => {'author' => 'XMATH','description' => 'Additional introspection methods and functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 46,'pod' => 53,'pod_errors' => 0,'total' => 99,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 2709,'unpacked' => 6241},'testers' => {'pass' => 11},'uses' => ['5.006','B','Carp','XSLoader','strict','warnings']},'B-Size-0.05.tar.gz' => {'author' => 'DOUGM','description' => 'Info about ops and their (estimated) size','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 835,'pod' => 54,'pod_errors' => 0,'total' => 889,'with_comments' => 36},'releases' => 3,'size' => {'packed' => 9548,'unpacked' => 28103},'testers' => {'pass' => 7},'uses' => ['B::Asmdata','strict']},'B-Tree-0.02.tar.gz' => {'author' => 'SIMON','description' => 'Simplified version of B::Graph for demonstration','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 25,'pod_errors' => 0,'total' => 100,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 1805,'unpacked' => 3529},'testers' => {'fail' => 3,'pass' => 3},'uses' => ['B','GraphViz','strict']},'B-Utils-0.04.tar.gz' => {'author' => 'SIMON','description' => 'Helper functions for op tree manipulation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 305,'pod' => 130,'pod_errors' => 0,'total' => 435,'with_comments' => 18},'releases' => 4,'size' => {'packed' => 6313,'unpacked' => 17494},'testers' => {'pass' => 14},'uses' => ['5.006','B','Carp','strict','warnings']},'BBDB-1.34.tar.gz' => {'author' => 'LAXEN','description' => 'Insiduous big brother database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 537,'pod' => 194,'pod_errors' => 0,'total' => 731,'with_comments' => 109},'releases' => 7,'size' => {'packed' => 9507,'unpacked' => 29629},'testers' => {'pass' => 11},'uses' => ['Exporter','strict','vars']},'BFD-0.3.tar.gz' => {'author' => 'RBS','description' => 'Impromptu dumping of data structures for debugging purposes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 51,'pod_errors' => 0,'total' => 128,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 2389,'unpacked' => 5319},'testers' => {'pass' => 12},'uses' => ['Cwd','Data::Dumper','File::Spec','strict','vars']},'BIND-Conf_Parser-0.95.tar.gz' => {'author' => 'PGUEN','description' => 'Parser class for BIND configuration files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 967,'pod' => 128,'pod_errors' => 0,'total' => 1095,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 12705,'unpacked' => 43833},'testers' => {'pass' => 3},'uses' => ['Carp','IO::File','IO::Scalar','constant','integer','strict','vars']},'BSD-Ipfwgen-1.5.tar.gz' => {'author' => 'MUIR','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1199,'pod' => 442,'pod_errors' => 0,'total' => 1641,'with_comments' => 80},'releases' => 6,'size' => {'packed' => 12745,'unpacked' => 45852},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','Exporter','IO::Handle','integer','vars']},'BSD-Itimer-0.8.tar.gz' => {'author' => 'HAG','description' => 'Perl extension for accessing interval timers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 99,'pod' => 52,'pod_errors' => 0,'total' => 151,'with_comments' => 21},'releases' => 1,'size' => {'packed' => 4282,'unpacked' => 10544},'testers' => {'pass' => 4},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'BSD-Resource-1.22.tar.gz' => {'author' => 'JHI','description' => 'getrusage(), s/getrlimit(), s/getpriority()','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 288,'pod' => 292,'pod_errors' => 0,'total' => 580,'with_comments' => 9},'releases' => 20,'size' => {'packed' => 17826,'unpacked' => 56235},'testers' => {'pass' => 9},'uses' => ['5.002','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'BSD-stat-1.21.tar.gz' => {'author' => 'DANKOGAI','description' => 'stat() with BSD 4.4 extentions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 211,'pod' => 152,'pod_errors' => 0,'total' => 363,'with_comments' => 17},'releases' => 15,'size' => {'packed' => 8805,'unpacked' => 24616},'testers' => {},'uses' => ['5.00503','AutoLoader','Carp','Devel::Peek','DynaLoader','Exporter','constant','strict','vars','warnings']},'BTRIEVE-SAVE-0.35.tar.gz' => {'author' => 'DLANE','description' => 'Read-write access to BTRIEVE SAVE files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 768,'pod' => 486,'pod_errors' => 0,'total' => 1254,'with_comments' => 143},'releases' => 1,'size' => {'packed' => 18575,'unpacked' => 61911},'testers' => {'pass' => 11},'uses' => ['5.004','Carp','Exporter','strict','vars']},'BabelObjects-1.01.tar.gz' => {'author' => 'KERMAGO','description' => 'logs events events in a very simple way.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1168,'pod' => 169,'pod_errors' => 0,'total' => 1337,'with_comments' => 363},'releases' => 2,'requires' => ['XML-DOM-1.42.tar.gz'],'requires_module' => {'XML::DOM' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12306,'unpacked' => 61739},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['AutoLoader','Carp','Exporter','XML::DOM','strict','vars']},'BabelObjects-Component-Data-Configurator-1.01.tar.gz' => {'author' => 'KERMAGO','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 186,'pod' => 24,'pod_errors' => 0,'total' => 210,'with_comments' => 63},'releases' => 2,'requires' => ['XML-DOM-1.42.tar.gz'],'requires_module' => {'XML::DOM' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 32289,'unpacked' => 141165},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['AutoLoader','BabelObjects::Util::Dvlpt::Log','BabelObjects::Util::Facility::XMLFacility','Carp','Exporter','strict','vars']},'BabelObjects-Component-Directory-Bookmark-1.00.tar.gz' => {'author' => 'KERMAGO','description' => 'loads user bookmark and puts it on the web','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 300,'pod' => 29,'pod_errors' => 0,'total' => 329,'with_comments' => 62},'releases' => 1,'requires' => ['URI-Bookmarks-0.92.tar.gz','XML-DOM-1.42.tar.gz'],'requires_module' => {'URI::Bookmarks' => 0,'XML::DOM' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Tree-DAG_Node-1.04.tar.gz','URI-1.24.tar.gz','URI-Bookmarks-0.92.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7005,'unpacked' => 18230},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['AutoLoader','BabelObjects::Util::Dvlpt::Log','Carp','Exporter','URI::Bookmarks','strict','vars']},'Barcode-Code128-2.00.tar.gz' => {'author' => 'WRW','description' => 'Generate CODE 128 bar codes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 624,'pod' => 288,'pod_errors' => 0,'total' => 912,'with_comments' => 29},'releases' => 4,'size' => {'packed' => 14631,'unpacked' => 39052},'testers' => {'pass' => 8},'uses' => ['5.004','Carp','Exporter','strict','vars']},'Barcode-Cuecat-1.20.tar.gz' => {'author' => 'LUISMUNOZ','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 96,'pod' => 58,'pod_errors' => 0,'total' => 154,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 2802,'unpacked' => 5381},'testers' => {'pass' => 4},'uses' => ['5.005_62','strict','warnings']},'BaseLib-0.05.tar.gz' => {'author' => 'HASANT','description' => 'manipulate @INC dynamically for independent installation path','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 87,'pod_errors' => 0,'total' => 182,'with_comments' => 13},'releases' => 2,'size' => {'packed' => 8109,'unpacked' => 22394},'testers' => {'pass' => 5},'uses' => ['Carp','Cwd','File::Basename','File::Spec','lib','strict']},'Batch-Batchrun-1.03.tar.gz' => {'author' => 'BRTEAM','description' => 'Batch Control language','files' => [],'lines' => {'nonpod' => 6929,'pod' => 406,'pod_errors' => 1,'total' => 7335,'with_comments' => 1435},'releases' => 1,'size' => {'packed' => 45896,'unpacked' => 244469},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Batch::Batchrun::Commands','Batch::Batchrun::Library','Batch::Batchrun::RunCommand','Config','Cwd','DBI','Env','Exporter','File::Basename','File::Copy','File::Path','Getopt::Mixed','MIME::Lite','strict','vars']},'Be-Attribute-0.1.tar.gz' => {'author' => 'TSPIN','description' => 'Manipulate BeOS BFS MIME file attributes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 30,'pod' => 31,'pod_errors' => 0,'total' => 61,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 2987,'unpacked' => 6103},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Be-Query-0.1.tar.gz' => {'author' => 'TSPIN','description' => 'Query a BeOS file system','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 33,'pod' => 32,'pod_errors' => 0,'total' => 65,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 2604,'unpacked' => 4696},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Beautifier-0.04.tar.gz' => {'author' => 'TEUN','description' => 'Perl extension for beautifying/styling/prettyprinting perl code.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 186,'pod' => 57,'pod_errors' => 0,'total' => 243,'with_comments' => 30},'releases' => 4,'size' => {'packed' => 4046,'unpacked' => 10423},'testers' => {'pass' => 3},'uses' => ['strict','warnings']},'Befunge-Interpreter-0.01c.tar.gz' => {'author' => 'JHARDING','description' => 'Perl extension for interpreting befunge.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 357,'pod' => 35,'pod_errors' => 0,'total' => 392,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 6379,'unpacked' => 17275},'testers' => {'pass' => 6},'uses' => []},'Benchmark-Thread-Size-0.03.tar.gz' => {'author' => 'ELIZABETH','description' => 'report size of threads for different code approaches','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 312,'pod' => 130,'pod_errors' => 0,'total' => 442,'with_comments' => 62},'releases' => 2,'size' => {'packed' => 6547,'unpacked' => 17064},'testers' => {},'uses' => ['strict']},'Benchmark-Timer-0.5.tar.gz' => {'author' => 'ANDREWHO','description' => 'Perl code benchmarking tool','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 320,'pod' => 85,'pod_errors' => 0,'total' => 405,'with_comments' => 47},'releases' => 2,'requires' => ['Time-HiRes-1.49.tar.gz'],'requires_module' => {'Time::HiRes' => 0},'requires_recursive' => ['Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 7841,'unpacked' => 30397},'testers' => {'pass' => 11},'uses' => ['5.005','Carp','Time::HiRes','constant','strict','vars']},'Benchmark-Timer-Class-0.02.tar.gz' => {'author' => 'DNEIL','description' => 'Perl module for timing the execution of methods in a specified object','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 58,'pod_errors' => 0,'total' => 178,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 3190,'unpacked' => 7333},'testers' => {'fail' => 2,'pass' => 3},'uses' => ['Benchmark::Timer','Exporter','strict','vars']},'BerkDB-0.01.tar.gz' => {'author' => 'PMQS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 586,'pod' => 320,'pod_errors' => 0,'total' => 906,'with_comments' => 54},'releases' => 1,'size' => {'packed' => 22535,'unpacked' => 95626},'testers' => {'fail' => 2},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','FileHandle','UNIVERSAL','strict','vars']},'BerkeleyDB-0.23.tar.gz' => {'author' => 'PMQS','description' => 'Interface to Berkeley DB version 2, 3 or 4','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2180,'pod' => 1562,'pod_errors' => 2,'total' => 3742,'with_comments' => 209},'releases' => 22,'size' => {'packed' => 123886,'unpacked' => 704352},'testers' => {'pass' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','File::Path','Symbol','UNIVERSAL','strict','vars']},'BerkeleyDB-Lite-0_40.tar.gz' => {'author' => 'TQISJIM','description' => 'Simplified Access to BerkeleyDB Methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 489,'pod' => 187,'pod_errors' => 0,'total' => 676,'with_comments' => 39},'releases' => 1,'requires' => ['BerkeleyDB-0.23.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'BerkeleyDB' => 0,'Storable' => 0},'requires_recursive' => ['BerkeleyDB-0.23.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7351,'unpacked' => 20016},'testers' => {'pass' => 3},'uses' => ['5.006','BerkeleyDB','BerkeleyDB::Lite::Hash','Carp','Exporter','Storable','strict','warnings']},'BerkeleyDB_Locks_0_02.tar.gz' => {'author' => 'TQISJIM','description' => 'Berkeley lock subsystem toolkit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 142,'pod' => 80,'pod_errors' => 0,'total' => 222,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 6820,'unpacked' => 16331},'testers' => {},'uses' => ['5.006','DynaLoader','Exporter','strict','warnings']},'Biblio-Thesaurus-0.16.tar.gz' => {'author' => 'AMBS','description' => 'A Multi-Lingue Thesaurus tool;','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1441,'pod' => 477,'pod_errors' => 0,'total' => 1918,'with_comments' => 236},'releases' => 2,'requires' => ['Storable-2.07.tar.gz'],'requires_module' => {'Storable' => '1.0006'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 21224,'unpacked' => 63301},'testers' => {'pass' => 3},'uses' => ['5.6.0','CGI','Data::Dumper','Exporter','Storable','strict','warnings']},'BikePower-0.33.tar.gz' => {'author' => 'SREZIC','description' => 'bicycle power-output calculator with command-line and Tk interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1546,'pod' => 193,'pod_errors' => 0,'total' => 1739,'with_comments' => 108},'releases' => 9,'size' => {'packed' => 21121,'unpacked' => 78065},'testers' => {'pass' => 4},'uses' => ['CGI','DynaLoader','FindBin','Tk::Balloon','Tk::BrowseEntry','Tk::Dialog','Tk::FileSelect','Tk::Menubar','Tk::NumEntry','Tk::NumEntryPlain','Tk::Pod','Win32Util','strict','vars']},'Billing-Allopass-0.04.tar.gz' => {'author' => 'BPGN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 260,'pod' => 13,'pod_errors' => 0,'total' => 273,'with_comments' => 8},'releases' => 4,'size' => {'packed' => 9913,'unpacked' => 27143},'testers' => {'pass' => 2},'uses' => ['CGI::Cookie','Exporter','HTTP::Request::Common','LWP::UserAgent','strict','vars']},'BingoX-1.93.tar.gz' => {'author' => 'CNATION','description' => 'Time display parent class containing generic methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5484,'pod' => 3134,'pod_errors' => 3,'total' => 8618,'with_comments' => 593},'releases' => 4,'requires' => ['DBI-1.37.tar.gz','Time-Object-1.00.tar.gz','TimeDate-1.16.tar.gz'],'requires_module' => {'DBI' => 0,'Date::Parse' => 0,'Time::Object' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Time-Object-1.00.tar.gz','TimeDate-1.16.tar.gz'],'size' => {'packed' => 75542,'unpacked' => 283759},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Apache','Apache::Constants','Apache::XPP','CGI','Carp','DBI','Data::Dumper','Date::Language','Date::Language::English','Date::Parse','Time::Object','overload','strict','vars']},'Bio-Das-0.20.tar.gz' => {'author' => 'LDS','description' => 'Interface to Distributed Annotation System','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2102,'pod' => 923,'pod_errors' => 0,'total' => 3025,'with_comments' => 139},'releases' => 4,'requires' => ['XML-Parser-2.31.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => 5,'XML::Parser' => 1},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 23260,'unpacked' => 83797},'testers' => {'fail' => 2,'tests' => '30'},'uses' => ['Bio::Das::Parser','Bio::Das::Type','Bio::Das::Util','Carp','Cwd','Exporter','HTTP::Request::Common','LWP::UserAgent','URI::Escape','URI::URL','XML::Parser','constant','overload','strict','vars']},'Bio-Das-0.75.tar.gz' => {'author' => 'LDS','description' => 'Interface to Distributed Annotation System','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2426,'pod' => 561,'pod_errors' => 1,'total' => 2987,'with_comments' => 270},'releases' => 4,'requires' => ['Compress-Zlib-1.22.tar.gz','HTML-Parser-3.28.tar.gz','MIME-Base64-2.20.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Compress::Zlib' => 1,'HTML::Parser' => 3,'LWP' => 5,'MIME::Base64' => '2.12'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21844,'unpacked' => 82644},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.6.0','Bio::Das::Segment','Carp','Compress::Zlib','Errno','Exporter','HTML::Parser','IO::Select','IO::Socket','MIME::Base64','constant','overload','strict','vars']},'Bio-Emboss-0.4.tar.gz' => {'author' => 'PERNST','description' => 'Write EMBOSS programs in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2126,'pod' => 103,'pod_errors' => 0,'total' => 2229,'with_comments' => 32},'releases' => 4,'size' => {'packed' => 60979,'unpacked' => 386151},'testers' => {},'uses' => ['5.000','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Bio-Genex-2.4.0.tar.gz' => {'author' => 'JASONS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 30604,'pod' => 25234,'pod_errors' => 2,'total' => 55838,'with_comments' => 3430},'releases' => 2,'size' => {'packed' => 586754,'unpacked' => 4204550},'testers' => {},'uses' => ['Bio::Genex','Bio::Genex::DBUtils','Bio::Genex::Fkey','Carp','DBI','Exporter','IO::File','ObjectTemplate','POSIX','constant','strict','vars']},'Bio-Genex-2.6.0.tar.gz' => {'author' => 'JASONS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 28396,'pod' => 23966,'pod_errors' => 2,'total' => 52362,'with_comments' => 3190},'releases' => 2,'requires' => ['Class-ObjectTemplate-DB-0.27.tar.gz'],'requires_module' => {'Class::ObjectTemplate::DB' => '0.22'},'requires_recursive' => ['Class-ObjectTemplate-0.7.tar.gz','Class-ObjectTemplate-DB-0.27.tar.gz'],'size' => {'packed' => 560700,'unpacked' => 4080648},'testers' => {},'uses' => ['Bio::Genex','Bio::Genex::DBUtils','Carp','Class::ObjectTemplate::DB','DBI','Exporter','IO::File','POSIX','constant','strict','vars']},'Bio-MAGE-20020902.3.tar.gz' => {'author' => 'JASONS','description' => 'Container module for classes in the MAGE MAGE package','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 80809,'pod' => 66546,'pod_errors' => 198,'total' => 147355,'with_comments' => 9030},'releases' => 2,'requires' => ['Tie-IxHash-1.21.tar.gz'],'requires_module' => {'Tie::IxHash' => '1.21'},'requires_recursive' => ['Tie-IxHash-1.21.tar.gz'],'size' => {'packed' => 455088,'unpacked' => 6431038},'testers' => {'pass' => 4},'uses' => ['Benchmark','Bio::MAGE::Array','Bio::MAGE::Array::Array','Bio::MAGE::Array::ArrayGroup','Bio::MAGE::Array::ArrayManufacture','Bio::MAGE::Array::ArrayManufactureDeviation','Bio::MAGE::Array::FeatureDefect','Bio::MAGE::Array::Fiducial','Bio::MAGE::Array::ManufactureLIMS','Bio::MAGE::Array::ManufactureLIMSBiomaterial','Bio::MAGE::Array::PositionDelta','Bio::MAGE::Array::ZoneDefect','Bio::MAGE::ArrayDesign','Bio::MAGE::ArrayDesign::ArrayDesign','Bio::MAGE::ArrayDesign::CompositeGroup','Bio::MAGE::ArrayDesign::DesignElementGroup','Bio::MAGE::ArrayDesign::FeatureGroup','Bio::MAGE::ArrayDesign::PhysicalArrayDesign','Bio::MAGE::ArrayDesign::ReporterGroup','Bio::MAGE::ArrayDesign::Zone','Bio::MAGE::ArrayDesign::ZoneGroup','Bio::MAGE::ArrayDesign::ZoneLayout','Bio::MAGE::Association','Bio::MAGE::AuditAndSecurity','Bio::MAGE::AuditAndSecurity::Audit','Bio::MAGE::AuditAndSecurity::Contact','Bio::MAGE::AuditAndSecurity::Organization','Bio::MAGE::AuditAndSecurity::Person','Bio::MAGE::AuditAndSecurity::Security','Bio::MAGE::AuditAndSecurity::SecurityGroup','Bio::MAGE::BQS','Bio::MAGE::BQS::BibliographicReference','Bio::MAGE::Base','Bio::MAGE::BioAssay','Bio::MAGE::BioAssay::BioAssay','Bio::MAGE::BioAssay::BioAssayCreation','Bio::MAGE::BioAssay::BioAssayTreatment','Bio::MAGE::BioAssay::Channel','Bio::MAGE::BioAssay::DerivedBioAssay','Bio::MAGE::BioAssay::FeatureExtraction','Bio::MAGE::BioAssay::Hybridization','Bio::MAGE::BioAssay::Image','Bio::MAGE::BioAssay::ImageAcquisition','Bio::MAGE::BioAssay::MeasuredBioAssay','Bio::MAGE::BioAssay::PhysicalBioAssay','Bio::MAGE::BioAssayData','Bio::MAGE::BioAssayData::BioAssayData','Bio::MAGE::BioAssayData::BioAssayDatum','Bio::MAGE::BioAssayData::BioAssayDimension','Bio::MAGE::BioAssayData::BioAssayMap','Bio::MAGE::BioAssayData::BioAssayMapping','Bio::MAGE::BioAssayData::BioDataCube','Bio::MAGE::BioAssayData::BioDataTuples','Bio::MAGE::BioAssayData::BioDataValues','Bio::MAGE::BioAssayData::CompositeSequenceDimension','Bio::MAGE::BioAssayData::DerivedBioAssayData','Bio::MAGE::BioAssayData::DesignElementDimension','Bio::MAGE::BioAssayData::DesignElementMap','Bio::MAGE::BioAssayData::DesignElementMapping','Bio::MAGE::BioAssayData::FeatureDimension','Bio::MAGE::BioAssayData::MeasuredBioAssayData','Bio::MAGE::BioAssayData::QuantitationTypeDimension','Bio::MAGE::BioAssayData::QuantitationTypeMap','Bio::MAGE::BioAssayData::QuantitationTypeMapping','Bio::MAGE::BioAssayData::ReporterDimension','Bio::MAGE::BioAssayData::Transformation','Bio::MAGE::BioEvent','Bio::MAGE::BioEvent::BioEvent','Bio::MAGE::BioEvent::Map','Bio::MAGE::BioMaterial','Bio::MAGE::BioMaterial::BioMaterial','Bio::MAGE::BioMaterial::BioMaterialMeasurement','Bio::MAGE::BioMaterial::BioSample','Bio::MAGE::BioMaterial::BioSource','Bio::MAGE::BioMaterial::Compound','Bio::MAGE::BioMaterial::CompoundMeasurement','Bio::MAGE::BioMaterial::LabeledExtract','Bio::MAGE::BioMaterial::Treatment','Bio::MAGE::BioSequence','Bio::MAGE::BioSequence::BioSequence','Bio::MAGE::BioSequence::SeqFeature','Bio::MAGE::BioSequence::SeqFeatureLocation','Bio::MAGE::BioSequence::SequencePosition','Bio::MAGE::Describable','Bio::MAGE::Description','Bio::MAGE::Description::Database','Bio::MAGE::Description::DatabaseEntry','Bio::MAGE::Description::Description','Bio::MAGE::Description::ExternalReference','Bio::MAGE::Description::OntologyEntry','Bio::MAGE::DesignElement','Bio::MAGE::DesignElement::CompositeCompositeMap','Bio::MAGE::DesignElement::CompositePosition','Bio::MAGE::DesignElement::CompositeSequence','Bio::MAGE::DesignElement::DesignElement','Bio::MAGE::DesignElement::Feature','Bio::MAGE::DesignElement::FeatureInformation','Bio::MAGE::DesignElement::FeatureLocation','Bio::MAGE::DesignElement::FeatureReporterMap','Bio::MAGE::DesignElement::MismatchInformation','Bio::MAGE::DesignElement::Position','Bio::MAGE::DesignElement::Reporter','Bio::MAGE::DesignElement::ReporterCompositeMap','Bio::MAGE::DesignElement::ReporterPosition','Bio::MAGE::Experiment','Bio::MAGE::Experiment::Experiment','Bio::MAGE::Experiment::ExperimentDesign','Bio::MAGE::Experiment::ExperimentalFactor','Bio::MAGE::Experiment::FactorValue','Bio::MAGE::Extendable','Bio::MAGE::HigherLevelAnalysis','Bio::MAGE::HigherLevelAnalysis::BioAssayDataCluster','Bio::MAGE::HigherLevelAnalysis::Node','Bio::MAGE::HigherLevelAnalysis::NodeContents','Bio::MAGE::HigherLevelAnalysis::NodeValue','Bio::MAGE::Identifiable','Bio::MAGE::Measurement','Bio::MAGE::Measurement::ConcentrationUnit','Bio::MAGE::Measurement::DistanceUnit','Bio::MAGE::Measurement::MassUnit','Bio::MAGE::Measurement::Measurement','Bio::MAGE::Measurement::QuantityUnit','Bio::MAGE::Measurement::TemperatureUnit','Bio::MAGE::Measurement::TimeUnit','Bio::MAGE::Measurement::Unit','Bio::MAGE::Measurement::VolumeUnit','Bio::MAGE::NameValueType','Bio::MAGE::Protocol','Bio::MAGE::Protocol::Hardware','Bio::MAGE::Protocol::HardwareApplication','Bio::MAGE::Protocol::Parameter','Bio::MAGE::Protocol::ParameterValue','Bio::MAGE::Protocol::Parameterizable','Bio::MAGE::Protocol::ParameterizableApplication','Bio::MAGE::Protocol::Protocol','Bio::MAGE::Protocol::ProtocolApplication','Bio::MAGE::Protocol::Software','Bio::MAGE::Protocol::SoftwareApplication','Bio::MAGE::QuantitationType','Bio::MAGE::QuantitationType::ConfidenceIndicator','Bio::MAGE::QuantitationType::DerivedSignal','Bio::MAGE::QuantitationType::Error','Bio::MAGE::QuantitationType::ExpectedValue','Bio::MAGE::QuantitationType::Failed','Bio::MAGE::QuantitationType::MeasuredSignal','Bio::MAGE::QuantitationType::PValue','Bio::MAGE::QuantitationType::PresentAbsent','Bio::MAGE::QuantitationType::QuantitationType','Bio::MAGE::QuantitationType::Ratio','Bio::MAGE::QuantitationType::SpecializedQuantitationType','Bio::MAGE::QuantitationType::StandardQuantitationType','Bio::MAGE::XML::Handler::DocumentHandler','Carp','Data::Dumper','Exporter','Tie::IxHash','XML::Xerces','constant','strict','vars']},'Bio-Maxd-0.04.tar.gz' => {'author' => 'PRILUSKYJ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 664,'pod' => 111,'pod_errors' => 0,'total' => 775,'with_comments' => 23},'releases' => 2,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','HTML-Template-2.6.tar.gz'],'requires_module' => {'DBD::mysql' => '2.1','DBI' => '1.29','HTML::Template' => '2.5'},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 194842,'unpacked' => 973065},'testers' => {'fail' => 2},'uses' => ['5.005_62','AutoLoader','Exporter','File::Basename','HTML::Template','Sys::Hostname','strict','warnings']},'Bio-Tools-DNAGen-0.02.tar.gz' => {'author' => 'XERN','description' => 'Generating a pool of DNA sequences','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 128,'pod_errors' => 0,'total' => 233,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 3167,'unpacked' => 7617},'testers' => {'pass' => 3},'uses' => ['5.006','Exporter','List::Util','XSLoader','strict','subs']},'Bio-Tools-FuzzyHypercube-0.01.tar.gz' => {'author' => 'XERN','description' => 'Fuzzy Hypercube of sequence','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 30,'pod' => 28,'pod_errors' => 0,'total' => 58,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2104,'unpacked' => 4320},'testers' => {'pass' => 3},'uses' => ['5.006','List::Util','XSLoader','strict']},'Bio-Tools-LatticeProtein-0.02.tar.gz' => {'author' => 'XERN','description' => 'Lattice model for protein prediction','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 430,'pod' => 129,'pod_errors' => 0,'total' => 559,'with_comments' => 31},'releases' => 2,'requires' => ['Scalar-List-Utils-1.11.tar.gz'],'requires_module' => {'List::Util' => '1'},'requires_recursive' => ['Scalar-List-Utils-1.11.tar.gz'],'size' => {'packed' => 4878,'unpacked' => 15553},'testers' => {'pass' => 2},'uses' => ['Exporter','List::Util','strict']},'Bio-Tools-MT-0.01.tar.gz' => {'author' => 'XERN','description' => 'Calculating melting temperature of oligos','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 248,'pod' => 120,'pod_errors' => 0,'total' => 368,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 4446,'unpacked' => 11452},'testers' => {'pass' => 2},'uses' => ['Exporter','strict']},'Bio-Tools-Prepeat-0.06.tar.gz' => {'author' => 'XERN','description' => 'Finding repeats in protein sequences','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 217,'pod' => 82,'pod_errors' => 0,'total' => 299,'with_comments' => 11},'releases' => 6,'requires' => ['IO-1.20.tar.gz','String-Random-0.198.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Cwd' => '2.06','IO::File' => '1.09','String::Random' => '0.198'},'requires_recursive' => ['IO-1.20.tar.gz','String-Random-0.198.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6234,'unpacked' => 14707},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.006','Cwd','Data::Dumper','Exporter','IO::File','List::Util','String::Random','XSLoader','strict']},'Bioinf_V2.0.tar.gz' => {'author' => 'JONG','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 39094,'pod' => 0,'pod_errors' => 0,'total' => 39094,'with_comments' => 15895},'releases' => 1,'size' => {'packed' => 654707,'unpacked' => 3260250},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.000','Bio::Bioinf','Carp','Exporter']},'Bit-FlipFlop-0.01.tar.gz' => {'author' => 'CMEYER','description' => 'Facilitates the maintainance of one bit of state in Perl programs.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 213,'pod' => 295,'pod_errors' => 0,'total' => 508,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 7039,'unpacked' => 18686},'testers' => {'pass' => 6},'uses' => ['Carp','strict','warnings']},'Bit-ShiftReg-2.0.tar.gz' => {'author' => 'STBEY','description' => 'Bit Shift Registers with Rotate / Shift Operations Implements rotate left, rotate right, shift left and shift right operations with carry flag for all C integer types','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 117,'pod' => 232,'pod_errors' => 0,'total' => 349,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 8361,'unpacked' => 50680},'testers' => {'pass' => 2},'uses' => ['DynaLoader','Exporter','strict','vars']},'Bit-Vector-6.3.tar.gz' => {'author' => 'STBEY','description' => 'Fast virtual arbitrary-size-machineword CPU','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2982,'pod' => 2992,'pod_errors' => 0,'total' => 5974,'with_comments' => 92},'releases' => 16,'size' => {'packed' => 126096,'unpacked' => 633177},'testers' => {'pass' => 28},'uses' => ['Carp::Clan','DynaLoader','Exporter','strict','vars']},'Blatte-0.9.4.tar.gz' => {'author' => 'BOBG','description' => 'Convenient interface for compiling Blatte','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2237,'pod' => 886,'pod_errors' => 0,'total' => 3123,'with_comments' => 81},'releases' => 5,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'File::Basename' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 32081,'unpacked' => 118346},'testers' => {'pass' => 11},'uses' => ['Exporter','Test','constant','strict','vars']},'Blatte-HTML-0.9.tar.gz' => {'author' => 'BOBG','description' => 'Intrinsics for writing HTML in Blatte','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 351,'pod' => 161,'pod_errors' => 0,'total' => 512,'with_comments' => 11},'releases' => 4,'requires' => ['Blatte-0.9.4.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'requires_module' => {'Blatte' => 0,'HTML::Entities' => 0,'HTML::Tagset' => 0},'requires_recursive' => ['Blatte-0.9.4.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14406,'unpacked' => 42095},'testers' => {'pass' => 6},'uses' => ['Blatte','Blatte::Builtins','Exporter','HTML::Entities','HTML::Tagset','Symbol','Test','strict']},'Blog-Simple-0.02.tar.gz' => {'author' => 'GILAD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 295,'pod' => 165,'pod_errors' => 0,'total' => 460,'with_comments' => 56},'releases' => 2,'requires' => ['XML-XSLT-0.40.tar.gz'],'requires_module' => {'XML::XSLT' => '0.32'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','XML-XSLT-0.40.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6695,'unpacked' => 20452},'testers' => {'pass' => 4},'uses' => ['5.6.1','Exporter','XML::XSLT','strict','warnings']},'Blog-Simple-HTMLOnly-0.02.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 399,'pod' => 89,'pod_errors' => 0,'total' => 488,'with_comments' => 86},'releases' => 2,'size' => {'packed' => 9382,'unpacked' => 29275},'testers' => {'pass' => 3},'uses' => ['5.6.1','HTML::TokeParser','strict','vars','warnings']},'Bloom16-0.01.tar.gz' => {'author' => 'IWOODHEAD','description' => 'Perl extension for "threshold" Bloom filters','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 162,'pod' => 30,'pod_errors' => 0,'total' => 192,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3047,'unpacked' => 6050},'testers' => {'pass' => 2},'uses' => ['5.005_62','Digest::MD5','Inline','strict','vars']},'Bone-Easy-0.04.tar.gz' => {'author' => 'MSCHWERN','description' => 'Perl module for generating pickup lines.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 841,'pod' => 59,'pod_errors' => 0,'total' => 900,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 8850,'unpacked' => 25236},'testers' => {'pass' => 6},'uses' => ['Exporter','strict','vars']},'Bot-BasicBot-0.05.tar.gz' => {'author' => 'TOMI','description' => 'simple irc bot baseclass','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 766,'pod' => 357,'pod_errors' => 1,'total' => 1123,'with_comments' => 62},'releases' => 3,'requires' => ['POE-0.26.tar.gz','POE-Component-IRC-2.9.tar.gz'],'requires_module' => {'POE' => '0.22','POE::Component::IRC' => 2},'requires_recursive' => ['POE-0.26.tar.gz','POE-Component-IRC-2.9.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11209,'unpacked' => 31710},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','POE::Component::IRC','POE::Filter::Line','POE::Kernel','POE::Session','POE::Wheel::Run','constant','strict','vars']},'Bot-BasicBot-Pluggable-0.04.tar.gz' => {'author' => 'TOMI','description' => 'extension to the simple irc bot base class allowing for pluggable modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1341,'pod' => 545,'pod_errors' => 0,'total' => 1886,'with_comments' => 26},'releases' => 4,'requires' => ['Bot-BasicBot-0.05.tar.gz'],'requires_module' => {'Bot::BasicBot' => '0.04'},'requires_recursive' => ['Bot-BasicBot-0.05.tar.gz','POE-0.26.tar.gz','POE-Component-IRC-2.9.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18740,'unpacked' => 64993},'testers' => {'pass' => 6},'uses' => ['Bot::BasicBot','Bot::BasicBot::Pluggable::Module::Base','Carp','DBI','Data::Dumper','LWP::Simple','Net::Google','POE','Socket','Storable','XML::RSS','strict','warnings']},'Bot-BasicBot-Pluggable-0.05.tar.gz' => {'author' => 'TOMI','description' => 'extension to the simple irc bot base class allowing for pluggable modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1360,'pod' => 544,'pod_errors' => 0,'total' => 1904,'with_comments' => 41},'releases' => 4,'requires' => ['Bot-BasicBot-0.05.tar.gz'],'requires_module' => {'Bot::BasicBot' => '0.04'},'requires_recursive' => ['Bot-BasicBot-0.05.tar.gz','POE-0.26.tar.gz','POE-Component-IRC-2.9.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 20857,'unpacked' => 68950},'testers' => {'pass' => 2},'uses' => ['Bot::BasicBot','Carp','DBI','Data::Dumper','LWP::Simple','Net::Google','POE','Socket','Storable','XML::RSS','strict','warnings']},'Bot-BasicBot-Pluggable-Module-SimpleBlog-0.02.tar.gz' => {'author' => 'KAKE','description' => 'A simple URL collector for Bot::BasicBot::Pluggable.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 180,'pod' => 230,'pod_errors' => 0,'total' => 410,'with_comments' => 4},'releases' => 2,'requires' => ['Bot-BasicBot-Pluggable-0.05.tar.gz','DBD-SQLite-0.25.tar.gz','Regexp-Common-2.113.tar.gz','Test-DatabaseRow-1.00.tar.gz','Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Bot::BasicBot::Pluggable' => '0.04','Carp' => 0,'DBD::SQLite' => 0,'Regexp::Common' => 0,'Test::DatabaseRow' => 0,'Test::More' => 0,'Time::Piece' => 0},'requires_recursive' => ['Bot-BasicBot-0.05.tar.gz','Bot-BasicBot-Pluggable-0.05.tar.gz','DBD-SQLite-0.25.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','POE-0.26.tar.gz','POE-Component-IRC-2.9.tar.gz','Regexp-Common-2.113.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-DatabaseRow-1.00.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5054,'unpacked' => 18649},'testers' => {'fail' => 1,'pass' => 1,'tests' => '6'},'uses' => ['Bot::BasicBot::Pluggable::Module::Base','Carp','DBD::SQLite','Regexp::Common','Time::Piece','strict','vars']},'Bot-CPAN-0.74.tar.gz' => {'author' => 'FOX','description' => undef,'files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 3424,'pod' => 698,'pod_errors' => 1,'total' => 4122,'with_comments' => 229},'releases' => 1,'size' => {'packed' => 39841,'unpacked' => 133701},'testers' => {'pass' => 1},'uses' => ['$self->{path}::$self->{dispatch}','5.006','CPAN','CPANPLUS','CPANPLUS::Backend','Carp','Config','Cwd','Exporter','ExtUtils::MM_Unix','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Basename','File::Find','File::Path','File::Spec','FileHandle','LWP::Simple','Mail::Internet','Module::Install','Module::Install::Base','Net::FTP','Net::NNTP','POE','POE::Component::IRC','POE::Filter::Line','POE::Kernel','POE::Session','POE::Wheel::Run','POSIX','Socket','YAML','constant','inc::Module::Install','strict','vars']},'Bot-JabberBot-0.01.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 157,'pod' => 80,'pod_errors' => 0,'total' => 237,'with_comments' => 0},'releases' => 2,'requires' => ['Class-MethodMaker-1.10.tar.gz','Jabber-Connection-0.03.tar.gz'],'requires_module' => {'Class::MethodMaker' => '1.05','Jabber::Connection' => '0.02'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','Digest-SHA1-2.04.tar.gz','Jabber-Connection-0.03.tar.gz','XML-Parser-2.31.tar.gz'],'testers' => {'pass' => 3},'uses' => ['Jabber::Connection','Jabber::NodeFactory','strict']},'Bot-Pluggable-0.03.tar.gz' => {'author' => 'MSERGEANT','description' => 'A plugin based IRC bot','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 344,'pod' => 67,'pod_errors' => 0,'total' => 411,'with_comments' => 3},'releases' => 3,'requires' => ['POE-Component-IRC-Object-0.02.tar.gz'],'requires_module' => {'POE::Component::IRC::Object' => '0.02'},'requires_recursive' => ['POE-Component-IRC-Object-0.02.tar.gz'],'size' => {'packed' => 4179,'unpacked' => 11069},'testers' => {'pass' => 2},'uses' => ['Data::Dumper','POE','POE::Component::IRC::Object','POSIX','Time::Piece','Time::Seconds','strict']},'Bot-Pluggable-Blogger-0.01.tar.gz' => {'author' => 'PERIGRIN','description' => undef,'files' => [],'lines' => {'nonpod' => 103,'pod' => 29,'pod_errors' => 0,'total' => 132,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 3100,'unpacked' => 9551},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Bot::Pluggable::Common','HTML::Entities','Net::Blogger','POE','strict','warnings']},'Bot-Pluggable-Trust-0.05.tar.gz' => {'author' => 'PERIGRIN','description' => undef,'files' => [],'lines' => {'nonpod' => 950,'pod' => 77,'pod_errors' => 0,'total' => 1027,'with_comments' => 48},'releases' => 1,'size' => {'packed' => 8086,'unpacked' => 37817},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['DBI','POE','strict','warnings']},'Boulder-1.14.tar.gz' => {'author' => 'LDS','description' => 'XML format input/output for Boulder streams','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5268,'pod' => 2726,'pod_errors' => 2,'total' => 7994,'with_comments' => 731},'releases' => 13,'size' => {'packed' => 83258,'unpacked' => 272740},'testers' => {'fail' => 1,'pass' => 9,'tests' => '49'},'uses' => ['5.004','Boulder::Blast::NCBI','Boulder::Blast::WU','Boulder::Stream','Carp','DB_File','Exporter','Fcntl','IO::Socket','LabBase','Stone','Stone::Cursor','Stone::GB_Sequence','Symbol','XML::Parser','constant','overload','strict','vars']},'Boulder-1.15.tar.gz' => {'author' => 'LDS','description' => 'XML format input/output for Boulder streams','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5269,'pod' => 2685,'pod_errors' => 2,'total' => 7954,'with_comments' => 732},'releases' => 13,'size' => {'packed' => 81741,'unpacked' => 272588},'testers' => {'fail' => 1,'pass' => 8,'tests' => '49'},'uses' => ['5.004','Boulder::Blast::NCBI','Boulder::Blast::WU','Boulder::Stream','Carp','DB_File','Exporter','Fcntl','IO::Socket','LabBase','Stone','Stone::Cursor','Stone::GB_Sequence','Symbol','XML::Parser','constant','overload','strict','vars']},'Boulder-1.30.tar.gz' => {'author' => 'LDS','description' => 'XML format input/output for Boulder streams','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5993,'pod' => 2926,'pod_errors' => 2,'total' => 8919,'with_comments' => 809},'releases' => 13,'size' => {'packed' => 91202,'unpacked' => 301830},'testers' => {'pass' => 2},'uses' => ['5.004','CGI','Carp','DB_File','Exporter','Fcntl','File::Basename','IO::Socket','LabBase','Symbol','XML::Parser','constant','overload','strict','vars']},'Brasil-Checar-CGC-1.01a.tar.gz' => {'author' => 'HODEL','description' => 'Perl extension for check a CGC number. - Extensão Perl para validação de números de CGC/CNPJ (Cadastro Nacional de Pessoa Jurídica)','files' => [],'lines' => {'nonpod' => 146,'pod' => 33,'pod_errors' => 0,'total' => 179,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 2018,'unpacked' => 4919},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['AutoLoader','Exporter','strict','vars']},'Brasil-Checar-CPF-1.01a.tar.gz' => {'author' => 'HODEL','description' => undef,'files' => [],'lines' => {'nonpod' => 91,'pod' => 33,'pod_errors' => 0,'total' => 124,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 1804,'unpacked' => 3404},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['AutoLoader','Exporter','strict','vars']},'Bryar-1.2.tar.gz' => {'author' => 'SIMON','description' => 'A modular, extensible weblog tool','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 894,'pod' => 660,'pod_errors' => 0,'total' => 1554,'with_comments' => 25},'releases' => 2,'requires' => ['File-Find-Rule-0.10.tar.gz','Template-Toolkit-2.10.tar.gz','Time-Piece-1.08.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'requires_module' => {'File::Find::Rule' => '0.09','Template' => 2,'Time::Piece' => 1,'UNIVERSAL::require' => 0},'requires_recursive' => ['Exporter-Lite-0.01.tar.gz','File-Find-Rule-0.10.tar.gz','Template-Toolkit-2.10.tar.gz','Time-Piece-1.08.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'size' => {'packed' => 14547,'unpacked' => 50046},'testers' => {'pass' => 1},'uses' => ['5.006','Apache','CGI','Carp','Cwd','File::Basename','File::Find::Rule','Lingua::EN::Keywords','Template','Time::Local','Time::Piece','UNIVERSAL::require','strict','warnings']},'Btrees-1.00.tar.gz' => {'author' => 'RSQUIERS','description' => 'Binary trees using the AVL balancing method.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 386,'pod' => 39,'pod_errors' => 0,'total' => 425,'with_comments' => 174},'releases' => 1,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 11866,'unpacked' => 38641},'testers' => {'pass' => 5},'uses' => ['5.000','Exporter']},'Bundle-ABH-1.05.tar.gz' => {'author' => 'ABH','description' => 'A bundle to install all Ask\'s favorite modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 166,'pod_errors' => 0,'total' => 186,'with_comments' => 1},'releases' => 6,'size' => {'packed' => 2006,'unpacked' => 3706},'testers' => {'tests' => '0','unknown' => 3},'uses' => []},'Bundle-Apache-Wombat-0.5.1.tar.gz' => {'author' => 'IX','description' => 'a bundle to install all Apache::Wombat related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13,'pod' => 35,'pod_errors' => 0,'total' => 48,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 989,'unpacked' => 1685},'testers' => {},'uses' => ['5.6']},'Bundle-AppSpace-0.1.tar.gz' => {'author' => 'ADAMK','description' => 'A bundle to install all modules needed for an AppSpace installation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 12,'pod' => 73,'pod_errors' => 0,'total' => 85,'with_comments' => 0},'releases' => 1,'requires' => ['Archive-Builder-0.8.tar.gz','Archive-Tar-1.03.tar.gz','Archive-Zip-1.06.tar.gz','Array-Window-0.1.tar.gz','CGI.pm-2.98.tar.gz','Class-Autouse-0.7.tar.gz','Class-Default-0.2.tar.gz','Class-Handle-0.4.tar.gz','Class-Inspector-1.tar.gz','Clone-0.13.tar.gz','Config-Tiny-1.tar.gz','DBI-1.37.tar.gz','File-Flat-0.8.tar.gz','File-Flock-101.060501.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getopt-Long-2.33.tar.gz','HTTP-BrowserDetect-0.97.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','Proc-ProcessTable-0.38.tar.gz','Time-modules-2003.0211.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Archive::Builder' => '0.5','Archive::Tar' => 0,'Archive::Zip' => 0,'Array::Window' => 0,'Bundle::DBI' => 0,'CGI' => 0,'CGI::Carp' => 0,'Class::Autouse' => '0.7','Class::Default' => '0.2','Class::Handle' => '0.3','Class::Inspector' => '0.2','Clone' => '0.13','Config::Tiny' => '0.1','Cwd' => 0,'File::Copy' => 0,'File::Flat' => '0.6','File::Flock' => 0,'File::Spec' => '0.83','File::Temp' => 0,'FindBin' => 0,'Getopt::Long' => 0,'HTTP::BrowserDetect' => '0.97','IO::File' => 0,'IO::Scalar' => 0,'Proc::ProcessTable' => 0,'Time::ParseDate' => '100.010301','URI::Escape' => 0},'requires_recursive' => ['Archive-Builder-0.8.tar.gz','Archive-Tar-1.03.tar.gz','Archive-Zip-1.06.tar.gz','Array-Window-0.1.tar.gz','CGI.pm-2.98.tar.gz','Class-Autouse-0.7.tar.gz','Class-Default-0.2.tar.gz','Class-Handle-0.4.tar.gz','Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','Clone-0.13.tar.gz','Compress-Zlib-1.22.tar.gz','Config-Tiny-1.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','File-Flat-0.8.tar.gz','File-Flock-101.060501.tar.gz','File-NCopy0.32.tar.gz','File-Remove0.20.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getopt-Long-2.33.tar.gz','HTTP-BrowserDetect-0.97.tar.gz','IO-1.20.tar.gz','IO-Zlib-1.01.tar.gz','IO-stringy-2.108.tar.gz','PodParser-1.23.tar.gz','Proc-ProcessTable-0.38.tar.gz','Scalar-List-Utils-1.11.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz','Time-modules-2003.0211.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8830,'unpacked' => 23464},'testers' => {},'uses' => ['vars']},'Bundle-BDFOY-0.50.tar.gz' => {'author' => 'BDFOY','description' => 'bundle for all modules by brian d foy','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 13,'pod' => 59,'pod_errors' => 0,'total' => 72,'with_comments' => 0},'releases' => 1,'requires' => ['Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0,'Test::Pod' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 1189,'unpacked' => 1816},'testers' => {'fail' => 1,'pass' => 1},'uses' => []},'Bundle-BioPerl-2.05.tar.gz' => {'author' => 'CRAFFI','description' => 'A bundle to install external CPAN modules used by BioPerl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 51,'pod' => 100,'pod_errors' => 0,'total' => 151,'with_comments' => 0},'releases' => 7,'size' => {'packed' => 2951,'unpacked' => 6580},'testers' => {},'uses' => []},'Bundle-Bonsai-0.02.tar.gz' => {'author' => 'ZLIPTON','description' => 'A bundle of the modules required for Bonsai.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 19,'pod' => 44,'pod_errors' => 0,'total' => 63,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 1075,'unpacked' => 1613},'testers' => {},'uses' => []},'Bundle-Bricolage-1.6.0.tar.gz' => {'author' => 'DWHEELER','description' => 'Modules required to run Bricolage content management system.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 16,'pod' => 121,'pod_errors' => 0,'total' => 137,'with_comments' => 0},'releases' => 12,'size' => {'packed' => 3858,'unpacked' => 10162},'testers' => {'pass' => 2},'uses' => []},'Bundle-BricolagePlus-1.6.0.tar.gz' => {'author' => 'DWHEELER','description' => 'Optional and Required modules for the Bricolage content management system.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14,'pod' => 49,'pod_errors' => 0,'total' => 63,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 2082,'unpacked' => 4289},'testers' => {'pass' => 2},'uses' => []},'Bundle-Bugzilla-0.10.tar.gz' => {'author' => 'ZLIPTON','description' => 'Bundle to load modules for Bugzilla','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 28,'pod' => 70,'pod_errors' => 0,'total' => 98,'with_comments' => 0},'releases' => 11,'size' => {'packed' => 1431,'unpacked' => 2343},'testers' => {},'uses' => []},'Bundle-CVSMonitor-0.6.tar.gz' => {'author' => 'ADAMK','description' => 'A bundle to install all CVSMonitor modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11,'pod' => 77,'pod_errors' => 0,'total' => 88,'with_comments' => 0},'releases' => 6,'requires' => ['Array-Window-0.1.tar.gz','CGI.pm-2.98.tar.gz','Chart-Math-Axis-0.1.tar.gz','Class-Autouse-0.7.tar.gz','Class-Default-0.2.tar.gz','Class-Inspector-1.tar.gz','Clone-0.13.tar.gz','Config-Tiny-1.tar.gz','File-Flat-0.8.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getopt-Long-2.33.tar.gz','HTTP-BrowserDetect-0.97.tar.gz','IO-1.20.tar.gz','Net-Telnet-3.03.tar.gz','Proc-ProcessTable-0.38.tar.gz','Sort-Versions-1.4.tar.gz','Storable-2.07.tar.gz','Time-Duration-1.02.tar.gz','Time-modules-2003.0211.tar.gz','URI-1.24.tar.gz','Validate-Net-0.4.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Array::Window' => 0,'CGI' => 0,'CGI::Carp' => 0,'Chart::Math::Axis' => '0.1','Class::Autouse' => '0.7','Class::Default' => '0.2','Class::Inspector' => '0.2','Clone' => '0.13','Config::Tiny' => '0.1','Cwd' => 0,'File::Copy' => 0,'File::Flat' => '0.6','File::Spec' => '0.82','File::Temp' => 0,'FindBin' => 0,'Getopt::Long' => 0,'HTTP::BrowserDetect' => '0.97','IO::File' => 0,'Net::Telnet' => 0,'Proc::ProcessTable' => 0,'Sort::Versions' => '1.4','Storable' => 0,'Time::Duration' => 0,'Time::ParseDate' => '100.010301','URI::Escape' => 0,'Validate::Net' => '0.3'},'requires_recursive' => ['Array-Window-0.1.tar.gz','CGI.pm-2.98.tar.gz','Chart-Math-Axis-0.1.tar.gz','Class-Autouse-0.7.tar.gz','Class-Default-0.2.tar.gz','Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','Clone-0.13.tar.gz','Config-Tiny-1.tar.gz','File-Flat-0.8.tar.gz','File-NCopy0.32.tar.gz','File-Remove0.20.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getopt-Long-2.33.tar.gz','HTTP-BrowserDetect-0.97.tar.gz','IO-1.20.tar.gz','Math-BigInt-1.64.tar.gz','Net-Telnet-3.03.tar.gz','PodParser-1.23.tar.gz','Proc-ProcessTable-0.38.tar.gz','Sort-Versions-1.4.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Duration-1.02.tar.gz','Time-modules-2003.0211.tar.gz','URI-1.24.tar.gz','Validate-Net-0.4.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9206,'unpacked' => 24481},'testers' => {'pass' => 1},'uses' => []},'Bundle-Cascade-1.11.tar.gz' => {'author' => 'MARKSTOS','description' => 'A bundle to install all modules used for Cascade','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 15,'pod' => 49,'pod_errors' => 0,'total' => 64,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 1052,'unpacked' => 1377},'testers' => {'tests' => '0','unknown' => 3},'uses' => []},'Bundle-Cobalt-0.03.tar.gz' => {'author' => 'JPEACOCK','description' => 'Load modules for Cobalt administration under Perl 5.6.1','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 18,'pod' => 53,'pod_errors' => 0,'total' => 71,'with_comments' => 1},'releases' => 4,'size' => {'packed' => 1413,'unpacked' => 2834},'testers' => {},'uses' => []},'Bundle-DataMint-1.02.tar.gz' => {'author' => 'PRILUSKYJ','description' => 'A bundle to install external CPAN modules for Data Mining and Data Integration','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 87,'pod_errors' => 0,'total' => 116,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1371,'unpacked' => 1959},'testers' => {},'uses' => ['5.005_62','AutoLoader','Exporter','strict','warnings']},'Bundle-DateTime-0.07.tar.gz' => {'author' => 'PIJLL','description' => 'Bundle with all DateTime related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10,'pod' => 87,'pod_errors' => 0,'total' => 97,'with_comments' => 0},'releases' => 7,'size' => {'packed' => 1165,'unpacked' => 2378},'testers' => {},'uses' => []},'Bundle-Devel-0.1.tar.gz' => {'author' => 'ADAMK','description' => 'A bundle to install the main set of Devel:: modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 18,'pod' => 47,'pod_errors' => 0,'total' => 65,'with_comments' => 0},'releases' => 1,'requires' => ['DProf-19990108.tar.gz','Devel-Cover-0.20.tar.gz','Devel-Coverage-0.2.tar.gz'],'requires_module' => {'Devel::Cover' => 0,'Devel::Coverage' => 0,'Devel::DProf' => 0},'requires_recursive' => ['DProf-19990108.tar.gz','Devel-Cover-0.20.tar.gz','Devel-Coverage-0.2.tar.gz'],'size' => {'packed' => 9978,'unpacked' => 26924},'testers' => {},'uses' => ['vars']},'Bundle-Egrail-0.02.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13,'pod' => 60,'pod_errors' => 0,'total' => 73,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 1311,'unpacked' => 2551},'testers' => {},'uses' => []},'Bundle-Everything-0.02.tar.gz' => {'author' => 'ABH','description' => 'CPAN Bundle for all of CPAN','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11,'pod' => 4703,'pod_errors' => 0,'total' => 4714,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 14392,'unpacked' => 39115},'testers' => {},'uses' => []},'Bundle-Expect-1.09.tar.gz' => {'author' => 'RGIERSIG','description' => 'Everything that Expect.pm needs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9,'pod' => 27,'pod_errors' => 0,'total' => 36,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 667,'unpacked' => 726},'testers' => {},'uses' => []},'Bundle-Interchange-0.07.tar.gz' => {'author' => 'MIKEH','description' => 'A bundle of the modules nice to have for Interchange.','files' => ['MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 84,'pod_errors' => 0,'total' => 115,'with_comments' => 0},'releases' => 5,'size' => {'packed' => 1480,'unpacked' => 2395},'testers' => {'pass' => 1},'uses' => []},'Bundle-Interchange5-0.01.tar.gz' => {'author' => 'MIKEH','description' => 'A bundle of the modules nice to have for Interchange.','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 107,'pod_errors' => 0,'total' => 139,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3751,'unpacked' => 4723},'testers' => {},'uses' => []},'Bundle-InterchangeKitchenSink-0.11.tar.gz' => {'author' => 'MIKEH','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 154,'pod_errors' => 0,'total' => 196,'with_comments' => 0},'releases' => 6,'size' => {'packed' => 2474,'unpacked' => 4784},'testers' => {},'uses' => []},'Bundle-KohaSupport-0.08.tar.gz' => {'author' => 'KOHA','description' => 'A bundle of the modules required for Koha','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 23,'pod' => 74,'pod_errors' => 0,'total' => 97,'with_comments' => 0},'releases' => 7,'size' => {'packed' => 1708,'unpacked' => 3007},'testers' => {},'uses' => []},'Bundle-LawMonkey-0.01.tar.gz' => {'author' => 'MPRUNTY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 49,'pod' => 14,'pod_errors' => 0,'total' => 63,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1903,'unpacked' => 3133},'testers' => {'fail' => 2,'tests' => '1'},'uses' => []},'Bundle-MP3-1.00.tar.gz' => {'author' => 'LDS','description' => 'A bundle to install all MP3-related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10,'pod' => 27,'pod_errors' => 0,'total' => 37,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 788,'unpacked' => 969},'testers' => {'tests' => '0','unknown' => 3},'uses' => []},'Bundle-Minivend-4.0.tar.gz' => {'author' => 'MIKEH','description' => 'A nice to have modules for MiniVend','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 25,'pod' => 60,'pod_errors' => 0,'total' => 85,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 1513,'unpacked' => 2362},'testers' => {'tests' => '0','unknown' => 3},'uses' => []},'Bundle-MusicBrainz-Client-0.01.tar.gz' => {'author' => 'SVANZOEST','description' => 'A bundle to install MusicBrainz::Client and required modules.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 17,'pod' => 29,'pod_errors' => 0,'total' => 46,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 1634,'unpacked' => 2919},'testers' => {},'uses' => []},'Bundle-MusicBrainz-Server-0.01.tar.gz' => {'author' => 'JAYJ','description' => 'Bundled dependancies to run a MusicBrainz Server.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9,'pod' => 57,'pod_errors' => 0,'total' => 66,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 963,'unpacked' => 1204},'testers' => {},'uses' => []},'Bundle-MyLibrary-0.05.tar.gz' => {'author' => 'ESUMMERS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 15,'pod' => 65,'pod_errors' => 0,'total' => 80,'with_comments' => 0},'releases' => 5,'size' => {'packed' => 1621,'unpacked' => 2478},'testers' => {'pass' => 3},'uses' => []},'Bundle-NiceSleep-0.11.tar.gz' => {'author' => 'JOSHR','description' => 'NiceSleep-related functionality.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14,'pod' => 39,'pod_errors' => 0,'total' => 53,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 1889,'unpacked' => 3608},'testers' => {'pass' => 2},'uses' => []},'Bundle-OS2_default-1.06.tar.gz' => {'author' => 'ILYAZ','description' => 'Modules to install last for OS/2 binary distribution','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 60,'pod' => 331,'pod_errors' => 0,'total' => 391,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 5571,'unpacked' => 15781},'testers' => {'tests' => '0','unknown' => 6},'uses' => []},'Bundle-OpenInteract-1.11.tar.gz' => {'author' => 'CWINTERS','description' => 'Bundle to install all the pre-requisites for OpenInteract','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 10,'pod' => 81,'pod_errors' => 0,'total' => 91,'with_comments' => 1},'releases' => 10,'size' => {'packed' => 1518,'unpacked' => 2416},'testers' => {},'uses' => []},'Bundle-Perl6-0.05.tar.gz' => {'author' => 'MARCEL','description' => 'A bundle to install Perl6-related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 12,'pod' => 63,'pod_errors' => 0,'total' => 75,'with_comments' => 0},'releases' => 5,'size' => {'packed' => 1953,'unpacked' => 4615},'testers' => {},'uses' => []},'Bundle-QuadPres-0.8.2.tar.gz' => {'author' => 'SHLOMIF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 16,'pod' => 47,'pod_errors' => 0,'total' => 63,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 1210,'unpacked' => 1865},'testers' => {},'uses' => []},'Bundle-SDK-SIMON-1.00.tar.gz' => {'author' => 'SIMON','description' => 'CPAN Bundle for \'10 Modules I Wouldn\'t Go Anywhere Without\'','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 534,'pod_errors' => 0,'total' => 640,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 3527,'unpacked' => 7545},'testers' => {},'uses' => []},'Bundle-SPOPS-1.11.tar.gz' => {'author' => 'CWINTERS','description' => 'Bundle to install all the pre-requisites for SPOPS','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 21,'pod' => 61,'pod_errors' => 0,'total' => 82,'with_comments' => 1},'releases' => 12,'size' => {'packed' => 1742,'unpacked' => 2846},'testers' => {},'uses' => ['strict']},'Bundle-SSH-1.00.tar.gz' => {'author' => 'SZABGAB','description' => 'Install modules to use SSH from Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 111,'pod_errors' => 0,'total' => 147,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1919,'unpacked' => 3139},'testers' => {},'uses' => []},'Bundle-Schwern-0.01.tar.gz' => {'author' => 'MSCHWERN','description' => 'A bunch of modules Schwern likes.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 18,'pod' => 21,'pod_errors' => 0,'total' => 39,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1292,'unpacked' => 2057},'testers' => {},'uses' => []},'Bundle-Search-InvertedIndex-1.01.tar.gz' => {'author' => 'SNOWHARE','description' => 'A bundle to install all Search::InvertedIndex related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9,'pod' => 31,'pod_errors' => 0,'total' => 40,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 878,'unpacked' => 1284},'testers' => {},'uses' => []},'Bundle-Slash-2.31.tar.gz' => {'author' => 'CNANDOR','description' => 'A bundle to install all modules used for Slash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11,'pod' => 89,'pod_errors' => 0,'total' => 100,'with_comments' => 0},'releases' => 11,'size' => {'packed' => 1658,'unpacked' => 2551},'testers' => {'pass' => 3},'uses' => []},'Bundle-Sledge-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Bundle to install all Sledge related modules','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 13,'pod' => 85,'pod_errors' => 0,'total' => 98,'with_comments' => 0},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1811,'unpacked' => 2767},'testers' => {'pass' => 11},'uses' => ['strict','vars']},'Bundle-Test-1.00.tar.gz' => {'author' => 'SZABGAB','description' => 'group of modules used to build test','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 73,'pod_errors' => 0,'total' => 107,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1714,'unpacked' => 2766},'testers' => {},'uses' => []},'Bundle-Tie-DB_File-SplitHash-1.01.tar.gz' => {'author' => 'SNOWHARE','description' => 'A bundle to install all Tie::DB_File::SplitHash related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9,'pod' => 23,'pod_errors' => 0,'total' => 32,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 839,'unpacked' => 1070},'testers' => {},'uses' => []},'Bundle-Tie-FileLRUCache-1.01.tar.gz' => {'author' => 'SNOWHARE','description' => 'A bundle to install all Tie::FileLRUCache related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9,'pod' => 27,'pod_errors' => 0,'total' => 36,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 859,'unpacked' => 1132},'testers' => {},'uses' => []},'Bundle-Tk_OS2src-1.00.tar.gz' => {'author' => 'ILYAZ','description' => 'Bundle to compile Tk4*.* on OS/2','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 7,'pod' => 15,'pod_errors' => 0,'total' => 22,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 576,'unpacked' => 548},'testers' => {},'uses' => []},'Bundle-WING-0.11.tar.gz' => {'author' => 'SIMON','description' => 'Modules required for the Web IMAP and News Gateway','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 12,'pod' => 59,'pod_errors' => 0,'total' => 71,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2053,'unpacked' => 3353},'testers' => {'pass' => 2},'uses' => []},'Bundle-WWW-Scraper-Auction-0.01.tar.gz' => {'author' => 'GLENNWOOD','description' => 'Scrapes www.eBay.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 30,'pod_errors' => 0,'total' => 252,'with_comments' => 34},'releases' => 1,'requires' => ['Scraper-3.04.tar.gz'],'requires_module' => {'WWW::Scraper' => '3.01'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Scraper-3.04.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Tie-Persistent-1.00.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','XML-Parser-2.31.tar.gz','XML-XPath-1.13.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7214,'unpacked' => 23737},'testers' => {},'uses' => ['WWW::Scraper','strict','vars']},'Bundle-WWW-Scraper-Housing-0.02.tar.gz' => {'author' => 'GLENNWOOD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 150,'pod' => 53,'pod_errors' => 0,'total' => 203,'with_comments' => 25},'releases' => 2,'size' => {'packed' => 2947,'unpacked' => 7028},'testers' => {},'uses' => ['WWW::Search::Scraper','WWW::Search::Scraper::Response','strict','vars']},'Bundle-WWW-Scraper-Housing-0.03.tar.gz' => {'author' => 'GLENNWOOD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 51,'pod_errors' => 0,'total' => 186,'with_comments' => 20},'releases' => 2,'requires' => ['Scraper-3.04.tar.gz'],'requires_module' => {'WWW::Scraper' => '2.28'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Scraper-3.04.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Tie-Persistent-1.00.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','XML-Parser-2.31.tar.gz','XML-XPath-1.13.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3572,'unpacked' => 7577},'testers' => {},'uses' => ['WWW::Scraper','WWW::Scraper::Response','strict','vars']},'Bundle-WWW-Scraper-Job-0.01.tar.gz' => {'author' => 'GLENNWOOD','description' => 'Scrapes BAJobs.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2390,'pod' => 1860,'pod_errors' => 1,'total' => 4250,'with_comments' => 226},'releases' => 1,'requires' => ['Scraper-3.04.tar.gz'],'requires_module' => {'WWW::Scraper' => '3.01'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Scraper-3.04.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Tie-Persistent-1.00.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','XML-Parser-2.31.tar.gz','XML-XPath-1.13.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 38295,'unpacked' => 145856},'testers' => {},'uses' => ['Exporter','HTML::Form','HTTP::Cookies','LWP::UserAgent','WWW::Scraper','WWW::Scraper::FieldTranslation','WWW::Scraper::Request','WWW::Scraper::Response','WWW::Search::Scraper','strict','vars']},'Bundle-WWW-Scraper-News-0.01.tar.gz' => {'author' => 'GLENNWOOD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 297,'pod' => 13,'pod_errors' => 0,'total' => 310,'with_comments' => 26},'releases' => 1,'requires' => ['Scraper-3.04.tar.gz'],'requires_module' => {'WWW::Scraper' => '3.02'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Scraper-3.04.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Tie-Persistent-1.00.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','XML-Parser-2.31.tar.gz','XML-XPath-1.13.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7927,'unpacked' => 25685},'testers' => {},'uses' => ['WWW::Scraper','WWW::Scraper::Response','strict','vars']},'Bundle-WWW-Search-1.06.tar.gz' => {'author' => 'MTHURN','description' => 'A bundle to install basic WWW::Search modules and prerequisites','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 15,'pod' => 39,'pod_errors' => 0,'total' => 54,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 1019,'unpacked' => 1928},'testers' => {},'uses' => []},'Bundle-WWW-Search-ALL-1.18.tar.gz' => {'author' => 'MTHURN','description' => 'A bundle to install all WWW::Search modules and backends','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13,'pod' => 73,'pod_errors' => 0,'total' => 86,'with_comments' => 0},'releases' => 15,'size' => {'packed' => 1073,'unpacked' => 2050},'testers' => {},'uses' => []},'Bundle-Wombat-0.7.1.tar.gz' => {'author' => 'IX','description' => 'a bundle to install all Wombat related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14,'pod' => 29,'pod_errors' => 0,'total' => 43,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 985,'unpacked' => 1694},'testers' => {},'uses' => ['5.6']},'Bundle-XML-0.11.tar.gz' => {'author' => 'MULL','description' => 'A bundle to install XML-related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 18,'pod' => 109,'pod_errors' => 0,'total' => 127,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 1648,'unpacked' => 3751},'testers' => {'tests' => '0','unknown' => 3},'uses' => []},'Bundle-Zavitan-0.2.0.tar.gz' => {'author' => 'SHLOMIF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13,'pod' => 53,'pod_errors' => 0,'total' => 66,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1200,'unpacked' => 1853},'testers' => {},'uses' => []},'Bundle-ePortal-0.04.tar.gz' => {'author' => 'RUSAKOV','description' => 'Bundle with all ePortal related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 33,'pod' => 63,'pod_errors' => 0,'total' => 96,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 975,'unpacked' => 1318},'testers' => {},'uses' => []},'Bundle-libnet-1.00.tar.gz' => {'author' => 'GBARR','description' => 'A bundle to install all libnet related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11,'pod' => 25,'pod_errors' => 0,'total' => 36,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 820,'unpacked' => 941},'testers' => {'pass' => 3,'tests' => '0','unknown' => 15},'uses' => []},'Bundle-libservlet-0.9.3.tar.gz' => {'author' => 'IX','description' => 'a bundle to install all libservlet related modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14,'pod' => 25,'pod_errors' => 0,'total' => 39,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 903,'unpacked' => 1432},'testers' => {},'uses' => ['5.6']},'Bundle-myxCal-0.03.tar.gz' => {'author' => 'OUBIWANN','description' => 'a CPAN bundle for the myxCal XML/CGI calendaring application','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10,'pod' => 88,'pod_errors' => 0,'total' => 98,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 2163,'unpacked' => 3882},'testers' => {},'uses' => []},'Bundle-perlWebSite-0.02.tar.gz' => {'author' => 'OUBIWANN','description' => 'a bundle for perlWebSite','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 11,'pod' => 62,'pod_errors' => 0,'total' => 73,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 1378,'unpacked' => 2176},'testers' => {},'uses' => []},'Business-Associates-1.00.tar.gz' => {'author' => 'CYBAEA','description' => 'a library to handle the new XML interface for the Amazon.com Associates program.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1488,'pod' => 1422,'pod_errors' => 0,'total' => 2910,'with_comments' => 259},'releases' => 2,'requires' => ['Cache-Cache-1.02.tar.gz','File-Spec-0.82.tar.gz','Image-Info-1.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXSLT-1.53.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Cache::Cache' => '0.99','Cache::SizeAwareFileCache' => 0,'File::Spec' => '0.82','HTTP::Request' => '1.3','Image::Info' => '1.09','LWP::UserAgent' => '2.001','XML::LibXML' => '1.4','XML::LibXSLT' => '1.31'},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','Image-Info-1.12.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 46133,'unpacked' => 187168},'testers' => {'pass' => 1},'uses' => ['5.6.0','Apache::Constants','Exporter','strict','warnings']},'Business-BancaSella-0.12.tar.gz' => {'author' => 'EBRUNI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1866,'pod' => 1037,'pod_errors' => 0,'total' => 2903,'with_comments' => 201},'releases' => 3,'requires' => ['HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'HTML::Entities' => 0,'URI' => 0,'URI::Escape' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','URI-1.24.tar.gz'],'size' => {'packed' => 46742,'unpacked' => 133916},'testers' => {'pass' => 1},'uses' => ['5.004','Carp','HTML::Entities','URI','URI::Escape','strict','warnings']},'Business-BankAccount-NZ-0.02.tar.gz' => {'author' => 'UNISOLVE','description' => 'validates New Zealand bank account numbers','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 489,'pod' => 99,'pod_errors' => 0,'total' => 588,'with_comments' => 151},'releases' => 1,'size' => {'packed' => 4851,'unpacked' => 16854},'testers' => {'pass' => 4},'uses' => ['5','Carp','strict','vars','warnings']},'Business-Barcode-EAN13-0.06.tar.gz' => {'author' => 'TMTM','description' => 'Perform simple validation of an EAN-13 barcode','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 260,'pod' => 76,'pod_errors' => 0,'total' => 336,'with_comments' => 23},'releases' => 1,'size' => {'packed' => 4552,'unpacked' => 11595},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','strict','vars']},'Business-CINS-1.13.tar.gz' => {'author' => 'TAYERS','description' => 'Verify CUSIP International Numbering System Numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 170,'pod' => 95,'pod_errors' => 0,'total' => 265,'with_comments' => 19},'releases' => 7,'requires' => ['Algorithm-LUHN-1.00.tar.gz'],'requires_module' => {'Algorithm::LUHN' => 0},'requires_recursive' => ['Algorithm-LUHN-1.00.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 5313,'unpacked' => 14822},'testers' => {'pass' => 5},'uses' => ['strict','vars']},'Business-CSI-0.81.1.tar.gz' => {'author' => 'JETTERO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 337,'pod' => 208,'pod_errors' => 0,'total' => 545,'with_comments' => 29},'releases' => 8,'requires' => ['Time-HiRes-1.49.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'Net::SMTP' => undef,'Time::HiRes' => 'Net::DNS'},'requires_recursive' => ['IO-1.20.tar.gz','Time-HiRes-1.49.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14384,'unpacked' => 45558},'testers' => {},'uses' => ['5.6.0','AutoLoader','Carp','DynaLoader','Exporter','Net::DNS','Net::SMTP','Sys::Hostname','Time::HiRes','strict','warnings']},'Business-CUSIP-1.02.tar.gz' => {'author' => 'TAYERS','description' => 'Verify Committee on Uniform Security Identification Procedures Numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 76,'pod_errors' => 0,'total' => 205,'with_comments' => 12},'releases' => 6,'requires' => ['Algorithm-LUHN-1.00.tar.gz'],'requires_module' => {'Algorithm::LUHN' => 0},'requires_recursive' => ['Algorithm-LUHN-1.00.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 4212,'unpacked' => 12020},'testers' => {'pass' => 5},'uses' => ['strict','vars']},'Business-Cashcow-0.08.tar.gz' => {'author' => 'GKE','description' => 'Internet payment with the Danish PBS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 70,'pod' => 75,'pod_errors' => 0,'total' => 145,'with_comments' => 8},'releases' => 6,'size' => {'packed' => 4691,'unpacked' => 13426},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Business-CreditCard-0.27.tar.gz' => {'author' => 'IVAN','description' => 'Credit card number check digit test','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 126,'pod' => 41,'pod_errors' => 0,'total' => 167,'with_comments' => 34},'releases' => 8,'size' => {'packed' => 3485,'unpacked' => 8626},'testers' => {'pass' => 18},'uses' => ['5','Exporter','vars']},'Business-DE-Konto-0.1.tar.gz' => {'author' => 'TINITA','description' => 'Validating Bank-Account Numbers for Germany','files' => [],'lines' => {'nonpod' => 465,'pod' => 51,'pod_errors' => 0,'total' => 516,'with_comments' => 43},'releases' => 1,'size' => {'packed' => 216579,'unpacked' => 823993},'testers' => {'pass' => 4},'uses' => ['5.00503','Cwd','Exporter','strict','vars']},'Business-FedEx-DirectConnect-0.17.tar.gz' => {'author' => 'JPOWERS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 727,'pod' => 203,'pod_errors' => 0,'total' => 930,'with_comments' => 52},'releases' => 16,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::UserAgent' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12295,'unpacked' => 38407},'testers' => {'pass' => 2},'uses' => ['Exporter','LWP::UserAgent','strict','vars']},'Business-Hours-0.06.tar.gz' => {'author' => 'JESSE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 410,'pod' => 105,'pod_errors' => 0,'total' => 515,'with_comments' => 44},'releases' => 6,'requires' => ['Set-IntSpan-1.07.tar.gz','Test-Inline-0.15.tar.gz'],'requires_module' => {'Set::IntSpan' => 0,'Test::Inline' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Set-IntSpan-1.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 13267,'unpacked' => 41302},'testers' => {'pass' => 1},'uses' => ['5.006','Set::IntSpan','Time::Local','strict','vars']},'Business-IBAN-0.03.tar.gz' => {'author' => 'TINITA','description' => 'Validate and generate IBANs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 101,'pod_errors' => 3,'total' => 231,'with_comments' => 8},'releases' => 1,'requires' => ['Locale-Codes-2.06.tar.gz'],'requires_module' => {'Locale::Country' => '2.03'},'requires_recursive' => ['Locale-Codes-2.06.tar.gz'],'size' => {'packed' => 2996,'unpacked' => 8819},'testers' => {'pass' => 4},'uses' => ['5.005_62','Exporter','Math::BigInt','constant','strict','vars']},'Business-ISBN-1.70.tar.gz' => {'author' => 'BDFOY','description' => 'Work with ISBN as objects','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 582,'pod' => 175,'pod_errors' => 0,'total' => 757,'with_comments' => 42},'releases' => 17,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Find::Rule' => 0,'Test::More' => 0,'Test::Pod' => 0},'requires_recursive' => ['File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 347818,'unpacked' => 1208108},'testers' => {'pass' => 8},'uses' => ['Business::ISBN::Data','Exporter','GD::Barcode::EAN13','strict','subs','vars']},'Business-ISBN-Data-1.03.tar.gz' => {'author' => 'BDFOY','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 156,'pod' => 30,'pod_errors' => 0,'total' => 186,'with_comments' => 4},'releases' => 2,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','Test::Manifest' => '0.9','Test::More' => '0','Test::Pod' => '0'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 4273,'unpacked' => 14924},'testers' => {'pass' => 1},'uses' => ['vars']},'Business-ISIN-0.20.tgz' => {'author' => 'DIVEC','description' => 'validate International Securities Identification Numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 145,'pod' => 74,'pod_errors' => 0,'total' => 219,'with_comments' => 26},'releases' => 5,'size' => {'packed' => 4517,'unpacked' => 10710},'testers' => {'pass' => 2,'tests' => '0','unknown' => 3},'uses' => ['5.005','Carp','Locale::Country','strict','subs','vars']},'Business-ISMN-1.4.tar.gz' => {'author' => 'BDFOY','description' => 'work with International Standard Music Numbers','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 171,'pod_errors' => 0,'total' => 608,'with_comments' => 25},'releases' => 4,'requires' => ['File-Find-Rule-0.10.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Tie-Cycle-1.06.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','List::Util' => '0','Test::Manifest' => '0.9','Test::More' => '0','Test::Pod' => '0','Test::Prereq' => '0.14','Tie::Cycle' => '0'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Tie-Cycle-1.06.tar.gz'],'size' => {'packed' => 8068,'unpacked' => 22137},'testers' => {'fail' => 3,'tests' => '23'},'uses' => ['Business::ISMN::Data','Exporter','GD::Barcode::EAN13','List::Util','Tie::Cycle','strict','subs','vars']},'Business-ISSN-0.90.tar.gz' => {'author' => 'SAPAPO','description' => 'Object and functions to work with ISSN','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 228,'pod' => 82,'pod_errors' => 0,'total' => 310,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 3694,'unpacked' => 9456},'testers' => {'pass' => 6},'uses' => ['Exporter','strict','subs','vars']},'Business-NoChex-0.02.tar.gz' => {'author' => 'RSZEMETI','description' => 'An OO interface to the NoChex apc','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 60,'pod' => 35,'pod_errors' => 0,'total' => 95,'with_comments' => 0},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz','Class-MethodMaker-1.10.tar.gz'],'requires_module' => {'CGI' => 2,'Class::MethodMaker' => '1.05'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Class-MethodMaker-1.10.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 3155,'unpacked' => 6191},'testers' => {'pass' => 5},'uses' => ['5.005_62','CGI','Class::MethodMaker','LWP::UserAgent','strict','vars','warnings']},'Business-OCV-0.1.tar.gz' => {'author' => 'BENL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2195,'pod' => 0,'pod_errors' => 0,'total' => 2195,'with_comments' => 922},'releases' => 1,'size' => {'packed' => 39207,'unpacked' => 114239},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','Fcntl','IO::File','IO::Select','IO::Socket','POSIX','Socket','strict','vars']},'Business-OnlinePayment-2.00.tar.gz' => {'author' => 'JASONK','description' => 'Ecommerce middleware','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 185,'pod_errors' => 0,'total' => 322,'with_comments' => 4},'releases' => 4,'requires' => ['Net_SSLeay.pm-1.23.tar.gz'],'requires_module' => {'Net::SSLeay' => 0},'requires_recursive' => ['Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 5365,'unpacked' => 13919},'testers' => {'pass' => 14},'uses' => ['5.004','Exporter','strict','vars']},'Business-OnlinePayment-2CheckOut-0.02.tar.gz' => {'author' => 'AKHOBOV','description' => '2CheckOut backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 187,'pod' => 59,'pod_errors' => 0,'total' => 246,'with_comments' => 6},'releases' => 2,'requires' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz','Text-CSV_XS-0.23.tar.gz'],'requires_module' => {'Business::OnlinePayment' => 0,'Net::SSLeay' => 0,'Text::CSV_XS' => 0},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz','Text-CSV_XS-0.23.tar.gz'],'size' => {'packed' => 3750,'unpacked' => 9601},'testers' => {'pass' => 4},'uses' => ['5.006','Business::OnlinePayment','Exporter','Net::SSLeay','strict','vars']},'Business-OnlinePayment-AuthorizeNet-3.12.tar.gz' => {'author' => 'IVAN','description' => 'AuthorizeNet backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 224,'pod' => 82,'pod_errors' => 0,'total' => 306,'with_comments' => 9},'releases' => 8,'requires' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz','Text-CSV_XS-0.23.tar.gz'],'requires_module' => {'Business::OnlinePayment' => 0,'Net::SSLeay' => 0,'Text::CSV_XS' => 0},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz','Text-CSV_XS-0.23.tar.gz'],'size' => {'packed' => 5901,'unpacked' => 17739},'testers' => {'pass' => 8},'uses' => ['Business::OnlinePayment','Carp','Exporter','Net::SSLeay','Text::CSV_XS','strict','vars']},'Business-OnlinePayment-BankOfAmerica-1.02.tar.gz' => {'author' => 'IVAN','description' => 'Bank of America backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 234,'pod' => 111,'pod_errors' => 0,'total' => 345,'with_comments' => 18},'releases' => 3,'requires' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'requires_module' => {'Business::OnlinePayment' => '0','Net::SSLeay' => '0'},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 4994,'unpacked' => 16163},'testers' => {'pass' => 3},'uses' => ['Business::OnlinePayment','Carp','Exporter','Net::SSLeay','Text::CSV','strict','vars']},'Business-OnlinePayment-Beanstream-0.01.tar.gz' => {'author' => 'ILYALIT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 169,'pod' => 95,'pod_errors' => 0,'total' => 264,'with_comments' => 7},'releases' => 1,'requires' => ['Business-OnlinePayment-2.00.tar.gz'],'requires_module' => {'Business::OnlinePayment' => 0},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 3549,'unpacked' => 10208},'testers' => {'pass' => 3},'uses' => ['Business::OnlinePayment','Net::SSLeay','strict','vars']},'Business-OnlinePayment-Cardstream-1.0.tar.gz' => {'author' => 'BELCHAM','description' => 'Cardstream Plugin for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 118,'pod' => 65,'pod_errors' => 0,'total' => 183,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 8223,'unpacked' => 23108},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Business::OnlinePayment','Exporter','Net::SSLeay','strict','vars']},'Business-OnlinePayment-Jettis-0.01.tar.gz' => {'author' => 'IVAN','description' => 'Jettis backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 268,'pod' => 49,'pod_errors' => 0,'total' => 317,'with_comments' => 4},'releases' => 1,'requires' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'requires_module' => {'Business::OnlinePayment' => 0,'Net::SSLeay' => 0},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 4491,'unpacked' => 10804},'testers' => {'pass' => 5},'uses' => ['Business::CreditCard','Business::OnlinePayment','Carp','Exporter','Net::SSLeay','URI','strict','vars']},'Business-OnlinePayment-LinkPoint-0.02.tar.gz' => {'author' => 'IVAN','description' => 'LinkPoint backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 64,'pod_errors' => 0,'total' => 240,'with_comments' => 12},'releases' => 2,'requires' => ['Business-OnlinePayment-2.00.tar.gz'],'requires_module' => {'Business::OnlinePayment' => 0},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 3821,'unpacked' => 10302},'testers' => {'pass' => 5},'uses' => ['AutoLoader','Business::OnlinePayment','Carp','Exporter','lperl','strict','vars']},'Business-OnlinePayment-MerchantCommerce-0.01.tar.gz' => {'author' => 'TMAC','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 255,'pod' => 249,'pod_errors' => 0,'total' => 504,'with_comments' => 0},'releases' => 1,'requires' => ['Business-OnlinePayment-2.00.tar.gz'],'requires_module' => {'Business::OnlinePayment' => 0},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 5286,'unpacked' => 16238},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','Net::SSLeay','strict','vars']},'Business-OnlinePayment-Network1Financial-0.02.tar.gz' => {'author' => 'IVAN','description' => 'Network1 Financial backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 209,'pod' => 50,'pod_errors' => 0,'total' => 259,'with_comments' => 71},'releases' => 2,'requires' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'requires_module' => {'Business::OnlinePayment' => '0','Net::SSLeay' => '0'},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 4034,'unpacked' => 11582},'testers' => {'pass' => 3},'uses' => ['Business::CreditCard','Business::OnlinePayment','Carp','Exporter','Net::SSLeay','URI','strict','vars']},'Business-OnlinePayment-OCV-0.01.tar.gz' => {'author' => 'IVAN','description' => 'OCV backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 47,'pod_errors' => 0,'total' => 129,'with_comments' => 9},'releases' => 1,'requires' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'requires_module' => {'Business::OnlinePayment' => 0,'Net::SSLeay' => 0},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 2996,'unpacked' => 7139},'testers' => {'fail' => 4,'tests' => '2'},'uses' => ['Business::CreditCard','Business::OCV','Business::OnlinePayment','Carp','Exporter','Net::SSLeay','strict','subs','vars']},'Business-OnlinePayment-PayConnect-0.02.tar.gz' => {'author' => 'IVAN','description' => 'PaymentOne (formerly eBillit) PayConnect backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 51,'pod_errors' => 0,'total' => 181,'with_comments' => 15},'releases' => 2,'requires' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'requires_module' => {'Business::OnlinePayment' => '0','Net::SSLeay' => '0'},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 3448,'unpacked' => 8737},'testers' => {'pass' => 8},'uses' => ['Business::CreditCard','Business::OnlinePayment','Carp','Exporter','Net::SSLeay','strict','vars']},'Business-OnlinePayment-PayflowPro-0.01.tar.gz' => {'author' => 'IVAN','description' => 'Verisign PayflowPro backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 203,'pod' => 62,'pod_errors' => 0,'total' => 265,'with_comments' => 23},'releases' => 1,'requires' => ['Business-OnlinePayment-2.00.tar.gz'],'requires_module' => {'Business::OnlinePayment' => 0},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 3961,'unpacked' => 11242},'testers' => {'fail' => 1,'tests' => '4'},'uses' => ['AutoLoader','Business::OnlinePayment','Carp','Exporter','PFProAPI','strict','vars']},'Business-OnlinePayment-PaymentsGateway-0.01.tar.gz' => {'author' => 'IVAN','description' => 'PaymentsGateway.Net backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 228,'pod' => 51,'pod_errors' => 0,'total' => 279,'with_comments' => 25},'releases' => 1,'requires' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'requires_module' => {'Business::OnlinePayment' => '0','Net::SSLeay' => '0'},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 4393,'unpacked' => 12673},'testers' => {'pass' => 2},'uses' => ['Business::OnlinePayment','Carp','Exporter','Net::SSLeay','strict','vars']},'Business-OnlinePayment-SurePay-0.01.tar.gz' => {'author' => 'AKHOBOV','description' => 'SurePay backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 741,'pod' => 61,'pod_errors' => 0,'total' => 802,'with_comments' => 5},'releases' => 1,'requires' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'requires_module' => {'Business::OnlinePayment' => 0,'Net::SSLeay' => 0},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 7591,'unpacked' => 26654},'testers' => {'pass' => 3},'uses' => ['5.006','Business::OnlinePayment','Exporter','Net::SSLeay','strict','vars','warnings']},'Business-OnlinePayment-TCLink-1.03.tar.gz' => {'author' => 'WITTEN','description' => 'TrustCommerce backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 173,'pod' => 65,'pod_errors' => 0,'total' => 238,'with_comments' => 5},'releases' => 3,'requires' => ['Business-OnlinePayment-2.00.tar.gz','Net_TCLink.pm-3.3.1.tar.gz'],'requires_module' => {'Business::OnlinePayment' => 0,'Net::TCLink' => 0},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz','Net_TCLink.pm-3.3.1.tar.gz'],'size' => {'packed' => 4963,'unpacked' => 13844},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Business::OnlinePayment','Exporter','Net::TCLink','strict','vars']},'Business-OnlinePayment-VirtualNet-0.02.tar.gz' => {'author' => 'IVAN','description' => 'Vital VirtualNet backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 695,'pod' => 115,'pod_errors' => 0,'total' => 810,'with_comments' => 202},'releases' => 2,'requires' => ['Business-OnlinePayment-2.00.tar.gz','File-CounterFile-1.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz','String-LRC-1.01.tar.gz','String-Parity-1.31.tar.gz','TimeDate-1.16.tar.gz'],'requires_module' => {'Business::OnlinePayment' => 0,'Date::Format' => 0,'File::CounterFile' => 0,'Net::SSLeay' => 0,'String::LRC' => 0,'String::Parity' => 0},'requires_recursive' => ['Business-OnlinePayment-2.00.tar.gz','File-CounterFile-1.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz','String-LRC-1.01.tar.gz','String-Parity-1.31.tar.gz','TimeDate-1.16.tar.gz'],'size' => {'packed' => 10014,'unpacked' => 43309},'testers' => {'fail' => 2,'pass' => 1,'tests' => '10'},'uses' => ['Business::CreditCard','Business::OnlinePayment','Carp','Date::Format','Exporter','File::CounterFile','Net::SSLeay','String::LRC','String::Parity','strict','vars']},'Business-OnlinePayment-WorldPay-Junior-1.05.tar.gz' => {'author' => 'CLIFFORDJ','description' => 'Module for WorldPay Junior Payment Service','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 546,'pod' => 132,'pod_errors' => 0,'total' => 678,'with_comments' => 67},'releases' => 5,'size' => {'packed' => 18579,'unpacked' => 54555},'testers' => {'pass' => 3},'uses' => ['5.006','AutoLoader','DBI','Exporter','strict','warnings']},'Business-OnlinePayment-eSec-0.02.tar.gz' => {'author' => 'IVAN','description' => 'eSec backend for Business::OnlinePayment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 134,'pod' => 47,'pod_errors' => 0,'total' => 181,'with_comments' => 3},'releases' => 2,'requires' => ['Business-CreditCard-0.27.tar.gz','Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'requires_module' => {'Business::CreditCard' => '0.27','Business::OnlinePayment' => 0,'Net::SSLeay' => 0},'requires_recursive' => ['Business-CreditCard-0.27.tar.gz','Business-OnlinePayment-2.00.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 3359,'unpacked' => 8401},'testers' => {'pass' => 6},'uses' => ['Business::CreditCard','Business::OnlinePayment','Carp','Exporter','Net::SSLeay','strict','vars']},'Business-PayPal-0.02.tar.gz' => {'author' => 'MOCK','description' => 'Perl extension for automating PayPal transactions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 221,'pod' => 301,'pod_errors' => 0,'total' => 522,'with_comments' => 14},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'requires_module' => {'CGI' => 0,'Digest::MD5' => 0,'Net::SSLeay' => '1.14'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 7905,'unpacked' => 20425},'testers' => {'pass' => 2},'uses' => ['5.6.1','CGI','Digest::MD5','Net::SSLeay','strict','warnings']},'Business-PayPal-IPN-1.93.tar.gz' => {'author' => 'SHERZODR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 405,'pod' => 184,'pod_errors' => 0,'total' => 589,'with_comments' => 35},'releases' => 8,'requires' => ['Crypt-SSLeay-0.51.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Crypt::SSLeay' => undef,'LWP' => undef},'requires_recursive' => ['Crypt-SSLeay-0.51.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8549,'unpacked' => 29007},'testers' => {'pass' => 3},'uses' => ['CGI','Carp','Data::Dumper','LWP::UserAgent','strict','vars']},'Business-PhoneBill-Allopass-1.04.tar.gz' => {'author' => 'BPGN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 316,'pod' => 137,'pod_errors' => 1,'total' => 453,'with_comments' => 3},'releases' => 4,'requires' => ['CGI.pm-2.98.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'CGI::Cookie' => 1,'HTTP::Request::Common' => 1,'LWP::UserAgent' => 1},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11690,'unpacked' => 32963},'testers' => {'pass' => 2},'uses' => ['CGI::Cookie','HTTP::Request::Common','LWP::UserAgent','strict','vars']},'Business-SEDOL-1.02.tar.gz' => {'author' => 'TAYERS','description' => 'Verify Stock Exchange Daily Official List Numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 93,'pod' => 60,'pod_errors' => 0,'total' => 153,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 2860,'unpacked' => 6969},'testers' => {'pass' => 5},'uses' => ['strict','vars']},'Business-Tax-VAT-0.91.tar.gz' => {'author' => 'TMTM','description' => 'perform European VAT calculations','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 106,'pod_errors' => 0,'total' => 196,'with_comments' => 0},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.17'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3120,'unpacked' => 7299},'testers' => {'pass' => 4},'uses' => ['strict','vars']},'Business-UPC-0.04.tar.gz' => {'author' => 'ROBF','description' => 'manipulating Universal Product Codes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 363,'pod' => 54,'pod_errors' => 0,'total' => 417,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 4897,'unpacked' => 14936},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','subs','vars']},'Business-UPS-1.13.tar.gz' => {'author' => 'MSOLOMON','description' => 'A UPS Interface Module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 242,'pod_errors' => 1,'total' => 419,'with_comments' => 19},'releases' => 4,'size' => {'packed' => 8312,'unpacked' => 18139},'testers' => {'pass' => 4},'uses' => ['5.003','Exporter','LWP::Simple','strict','vars']},'Business-US_Amort-0.08.tar.gz' => {'author' => 'SBURKE','description' => 'US-style loan amortization calculations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 424,'pod' => 243,'pod_errors' => 0,'total' => 667,'with_comments' => 60},'releases' => 4,'size' => {'packed' => 8471,'unpacked' => 23188},'testers' => {'pass' => 5},'uses' => ['5','Carp','strict','vars']},'Business-WorldPay-Junior-1.06.tar.gz' => {'author' => 'CLIFFORDJ','description' => 'Interface to use WorldPay\'s Junior service.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 547,'pod' => 132,'pod_errors' => 0,'total' => 679,'with_comments' => 67},'releases' => 2,'size' => {'packed' => 18563,'unpacked' => 54317},'testers' => {'pass' => 3},'uses' => ['5.006','AutoLoader','DBI','Exporter','strict','warnings']},'ByClock-1.01.tar.gz' => {'author' => 'SCHAFFTER','description' => 'Return to caller at given second/minute','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 245,'pod' => 177,'pod_errors' => 0,'total' => 422,'with_comments' => 20},'releases' => 4,'size' => {'packed' => 4946,'unpacked' => 19849},'testers' => {'pass' => 2},'uses' => ['Carp','Time::localtime','strict','vars']},'ByteCache-0.01.tar.gz' => {'author' => 'SIMON','description' => 'byte-compile modules when needed','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 26,'pod_errors' => 0,'total' => 83,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 1795,'unpacked' => 3299},'testers' => {'pass' => 6},'uses' => ['5.6.0','strict','warnings']},'C-DynaLib-0.55.tar.gz' => {'author' => 'JTOBEY','description' => 'Allows direct calls to dynamic libraries','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 587,'pod' => 357,'pod_errors' => 0,'total' => 944,'with_comments' => 35},'releases' => 5,'size' => {'packed' => 36058,'unpacked' => 90367},'testers' => {'fail' => 2,'pass' => 7},'uses' => ['5.002','Carp','DynaLoader','Exporter','strict','subs','vars']},'C-Include-1.40.tar.gz' => {'author' => 'AMICHAUER','description' => 'Operate C/C++ structs like perl deep struct','files' => ['Makefile.PL'],'lines' => {'nonpod' => 589,'pod' => 369,'pod_errors' => 0,'total' => 958,'with_comments' => 61},'releases' => 3,'size' => {'packed' => 16233,'unpacked' => 63801},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.005','Exporter','IO::File','Storable','strict','vars']},'C-Scan-0.74.tar.gz' => {'author' => 'HVDS','description' => 'Heuristic parse of C files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 927,'pod' => 94,'pod_errors' => 0,'total' => 1021,'with_comments' => 155},'releases' => 13,'requires' => ['Data-Flow-0.05.tar.gz'],'requires_module' => {'Data::Flow' => '0.05'},'requires_recursive' => ['Data-Flow-0.05.tar.gz'],'size' => {'packed' => 14202,'unpacked' => 44668},'testers' => {'pass' => 19},'uses' => ['Config','Data::Flow','Exporter','File::Basename','Symbol','strict']},'C-Sharp-0.01.tar.gz' => {'author' => 'SIMON','description' => 'Parser and Lexer for C# Programming Language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 171,'pod' => 53,'pod_errors' => 0,'total' => 224,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 17238,'unpacked' => 64227},'testers' => {'pass' => 4},'uses' => ['5.006','Exporter','strict','warnings']},'CAM-App-0.07.tar.gz' => {'author' => 'CLOTHO','description' => 'Web database application framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 753,'pod' => 302,'pod_errors' => 0,'total' => 1055,'with_comments' => 100},'releases' => 4,'requires' => ['CAM-Template-0.79.tar.gz','CGI.pm-2.98.tar.gz'],'requires_module' => {'CAM::Template' => '0.76','CGI' => 2},'requires_recursive' => ['CAM-Template-0.79.tar.gz','CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 18366,'unpacked' => 52685},'testers' => {'pass' => 3},'uses' => ['5.005_62','CAM::EmailTemplate','CAM::EmailTemplate::SMTP','CAM::Session','CAM::Template','CAM::Template::Cache','CGI','Carp','DBI','Exporter','strict','warnings']},'CAM-EmailTemplate-0.15.tar.gz' => {'author' => 'CLOTHO','description' => 'Template-based email message sender','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 170,'pod' => 98,'pod_errors' => 0,'total' => 268,'with_comments' => 8},'releases' => 1,'requires' => ['CAM-Template-0.79.tar.gz'],'requires_module' => {'CAM::Template' => '0.5'},'requires_recursive' => ['CAM-Template-0.79.tar.gz'],'size' => {'packed' => 11103,'unpacked' => 28536},'testers' => {'pass' => 5},'uses' => ['5.005_62','CAM::Template','Carp','strict','warnings']},'CAM-EmailTemplate-SMTP-0.20.tar.gz' => {'author' => 'CLOTHO','description' => 'Net::SMTP based email message sender','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 45,'pod_errors' => 0,'total' => 197,'with_comments' => 8},'releases' => 1,'requires' => ['CAM-EmailTemplate-0.15.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'CAM::EmailTemplate' => '0.11','Net::SMTP' => '1.03'},'requires_recursive' => ['CAM-EmailTemplate-0.15.tar.gz','CAM-Template-0.79.tar.gz','IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10291,'unpacked' => 26303},'testers' => {'pass' => 5},'uses' => ['5.005_62','CAM::EmailTemplate','Net::SMTP','strict','warnings']},'CAM-Template-0.79.tar.gz' => {'author' => 'CLOTHO','description' => 'Clotho-style search/replace HTML templates','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 575,'pod' => 333,'pod_errors' => 0,'total' => 908,'with_comments' => 51},'releases' => 4,'size' => {'packed' => 17458,'unpacked' => 51322},'testers' => {'pass' => 4},'uses' => ['5.005_62','Carp','Exporter','strict','warnings']},'CAM-Template-Cache-0.24.tar.gz' => {'author' => 'CLOTHO','description' => 'Template files with database storage','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 339,'pod' => 124,'pod_errors' => 0,'total' => 463,'with_comments' => 29},'releases' => 3,'requires' => ['CAM-Template-0.79.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'CAM::Template' => '0.5','DBI' => 1},'requires_recursive' => ['CAM-Template-0.79.tar.gz','DBI-1.37.tar.gz'],'size' => {'packed' => 11682,'unpacked' => 32076},'testers' => {'pass' => 3},'uses' => ['5.005_62','CAM::Template','Carp','strict','warnings']},'CArray-0.11.tar.gz' => {'author' => 'RURBAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 319,'pod' => 295,'pod_errors' => 1,'total' => 614,'with_comments' => 80},'releases' => 2,'size' => {'packed' => 21182,'unpacked' => 82666},'testers' => {'fail' => 6,'tests' => '90'},'uses' => ['Autoloader','Carp','DynaLoader','Tie::Array','integer','strict','vars']},'CDB_File-0.93.tar.gz' => {'author' => 'MSERGEANT','description' => 'Tie to CDB (Bernstein\'s constant DB) files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 242,'pod_errors' => 0,'total' => 334,'with_comments' => 1},'releases' => 12,'size' => {'packed' => 14521,'unpacked' => 40489},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'CDB_File-BiIndex-0.030.tar.gz' => {'author' => 'MIKEDLR','description' => 'Two directional index based on CDB File','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 514,'pod' => 141,'pod_errors' => 0,'total' => 655,'with_comments' => 82},'releases' => 4,'requires' => ['CDB_File-0.93.tar.gz','CDB_File-Generator-0.030.tar.gz'],'requires_module' => {'CDB_File' => '0.86','CDB_File::Generator' => '0.018'},'requires_recursive' => ['CDB_File-0.93.tar.gz','CDB_File-Generator-0.030.tar.gz'],'size' => {'packed' => 17921,'unpacked' => 63383},'testers' => {'fail' => 1,'pass' => 6,'tests' => '20'},'uses' => ['CDB_File','CDB_File::Generator','Carp','Fcntl','strict','vars','warnings']},'CDB_File-Generator-0.030.tar.gz' => {'author' => 'MIKEDLR','description' => 'CDB_File::Generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 166,'pod' => 57,'pod_errors' => 0,'total' => 223,'with_comments' => 15},'releases' => 4,'requires' => ['CDB_File-0.93.tar.gz'],'requires_module' => {'CDB_File' => '0.6'},'requires_recursive' => ['CDB_File-0.93.tar.gz'],'size' => {'packed' => 11518,'unpacked' => 30128},'testers' => {'fail' => 6,'pass' => 2,'tests' => '12'},'uses' => ['Carp','IO::File','strict','vars']},'CDDB-1.08.tar.gz' => {'author' => 'RCAPUTO','description' => 'high-level interface to cddb/freedb protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1025,'pod' => 341,'pod_errors' => 0,'total' => 1366,'with_comments' => 178},'releases' => 12,'size' => {'packed' => 20441,'unpacked' => 60286},'testers' => {'pass' => 9},'uses' => ['5.001','Carp','IO::Socket','MIME::QuotedPrint','Mail::Header','Mail::Internet','Sys::Hostname','strict','vars']},'CDDB-File-1.03.tar.gz' => {'author' => 'TMTM','description' => 'Parse a CDDB/freedb data file','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 103,'pod_errors' => 0,'total' => 270,'with_comments' => 9},'releases' => 8,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.17'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5380,'unpacked' => 13219},'testers' => {'pass' => 4},'uses' => ['IO::File','overload','strict']},'CDDB_get-2.2.tar.gz' => {'author' => 'FONKIE','description' => 'Read the CDDB entry for an audio CD in your drive','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 523,'pod' => 77,'pod_errors' => 0,'total' => 600,'with_comments' => 44},'releases' => 11,'size' => {'packed' => 18654,'unpacked' => 53078},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Data::Dumper','Exporter','Fcntl','IO::Socket','strict','vars']},'CECALA.tar.gz' => {'author' => 'CECALA','description' => undef,'files' => [],'lines' => {'nonpod' => 1898,'pod' => 0,'pod_errors' => 0,'total' => 1898,'with_comments' => 87},'releases' => 1,'size' => {'packed' => 65192,'unpacked' => 152233},'testers' => {'fail' => 1,'tests' => '0','unknown' => 6},'uses' => ['Exporter','Math::Trig','Tk','Tk::Canvas','lib','strict','vars']},'CFITSIO-0.96.tar.gz' => {'author' => 'PRATZLAFF','description' => 'obsolete module for FITS file manipulation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 23,'pod' => 25,'pod_errors' => 0,'total' => 48,'with_comments' => 0},'releases' => 10,'requires' => ['Astro-FITS-CFITSIO-1.01.tar.gz'],'requires_module' => {'Astro::FITS::CFITSIO' => '1.00'},'requires_recursive' => ['Astro-FITS-CFITSIO-1.01.tar.gz'],'size' => {'packed' => 1492,'unpacked' => 2394},'testers' => {},'uses' => ['5.005','Astro::FITS::CFITSIO','AutoLoader','Carp','strict','vars']},'CGI-AIS-Session-0.02.tar.gz' => {'author' => 'DAVIDNICO','description' => 'Perl extension to manage CGI user sessions with external identity authentication via AIS','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 235,'pod' => 92,'pod_errors' => 0,'total' => 327,'with_comments' => 22},'releases' => 2,'size' => {'packed' => 4998,'unpacked' => 10760},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','IO::Handle','Socket','strict','vars']},'CGI-AppToolkit-0.051.tgz' => {'author' => 'GISEBURT','description' => 'An object-oriented application development framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1687,'pod' => 1129,'pod_errors' => 0,'total' => 2816,'with_comments' => 228},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'CGI' => '0','DBI' => '0'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 81129,'unpacked' => 468806},'testers' => {'fail' => 2,'pass' => 1,'tests' => '80'},'uses' => ['5.004','Carp','DBI','DynaLoader','Exporter','strict','vars']},'CGI-Application-2.3.tar.gz' => {'author' => 'JERLBAUM','description' => 'Framework for building reusable web-applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1585,'pod' => 774,'pod_errors' => 0,'total' => 2359,'with_comments' => 180},'releases' => 14,'requires' => ['CGI.pm-2.98.tar.gz','HTML-Template-2.6.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'CGI' => 0,'HTML::Template' => 0,'Test::More' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 26494,'unpacked' => 90142},'testers' => {'pass' => 5},'uses' => ['CGI','CGI::Application','CGI::Carp','Carp','HTML::Template','Net::SMTP','TestApp','strict']},'CGI-Application-3.1.tar.gz' => {'author' => 'JERLBAUM','description' => 'Framework for building reusable web-applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1990,'pod' => 919,'pod_errors' => 1,'total' => 2909,'with_comments' => 218},'releases' => 14,'requires' => ['CGI.pm-2.98.tar.gz','HTML-Template-2.6.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'CGI' => 0,'HTML::Template' => 0,'Test::More' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 40599,'unpacked' => 135592},'testers' => {'pass' => 3},'uses' => ['CGI','CGI::Carp','Carp','Data::Dumper','HTML::Template','Net::SMTP','strict']},'CGI-Application-Generator-1.0.tar.gz' => {'author' => 'JERLBAUM','description' => 'Dynamically build CGI::Application modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 329,'pod' => 177,'pod_errors' => 1,'total' => 506,'with_comments' => 26},'releases' => 1,'requires' => ['CGI-Application-3.1.tar.gz','HTML-Template-2.6.tar.gz'],'requires_module' => {'CGI::Application' => 3,'HTML::Template' => '2.6'},'requires_recursive' => ['CGI-Application-3.1.tar.gz','CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14408,'unpacked' => 42979},'testers' => {'pass' => 10},'uses' => ['HTML::Template','strict','warnings']},'CGI-Application-MailPage-1.0.tar.gz' => {'author' => 'SAMTREGAR','description' => 'module to allow users to send HTML pages to friends.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 661,'pod' => 134,'pod_errors' => 0,'total' => 795,'with_comments' => 102},'releases' => 1,'requires' => ['CGI-Application-3.1.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','HTML-Tree-3.17.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','Text-Format0.52.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'CGI::Application' => 0,'File::Spec' => 0,'HTML::Template' => 0,'HTML::TreeBuilder' => 0,'HTTP::Date' => 0,'MIME::Entity' => 0,'Mail::Header' => 0,'Mail::Internet' => 0,'Net::SMTP' => 0,'Text::Format' => 0},'requires_recursive' => ['CGI-Application-3.1.tar.gz','CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Template-2.6.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Format0.52.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9598,'unpacked' => 39721},'testers' => {},'uses' => ['CGI::Application','File::Spec','HTML::Template','HTML::TreeBuilder','HTTP::Date','MIME::Entity','Mail::Header','Mail::Internet','Net::SMTP','Text::Format','strict','vars']},'CGI-Application-PhotoGallery-0.02.tar.gz' => {'author' => 'BRICAS','description' => 'module to provide a simple photo gallery','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 386,'pod' => 111,'pod_errors' => 0,'total' => 497,'with_comments' => 12},'releases' => 2,'requires' => ['CGI-Application-3.1.tar.gz','HTML-Template-2.6.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI::Application' => 0,'File::Basename' => 0,'HTML::Template' => 0},'requires_recursive' => ['CGI-Application-3.1.tar.gz','CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5863,'unpacked' => 16976},'testers' => {'pass' => 1},'uses' => ['CGI::Application','CGI::Application::PhotoGallery::$graphics_lib','File::Basename','GD','Image::Magick','strict']},'CGI-Application-ValidateRM-1.05.tar.gz' => {'author' => 'MARKSTOS','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 150,'pod' => 121,'pod_errors' => 0,'total' => 271,'with_comments' => 8},'releases' => 6,'size' => {'packed' => 6494,'unpacked' => 17030},'testers' => {'pass' => 1},'uses' => ['CGI::Application','CGI::Carp','Data::FormValidator','Exporter','HTML::FillInForm','strict','vars']},'CGI-ArgChecker-0.02.tar.gz' => {'author' => 'DLOWE','description' => 'Consistent, extensible CGI param validation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 197,'pod' => 42,'pod_errors' => 0,'total' => 239,'with_comments' => 77},'releases' => 1,'requires' => ['String-Checker-0.03.tar.gz'],'requires_module' => {'String::Checker' => '0.01'},'requires_recursive' => ['DateManip-5.42a.tar.gz','String-Checker-0.03.tar.gz'],'size' => {'packed' => 3093,'unpacked' => 8349},'testers' => {'pass' => 9},'uses' => ['String::Checker','strict','vars']},'CGI-Auth-2.4.1.tar.gz' => {'author' => 'CCWALLACE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 782,'pod' => 224,'pod_errors' => 0,'total' => 1006,'with_comments' => 56},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz'],'requires_module' => {'CGI' => 2},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 11388,'unpacked' => 32968},'testers' => {'pass' => 1,'tests' => '0','unknown' => 3},'uses' => ['CGI','Carp','HTML::Template','strict','vars']},'CGI-Authent-0.2.1.tar.gz' => {'author' => 'JENDA','description' => 'conditionaly send the HTTP authent request','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 155,'pod' => 130,'pod_errors' => 0,'total' => 285,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 4687,'unpacked' => 11289},'testers' => {'pass' => 11},'uses' => []},'CGI-Bus-0.51.tar.gz' => {'author' => 'MAKAROW','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 8291,'pod' => 2962,'pod_errors' => 9,'total' => 11253,'with_comments' => 987},'releases' => 7,'size' => {'packed' => 97769,'unpacked' => 359152},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.000','Apache','CGI::Bus','CGI::Bus::Base','CGI::Bus::lngbase::CGI_Bus','CGI::Bus::lngbase::CGI_Bus_tm','CGI::Bus::lngbase::CGI_Bus_tm_ru','CGI::Bus::lngbase::CGI_Bus_tmsql','CGI::Bus::lngbase::CGI_Bus_upws','CGI::Bus::lngbase::CGI_Bus_wg','CGI::Bus::tm','CGI::Carp','DBI','Fcntl','File::Compare','File::Copy','IO::File','Net::SMTP','Sys::Hostname','Win32','Win32::TieRegistry','strict','vars']},'CGI-Bus-0.56.tar.gz' => {'author' => 'MAKAROW','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 9057,'pod' => 3455,'pod_errors' => 9,'total' => 12512,'with_comments' => 1041},'releases' => 7,'size' => {'packed' => 115461,'unpacked' => 418475},'testers' => {'pass' => 2},'uses' => ['5.000','Apache','CGI::Carp','DBI','Fcntl','File::Compare','File::Copy','IO::File','Net::SMTP','Safe','Sys::Hostname','Win32','Win32::TieRegistry','strict','vars']},'CGI-CIPP-0.07.tar.gz' => {'author' => 'JRED','description' => 'Use CIPP embedded HTML Pages in a CGI environment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 676,'pod' => 193,'pod_errors' => 0,'total' => 869,'with_comments' => 29},'releases' => 5,'requires' => ['CIPP-2.40.tar.gz'],'requires_module' => {'CIPP' => '2.13'},'requires_recursive' => ['CIPP-2.40.tar.gz'],'size' => {'packed' => 9459,'unpacked' => 27513},'testers' => {'pass' => 6},'uses' => ['CIPP','Carp','Config','Fcntl','File::Path','FileHandle','strict']},'CGI-Cache-1.40.tar.gz' => {'author' => 'DCOPPIT','description' => 'Speed up slow CGI scripts by caching','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 672,'pod' => 402,'pod_errors' => 0,'total' => 1074,'with_comments' => 76},'releases' => 11,'requires' => ['Cache-Cache-1.02.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Storable-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Cache::SizeAwareFileCache' => 0,'File::Path' => 0,'File::Spec' => 0,'File::Spec::Functions' => 0,'IO::File' => 0,'Storable' => 0},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15370,'unpacked' => 62266},'testers' => {'pass' => 6},'uses' => ['Cache::SizeAwareFileCache','File::Path','File::Spec','File::Spec::Functions','Storable','strict','vars']},'CGI-ClientError-0.03.tar.gz' => {'author' => 'TOBIX','description' => 'send minimalistic error messages to the browser','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 103,'pod' => 41,'pod_errors' => 0,'total' => 144,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2411,'unpacked' => 4887},'testers' => {'pass' => 10},'uses' => ['Exporter','vars']},'CGI-Compress-Gzip-0.11.tar.gz' => {'author' => 'CLOTHO','description' => 'CGI with automatically compressed output','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 422,'pod' => 99,'pod_errors' => 0,'total' => 521,'with_comments' => 36},'releases' => 6,'requires' => ['CGI.pm-2.98.tar.gz','IO-Zlib-1.01.tar.gz'],'requires_module' => {'CGI' => 2,'IO::Zlib' => '1.01'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Compress-Zlib-1.22.tar.gz','File-Spec-0.82.tar.gz','IO-Zlib-1.01.tar.gz'],'size' => {'packed' => 13749,'unpacked' => 37101},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['5.005_62','CGI','Carp','strict','warnings']},'CGI-ContactForm-1.14.tar.gz' => {'author' => 'GUNNAR','description' => 'Perl extension for generating a web contact form','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 368,'pod' => 205,'pod_errors' => 0,'total' => 573,'with_comments' => 9},'releases' => 14,'requires' => ['Mail-Sender-0.8.06.tar.gz','Text-Flowed-0.14.tar.gz'],'requires_module' => {'Mail::Sender' => 0,'Text::Flowed' => 0},'requires_recursive' => ['MIME-Base64-2.20.tar.gz','Mail-Sender-0.8.06.tar.gz','Text-Flowed-0.14.tar.gz'],'size' => {'packed' => 8197,'unpacked' => 26926},'testers' => {'pass' => 4},'uses' => ['CGI','Exporter','strict','vars']},'CGI-ConvertParam-0.05.tar.gz' => {'author' => 'OYAMA','description' => 'Decorator class which adds several hook to CGI::param().','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 323,'pod' => 330,'pod_errors' => 0,'total' => 653,'with_comments' => 4},'releases' => 3,'size' => {'packed' => 4328,'unpacked' => 15548},'testers' => {'pass' => 3},'uses' => ['5.00','Jcode','strict','vars']},'CGI-Cookie-Jam-0.01.tar.gz' => {'author' => 'HATA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 89,'pod_errors' => 0,'total' => 263,'with_comments' => 13},'releases' => 1,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Exporter' => '5.566'},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 11609,'unpacked' => 37512},'testers' => {'pass' => 3},'uses' => ['5.008','Carp','Exporter','strict','warnings']},'CGI-CookieSerial-0.06.tar.gz' => {'author' => 'OUBIWANN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 146,'pod_errors' => 0,'total' => 262,'with_comments' => 17},'releases' => 6,'size' => {'packed' => 4470,'unpacked' => 10747},'testers' => {'pass' => 3},'uses' => ['5.006','CGI::Cookie','Data::Serializer','warnings']},'CGI-Debug-1.0.tar.gz' => {'author' => 'JONAS','description' => 'show CGI debugging data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1003,'pod' => 324,'pod_errors' => 0,'total' => 1327,'with_comments' => 64},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz','Data-Dumper-2.101.tar.gz','MailTools-1.58.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'CGI' => 0,'Data::Dumper' => 0,'Mail::Send' => 0,'Time::HiRes' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','MailTools-1.58.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 15348,'unpacked' => 55288},'testers' => {'pass' => 9},'uses' => ['strict','vars']},'CGI-Deurl-1.08.tar.gz' => {'author' => 'JENDA','description' => 'decode the CGI parameters','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 244,'pod' => 187,'pod_errors' => 0,'total' => 431,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 5102,'unpacked' => 13659},'testers' => {'pass' => 8},'uses' => ['Exporter','vars']},'CGI-EZForm-2002.0403.tar.gz' => {'author' => 'STHOMAS','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 507,'pod' => 320,'pod_errors' => 0,'total' => 827,'with_comments' => 48},'releases' => 1,'size' => {'packed' => 8499,'unpacked' => 24900},'testers' => {'pass' => 2},'uses' => ['Carp']},'CGI-Echo-1.03.tgz' => {'author' => 'RSAVAGE','description' => 'Echo form data to test form design','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 100,'pod_errors' => 0,'total' => 338,'with_comments' => 52},'releases' => 4,'size' => {'packed' => 6524,'unpacked' => 21052},'testers' => {'pass' => 1},'uses' => ['5.005_62','CGI::DBI','Carp','Exporter','strict','warnings']},'CGI-EncryptForm-1.02.tar.gz' => {'author' => 'MARAL','description' => 'Implement trusted stateful CGI Form Data using cryptography.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 392,'pod' => 192,'pod_errors' => 0,'total' => 584,'with_comments' => 121},'releases' => 3,'requires' => ['Crypt-HCE_SHA-0.60.tar.gz','Digest-SHA1-2.04.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'Crypt::HCE_SHA' => 0,'Digest::SHA1' => 0,'Storable' => 0},'requires_recursive' => ['Crypt-HCE_SHA-0.60.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 9754,'unpacked' => 35066},'testers' => {'pass' => 7},'uses' => ['Crypt::HCE_SHA','Digest::SHA1','Storable','strict','vars']},'CGI-Enurl-1.07.tar.gz' => {'author' => 'JENDA','description' => 'encode the CGI parameters','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 149,'pod_errors' => 0,'total' => 238,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 3592,'unpacked' => 8090},'testers' => {'pass' => 16},'uses' => ['Exporter']},'CGI-Explorer-2.00.tgz' => {'author' => 'RSAVAGE','description' => 'A CGI support module for trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 497,'pod' => 594,'pod_errors' => 0,'total' => 1091,'with_comments' => 64},'releases' => 6,'size' => {'packed' => 31430,'unpacked' => 129243},'testers' => {},'uses' => ['5.005_62','Carp','Exporter','strict','warnings']},'CGI-Extratags-0.02.tar.gz' => {'author' => 'HORNBURG','description' => 'Useful Extensions for the CGI Module','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 158,'pod' => 74,'pod_errors' => 0,'total' => 232,'with_comments' => 51},'releases' => 2,'size' => {'packed' => 3912,'unpacked' => 9071},'testers' => {'tests' => '0','unknown' => 24},'uses' => ['CGI','URI::Escape','strict','vars']},'CGI-FastTemplate-1.09.tar.gz' => {'author' => 'JMOORE','description' => 'Perl extension for managing templates, and performing variable interpolation.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 703,'pod' => 460,'pod_errors' => 0,'total' => 1163,'with_comments' => 225},'releases' => 6,'size' => {'packed' => 13635,'unpacked' => 43236},'testers' => {'pass' => 14},'uses' => ['strict']},'CGI-Form2XML-1.3.tar.gz' => {'author' => 'JSTOWE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 341,'pod' => 86,'pod_errors' => 0,'total' => 427,'with_comments' => 30},'releases' => 2,'size' => {'packed' => 4889,'unpacked' => 13587},'testers' => {'pass' => 4},'uses' => ['CGI','POSIX','strict','vars']},'CGI-FormBuilder-2.11.tar.gz' => {'author' => 'NWIGER','description' => 'Easily generate and process stateful forms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2442,'pod' => 2108,'pod_errors' => 0,'total' => 4550,'with_comments' => 395},'releases' => 17,'requires' => ['CGI.pm-2.98.tar.gz'],'requires_module' => {'CGI' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 59061,'unpacked' => 208015},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'CGI-FormMagick-0.4.0.tar.gz' => {'author' => 'SKUD','description' => 'easily create CGI form-based applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3742,'pod' => 868,'pod_errors' => 9,'total' => 4610,'with_comments' => 755},'releases' => 17,'requires' => ['Object-Persistence-0.92.tar.gz','Text-Template-1.44.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Persistence::Object::Simple' => '0.47','Text::Template' => '1.23','XML::Parser' => '2.3'},'requires_recursive' => ['Object-Persistence-0.92.tar.gz','Text-Template-1.44.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 84427,'unpacked' => 266674},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['5.004','CGI::FormMagick::L10N','CGI::FormMagick::TagMaker','CGI::FormMagick::Validator','CGI::Persistent','Carp','Class::ParamParser','Exporter','File::Basename','Geography::States','Locale::Country','Locale::Maketext','Net::IPV4Addr','Text::Template','Time::ParseDate','XML::Parser','strict','vars']},'CGI-FormMagick-0.49.tar.gz' => {'author' => 'SKUD','description' => 'easily create CGI form-based applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4165,'pod' => 1204,'pod_errors' => 18,'total' => 5369,'with_comments' => 550},'releases' => 17,'requires' => ['Class-ParamParser-1.041.tar.gz','Object-Persistence-0.92.tar.gz','Text-Template-1.44.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Class::ParamParser' => '1.0401','Persistence::Object::Simple' => '0.47','Text::Template' => '1.23','XML::Parser' => '2.3'},'requires_recursive' => ['Class-ParamParser-1.041.tar.gz','Object-Persistence-0.92.tar.gz','Text-Template-1.44.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 68266,'unpacked' => 211806},'testers' => {'fail' => 1,'pass' => 1,'tests' => '5'},'uses' => ['5.004','CGI::FormMagick::Events','CGI::FormMagick::HTML','CGI::FormMagick::L10N','CGI::FormMagick::Setup','CGI::FormMagick::TagMaker','CGI::FormMagick::Utils','CGI::FormMagick::Validator','CGI::Persistent','Carp','Class::ParamParser','Exporter','File::Basename','Geography::States','Locale::Country','Locale::Maketext','Net::IPV4Addr','Text::Template','Time::ParseDate','XML::Parser','strict','vars']},'CGI-FormMagick-0.60.tar.gz' => {'author' => 'SKUD','description' => 'easily create CGI form-based applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3659,'pod' => 1474,'pod_errors' => 25,'total' => 5133,'with_comments' => 239},'releases' => 17,'requires' => ['CGI-Persistent-0.23.tar.gz','Class-ParamParser-1.041.tar.gz','Object-Persistence-0.92.tar.gz','Text-Template-1.44.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'CGI::Persistent' => '0.21','Class::ParamParser' => '1.0401','Persistence::Object::Simple' => '0.47','Text::Template' => '1.23','XML::Parser' => '2.3'},'requires_recursive' => ['CGI-Persistent-0.23.tar.gz','Class-ParamParser-1.041.tar.gz','Object-Persistence-0.92.tar.gz','Text-Template-1.44.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 64575,'unpacked' => 191420},'testers' => {},'uses' => ['5.004','CGI::FormMagick::Events','CGI::FormMagick::HTML','CGI::FormMagick::Setup','CGI::FormMagick::Sub','CGI::FormMagick::TagMaker','CGI::FormMagick::Utils','CGI::FormMagick::Validator','CGI::FormMagick::Validator::Basic','CGI::FormMagick::Validator::Business','CGI::FormMagick::Validator::Geography','CGI::FormMagick::Validator::Length','CGI::FormMagick::Validator::Network','CGI::Persistent','Carp','Class::ParamParser','Data::Dumper','Exporter','File::Basename','Geography::States','Locale::Country','Locale::Maketext','Text::Template','Time::ParseDate','XML::Parser','constant','strict','vars']},'CGI-FormMagick-0.86.tar.gz' => {'author' => 'SKUD','description' => 'easily create CGI form-based applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4060,'pod' => 1575,'pod_errors' => 23,'total' => 5635,'with_comments' => 260},'releases' => 17,'requires' => ['CGI-Persistent-0.23.tar.gz','Class-ParamParser-1.041.tar.gz','I18N-LangTags-0.28.tar.gz','Object-Persistence-0.92.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','Text-Template-1.44.tar.gz','Time-modules-2003.0211.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'CGI::Persistent' => '0.21','Class::ParamParser' => '1.0401','I18N::LangTags' => '0.13','Persistence::Object::Simple' => '0.47','Test::Inline' => '0.15','Test::More' => '0.42','Text::Iconv' => '1.2','Text::Template' => '1.4','Time::ParseDate' => '100.01','XML::Parser' => '2.3'},'requires_recursive' => ['CGI-Persistent-0.23.tar.gz','Class-ParamParser-1.041.tar.gz','File-Spec-0.82.tar.gz','I18N-LangTags-0.28.tar.gz','Object-Persistence-0.92.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','Text-Template-1.44.tar.gz','Time-modules-2003.0211.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 70547,'unpacked' => 211071},'testers' => {'fail' => 3,'tests' => '329'},'uses' => ['5.004','CGI::FormMagick::Events','CGI::FormMagick::HTML','CGI::FormMagick::L10N','CGI::FormMagick::Setup','CGI::FormMagick::Utils','CGI::FormMagick::Validator::Basic','CGI::FormMagick::Validator::Business','CGI::FormMagick::Validator::Geography','CGI::FormMagick::Validator::Length','CGI::FormMagick::Validator::Network','CGI::Persistent','Carp','Class::ParamParser','Data::Dumper','Exporter','File::Basename','Geography::States','I18N::LangTags','Locale::Country','Text::Iconv','Text::Template','Time::ParseDate','XML::Parser','constant','strict','vars']},'CGI-FormMagick-0.89.tar.gz' => {'author' => 'MITEL','description' => 'FormMagick','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4102,'pod' => 1573,'pod_errors' => 23,'total' => 5675,'with_comments' => 294},'releases' => 17,'requires' => ['CGI-Persistent-0.23.tar.gz','Class-ParamParser-1.041.tar.gz','I18N-LangTags-0.28.tar.gz','Object-Persistence-0.92.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','Text-Template-1.44.tar.gz','Time-modules-2003.0211.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'CGI::Persistent' => '0.21','Class::ParamParser' => '1.0401','I18N::LangTags' => '0.13','Persistence::Object::Simple' => '0.47','Test::Inline' => '0.15','Test::More' => '0.42','Text::Iconv' => '1.2','Text::Template' => '1.4','Time::ParseDate' => '100.01','XML::Parser' => '2.3'},'requires_recursive' => ['CGI-Persistent-0.23.tar.gz','Class-ParamParser-1.041.tar.gz','File-Spec-0.82.tar.gz','I18N-LangTags-0.28.tar.gz','Object-Persistence-0.92.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','Text-Template-1.44.tar.gz','Time-modules-2003.0211.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 76066,'unpacked' => 232758},'testers' => {},'uses' => ['5.004','CGI::FormMagick::Events','CGI::FormMagick::HTML','CGI::FormMagick::L10N','CGI::FormMagick::Setup','CGI::FormMagick::Sub','CGI::FormMagick::TagMaker','CGI::FormMagick::Utils','CGI::FormMagick::Validator','CGI::FormMagick::Validator::Basic','CGI::FormMagick::Validator::Business','CGI::FormMagick::Validator::Geography','CGI::FormMagick::Validator::Length','CGI::FormMagick::Validator::Network','CGI::Persistent','Carp','Class::ParamParser','Data::Dumper','Exporter','File::Basename','Geography::States','I18N::LangTags','Locale::Country','Mail::RFC822::Address','Text::Iconv','Text::Template','Time::ParseDate','XML::Parser','constant','strict','vars']},'CGI-Formalware-1.11.tgz' => {'author' => 'RSAVAGE','description' => 'Convert an XML file to a suite of CGI forms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 967,'pod' => 366,'pod_errors' => 0,'total' => 1333,'with_comments' => 134},'releases' => 8,'requires' => ['CGI.pm-2.98.tar.gz','Net-Telnet-3.03.tar.gz','XML-DOM-1.42.tar.gz'],'requires_module' => {'CGI' => '2.45','Net::Telnet' => '3.01','XML::DOM' => '1.14'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-Telnet-3.03.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14832,'unpacked' => 69332},'testers' => {},'uses' => ['CGI','CGI::Carp','Exporter','Net::Telnet','XML::DOM','constant','strict','vars']},'CGI-Framework-0.06.tar.gz' => {'author' => 'MNAGUIB','description' => 'A simple-to-use, lightweight web CGI framework It is primarily a glue between HTML::Template, CGI::Session, CGI, and some magic :)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 969,'pod' => 545,'pod_errors' => 0,'total' => 1514,'with_comments' => 181},'releases' => 5,'requires' => ['CGI-Session-3.95.tar.gz','CGI.pm-2.98.tar.gz','HTML-Template-2.6.tar.gz'],'requires_module' => {'CGI' => 0,'CGI::Carp' => 0,'CGI::Session' => 0,'HTML::Template' => 0},'requires_recursive' => ['CGI-Session-3.95.tar.gz','CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 24512,'unpacked' => 75561},'testers' => {'pass' => 1},'uses' => ['CGI','CGI::Carp','CGI::Session','HTML::Template','lib','pre_post','strict','vars']},'CGI-Htauth-1.21.tar.gz' => {'author' => 'PJB','description' => 'Authentication services for CGI scripts.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1046,'pod' => 205,'pod_errors' => 0,'total' => 1251,'with_comments' => 141},'releases' => 6,'requires' => ['CGI-FormBuilder-2.11.tar.gz','CGI.pm-2.98.tar.gz','Crypt-Tea-1.43.tar.gz'],'requires_module' => {'CGI' => 0,'CGI::FormBuilder' => 0,'Crypt::Tea' => 0},'requires_recursive' => ['CGI-FormBuilder-2.11.tar.gz','CGI.pm-2.98.tar.gz','Crypt-Tea-1.43.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 27483,'unpacked' => 88208},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Crypt::Tea','Exporter']},'CGI-Kwiki-0.13.tar.gz' => {'author' => 'INGY','description' => 'A Quickie Wiki that\'s not too Tricky','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 3659,'pod' => 427,'pod_errors' => 0,'total' => 4086,'with_comments' => 140},'releases' => 8,'size' => {'packed' => 28449,'unpacked' => 103290},'testers' => {'pass' => 2},'uses' => ['$self->{path}::$self->{dispatch}','5.004','CGI','CGI::Carp','CGI::Kwiki','CGI::Kwiki::Config','CGI::Kwiki::Formatter','Carp','Config','Exporter','ExtUtils::MM_Unix','File::Basename','File::Find','File::Path','File::Spec','LWP::Simple','Module::Install','Module::Install::Base','Test::Builder','inc::Module::Install','lib','strict','threads::shared','vars']},'CGI-Kwiki-0.17.tar.gz' => {'author' => 'INGY','description' => 'A Quickie Wiki that\'s not too Tricky','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 5266,'pod' => 561,'pod_errors' => 0,'total' => 5827,'with_comments' => 254},'releases' => 8,'size' => {'packed' => 41097,'unpacked' => 151784},'testers' => {'pass' => 3},'uses' => ['$self->{path}::$self->{dispatch}','5.004','CGI','Carp','Config','Exporter','ExtUtils::MM_Unix','File::Basename','File::Find','File::Path','File::Spec','LWP::Simple','Module::Install','Module::Install::Base','Test::Builder','YAML','constant','inc::Module::Install','lib','strict','threads::shared','vars']},'CGI-Listman-0.05.tar.gz' => {'author' => 'HPYHACKER','description' => 'Easily managing web subscribtion lists','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1563,'pod' => 1138,'pod_errors' => 0,'total' => 2701,'with_comments' => 59},'releases' => 5,'requires' => ['DBI-1.37.tar.gz','Text-CSV_XS-0.23.tar.gz'],'requires_module' => {'DBI' => '1.00','Text::CSV_XS' => '0.22'},'requires_recursive' => ['DBI-1.37.tar.gz','Text-CSV_XS-0.23.tar.gz'],'size' => {'packed' => 17663,'unpacked' => 70740},'testers' => {'pass' => 3},'uses' => ['CGI::Listman::dictionary','CGI::Listman::dictionary::term','CGI::Listman::line','CGI::Listman::selection','Carp','DBD::','DBI','Text::CSV_XS','strict','vars']},'CGI-Lite-2.001-emergencyrelease.tar.gz' => {'author' => 'ANDK','description' => 'Perl module to process and decode WWW forms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 826,'pod' => 359,'pod_errors' => 0,'total' => 1185,'with_comments' => 61},'releases' => 1,'size' => {'packed' => 15095,'unpacked' => 46195},'testers' => {'fail' => 2,'pass' => 3,'tests' => '0','unknown' => 39},'uses' => ['5.002','Exporter']},'CGI-Log-1.00.tar.gz' => {'author' => 'JMOORE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 494,'pod' => 214,'pod_errors' => 0,'total' => 708,'with_comments' => 145},'releases' => 1,'size' => {'packed' => 6741,'unpacked' => 18538},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['strict']},'CGI-Minimal-1.10.tar.gz' => {'author' => 'SNOWHARE','description' => 'A micro-sized CGI handler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 750,'pod' => 280,'pod_errors' => 0,'total' => 1030,'with_comments' => 80},'releases' => 7,'size' => {'packed' => 10095,'unpacked' => 34076},'testers' => {'pass' => 4},'uses' => ['Apache','Carp','strict','vars']},'CGI-MultiValuedHash-1.081.tar.gz' => {'author' => 'DUNCAND','description' => 'Store and manipulate url-encoded data','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 512,'pod' => 201,'pod_errors' => 0,'total' => 713,'with_comments' => 46},'releases' => 2,'requires' => ['Data-MultiValuedHash-1.081.tar.gz'],'requires_module' => {'Data::MultiValuedHash' => '1.081'},'requires_recursive' => ['Data-MultiValuedHash-1.081.tar.gz'],'size' => {'packed' => 16969,'unpacked' => 52511},'testers' => {'pass' => 6},'uses' => ['5.004','Data::MultiValuedHash','vars','warnings']},'CGI-MxScreen-0.1.1.tar.gz' => {'author' => 'RAM','description' => 'a multi-screen stateful CGI framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6043,'pod' => 2365,'pod_errors' => 1,'total' => 8408,'with_comments' => 2013},'releases' => 4,'requires' => ['CGI-Test-0.1.3.tar.gz','Carp-Datum-0.1.3.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Digest-MD5-2.26.tar.gz','Getargs-Long-0.1.3.tar.gz','LockFile-Simple-0.2.5.tar.gz','Log-Agent-0.304.tar.gz','Log-Agent-Logger-0.1.1.tar.gz','Log-Agent-Rotate-0.104.tar.gz','Storable-2.07.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'CGI::Test' => '0.103','Carp::Datum' => '0','Crypt::Blowfish' => '0','Crypt::CBC' => '1.22','Digest::MD5' => '0','Getargs::Long' => '0.103','LockFile::Simple' => '0.205','Log::Agent' => '0.208','Log::Agent::Logger' => '0.101','Log::Agent::Rotate' => '0.103','Storable' => '1.011','Time::HiRes' => '0'},'requires_recursive' => ['CGI-Test-0.1.3.tar.gz','CGI.pm-2.98.tar.gz','Carp-Datum-0.1.3.tar.gz','Compress-Zlib-1.22.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getargs-Long-0.1.3.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','LockFile-Simple-0.2.5.tar.gz','Log-Agent-0.304.tar.gz','Log-Agent-Logger-0.1.1.tar.gz','Log-Agent-Rotate-0.104.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 74340,'unpacked' => 272008},'testers' => {'pass' => 1},'uses' => ['CGI','CGI::Carp','Carp::Datum','Compress::Zlib','Crypt::CBC','Digest::MD5','Exporter','Fcntl','File::Basename','File::Path','File::Spec','FindBin','Getargs::Long','LockFile::Simple','Log::Agent','Log::Agent::Channel::File','Log::Agent::Driver::File','Log::Agent::Logger','Log::Agent::Rotate','Log::Agent::Tag::String','MIME::Base64','Storable','Symbol','Tie::Handle','Tie::Hash','Time::HiRes','constant','lib','overload','strict','vars']},'CGI-MxScreen-0.1.2.tar.gz' => {'author' => 'PURDY','description' => 'Screen multi-plexer framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6043,'pod' => 2365,'pod_errors' => 1,'total' => 8408,'with_comments' => 2013},'releases' => 4,'requires' => ['CGI-Test-0.1.3.tar.gz','Carp-Datum-0.1.3.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Digest-MD5-2.26.tar.gz','Getargs-Long-0.1.3.tar.gz','LockFile-Simple-0.2.5.tar.gz','Log-Agent-0.304.tar.gz','Log-Agent-Logger-0.1.1.tar.gz','Log-Agent-Rotate-0.104.tar.gz','Storable-2.07.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'CGI::Test' => '0.103','Carp::Datum' => '0','Crypt::Blowfish' => '0','Crypt::CBC' => '1.22','Digest::MD5' => '0','Getargs::Long' => '0.103','LockFile::Simple' => '0.205','Log::Agent' => '0.208','Log::Agent::Logger' => '0.101','Log::Agent::Rotate' => '0.103','Storable' => '1.011','Time::HiRes' => '0'},'requires_recursive' => ['CGI-Test-0.1.3.tar.gz','CGI.pm-2.98.tar.gz','Carp-Datum-0.1.3.tar.gz','Compress-Zlib-1.22.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getargs-Long-0.1.3.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','LockFile-Simple-0.2.5.tar.gz','Log-Agent-0.304.tar.gz','Log-Agent-Logger-0.1.1.tar.gz','Log-Agent-Rotate-0.104.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 74694,'unpacked' => 272797},'testers' => {'fail' => 1,'tests' => '128'},'uses' => ['CGI','CGI::Carp','CGI::MxScreen::Action_Env','CGI::MxScreen::Config','CGI::MxScreen::Constant','CGI::MxScreen::Error','CGI::MxScreen::Exception','CGI::MxScreen::Exception::Bounce','CGI::MxScreen::Form::Button','CGI::MxScreen::Form::Field','CGI::MxScreen::Form::Utils','CGI::MxScreen::Layout','CGI::MxScreen::Serializer','CGI::MxScreen::Serializer::Storable','CGI::MxScreen::Session','CGI::MxScreen::Session::Medium::Browser','CGI::MxScreen::Session::Medium::File','CGI::MxScreen::Tie::Buffered_Output','CGI::MxScreen::Tie::Read_Checked','CGI::MxScreen::Tie::Sinkable','CGI::MxScreen::Tie::Stdout','Carp::Datum','Compress::Zlib','Crypt::CBC','Digest::MD5','Exporter','Fcntl','File::Basename','File::Path','File::Spec','FindBin','Getargs::Long','LockFile::Simple','Log::Agent','Log::Agent::Channel::File','Log::Agent::Driver::File','Log::Agent::Logger','Log::Agent::Rotate','Log::Agent::Tag::String','MIME::Base64','Storable','Symbol','Tie::Handle','Tie::Hash','Time::HiRes','constant','lib','overload','strict','vars']},'CGI-Out-101.121401.tar.gz' => {'author' => 'MUIR','description' => 'buffer output when building CGI programs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 397,'pod' => 97,'pod_errors' => 0,'total' => 494,'with_comments' => 11},'releases' => 9,'size' => {'packed' => 3759,'unpacked' => 8878},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['CGI::BigDeath','CGI::Carp','Carp','Cwd','Exporter','Net::SMTP','strict','vars']},'CGI-Panel-0.96.tar.gz' => {'author' => 'RSYMES','description' => 'Event-driven web apps from panel objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 962,'pod' => 460,'pod_errors' => 0,'total' => 1422,'with_comments' => 132},'releases' => 8,'requires' => ['Apache-Session-1.54.tar.gz'],'requires_module' => {'Apache::Session::File' => '0'},'requires_recursive' => ['Apache-Session-1.54.tar.gz'],'size' => {'packed' => 19845,'unpacked' => 72669},'testers' => {'pass' => 6},'uses' => ['Apache::Session::File','Basket','CGI','CGI::Carp','CGI::Panel','strict','vars']},'CGI-Panel-0.97.tar.gz' => {'author' => 'RSYMES','description' => 'Event-driven web apps from panel objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 930,'pod' => 452,'pod_errors' => 0,'total' => 1382,'with_comments' => 133},'releases' => 8,'requires' => ['Apache-Session-1.54.tar.gz'],'requires_module' => {'Apache::Session::File' => '0'},'requires_recursive' => ['Apache-Session-1.54.tar.gz'],'size' => {'packed' => 37401,'unpacked' => 141193},'testers' => {'pass' => 2},'uses' => ['Apache::Session::File','CGI','CGI::Carp','strict','vars']},'CGI-PathInfo-1.00.tar.gz' => {'author' => 'SNOWHARE','description' => 'A lightweight PATH_INFO based CGI package','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 340,'pod' => 145,'pod_errors' => 0,'total' => 485,'with_comments' => 60},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Entities' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 6080,'unpacked' => 16875},'testers' => {'pass' => 9},'uses' => ['Apache','Carp','strict','vars']},'CGI-Persistent-0.23.tar.gz' => {'author' => 'VIPUL','description' => 'Transparent State Persistence in CGI scripts','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 142,'pod' => 68,'pod_errors' => 0,'total' => 210,'with_comments' => 11},'releases' => 4,'size' => {'packed' => 4011,'unpacked' => 8874},'testers' => {'fail' => 5,'pass' => 9},'uses' => ['CGI','Data::Dumper','Persistence::Object::Simple','vars']},'CGI-Portable-0.472.tar.gz' => {'author' => 'DUNCAND','description' => 'Framework for server-generic web apps','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 7199,'pod' => 2842,'pod_errors' => 1,'total' => 10041,'with_comments' => 726},'releases' => 9,'requires' => ['CGI-MultiValuedHash-1.081.tar.gz','File-VirtualPath-1.011.tar.gz','HTML-EasyTags-1.071.tar.gz','HTML-FormTemplate-2.021.tar.gz','IO-1.20.tar.gz','libnet-1.16.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 1,'CGI::MultiValuedHash' => '1.081','File::VirtualPath' => '1.011','HTML::EasyTags' => '1.071','HTML::FormTemplate' => '2.021','IO::Socket' => 1,'Net::SMTP' => 1},'requires_recursive' => ['CGI-MultiValuedHash-1.081.tar.gz','Class-ParamParser-1.041.tar.gz','Data-MultiValuedHash-1.081.tar.gz','File-VirtualPath-1.011.tar.gz','HTML-EasyTags-1.071.tar.gz','HTML-FormTemplate-2.021.tar.gz','IO-1.20.tar.gz','libnet-1.16.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 100553,'unpacked' => 438374},'testers' => {'pass' => 5},'uses' => ['5.004','Apache','CGI::MultiValuedHash','Fcntl','File::VirtualPath','GD','HTML::EasyTags','HTML::FormTemplate','IO::Socket','Net::SMTP','Symbol','strict','vars','warnings']},'CGI-PrintWrapper-0.8.tar.gz' => {'author' => 'BINKLEY','description' => 'CGI methods output to a print handle','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 114,'pod_errors' => 0,'total' => 239,'with_comments' => 15},'releases' => 5,'requires' => ['CGI.pm-2.98.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI' => 2,'Carp' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5166,'unpacked' => 15687},'testers' => {'fail' => 3,'pass' => 6,'tests' => '16'},'uses' => ['CGI::Pretty','strict']},'CGI-ProgressBar-0.01.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 199,'pod' => 160,'pod_errors' => 0,'total' => 359,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 6307,'unpacked' => 19392},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['5.004','CGI','CGI::Util','strict','warnings']},'CGI-QuickForm-1.93.tar.gz' => {'author' => 'SUMMER','description' => 'Handles UI & validation for CGI forms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 607,'pod' => 813,'pod_errors' => 0,'total' => 1420,'with_comments' => 32},'releases' => 32,'size' => {'packed' => 44511,'unpacked' => 162241},'testers' => {'pass' => 5},'uses' => ['5.004','Apache::Constants','CGI','CGI::Carp','strict','vars']},'CGI-Response-0.03.tar.gz' => {'author' => 'MGH','description' => 'Response construction for CGI applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 501,'pod' => 151,'pod_errors' => 0,'total' => 652,'with_comments' => 60},'releases' => 3,'size' => {'packed' => 11464,'unpacked' => 31745},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['CGI::Base','Carp','Exporter','HTTP::Date','HTTP::Headers','HTTP::Status','SelfLoader','strict']},'CGI-SSI-0.53.tar.gz' => {'author' => 'JAMES','description' => 'Use SSI from CGI scripts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 464,'pod' => 191,'pod_errors' => 0,'total' => 655,'with_comments' => 40},'releases' => 9,'requires' => ['File-Spec-0.82.tar.gz','HTML-SimpleParse-0.12.tar.gz','TimeDate-1.16.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Date::Parse' => 0,'File::Spec' => 0,'FindBin' => 0,'HTML::SimpleParse' => 0,'LWP::Simple' => 0,'URI' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-SimpleParse-0.12.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','TimeDate-1.16.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8791,'unpacked' => 31610},'testers' => {'pass' => 4},'uses' => ['Date::Format','File::Spec','FindBin','HTML::SimpleParse','LWP::Simple','URI','strict']},'CGI-SSI-Remote-0.03.tar.gz' => {'author' => 'SHERZODR','description' => 'Perl extension for fetching remote SSI scripts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 58,'pod_errors' => 0,'total' => 140,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 10316,'unpacked' => 27712},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'CGI-SSI_Parser-0.01.tar.gz' => {'author' => 'VADIM','description' => 'Implement SSI for Perl CGI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 429,'pod' => 91,'pod_errors' => 0,'total' => 520,'with_comments' => 46},'releases' => 1,'size' => {'packed' => 3852,'unpacked' => 12823},'testers' => {'pass' => 9},'uses' => ['Exporter','POSIX','strict','vars']},'CGI-Safe-1.24.tar.gz' => {'author' => 'OVID','description' => 'Safe method of using CGI.pm. This is pretty much a two-line change for most CGI scripts.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 181,'pod' => 133,'pod_errors' => 0,'total' => 314,'with_comments' => 18},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz'],'requires_module' => {'CGI' => '2.2'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 5709,'unpacked' => 16068},'testers' => {'pass' => 9},'uses' => ['CGI','Carp','Exporter','strict','vars']},'CGI-Screen-0.122.tar.gz' => {'author' => 'ULPFR','description' => 'Create multi screen CGI-scripts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 416,'pod' => 245,'pod_errors' => 1,'total' => 661,'with_comments' => 33},'releases' => 10,'requires' => ['CGI.pm-2.98.tar.gz'],'requires_module' => {'CGI' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 11902,'unpacked' => 40648},'testers' => {'pass' => 10},'uses' => ['CGI','strict','vars']},'CGI-Search-0.5.tar.gz' => {'author' => 'TMURRAY','description' => 'Simple way of using a CGI to search flat-text database files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 539,'pod' => 324,'pod_errors' => 0,'total' => 863,'with_comments' => 77},'releases' => 5,'requires' => ['Compress-Zlib-1.22.tar.gz','Email-Valid-0.14.tar.gz','HTML-Template-2.6.tar.gz','IO-Zlib-1.01.tar.gz'],'requires_module' => {'Compress::Zlib' => 0,'Email::Valid' => 0,'HTML::Template' => 0,'IO::Zlib' => 0},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','IO-Zlib-1.01.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 22278,'unpacked' => 62917},'testers' => {'pass' => 3},'uses' => ['Email::Valid','Fcntl','HTML::Template','IO::Zlib','strict','vars']},'CGI-SecureState-0.36.tar.gz' => {'author' => 'BEHROOZI','description' => 'Securely stores CGI parameters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 803,'pod' => 411,'pod_errors' => 0,'total' => 1214,'with_comments' => 67},'releases' => 10,'requires' => ['CGI.pm-2.98.tar.gz','Crypt-Blowfish-2.09.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI' => '2.0','Crypt::Blowfish' => '2.0','Digest::SHA1' => '1.0','Fcntl' => '0.1','File::Spec' => '0.1'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Crypt-Blowfish-2.09.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 20070,'unpacked' => 64316},'testers' => {'pass' => 5},'uses' => ['CGI','Crypt::Blowfish','Digest::SHA1','Fcntl','File::Spec','bytes','strict','vars']},'CGI-Session-3.94.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2444,'pod' => 1830,'pod_errors' => 0,'total' => 4274,'with_comments' => 213},'releases' => 27,'requires' => ['Digest-MD5-2.26.tar.gz'],'requires_module' => {'Digest::MD5' => undef},'requires_recursive' => ['Digest-MD5-2.26.tar.gz'],'testers' => {'fail' => 2,'pass' => 3},'uses' => ['','AutoLoader','CGI','CGI::Application','Carp','DBI','DB_File','Data::Dumper','Digest::MD5','Digest::SHA1','Fcntl','File::Spec','FreezeThaw','HTML::Template','Safe','Storable','Text::Abbrev','diagnostics','strict','vars']},'CGI-SpeedyCGI-2.02.tar.gz' => {'author' => 'HORROCKS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 611,'pod' => 324,'pod_errors' => 0,'total' => 935,'with_comments' => 62},'releases' => 15,'size' => {'packed' => 85672,'unpacked' => 278259},'testers' => {'fail' => 1,'pass' => 2,'tests' => '28'},'uses' => ['AutoLoader','DynaLoader','Exporter','ExtUtils::Embed','ExtUtils::MakeMaker','speedy.ph','strict','vars']},'CGI-SpeedyCGI-2.21.tar.gz' => {'author' => 'HORROCKS','description' => 'Run perl CGI scripts persistenly','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 598,'pod' => 639,'pod_errors' => 0,'total' => 1237,'with_comments' => 53},'releases' => 15,'size' => {'packed' => 148060,'unpacked' => 474919},'testers' => {'pass' => 3},'uses' => ['AutoLoader','Cwd','DynaLoader','Exporter','Socket','strict','vars']},'CGI-State-0.02.tar.gz' => {'author' => 'DKUBB','description' => 'CGI params into multi-dimensional hash','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 166,'pod_errors' => 0,'total' => 333,'with_comments' => 21},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI' => 0,'integer' => 0,'overload' => 0,'strict' => 0,'vars' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5121,'unpacked' => 11967},'testers' => {'pass' => 10},'uses' => ['integer','overload','strict','vars']},'CGI-Test-0.1.3.tar.gz' => {'author' => 'RAM','description' => 'CGI regression test framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4725,'pod' => 1930,'pod_errors' => 0,'total' => 6655,'with_comments' => 1774},'releases' => 3,'requires' => ['CGI.pm-2.98.tar.gz','Carp-Datum-0.1.3.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getargs-Long-0.1.3.tar.gz','HTML-Tree-3.17.tar.gz','Log-Agent-0.304.tar.gz','Storable-2.07.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'CGI' => '0','Carp::Datum' => '0','Digest::MD5' => '0','File::Spec' => '0','File::Temp' => '0','Getargs::Long' => '0.103','HTML::TreeBuilder' => '0','HTTP::Status' => '0','Log::Agent' => '0.207','Storable' => '1.000','URI' => '1.10'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Carp-Datum-0.1.3.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getargs-Long-0.1.3.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','Log-Agent-0.304.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 44114,'unpacked' => 171755},'testers' => {'fail' => 1,'pass' => 8},'uses' => ['Carp::Datum','Cwd','Exporter','File::Basename','File::Spec','File::Temp','Getargs::Long','HTML::TreeBuilder','HTTP::Status','Log::Agent','Storable','URI','strict','vars']},'CGI-Thin-0.52.tar.gz' => {'author' => 'RGEOFFREY','description' => 'A very lightweight Parser for CGI Forms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 309,'pod' => 178,'pod_errors' => 0,'total' => 487,'with_comments' => 41},'releases' => 2,'size' => {'packed' => 6360,'unpacked' => 19260},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'CGI-ToXML-0.02.tar.gz' => {'author' => 'MNEYLON','description' => 'Converts CGI to an XML structure','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 64,'pod_errors' => 0,'total' => 158,'with_comments' => 21},'releases' => 1,'requires' => ['CGI.pm-2.98.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'CGI' => 2,'XML::Simple' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz'],'size' => {'packed' => 2893,'unpacked' => 6281},'testers' => {'fail' => 2,'pass' => 4},'uses' => ['XML::Simple','strict','vars']},'CGI-URI2param-1.00.tar.gz' => {'author' => 'DOMM','description' => 'extract query keys and values out of an URI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 186,'pod_errors' => 0,'total' => 346,'with_comments' => 38},'releases' => 1,'size' => {'packed' => 4133,'unpacked' => 11426},'testers' => {'pass' => 7},'uses' => ['Carp','Exporter','strict','vars']},'CGI-Untaint-0.90.tar.gz' => {'author' => 'TMTM','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 266,'pod' => 252,'pod_errors' => 0,'total' => 518,'with_comments' => 27},'releases' => 7,'requires' => ['Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'requires_module' => {'Test::More' => '0.11','UNIVERSAL::require' => '0.01'},'requires_recursive' => ['Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'size' => {'packed' => 7230,'unpacked' => 19732},'testers' => {'pass' => 13},'uses' => ['Carp','UNIVERSAL::require','strict','vars']},'CGI-Untaint-creditcard-0.01.tar.gz' => {'author' => 'TMTM','description' => 'validate a creditcard','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 23,'pod' => 30,'pod_errors' => 0,'total' => 53,'with_comments' => 0},'releases' => 1,'requires' => ['Business-CreditCard-0.27.tar.gz','CGI-Untaint-0.90.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Business::CreditCard' => '0.21','CGI::Untaint' => '0.01','Test::More' => '0.1'},'requires_recursive' => ['Business-CreditCard-0.27.tar.gz','CGI-Untaint-0.90.tar.gz','Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'size' => {'packed' => 1444,'unpacked' => 2361},'testers' => {'pass' => 4},'uses' => ['Business::CreditCard','CGI::Untaint::printable','strict','vars']},'CGI-Untaint-date-0.03.tar.gz' => {'author' => 'TMTM','description' => 'validate a date','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 40,'pod' => 42,'pod_errors' => 0,'total' => 82,'with_comments' => 0},'releases' => 3,'requires' => ['CGI-Untaint-0.90.tar.gz','Date-Simple-1.03.tar.gz','DateManip-5.42a.tar.gz'],'requires_module' => {'CGI::Untaint' => '0.07','Date::Manip' => 5,'Date::Simple' => '0.01'},'requires_recursive' => ['CGI-Untaint-0.90.tar.gz','Date-Simple-1.03.tar.gz','DateManip-5.42a.tar.gz','Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'size' => {'packed' => 1970,'unpacked' => 3147},'testers' => {'pass' => 4},'uses' => ['CGI::Untaint::printable','Date::Manip','Date::Simple','strict','vars']},'CGI-Untaint-email-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'validate an email address','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 37,'pod' => 28,'pod_errors' => 0,'total' => 65,'with_comments' => 0},'releases' => 2,'requires' => ['CGI-Untaint-0.90.tar.gz','Email-Valid-0.14.tar.gz','MailTools-1.58.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'CGI::Untaint' => '0.07','Email::Valid' => '0.13','Mail::Address' => '1.4','Test::More' => '0.18'},'requires_recursive' => ['CGI-Untaint-0.90.tar.gz','Email-Valid-0.14.tar.gz','Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'size' => {'packed' => 1769,'unpacked' => 3181},'testers' => {'pass' => 2},'uses' => ['CGI::Untaint::printable','Email::Valid','Mail::Address','strict','vars']},'CGI-Untaint-isbn-0.01.tar.gz' => {'author' => 'SRUSHE','description' => 'validate an isbn','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 25,'pod' => 30,'pod_errors' => 0,'total' => 55,'with_comments' => 0},'releases' => 1,'requires' => ['Business-ISBN-1.70.tar.gz','CGI-Untaint-0.90.tar.gz'],'requires_module' => {'Business::ISBN' => 0,'CGI::Untaint' => 0},'requires_recursive' => ['Business-ISBN-1.70.tar.gz','CGI-Untaint-0.90.tar.gz','Exporter-Lite-0.01.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'size' => {'packed' => 1732,'unpacked' => 3269},'testers' => {'pass' => 1},'uses' => ['Business::ISBN','CGI::Untaint::printable','strict','vars']},'CGI-Untaint-uk_postcode-0.02.tar.gz' => {'author' => 'TMTM','description' => 'validate a UK postcode','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 28,'pod' => 30,'pod_errors' => 0,'total' => 58,'with_comments' => 0},'releases' => 1,'requires' => ['CGI-Untaint-0.90.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'CGI::Untaint' => '0.07','Test::More' => '0.11'},'requires_recursive' => ['CGI-Untaint-0.90.tar.gz','Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'size' => {'packed' => 1710,'unpacked' => 2653},'testers' => {'pass' => 3},'uses' => ['CGI::Untaint::object','strict','vars']},'CGI-Untaint-url-0.03.tar.gz' => {'author' => 'TMTM','description' => 'validate a URL','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 27,'pod' => 40,'pod_errors' => 0,'total' => 67,'with_comments' => 0},'releases' => 3,'requires' => ['CGI-Untaint-0.90.tar.gz','URI-Find-0.13.tar.gz'],'requires_module' => {'CGI::Untaint' => '0.07','URI::Find' => '0.01'},'requires_recursive' => ['CGI-Untaint-0.90.tar.gz','Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz','URI-1.24.tar.gz','URI-Find-0.13.tar.gz'],'size' => {'packed' => 1821,'unpacked' => 2954},'testers' => {'fail' => 3,'pass' => 1,'tests' => '15'},'uses' => ['CGI::Untaint::printable','URI::Find','strict','vars']},'CGI-Upload-1.05.tar.gz' => {'author' => 'ROBAU','description' => 'CGI class for handling browser file uploads','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 75,'pod_errors' => 0,'total' => 280,'with_comments' => 40},'releases' => 5,'requires' => ['File-MMagic-1.19.tar.gz','HTTP-BrowserDetect-0.97.tar.gz'],'requires_module' => {'File::MMagic' => '1.16','HTTP::BrowserDetect' => '0.97'},'requires_recursive' => ['File-MMagic-1.19.tar.gz','HTTP-BrowserDetect-0.97.tar.gz'],'size' => {'packed' => 4426,'unpacked' => 13534},'testers' => {'pass' => 6},'uses' => ['CGI','Carp','Config','Exporter','File::Basename','File::MMagic','HTTP::BrowserDetect','IO::File','strict','vars']},'CGI-Validate-2.000.tar.gz' => {'author' => 'ZENIN','description' => 'Advanced CGI form parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 290,'pod' => 287,'pod_errors' => 0,'total' => 577,'with_comments' => 46},'releases' => 4,'requires' => ['CGI.pm-2.98.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI' => '2.3','Carp' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10216,'unpacked' => 30501},'testers' => {'pass' => 8},'uses' => ['CGI','Carp','Exporter','strict','vars']},'CGI-WML-0.09.tar.gz' => {'author' => 'AMURREN','description' => 'Subclass of CGI.pm for WML output','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1365,'pod' => 263,'pod_errors' => 1,'total' => 1628,'with_comments' => 373},'releases' => 9,'size' => {'packed' => 21609,'unpacked' => 63232},'testers' => {'pass' => 7},'uses' => ['CGI','CGI::Util','Carp','Exporter','HTML::TableExtract','HTML::TokeParser','IO::File','IO::Handle','XML::Parser','vars']},'CGI-WeT-0.70.tar.gz' => {'author' => 'JSMITH','description' => 'Suite of modules to themeify a website','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3200,'pod' => 692,'pod_errors' => 5,'total' => 3892,'with_comments' => 282},'releases' => 7,'size' => {'packed' => 47195,'unpacked' => 178855},'testers' => {'pass' => 2},'uses' => ['Apache::Constants','CGI','CGI::WeT::Modules::Basic','CGI::WeT::User','Carp','integer','strict','vars']},'CGI-WeT-0.71.tar.gz' => {'author' => 'JSMITH','description' => 'Suite of modules to themeify a website','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2957,'pod' => 681,'pod_errors' => 4,'total' => 3638,'with_comments' => 304},'releases' => 7,'size' => {'packed' => 40841,'unpacked' => 156079},'testers' => {'pass' => 5},'uses' => ['Apache','Apache::Constants','CGI','CGI::Cookie','CGI::WeT::Engine','CGI::WeT::Theme','Carp','integer','strict','vars']},'CGI-Widget-0.15.tar.gz' => {'author' => 'ALLENDAY','description' => 'Base class for CGI::Widget::...','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 520,'pod' => 230,'pod_errors' => 0,'total' => 750,'with_comments' => 24},'releases' => 8,'requires' => ['CGI.pm-2.98.tar.gz'],'requires_module' => {'CGI' => 1},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 9217,'unpacked' => 28728},'testers' => {'fail' => 2,'pass' => 1,'tests' => '1'},'uses' => ['CGI','Exporter','Tree::DAG_Node','lib','strict','vars']},'CGI-Widget-Tabs-1.07.tar.gz' => {'author' => 'KPOL','description' => 'Create tab widgets in HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 821,'pod' => 425,'pod_errors' => 0,'total' => 1246,'with_comments' => 159},'releases' => 9,'requires' => ['HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'HTML::Entities' => 0,'URI::Escape' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','URI-1.24.tar.gz'],'size' => {'packed' => 17026,'unpacked' => 58580},'testers' => {'pass' => 2},'uses' => ['Carp','HTML::Entities','strict','vars']},'CGI-Wiki-0.44.tar.gz' => {'author' => 'KAKE','description' => 'A toolkit for building Wikis.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2249,'pod' => 1504,'pod_errors' => 0,'total' => 3753,'with_comments' => 106},'releases' => 37,'requires' => ['Class-Delegation-1.06.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-WikiFormat-0.6.tar.gz','Time-Piece-1.08.tar.gz'],'requires_module' => {'Class::Delegation' => 0,'Digest::MD5' => 0,'HTML::PullParser' => 0,'Test::MockObject' => '0.07','Test::More' => 0,'Text::WikiFormat' => '0.45','Time::Piece' => 0},'requires_recursive' => ['Class-Delegation-1.06.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-WikiFormat-0.6.tar.gz','Time-Piece-1.08.tar.gz'],'size' => {'packed' => 52812,'unpacked' => 213183},'testers' => {'pass' => 3},'uses' => ['CGI','CGI::Wiki::TestConfig','Carp','DBI','DBIx::FullTextSearch','Digest::MD5','HTML::PullParser','Search::InvertedIndex','Search::InvertedIndex::DB::Mysql','Search::InvertedIndex::DB::Pg','Text::WikiFormat','Time::Piece','Time::Seconds','strict','vars']},'CGI-Wiki-Formatter-Kwiki-0.02.tar.gz' => {'author' => 'TOMI','description' => 'A Kwiki formatter for CGI::Wiki.','files' => ['Makefile.PL','Build.PL','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 68,'pod_errors' => 1,'total' => 163,'with_comments' => 5},'releases' => 2,'requires' => ['CGI-Kwiki-0.17.tar.gz','CGI-Wiki-0.44.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'CGI::Kwiki' => '0','CGI::Wiki' => '0','Test::Simple' => '0'},'requires_recursive' => ['CGI-Kwiki-0.17.tar.gz','CGI-Wiki-0.44.tar.gz','Class-Delegation-1.06.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-WikiFormat-0.6.tar.gz','Time-Piece-1.08.tar.gz'],'size' => {'packed' => 4109,'unpacked' => 12423},'testers' => {'pass' => 2},'uses' => ['CGI','CGI::Kwiki::Formatter','Carp','strict','vars']},'CGI-Wiki-Formatter-Pod-0.01.tar.gz' => {'author' => 'KAKE','description' => 'A Pod to HTML formatter for CGI::Wiki.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 48,'pod_errors' => 0,'total' => 120,'with_comments' => 0},'releases' => 1,'requires' => ['IO-stringy-2.108.tar.gz','Pod-Tree-1.10.tar.gz'],'requires_module' => {'IO::Scalar' => 0,'Pod::Tree' => '1.10'},'requires_recursive' => ['HTML-Stream-1.54.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Tree-1.10.tar.gz'],'size' => {'packed' => 2155,'unpacked' => 5492},'testers' => {'fail' => 1,'pass' => 7,'tests' => '5'},'uses' => ['IO::Scalar','Pod::Tree::HTML','strict','vars']},'CGI-Wiki-Formatter-UseMod-0.05.tar.gz' => {'author' => 'KAKE','description' => 'UseModWiki-style formatting for CGI::Wiki','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 296,'pod' => 155,'pod_errors' => 0,'total' => 451,'with_comments' => 34},'releases' => 5,'requires' => ['HTML-Parser-3.28.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-WikiFormat-0.6.tar.gz','URI-1.24.tar.gz','URI-Find-Delimited-0.02.tar.gz'],'requires_module' => {'HTML::PullParser' => 0,'Test::MockObject' => '0.07','Test::More' => 0,'Text::WikiFormat' => '0.6','URI::Escape' => 0,'URI::Find::Delimited' => '0.02'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-WikiFormat-0.6.tar.gz','URI-1.24.tar.gz','URI-Find-0.13.tar.gz','URI-Find-Delimited-0.02.tar.gz'],'size' => {'packed' => 8325,'unpacked' => 28518},'testers' => {'pass' => 2},'uses' => ['HTML::PullParser','Text::WikiFormat','URI::Escape','URI::Find::Delimited','strict','vars']},'CGI-Wiki-Kwiki-0.21.tar.gz' => {'author' => 'TOMI','description' => undef,'files' => ['Makefile.PL','README','Build.PL','MANIFEST'],'lines' => {'nonpod' => 426,'pod' => 74,'pod_errors' => 0,'total' => 500,'with_comments' => 2},'releases' => 4,'requires' => ['CGI-Kwiki-0.17.tar.gz','CGI-Wiki-0.44.tar.gz','CGI-Wiki-Formatter-Kwiki-0.02.tar.gz','CGI.pm-2.98.tar.gz','Getopt-Long-2.33.tar.gz','Search-InvertedIndex-1.12.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz'],'requires_module' => {'CGI' => '0','CGI::Kwiki' => '0','CGI::Wiki' => '0.05','CGI::Wiki::Formatter::Kwiki' => '0','Getopt::Long' => '0','Search::InvertedIndex' => '0','Template' => '0','Test::Simple' => '0','Time::Piece' => '0'},'requires_recursive' => ['CGI-Kwiki-0.17.tar.gz','CGI-Wiki-0.44.tar.gz','CGI-Wiki-Formatter-Kwiki-0.02.tar.gz','CGI.pm-2.98.tar.gz','Class-Delegation-1.06.tar.gz','Class-NamedParms-1.04.tar.gz','Class-ParmList-1.03.tar.gz','DB_File-1.806.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','PodParser-1.23.tar.gz','Search-InvertedIndex-1.12.tar.gz','Storable-2.07.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-WikiFormat-0.6.tar.gz','Tie-DB_File-SplitHash-1.01.tar.gz','Tie-FileLRUCache-1.01.tar.gz','Time-Piece-1.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10126,'unpacked' => 31917},'testers' => {'pass' => 2},'uses' => ['CGI','CGI::Wiki','CGI::Wiki::Search::SII','Search::InvertedIndex','Template','strict','warnings']},'CGI-Wiki-Plugin-Categoriser-0.02.tar.gz' => {'author' => 'KAKE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 91,'pod_errors' => 0,'total' => 169,'with_comments' => 0},'releases' => 2,'requires' => ['CGI-Wiki-0.44.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI::Wiki' => '0.36','Carp' => 0,'Test::More' => 0},'requires_recursive' => ['CGI-Wiki-0.44.tar.gz','Class-Delegation-1.06.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-WikiFormat-0.6.tar.gz','Time-Piece-1.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3535,'unpacked' => 12793},'testers' => {'pass' => 2},'uses' => ['CGI::Wiki::Plugin','strict','vars']},'CGI-Wiki-Plugin-GeoCache-0.11.tar.gz' => {'author' => 'EMARTIN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 54,'pod_errors' => 0,'total' => 97,'with_comments' => 1},'releases' => 2,'requires' => ['CGI-Wiki-0.44.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI::Wiki' => '0.27','Carp' => 0,'Test::More' => 0},'requires_recursive' => ['CGI-Wiki-0.44.tar.gz','Class-Delegation-1.06.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-WikiFormat-0.6.tar.gz','Time-Piece-1.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2316,'unpacked' => 4383},'testers' => {'pass' => 5},'uses' => ['Carp','strict','vars']},'CGI-Wiki-Plugin-Locator-UK-0.06.tar.gz' => {'author' => 'KAKE','description' => 'A CGI::Wiki plugin to manage UK location data.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 142,'pod' => 107,'pod_errors' => 0,'total' => 249,'with_comments' => 6},'releases' => 6,'requires' => ['CGI-Wiki-0.44.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI::Wiki' => '0.36','Carp' => 0,'Test::More' => 0},'requires_recursive' => ['CGI-Wiki-0.44.tar.gz','Class-Delegation-1.06.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-WikiFormat-0.6.tar.gz','Time-Piece-1.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6052,'unpacked' => 22210},'testers' => {'pass' => 1},'uses' => ['CGI::Wiki::Plugin','Carp','strict','vars']},'CGI-Wiki-Plugin-RSS-ModWiki-0.03.tar.gz' => {'author' => 'KAKE','description' => 'A CGI::Wiki plugin to output RecentChanges RSS.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 154,'pod' => 132,'pod_errors' => 0,'total' => 286,'with_comments' => 6},'releases' => 3,'requires' => ['CGI-Wiki-0.44.tar.gz','Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz','URI-1.24.tar.gz','XML-RSS-1.02.tar.gz'],'requires_module' => {'CGI::Wiki' => '0.28','Test::More' => 0,'Time::Piece' => '1.08','URI::Escape' => 0,'XML::RSS' => 0},'requires_recursive' => ['CGI-Wiki-0.44.tar.gz','Class-Delegation-1.06.tar.gz','Digest-MD5-2.26.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-WikiFormat-0.6.tar.gz','Time-Piece-1.08.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','XML-RSS-1.02.tar.gz'],'size' => {'packed' => 5717,'unpacked' => 20841},'testers' => {'pass' => 1},'uses' => ['Carp','Time::Piece','URI::Escape','XML::RSS','strict','vars']},'CGI-Wiki-Simple-0.12.tar.gz' => {'author' => 'CORION','description' => 'A simple wiki application using CGI::Application.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 831,'pod' => 399,'pod_errors' => 0,'total' => 1230,'with_comments' => 18},'releases' => 7,'requires' => ['CGI-Application-3.1.tar.gz','CGI-Wiki-0.44.tar.gz','Class-Delegation-1.06.tar.gz','HTML-Parser-3.28.tar.gz','Test-HTML-Content-0.03.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Test-Without-Module-0.06.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'CGI::Application' => 3,'CGI::Wiki' => '0.26','Class::Delegation' => '1.06','HTML::Entities' => 0,'Test::HTML::Content' => '0.03','Test::MockObject' => 0,'Test::More' => 0,'Test::Without::Module' => '0.01','URI::Escape' => 0},'requires_recursive' => ['CGI-Application-3.1.tar.gz','CGI-Wiki-0.44.tar.gz','CGI.pm-2.98.tar.gz','Class-Delegation-1.06.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Template-2.6.tar.gz','Test-HTML-Content-0.03.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Test-Without-Module-0.06.tar.gz','Text-WikiFormat-0.6.tar.gz','Time-Piece-1.08.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 31697,'unpacked' => 117923},'testers' => {'fail' => 2,'pass' => 2,'tests' => '241'},'uses' => ['','CGI::Application','CGI::Wiki','Carp','Digest::MD5','HTML::Entities','URI::Escape','strict','vars']},'CGI-XML-0.1.tar.gz' => {'author' => 'EISEN','description' => 'Convert CGI.pm variables to/from XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 70,'pod' => 70,'pod_errors' => 1,'total' => 140,'with_comments' => 1},'releases' => 1,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.16'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 2946,'unpacked' => 5349},'testers' => {'fail' => 6},'uses' => ['CGI','XML::Parser','strict','vars']},'CGI-XMLApplication-1.1.2.tar.gz' => {'author' => 'PHISH','description' => '- Object Oriented Interface for CGI Script Applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1130,'pod' => 451,'pod_errors' => 0,'total' => 1581,'with_comments' => 234},'releases' => 7,'requires' => ['XML-LibXML-1.54.tar.gz','XML-LibXSLT-1.53.tar.gz'],'requires_module' => {'XML::LibXML' => '1.1','XML::LibXSLT' => '1.08'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21843,'unpacked' => 66982},'testers' => {'pass' => 1},'uses' => ['CGI','Carp','XML::LibXML','XML::LibXSLT','strict','vars']},'CGI-XMLForm-0.10.tar.gz' => {'author' => 'MSERGEANT','description' => 'Extension of CGI.pm which reads/generates formated XML. NB: This is a subclass of CGI.pm, so can be used in it\'s place.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 538,'pod' => 223,'pod_errors' => 1,'total' => 761,'with_comments' => 64},'releases' => 4,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.20'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 14313,'unpacked' => 53945},'testers' => {'pass' => 7},'uses' => ['AutoLoader','CGI','Exporter','XML::Parser','strict','vars']},'CGI-XMLPost-1.3.tar.gz' => {'author' => 'JSTOWE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 232,'pod' => 98,'pod_errors' => 0,'total' => 330,'with_comments' => 29},'releases' => 2,'size' => {'packed' => 3818,'unpacked' => 8963},'testers' => {'pass' => 2},'uses' => ['Carp','XML::XPath','strict','vars']},'CGI-kSession-0.5.3.tar.gz' => {'author' => 'KRZAK','description' => 'sessions manager for CGI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 210,'pod' => 183,'pod_errors' => 0,'total' => 393,'with_comments' => 16},'releases' => 2,'size' => {'packed' => 4352,'unpacked' => 13435},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['strict']},'CGI-pWiki-0.15.tar.gz' => {'author' => 'KRAEHE','description' => 'Perl Wiki Environment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 576,'pod' => 170,'pod_errors' => 0,'total' => 746,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 12075,'unpacked' => 31376},'testers' => {'pass' => 9},'uses' => ['5.00503','URI::Escape','strict','vars']},'CGI.pm-2.77.tar.gz' => {'author' => 'LDS','description' => 'Simple Common Gateway Interface Class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5739,'pod' => 2996,'pod_errors' => 0,'total' => 8735,'with_comments' => 974},'releases' => 79,'size' => {'packed' => 174010,'unpacked' => 545736},'testers' => {'pass' => 6},'uses' => ['5.000','5.004','Apache','CGI','CGI::Cookie','CGI::Util','Carp','Exporter','FCGI','strict','vars']},'CGI.pm-2.98.tar.gz' => {'author' => 'LDS','description' => 'Simple Common Gateway Interface Class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7047,'pod' => 3698,'pod_errors' => 0,'total' => 10745,'with_comments' => 1082},'releases' => 79,'requires' => ['File-Spec-0.82.tar.gz'],'requires_module' => {'File::Spec' => '0.82'},'requires_recursive' => ['File-Spec-0.82.tar.gz'],'size' => {'packed' => 202747,'unpacked' => 637735},'testers' => {'pass' => 4},'uses' => ['5.000','5.004','APR::Pool','Apache','Apache::RequestIO','Apache::RequestRec','Apache::RequestUtil','Apache::Response','Carp','Exporter','FCGI','File::Spec','ModPerl::Util','mod_perl','strict','vars']},'CGIGraph-0.9.tar.gz' => {'author' => 'MCHANG','description' => 'CGI Graphing Module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1984,'pod' => 327,'pod_errors' => 0,'total' => 2311,'with_comments' => 295},'releases' => 4,'requires' => ['CGI.pm-2.98.tar.gz','Data-Table-1.39.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz'],'requires_module' => {'CGI' => undef,'Data::Table' => undef,'GD' => undef,'GD::Graph' => undef},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Data-Table-1.39.tar.gz','File-Spec-0.82.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 24831,'unpacked' => 94917},'testers' => {},'uses' => ['CGI','CGI::Graph::Plot::bars','CGI::Graph::Plot::bars::numerical','CGI::Graph::Plot::bars::string','CGI::Graph::Plot::points','CGI::Graph::Plot::points::numerical','CGI::Graph::Plot::points::string','Data::Table','GD','GD::Graph','GD::Graph::bars','GD::Graph::points']},'CGIGraph-0.93.tar.gz' => {'author' => 'MCHANG','description' => 'Create interactive CGI-based graphs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1991,'pod' => 331,'pod_errors' => 0,'total' => 2322,'with_comments' => 296},'releases' => 4,'requires' => ['CGI.pm-2.98.tar.gz','Data-Table-1.39.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz'],'requires_module' => {'CGI' => undef,'Data::Table' => undef,'GD' => undef,'GD::Graph' => undef},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Data-Table-1.39.tar.gz','File-Spec-0.82.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19292,'unpacked' => 76078},'testers' => {'fail' => 1,'pass' => 2,'tests' => '1'},'uses' => ['CGI','CGI::Graph::Plot','Data::Table','GD','GD::Graph','GD::Graph::bars','GD::Graph::points']},'CGIS-1.6.tar.gz' => {'author' => 'SHERZODR','description' => 'Session enabled CGI.pm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 140,'pod' => 92,'pod_errors' => 0,'total' => 232,'with_comments' => 9},'releases' => 3,'requires' => ['CGI-Session-3.95.tar.gz'],'requires_module' => {'CGI::Session' => undef},'requires_recursive' => ['CGI-Session-3.95.tar.gz'],'size' => {'packed' => 4248,'unpacked' => 8730},'testers' => {'pass' => 4},'uses' => ['CGI','CGI::Session','File::Path','File::Spec','URI','diagnostics','strict']},'CGISession.tar.gz' => {'author' => 'JEFF','description' => undef,'files' => [],'lines' => {'nonpod' => 6941,'pod' => 3642,'pod_errors' => 26,'total' => 10583,'with_comments' => 767},'releases' => 1,'size' => {'packed' => 84350,'unpacked' => 362406},'testers' => {'fail' => 3,'tests' => '6'},'uses' => ['CGI','CGI::Carp','CGI::LDAPSession::CookieJar','Carp','DBI','Date::Format','Mozilla::LDAP::Conn','Mozilla::LDAP::Utils','Net::LDAP','Time::Local','strict','vars']},'CGI_Imagemap-1.00.tar.gz' => {'author' => 'MIKEH','description' => 'Imagemap handling for specialized apps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 369,'pod' => 162,'pod_errors' => 0,'total' => 531,'with_comments' => 63},'releases' => 1,'size' => {'packed' => 9576,'unpacked' => 23051},'testers' => {'pass' => 7},'uses' => ['Carp','Exporter','strict']},'CGI_Lite-1.8.tar.gz' => {'author' => 'SHGUN','description' => 'Light-weight interface for fast apps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 785,'pod' => 348,'pod_errors' => 0,'total' => 1133,'with_comments' => 56},'releases' => 3,'size' => {'packed' => 14122,'unpacked' => 44444},'testers' => {'fail' => 1,'pass' => 1,'tests' => '0','unknown' => 3},'uses' => ['5.002','Exporter']},'CIDR-Assign-0.01.tar.gz' => {'author' => 'MARKPRIOR','description' => 'Manage assignments out of a group of CIDR blocks','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 595,'pod' => 62,'pod_errors' => 0,'total' => 657,'with_comments' => 77},'releases' => 1,'size' => {'packed' => 6165,'unpacked' => 18188},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','DB_File','Exporter','File::lockf','FileHandle']},'CIPP-2.40.tar.gz' => {'author' => 'JRED','description' => 'Powerful preprocessor for embedding Perl and SQL in HTML','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 9154,'pod' => 3218,'pod_errors' => 0,'total' => 12372,'with_comments' => 1382},'releases' => 13,'size' => {'packed' => 89728,'unpacked' => 339561},'testers' => {'pass' => 7},'uses' => ['Apache::Constants','CGI','Carp','Config','Cwd','DBI','Data::Dumper','Fcntl','File::Basename','File::Path','FileHandle','Time::HiRes','strict','vars']},'CIPP-Doc-2.28.tar.gz' => {'author' => 'JRED','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3,'pod' => 0,'pod_errors' => 0,'total' => 3,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 290845,'unpacked' => 567925},'testers' => {'tests' => '0','unknown' => 15},'uses' => []},'CIsam-1.0.tar.gz' => {'author' => 'ILYAVERL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1225,'pod' => 327,'pod_errors' => 1,'total' => 1552,'with_comments' => 179},'releases' => 1,'size' => {'packed' => 12569,'unpacked' => 57549},'testers' => {},'uses' => ['AutoLoader','Carp','Class::Struct','DynaLoader','Exporter','strict','vars']},'CLASS-0.91.tar.gz' => {'author' => 'MSCHWERN','description' => 'Alias for __PACKAGE__','files' => ['Makefile.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 738,'pod' => 476,'pod_errors' => 0,'total' => 1214,'with_comments' => 51},'releases' => 5,'size' => {'packed' => 12719,'unpacked' => 34153},'testers' => {'pass' => 3},'uses' => ['5.004']},'CONFIG-V0.99.11.tar.gz' => {'author' => 'MWS','description' => 'Class to read 2-column files into a hash','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1314,'pod' => 422,'pod_errors' => 0,'total' => 1736,'with_comments' => 249},'releases' => 1,'size' => {'packed' => 15017,'unpacked' => 58226},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['Cwd','FileHandle','strict']},'CORBA-IDL-2.01.tar.gz' => {'author' => 'PERRAD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 45653,'pod' => 97,'pod_errors' => 0,'total' => 45750,'with_comments' => 7574},'releases' => 7,'size' => {'packed' => 146708,'unpacked' => 1095847},'testers' => {'pass' => 4},'uses' => ['5.004','BaseInterface','BasicType','CORBA::IDL::lexer','CORBA::IDL::node','CORBA::IDL::symbtab','Carp','Data::Dumper','Event','ForwardBaseInterface','ForwardEvent','ForwardInterface','ForwardValue','Interface','Literal','Math::BigFloat','Math::BigInt','UNIVERSAL','Value','_ConstructedType','_ForwardConstructedType','_TemplateType','constant','strict','vars']},'CORBA-IDLtree-1.3.tar.gz' => {'files' => ['README'],'lines' => {'nonpod' => 2920,'pod' => 0,'pod_errors' => 0,'total' => 2920,'with_comments' => 607},'releases' => 6,'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'CORBA-IOP-IOR-0.1.tar.gz' => {'author' => 'PHILIPA','description' => 'Decode, munge, and re-encode CORBA IORs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 312,'pod' => 0,'pod_errors' => 0,'total' => 312,'with_comments' => 31},'releases' => 1,'size' => {'packed' => 8443,'unpacked' => 25663},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.001','Exporter','strict','vars']},'CORBA-MICO-0.6.0.tar.gz' => {'author' => 'OTAYLOR','description' => 'Perl module implementing CORBA 2.0 via MICO','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 835,'pod' => 583,'pod_errors' => 1,'total' => 1418,'with_comments' => 17},'releases' => 9,'size' => {'packed' => 86934,'unpacked' => 298177},'testers' => {},'uses' => ['CORBA::MICO::Fixed','CORBA::MICO::LongDouble','CORBA::MICO::LongLong','CORBA::MICO::ULongLong','Carp','DynaLoader','Error','Exporter','Math::BigInt','strict','vars']},'CORBA-MICO-0.6.5.tar.gz' => {'author' => 'LOGVINON','description' => 'Perl module implementing CORBA 2.0 via MICO','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3979,'pod' => 583,'pod_errors' => 1,'total' => 4562,'with_comments' => 808},'releases' => 9,'size' => {'packed' => 119760,'unpacked' => 459996},'testers' => {},'uses' => ['CORBA::MICO::Fixed','CORBA::MICO::LongDouble','CORBA::MICO::LongLong','CORBA::MICO::ULongLong','Carp','DynaLoader','Error','Exporter','Gtk','Math::BigInt','strict','vars']},'CORBA-ORBit-0.4.3.tar.gz' => {'author' => 'OTAYLOR','description' => 'Perl module implementing CORBA 2.0 via ORBit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 575,'pod' => 377,'pod_errors' => 1,'total' => 952,'with_comments' => 20},'releases' => 9,'size' => {'packed' => 75290,'unpacked' => 262054},'testers' => {'pass' => 1,'tests' => '0','unknown' => 6},'uses' => ['CORBA::ORBit::Fixed','CORBA::ORBit::LongDouble','CORBA::ORBit::LongLong','CORBA::ORBit::ULongLong','Carp','DynaLoader','Error','Math::BigInt','strict','vars']},'CORBA-XS-0.20.tar.gz' => {'author' => 'PERRAD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 5861,'pod' => 0,'pod_errors' => 0,'total' => 5861,'with_comments' => 833},'releases' => 4,'size' => {'packed' => 31071,'unpacked' => 199061},'testers' => {'pass' => 7},'uses' => ['CORBA::XS::CORBA','CORBA::XS::c_cdr','CORBA::XS::pl_cdr','Calc','CalcCplx','Carp','CcdrVisitor','DynaLoader','Error','ExtUtils::MakeMaker','POSIX','PerlCdrVisitor','Test::Unit::TestCase','UNIVERSAL','strict','test','vars','warnings']},'CPAN-1.71.tar.gz' => {'author' => 'ANDK','description' => 'Perl Archive browse and download','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8613,'pod' => 884,'pod_errors' => 0,'total' => 9497,'with_comments' => 897},'releases' => 64,'size' => {'packed' => 131042,'unpacked' => 413919},'testers' => {'pass' => 4},'uses' => ['5.004','CPAN::Config','CPAN::MyConfig','Carp','Config','Cwd','Data::Dumper','DirHandle','Exporter','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Copy','File::Find','File::Spec','HTTP::Date','LWP::UserAgent','Mac::Files','Net::Ping','Sys::Hostname','Term::ReadLine','Test::Builder','Text::Wrap','URI::Escape','constant','overload','strict','threads::shared','vars']},'CPAN-Checksums-1.016.tar.gz' => {'author' => 'ANDK','description' => 'Write a CHECKSUMS file for a directory as on CPAN','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 243,'pod' => 52,'pod_errors' => 0,'total' => 295,'with_comments' => 23},'releases' => 11,'requires' => ['Compress-Zlib-1.22.tar.gz','Data-Compare-0.02.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Compress::Zlib' => 0,'Data::Compare' => 0,'Data::Dumper' => 0,'Digest::MD5' => 0,'DirHandle' => 0,'File::Spec' => 0,'IO::File' => 0},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Data-Compare-0.02.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6267,'unpacked' => 16154},'testers' => {'pass' => 14},'uses' => ['Exporter','Safe','strict','vars']},'CPAN-DistroBuilder-0.01.tar.gz' => {'author' => 'STAS','description' => 'Create a distro from a bundle or a number of modules from CPAN','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 172,'pod' => 59,'pod_errors' => 0,'total' => 231,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 3977,'unpacked' => 11275},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['CPAN','Data::Dumper','ExtUtils::MakeMaker','File::Find','File::Spec::Functions','FindBin','lib','strict']},'CPAN-MakeMaker-0.10.tar.gz' => {'author' => 'INGY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 504,'pod' => 301,'pod_errors' => 0,'total' => 805,'with_comments' => 25},'releases' => 1,'size' => {'packed' => 11182,'unpacked' => 29569},'testers' => {'pass' => 8},'uses' => ['$filepath','Config','Cwd','Exporter','File::Path','File::Spec','strict']},'CPAN-Site-0.014.tar.gz' => {'author' => 'ULPFR','description' => 'CPAN.pm subclass for adding site local modules','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 45,'pod_errors' => 0,'total' => 142,'with_comments' => 19},'releases' => 6,'size' => {'packed' => 4769,'unpacked' => 12293},'testers' => {'pass' => 1,'tests' => '0','unknown' => 12},'uses' => ['CPAN','vars']},'CPAN-Test-Reporter-0.02.tar.gz' => {'author' => 'SKUD','description' => 'Report test results of a package retrieved from CPAN','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 72,'pod_errors' => 0,'total' => 248,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 3241,'unpacked' => 7860},'testers' => {'fail' => 1,'pass' => 7,'tests' => '7'},'uses' => ['CPAN','Carp','Config','Getopt::Long','Mail::Send','strict','vars']},'CPAN-WAIT-0.27-2.tar.gz' => {'author' => 'ULPFR','description' => 'adds commands to search a WAIT4CPAN server to the CPAN C<shell()>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 517,'pod' => 88,'pod_errors' => 0,'total' => 605,'with_comments' => 58},'releases' => 1,'requires' => ['CPAN-1.71.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'CPAN' => 0,'Net::NNTP' => 0},'requires_recursive' => ['CPAN-1.71.tar.gz','IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8151,'unpacked' => 26509},'testers' => {'pass' => 13},'uses' => ['CPAN::Config','CPAN::MyConfig','Carp','ExtUtils::MakeMaker','FileHandle','Net::Cmd','WAIT::Client','strict','vars']},'CPANPLUS-0.042.tar.gz' => {'author' => 'KANE','description' => 'Command-line access to the CPAN interface','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 17799,'pod' => 4535,'pod_errors' => 1,'total' => 22334,'with_comments' => 3035},'releases' => 12,'size' => {'packed' => 261888,'unpacked' => 971677},'testers' => {'fail' => 4,'pass' => 9,'tests' => '156'},'uses' => ['AnyDBM_File','CPAN','CPANPLUS::Config','Carp','Config','Crypt::OpenPGP','Cwd','Data::Dumper','Digest::MD5','DirHandle','Exporter','ExtUtils::MakeMaker','ExtUtils::Manifest','Fcntl','File::Basename','File::Path','File::Spec','FileHandle','Locale::Maketext','Locale::Maketext::Lexicon','Module::Build','Storable','Term::ReadLine','Test','Time::Local','Your::Module::Here','eval','strict','vars']},'CPANPLUS-Shell-Curses-0.02.tar.gz' => {'author' => 'MARCUS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1426,'pod' => 149,'pod_errors' => 0,'total' => 1575,'with_comments' => 79},'releases' => 2,'requires' => ['Curses-UI-0.74.tar.gz','File-chdir-0.05.tar.gz','Module-ScanDeps-0.19.tar.gz'],'requires_module' => {'Curses::UI' => '0.72','File::chdir' => 0,'Module::ScanDeps' => 0},'requires_recursive' => ['Curses-1.06.tar.gz','Curses-UI-0.74.tar.gz','File-Spec-0.82.tar.gz','File-chdir-0.05.tar.gz','Module-ScanDeps-0.19.tar.gz','TermReadKey-2.21.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13565,'unpacked' => 52866},'testers' => {'pass' => 1},'uses' => ['CPANPLUS::Backend','CPANPLUS::I18N','Curses','Curses::UI','Cwd','File::Spec','File::chdir','Module::ScanDeps','Pod::Text','strict','vars','warnings']},'CSS-0.08.tar.gz' => {'author' => 'IAMCAL','description' => 'Perl Object oriented access to Cascading Style Sheets (CSS)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 351,'pod' => 171,'pod_errors' => 0,'total' => 522,'with_comments' => 13},'releases' => 10,'requires' => ['Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Parse::RecDescent' => 1},'requires_recursive' => ['Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 7654,'unpacked' => 29794},'testers' => {'pass' => 3},'uses' => ['CSS::Adaptor','CSS::Style','Carp','Parse::RecDescent','lib','overload','strict','vars','warnings']},'CSS-1.05.tar.gz' => {'author' => 'IAMCAL','description' => 'Object oriented access to Cascading Style Sheets (CSS)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14727,'pod' => 546,'pod_errors' => 0,'total' => 15273,'with_comments' => 265},'releases' => 10,'requires' => ['Parse-RecDescent-1.94.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Parse::RecDescent' => 1,'Test::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 33508,'unpacked' => 699590},'testers' => {'fail' => 1,'pass' => 2,'tests' => '25'},'uses' => ['Carp','Data::Dumper','Parse::RecDescent','overload','strict','vars','warnings']},'CSS-SAC-0.05.tar.gz' => {'author' => 'RBERJON','description' => 'Perl implementation of the Simple API to CSS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5857,'pod' => 1386,'pod_errors' => 0,'total' => 7243,'with_comments' => 1741},'releases' => 3,'requires' => ['Class-ArrayObjects-1.01.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Class::ArrayObjects' => '0.04','Text::Balanced' => '1.84'},'requires_recursive' => ['Class-ArrayObjects-1.01.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 39225,'unpacked' => 260624},'testers' => {'pass' => 2},'uses' => ['Text::Balanced','constant','strict','vars']},'CSS-Tiny-1.01.tar.gz' => {'author' => 'ADAMK','description' => 'Read/Write .css files with as little code as possible','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 118,'pod_errors' => 0,'total' => 253,'with_comments' => 19},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'FindBin' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13030,'unpacked' => 34800},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'CVS-Metrics-0.02.tar.gz' => {'author' => 'PERRAD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 726,'pod' => 19,'pod_errors' => 0,'total' => 745,'with_comments' => 32},'releases' => 1,'requires' => ['Chart-Plot-Canvas-0.02.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz','Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Chart::Plot::Canvas' => 0,'GD' => 0,'GD::Graph' => 0,'Parse::RecDescent' => 0},'requires_recursive' => ['Chart-Plot-0.11.tar.gz','Chart-Plot-Canvas-0.02.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz','Tk-800.024.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12121,'unpacked' => 47881},'testers' => {'pass' => 2},'uses' => ['Chart::Plot','Chart::Plot::Canvas','File::Basename','GD','GD::Graph::bars','GD::Graph::mixed','POSIX','Parse::RecDescent','strict','vars']},'CVSUtils-1.01.tar.gz' => {'author' => 'FLUFFY','description' => 'Placeholder for Package Values.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1713,'pod' => 779,'pod_errors' => 1,'total' => 2492,'with_comments' => 167},'releases' => 2,'size' => {'packed' => 211523,'unpacked' => 1084388},'testers' => {'fail' => 2,'tests' => '114'},'uses' => ['','5.00503','5.005_03','5.005_62','Carp','Config','Cwd','Data::Dumper','Env','Exporter','ExtUtils::MakeMaker','Fatal','Fcntl','File::Basename','File::Compare','File::Find','File::Path','File::Spec','FindBin','IO::File','IO::Pipe','IO::Select','IPC::Run','POSIX','Pipeline::DataFlow','Test','constant','happy','strict','test','vars','warnings']},'Cache-2.00.tar.gz' => {'author' => 'CLEISHMAN','description' => 'the Cache interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3383,'pod' => 924,'pod_errors' => 0,'total' => 4307,'with_comments' => 218},'releases' => 1,'requires' => ['DB_File-1.806.tar.gz','Digest-SHA1-2.04.tar.gz','File-NFSLock-1.20.tar.gz','File-Spec-0.82.tar.gz','Heap-0.50.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','Storable-2.07.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'DB_File' => '1.72','Date::Parse' => '2.24','Digest::SHA1' => '2.01','Fcntl' => '1.03','File::NFSLock' => '1.2','File::Path' => 1,'File::Spec' => '0.8','Heap::Fibonacci' => '0.01','IO::File' => '1.08','IO::Handle' => '1.21','IO::String' => '1.02','Storable' => 1,'Symbol' => '1.02','Test::More' => '0.45'},'requires_recursive' => ['DB_File-1.806.tar.gz','Digest-SHA1-2.04.tar.gz','File-NFSLock-1.20.tar.gz','File-Spec-0.82.tar.gz','Heap-0.50.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 32089,'unpacked' => 127056},'testers' => {'pass' => 1},'uses' => ['5.005','Cache::Memory::HeapElem','Carp','DB_File','Date::Parse','Digest::SHA1','Exporter','Fcntl','File::NFSLock','File::Path','File::Spec','File::Temp','Heap::Elem','Heap::Fibonacci','IO::File','IO::Handle','IO::String','Storable','Test::More','Tie::Hash','fields','strict','vars','warnings','warnings::register']},'Cache-Cache-0.09.tar.gz' => {'author' => 'DCLINTON','description' => '- the Cache interface.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6078,'pod' => 1360,'pod_errors' => 0,'total' => 7438,'with_comments' => 474},'releases' => 7,'size' => {'packed' => 32361,'unpacked' => 177236},'testers' => {'fail' => 1,'pass' => 2,'tests' => '487'},'uses' => ['Benchmark','Cache::BaseCache','Cache::BaseCacheTester','Cache::Cache','Cache::CacheMetaData','Cache::CacheUtils','Cache::FileCache','Cache::MemoryCache','Cache::Object','Cache::SharedMemoryCache','Cache::SizeAwareCache','Cache::SizeAwareFileCache','Cache::SizeAwareMemoryCache','Cache::SizeAwareSharedMemoryCache','Carp','Digest::MD5','Exporter','File::Path','File::Spec::Functions','IPC::ShareLite','Storable','strict','vars']},'Cache-Cache-0.99.tar.gz' => {'author' => 'DCLINTON','description' => '- the Cache interface.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4522,'pod' => 1199,'pod_errors' => 0,'total' => 5721,'with_comments' => 333},'releases' => 7,'size' => {'packed' => 31639,'unpacked' => 146720},'testers' => {'fail' => 2,'pass' => 3,'tests' => '244'},'uses' => ['Cache::BaseCache','Cache::BaseCacheTester','Cache::Cache','Cache::CacheMetaData','Cache::CacheSizer','Cache::CacheUtils','Cache::FileBackend','Cache::FileCache','Cache::MemoryBackend','Cache::MemoryCache','Cache::Object','Cache::SharedMemoryBackend','Cache::SharedMemoryCache','Cache::SizeAwareCache','Cache::SizeAwareMemoryCache','Digest::MD5','Error','Exporter','File::Path','File::Spec::Functions','IPC::ShareLite','Storable','strict','vars']},'Cache-Cache-1.02.tar.gz' => {'author' => 'DCLINTON','description' => '- the Cache interface.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4512,'pod' => 1152,'pod_errors' => 0,'total' => 5664,'with_comments' => 323},'releases' => 7,'size' => {'packed' => 33202,'unpacked' => 149540},'testers' => {'pass' => 7},'uses' => ['Digest::SHA1','Error','Exporter','File::Path','File::Spec','File::Spec::Functions','IPC::ShareLite','Storable','strict','vars']},'Cache-FastMemoryCache-0.01.tar.gz' => {'author' => 'MILLAWAY','description' => 'In-memory cache of arbitrary data.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 67,'pod_errors' => 0,'total' => 205,'with_comments' => 6},'releases' => 1,'requires' => ['Cache-Cache-1.02.tar.gz'],'requires_module' => {'Cache::Cache' => 0,'Cache::MemoryCache' => 0},'requires_recursive' => ['Cache-Cache-1.02.tar.gz'],'size' => {'packed' => 3466,'unpacked' => 7605},'testers' => {'pass' => 2},'uses' => ['','5.006','Cache::BaseCache','Cache::CacheUtils','Cache::MemoryBackend','strict','warnings']},'Cache-Mmap-0.07.tar.gz' => {'author' => 'PMH','description' => 'Shared data cache using memory mapped files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 861,'pod' => 155,'pod_errors' => 0,'total' => 1016,'with_comments' => 185},'releases' => 7,'requires' => ['Storable-2.07.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Fcntl' => 0,'Storable' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19897,'unpacked' => 61662},'testers' => {'pass' => 2},'uses' => ['1','Carp','Fcntl','IO::Seekable','Storable','constant','integer','strict','vars']},'Calendar-CSA-0.8.tar.gz' => {'author' => 'KJALB','description' => 'interface with calenders such as Sun and CDE','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 127,'pod' => 18,'pod_errors' => 0,'total' => 145,'with_comments' => 12},'releases' => 4,'size' => {'packed' => 19536,'unpacked' => 89857},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Calendar-Simple-1.08.tar.gz' => {'author' => 'DAVECROSS','description' => 'Perl extension to create simple calendars','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 132,'pod' => 63,'pod_errors' => 0,'total' => 195,'with_comments' => 37},'releases' => 7,'requires' => ['Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0,'Test::Pod' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 3766,'unpacked' => 8201},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','Time::Local','strict','vars']},'Callback-1.04.tar.gz' => {'author' => 'MUIR','description' => 'Define easy to use function callback objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 57,'pod_errors' => 0,'total' => 177,'with_comments' => 11},'releases' => 4,'size' => {'packed' => 3897,'unpacked' => 10317},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','UNIVERSAL','strict']},'CallerItem-1.0.tar.gz' => {'author' => 'JACKS','description' => '\'caller()\' Object wrapper + useful methods','files' => [],'lines' => {'nonpod' => 195,'pod' => 145,'pod_errors' => 0,'total' => 340,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 3479,'unpacked' => 9400},'testers' => {'tests' => '0','unknown' => 12},'uses' => []},'Cant-1.01.tar.gz' => {'author' => 'PGUEN','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 73,'pod_errors' => 0,'total' => 220,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 3285,'unpacked' => 6794},'testers' => {'pass' => 2},'uses' => ['5.005_62','Carp','Exporter','strict','warnings']},'Carp-Assert-0.17.tar.gz' => {'author' => 'MSCHWERN','description' => 'Stating the obvious to let the computer know','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 270,'pod' => 227,'pod_errors' => 0,'total' => 497,'with_comments' => 10},'releases' => 10,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Test::More' => '0.18'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8815,'unpacked' => 26070},'testers' => {'fail' => 3,'pass' => 57,'tests' => '32'},'uses' => ['5.004','Carp','Exporter','strict','vars']},'Carp-Assert-More-0.04.tar.gz' => {'author' => 'PETDANCE','description' => 'convenience wrappers around Carp::Assert','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 150,'pod' => 108,'pod_errors' => 0,'total' => 258,'with_comments' => 1},'releases' => 4,'requires' => ['Carp-Assert-0.17.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Carp::Assert' => 0,'Test::More' => '0.18'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4126,'unpacked' => 12346},'testers' => {'pass' => 5},'uses' => ['Carp','Carp::Assert','Exporter','strict','vars','warnings']},'Carp-Datum-0.1.2.tar.gz' => {'author' => 'RAM','description' => 'Debugging And Tracing Ultimate Module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3103,'pod' => 784,'pod_errors' => 1,'total' => 3887,'with_comments' => 781},'releases' => 4,'requires' => ['Getargs-Long-0.1.3.tar.gz','Log-Agent-0.304.tar.gz'],'requires_module' => {'Getargs::Long' => '0.103','Log::Agent' => '0.207'},'requires_recursive' => ['Getargs-Long-0.1.3.tar.gz','Log-Agent-0.304.tar.gz'],'size' => {'packed' => 39133,'unpacked' => 147583},'testers' => {'pass' => 3},'uses' => ['Carp','Data::Dumper','Exporter','ExtUtils::MakeMaker','Getargs::Long','Log::Agent','strict','vars']},'Carp-Datum-0.1.3.tar.gz' => {'author' => 'SQUIRREL','description' => 'Debugging And Tracing Ultimate Module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3090,'pod' => 796,'pod_errors' => 1,'total' => 3886,'with_comments' => 781},'releases' => 4,'requires' => ['Getargs-Long-0.1.3.tar.gz','Log-Agent-0.304.tar.gz'],'requires_module' => {'Getargs::Long' => '0.103','Log::Agent' => '0.207'},'requires_recursive' => ['Getargs-Long-0.1.3.tar.gz','Log-Agent-0.304.tar.gz'],'size' => {'packed' => 39576,'unpacked' => 147823},'testers' => {'pass' => 9},'uses' => ['Carp','Carp::Datum::Cfg','Carp::Datum::Flags','Carp::Datum::Parser','Data::Dumper','Exporter','ExtUtils::MakeMaker','Getargs::Long','Log::Agent','strict','vars']},'Carp-Ensure-0.23.tar.gz' => {'author' => 'SMERTEN','description' => 'Ensure a value is of the expected type','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 603,'pod' => 330,'pod_errors' => 0,'total' => 933,'with_comments' => 58},'releases' => 1,'size' => {'packed' => 13716,'unpacked' => 60055},'testers' => {'pass' => 6},'uses' => ['Carp','Exporter','strict','vars']},'Carp-Notify-1.10.tar.gz' => {'author' => 'JIMT','description' => 'Loudly complain in lots of places when things break badly','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 538,'pod' => 446,'pod_errors' => 3,'total' => 984,'with_comments' => 52},'releases' => 2,'size' => {'packed' => 10752,'unpacked' => 30836},'testers' => {'pass' => 12},'uses' => ['5.005','strict']},'Carp-Trace-0.01.tar.gz' => {'author' => 'KANE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 86,'pod_errors' => 0,'total' => 162,'with_comments' => 0},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2302,'unpacked' => 4580},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Cartography-Projection-GCTP-0.02.tar.gz' => {'author' => 'DSTAHLKE','description' => 'XS interface for GCTP map projection library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 46,'pod_errors' => 0,'total' => 207,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 77968,'unpacked' => 408190},'testers' => {'pass' => 8},'uses' => ['5.0.8','AutoLoader','Carp','Exporter','XSLoader','constant','strict','vars','warnings']},'Catalog-0.5.tar.gz' => {'author' => 'LDACHARY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9580,'pod' => 50,'pod_errors' => 0,'total' => 9630,'with_comments' => 1260},'releases' => 7,'size' => {'packed' => 899909,'unpacked' => 1549390},'testers' => {},'uses' => ['CGI','CGI::Carp','Carp','Catalog','Catalog::external','Catalog::tools::sqledit','Catalog::tools::tools','Cwd','DBD::Fulcrum','DBD::mysql','DBI','Ecila::tools::cgi','Ecila::tools::fulcrum','Ecila::tools::tools','Exporter','File::Basename','File::Path','Getopt::Long','MD5','Unicode::Map8','Unicode::String','XML::DOM','XML::Parser','integer','strict','vars']},'Catalog-1.02.tar.gz' => {'author' => 'LDACHARY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11081,'pod' => 58,'pod_errors' => 0,'total' => 11139,'with_comments' => 1818},'releases' => 7,'size' => {'packed' => 949415,'unpacked' => 1685603},'testers' => {},'uses' => ['CGI','CGI::Carp','Carp','Cwd','DBD::Fulcrum','DBI','DB_File','Exporter','File::Basename','File::Path','Getopt::Long','MD5','Mail::Address','Mail::Send','Net::Domain','Net::SMTP','POSIX','Pg','Text::Query','Unicode::Map8','Unicode::String','XML::DOM','XML::Parser','cgitools','integer','perltools','strict','vars']},'Cellular-Automata-Wolfram-1.1.tar.gz' => {'author' => 'JMFREEMAN','description' => 'dimensional non-totalistic cellular automata as described in Dr. Steven Wolfram\'s, A New Kind of Science, ISBN:1-57955-008-8','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 442,'pod' => 329,'pod_errors' => 0,'total' => 771,'with_comments' => 44},'releases' => 2,'requires' => ['Class-MethodMaker-1.10.tar.gz','GD-2.07.tar.gz','Graphics-ColorNames-0.32.tar.gz','Math-BaseCalc-1.011.tar.gz'],'requires_module' => {'Class::MethodMaker' => '1.08','GD' => '2.041','Graphics::ColorNames' => '0.31','Math::BaseCalc' => '1.011'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','GD-2.07.tar.gz','Graphics-ColorNames-0.32.tar.gz','Math-BaseCalc-1.011.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10046,'unpacked' => 42104},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','GD','Graphics::ColorNames','Math::BaseCalc','strict','warnings']},'CfgTie-0.41.tar.gz' => {'author' => 'RANDYM','description' => '- A module to tie in the net database','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 5657,'pod' => 1560,'pod_errors' => 1,'total' => 7217,'with_comments' => 728},'releases' => 4,'size' => {'packed' => 85507,'unpacked' => 330767},'testers' => {'fail' => 2,'pass' => 7,'tests' => '27'},'uses' => ['AutoLoader','BSD::Resource','Carp','Exporter','File::Find','FileHandle','Getopt::Long','HTTPD::Realm','IO::File','IO::Seekable','POSIX','Quota','Tie::Hash','User::pwent','strict','vars']},'Cgi-Simple-0.06.tar.gz' => {'author' => 'JFREEMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3381,'pod' => 2923,'pod_errors' => 0,'total' => 6304,'with_comments' => 298},'releases' => 4,'size' => {'packed' => 145416,'unpacked' => 534901},'testers' => {'pass' => 5},'uses' => ['5.004','Apache','Carp','Config','Data::Dumper','Exporter','SelfLoader','strict','vars']},'Chart-2.2.tar.gz' => {'author' => 'CHARTGRP','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9220,'pod' => 0,'pod_errors' => 0,'total' => 9220,'with_comments' => 2242},'releases' => 10,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => '1.2'},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4405514,'unpacked' => 15322596},'testers' => {'pass' => 6},'uses' => ['Carp','FileHandle','GD','POSIX','strict','vars']},'Chart-GRACE-0.95.tar.gz' => {'author' => 'TJENNESS','description' => 'Interface to GRACE plotting package','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 789,'pod' => 264,'pod_errors' => 0,'total' => 1053,'with_comments' => 100},'releases' => 1,'size' => {'packed' => 8709,'unpacked' => 24452},'testers' => {'fail' => 2,'tests' => '6'},'uses' => ['5.003','Carp','Exporter','IO::File','IO::Pipe','PDL::Options','strict','subs','vars']},'Chart-Graph-1.1.tar.gz' => {'author' => 'MHYOUNG','description' => 'Perl extension for a front-end to gnuplot and XRT. 23/4/99 Version 1.1','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1342,'pod' => 108,'pod_errors' => 0,'total' => 1450,'with_comments' => 412},'releases' => 3,'size' => {'packed' => 44677,'unpacked' => 104660},'testers' => {'fail' => 1,'tests' => '2'},'uses' => ['Carp','Exporter','File::Path','FileHandle','Graph','POSIX','strict','vars']},'Chart-Graph-2.0.tar.gz' => {'author' => 'CAIDAPERL','description' => 'Perl extension for a front-end to gnuplot, XRT, and Xmgrace.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6760,'pod' => 1451,'pod_errors' => 0,'total' => 8211,'with_comments' => 1933},'releases' => 3,'size' => {'packed' => 259006,'unpacked' => 606067},'testers' => {'fail' => 1,'tests' => '13'},'uses' => ['Base_Option','Carp','Chart::Graph::Gnuplot','Chart::Graph::Utils','Chart::Graph::Xmgrace::Axis_Options','Chart::Graph::Xmgrace::Dataset_Options','Chart::Graph::Xmgrace::Graph_Options','Chart::Graph::Xrt3d','File::Basename','File::Path','FileHandle','Graph','POSIX','strict','vars']},'Chart-Math-Axis-0.1.tar.gz' => {'author' => 'ADAMK','description' => 'Implements an algorithm to find good values for chart axis','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 380,'pod' => 100,'pod_errors' => 0,'total' => 480,'with_comments' => 99},'releases' => 1,'requires' => ['Math-BigInt-1.64.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.04','Math::BigInt' => 0,'Test::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Math-BigInt-1.64.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 15368,'unpacked' => 50863},'testers' => {'pass' => 5},'uses' => ['Math::BigFloat','Math::BigInt','UNIVERSAL','strict','vars']},'Chart-PNGgraph-1.15.tar.gz' => {'author' => 'SBONDS','description' => 'Graph Plotting Module for Perl 5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3414,'pod' => 540,'pod_errors' => 0,'total' => 3954,'with_comments' => 588},'releases' => 6,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => '1.20'},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 132287,'unpacked' => 277551},'testers' => {'fail' => 1,'pass' => 1,'tests' => '23'},'uses' => ['5.004','Chart::PNGgraph','Chart::PNGgraph::area','Chart::PNGgraph::axestype','Chart::PNGgraph::bars','Chart::PNGgraph::lines','Chart::PNGgraph::linespoints','Chart::PNGgraph::points','Exporter','GD','strict','vars']},'Chart-PNGgraph-1.21.tar.gz' => {'author' => 'SBONDS','description' => 'Graph Plotting Module (deprecated)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 346,'pod' => 39,'pod_errors' => 0,'total' => 385,'with_comments' => 121},'releases' => 6,'requires' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz'],'requires_module' => {'GD' => '1.14','GD::Graph' => '1.20'},'requires_recursive' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 34284,'unpacked' => 97241},'testers' => {'pass' => 2},'uses' => ['Carp','GD::Graph','GD::Graph::area','GD::Graph::axestype','GD::Graph::bars','GD::Graph::lines','GD::Graph::linespoints','GD::Graph::mixed','GD::Graph::pie','GD::Graph::points','strict']},'Chart-Plot-0.11.tar.gz' => {'author' => 'SMORTON','description' => 'Graph two-dimensional data (uses GD.pm)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 799,'pod' => 214,'pod_errors' => 0,'total' => 1013,'with_comments' => 171},'releases' => 3,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => 0},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15664,'unpacked' => 49039},'testers' => {'pass' => 3},'uses' => ['GD','strict']},'Chart-Plot-Annotated-0.01.tar.gz' => {'author' => 'KAHN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 129,'pod_errors' => 0,'total' => 367,'with_comments' => 43},'releases' => 1,'requires' => ['Chart-Plot-0.11.tar.gz','Class-MethodMaker-1.10.tar.gz','GD-2.07.tar.gz'],'requires_module' => {'Chart::Plot' => '0.1','Class::MethodMaker' => '1.02','GD' => '1.27'},'requires_recursive' => ['Chart-Plot-0.11.tar.gz','Class-MethodMaker-1.10.tar.gz','GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4442,'unpacked' => 12322},'testers' => {},'uses' => ['5.006','Carp','Chart::Plot','GD','strict','warnings']},'Chart-Plot-Canvas-0.02.tar.gz' => {'author' => 'PERRAD','description' => 'Plot two dimensional data in an Tk Canvas','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 406,'pod' => 69,'pod_errors' => 0,'total' => 475,'with_comments' => 90},'releases' => 1,'requires' => ['Chart-Plot-0.11.tar.gz','Tk-800.024.tar.gz'],'requires_module' => {'Chart::Plot' => '0.11','Tk' => 0},'requires_recursive' => ['Chart-Plot-0.11.tar.gz','GD-2.07.tar.gz','Tk-800.024.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5333,'unpacked' => 16741},'testers' => {'pass' => 2},'uses' => ['Chart::Plot','GD','Tk','strict','vars']},'Chart-Ploticus-0.01.tar.gz' => {'author' => 'DANIEL','description' => 'Perl API for Ploticus','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 40,'pod_errors' => 0,'total' => 76,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 1755,'unpacked' => 3232},'testers' => {'fail' => 1},'uses' => ['DynaLoader','Exporter','strict','vars']},'Chart-Sequence-0.002.tar.gz' => {'author' => 'RBS','description' => 'A sequence class','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 897,'pod' => 430,'pod_errors' => 0,'total' => 1327,'with_comments' => 61},'releases' => 2,'requires' => ['Imager-0.41.tar.gz','XML-Filter-Dispatcher-0.52.tar.gz','XML-SAX-0.12.tar.gz'],'requires_module' => {'Imager' => 0,'XML::Filter::Dispatcher' => '0.42','XML::SAX::PurePerl' => 1},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Imager-0.41.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-Filter-Dispatcher-0.52.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Machines-0.4.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15179,'unpacked' => 43115},'testers' => {},'uses' => ['Carp','POSIX','XML::Filter::Dispatcher','XML::SAX::ParserFactory','constant','strict','vars']},'Chart-ThreeD-0.01.tar.gz' => {'author' => 'FTASSIN','description' => '3D Piechart','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 394,'pod' => 255,'pod_errors' => 0,'total' => 649,'with_comments' => 22},'releases' => 1,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => 0},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5565,'unpacked' => 18327},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','Exporter','GD','strict','vars']},'Chart-XMGR-0.95.tar.gz' => {'author' => 'TJENNESS','description' => 'interface to XMGR plotting package','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 794,'pod' => 260,'pod_errors' => 0,'total' => 1054,'with_comments' => 98},'releases' => 1,'size' => {'packed' => 8529,'unpacked' => 24022},'testers' => {'fail' => 1},'uses' => ['5.003','Carp','Exporter','IO::File','IO::Pipe','PDL::Options','strict','subs','vars']},'Chatbot-Eliza-1.04.tar.gz' => {'author' => 'JNOLAN','description' => 'Eliza algorithm encapsulated in an object','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1296,'pod' => 467,'pod_errors' => 0,'total' => 1763,'with_comments' => 193},'releases' => 12,'size' => {'packed' => 38361,'unpacked' => 133024},'testers' => {'pass' => 8},'uses' => ['5.003','Carp','strict','vars']},'Chatbot-Integral-0.0.01.tar.gz' => {'author' => 'BSMITH','description' => 'Chat like integral','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 19,'pod' => 45,'pod_errors' => 0,'total' => 64,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2106,'unpacked' => 3649},'testers' => {'pass' => 3},'uses' => ['5.006001','strict','warnings']},'Chatbot-TalkerBot-1.8.tar.gz' => {'author' => 'PKENT','description' => 'A robot client for a talker, with command handling','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 618,'pod' => 238,'pod_errors' => 0,'total' => 856,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 17234,'unpacked' => 61726},'testers' => {'pass' => 7},'uses' => ['Exporter','IO::Socket','vars']},'Chemistry-MolecularMass-0.1.tar.gz' => {'author' => 'MKHRAPOV','description' => 'Perl extension for calculating molecular mass of a chemical compound given its chemical formula.','files' => [],'lines' => {'nonpod' => 324,'pod' => 59,'pod_errors' => 0,'total' => 383,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 6735,'unpacked' => 24370},'testers' => {'pass' => 6},'uses' => ['DynaLoader','strict','vars']},'Chess-0.5.2.tar.gz' => {'author' => 'BJR','description' => 'Manipulate and validate a chessboard in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1257,'pod' => 69,'pod_errors' => 0,'total' => 1326,'with_comments' => 52},'releases' => 3,'size' => {'packed' => 9507,'unpacked' => 44463},'testers' => {'pass' => 9},'uses' => ['5.006','Carp','Exporter','constant','lib','strict','warnings']},'Chess-ICC-0.02.tar.gz' => {'author' => 'TBONE','description' => 'manipulate the Internet Chess Club from the command line.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 29,'pod_errors' => 0,'total' => 88,'with_comments' => 10},'releases' => 2,'requires' => ['HTML-Tree-3.17.tar.gz'],'requires_module' => {'HTML::Tree' => '3.11'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz'],'size' => {'packed' => 1978,'unpacked' => 3185},'testers' => {'pass' => 3},'uses' => ['5.005_62','Data::Dumper','Exporter','HTML::TreeBuilder','LWP::Simple','strict','warnings']},'Chess-Mbox-1.3.tar.gz' => {'author' => 'TBONE','description' => 'write mbox files with chess games into them onto disk','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 35,'pod_errors' => 0,'total' => 107,'with_comments' => 2},'releases' => 2,'requires' => ['Chess-PGN-Parse-0.17.tgz','Mail-MboxParser-0.38.tar.gz'],'requires_module' => {'Chess::PGN::Parse' => 0,'Mail::MboxParser' => 0},'requires_recursive' => ['Chess-PGN-Parse-0.17.tgz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','Mail-MboxParser-0.38.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4838,'unpacked' => 12572},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['5.005_62','Chess::PGN::Parse','Mail::MboxParser','strict','warnings']},'Chess-PGN-EPD-0.21.tar.gz' => {'author' => 'HSMYERS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1163,'pod' => 471,'pod_errors' => 0,'total' => 1634,'with_comments' => 101},'releases' => 19,'requires' => ['Chess-PGN-Moves-0.04.tar.gz','DB_File-1.806.tar.gz','Test-1.24.tar.gz','Text-CSV-0.01.tar.gz'],'requires_module' => {'Chess::PGN::Moves' => '0.03','DB_File' => '1.73','Test' => '1.15','Text::CSV' => '0.01'},'requires_recursive' => ['Chess-PGN-Moves-0.04.tar.gz','DB_File-1.806.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Text-CSV-0.01.tar.gz'],'size' => {'packed' => 165241,'unpacked' => 812159},'testers' => {'pass' => 7},'uses' => ['5.006','Chess::PGN::Moves','DB_File','Data::Dumper','Exporter','strict','warnings']},'Chess-PGN-Filter-0.11.tar.gz' => {'author' => 'HSMYERS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 652,'pod' => 373,'pod_errors' => 0,'total' => 1025,'with_comments' => 17},'releases' => 8,'requires' => ['Chess-PGN-EPD-0.21.tar.gz','Chess-PGN-Parse-0.17.tgz','DelimMatch-1.06a.tar.gz','Test-1.24.tar.gz'],'requires_module' => {'Chess::PGN::EPD' => '0.08','Chess::PGN::Parse' => '0.01','Test' => '1.15','Text::DelimMatch' => '1.01'},'requires_recursive' => ['Chess-PGN-EPD-0.21.tar.gz','Chess-PGN-Moves-0.04.tar.gz','Chess-PGN-Parse-0.17.tgz','DB_File-1.806.tar.gz','DelimMatch-1.06a.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Text-CSV-0.01.tar.gz'],'size' => {'packed' => 17721,'unpacked' => 92327},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.006','Carp','Chess::PGN::EPD','Chess::PGN::Parse','Data::Dumper','Exporter','Text::DelimMatch','strict','vars','warnings']},'Chess-PGN-Moves-0.04.tar.gz' => {'author' => 'HSMYERS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 400,'pod' => 52,'pod_errors' => 0,'total' => 452,'with_comments' => 1},'releases' => 4,'size' => {'packed' => 5560,'unpacked' => 20451},'testers' => {'pass' => 17},'uses' => ['5.006','Exporter','strict','vars','warnings']},'Chess-PGN-Parse-0.17.tgz' => {'author' => 'GMAX','description' => 'reads and parses PGN (Portable Game Notation) Chess files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1316,'pod' => 399,'pod_errors' => 0,'total' => 1715,'with_comments' => 165},'releases' => 11,'size' => {'packed' => 25864,'unpacked' => 94111},'testers' => {'pass' => 1},'uses' => ['5.006','Exporter','IO::File','Regexp::Common','strict','warnings']},'Chess-Pgn-0.03.tar.gz' => {'author' => 'MAIRE','description' => 'Perl extension for manipulation of chess PGN format. PGN is for Portable Game Notation and follow the I<Portable Game Notation Specification and Implementation Guide> revised 1994.03.12. You can find it at L<http://members.nbci.com/sghudson/standard.txt>. The goal of this module is not to play chess but to help to manipulate PGN File. A PGN file is like this : [Event "?"] [Site "?"] [Date "????.??.??"] [Round "?"] [White "Greco"] [Black "NN"] [Result "1-0"] [ECO "C57"] [WhiteElo "2010"] [BlackElo "1620"] [PlyCount "17"] 1.e4 e5 2.Nf3 Nc6 3.Bc4 Nf6 4.Ng5 d5 5.exd5 Nxd5 6.Nxf7 Kxf7 7.Qf3+ Ke6 8.Nc3 Ne7 9.O-O c6 10.Re1 Bd7 11.d4 Kd6 12.Rxe5 Ng6 13.Nxd5 Nxe5 14.dxe5+ Kc5 15.Qa3+ Kxc4 16.Qd3+ Kc5 17.b4# 1-0 [Event "?"] [Site "corr CS ch 22 (FS"] [Date "????.??.??"] [Round "12.0"] [White "Rosenzweig V"] [Black "Necesany Z"] [Result "1/2-1/2"] [ECO "C55"] [WhiteElo "2410"] [BlackElo "2620"] [PlyCount "22"] 1.e4 e5 2.Nf3 Nc6 3.Bc4 Nf6 4.O-O Be7 5.Nc3 Nxe4 6.Nxe4 d5 7.d4 dxc4 8.d5 Nd4 9.Nxd4 Qxd5 10.Nf3 Qxe4 11.Re1 Qc6 12.Nxe5 Qf6 13.Bd2 O-O 14.Bc3 Bc5 15.Re2 Qf5 16.Qd5 Bd6 17.Rae1 Be6 18.Qxb7 f6 19.Nc6 Bd5 20.Rd2 Bxg2 21.Rxd6 Bxc6 22.Rxc6 Qg4+ 1/2-1/2 With Chess:Pgn you will find a game by $game->date or $game->game. For our last example we will have $game->date : "????.??.??" $game->game : "1.e4 e5 2.Nf3 Nc6 3.Bc4 Nf6 4.Ng5 d5 5.exd5 Nxd5 6.Nxf7 Kxf7 7.Qf3+ Ke6 8.Nc3 Ne7 9.O-O c6 10.Re1 Bd7 11.d4 Kd6 12.Rxe5 Ng6 13.Nxd5 Nxe5 14.dxe5+ Kc5 15.Qa3+ Kxc4 16.Qd3+ Kc5 17.b4# 1-0" The module provide a good set of tools to modify PGN File but you will have to make yourself the while :)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 224,'pod' => 139,'pod_errors' => 0,'total' => 363,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 4950,'unpacked' => 16850},'testers' => {'pass' => 7},'uses' => ['5.004','Exporter','warnings']},'ChildExit_0-1.tar.gz' => {'author' => 'TQISJIM','description' => 'alt Apache::Registry END block handler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 109,'pod' => 70,'pod_errors' => 0,'total' => 179,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 4854,'unpacked' => 10901},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','DynaLoader','Exporter','strict','warnings']},'Chipcard-CTAPI-0.2.tar.gz' => {'author' => 'WHOM','description' => 'Communication with chipcard terminals','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1128,'pod' => 382,'pod_errors' => 0,'total' => 1510,'with_comments' => 163},'releases' => 2,'size' => {'packed' => 29281,'unpacked' => 119156},'testers' => {},'uses' => ['5.005','AutoLoader','Carp','Exporter','Fcntl','XSLoader','strict','warnings']},'CircuitLayout-0.04.tar.gz' => {'author' => 'SCHUMACK','description' => undef,'files' => ['README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 2292,'pod' => 414,'pod_errors' => 2,'total' => 2706,'with_comments' => 288},'releases' => 2,'size' => {'packed' => 13502,'unpacked' => 76130},'testers' => {},'uses' => ['5.006','CircuitLayout::Boundary','CircuitLayout::Coord','CircuitLayout::Edge','CircuitLayout::Rectangle','CircuitLayout::Text','Math::Trig','Tk','Tk::WorldCanvas','strict']},'Cisco-Conf-0.10.tar.gz' => {'author' => 'JWIED','description' => 'Perl module for configuring Cisco routers via TFTP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 953,'pod' => 269,'pod_errors' => 0,'total' => 1222,'with_comments' => 74},'releases' => 6,'size' => {'packed' => 15530,'unpacked' => 54170},'testers' => {'pass' => 4},'uses' => ['Data::Dumper','ExtUtils::MakeMaker','File::Basename','File::Copy','IO::AtomicFile','IO::File','Net::Telnet','Safe','Socket','Sys::Hostname','Term::ReadKey','strict']},'Cisco-CopyConfig-1.2.tgz' => {'author' => 'AARONSCA','description' => 'IOS running-config manipulation','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 267,'pod' => 97,'pod_errors' => 0,'total' => 364,'with_comments' => 51},'releases' => 1,'requires' => ['Net-SNMP-4.1.0.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Net::SNMP' => 0,'Socket' => 0},'requires_recursive' => ['Crypt-DES-2.03.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','Net-SNMP-4.1.0.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4429,'unpacked' => 11177},'testers' => {'pass' => 1},'uses' => ['Exporter','Net::SNMP','Socket','strict','vars']},'Cisco-IPPhone-0.05.tar.gz' => {'author' => 'MRPALMER','description' => 'Cisco IP Phone interface using XML Objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 641,'pod' => 615,'pod_errors' => 0,'total' => 1256,'with_comments' => 122},'releases' => 5,'size' => {'packed' => 175465,'unpacked' => 423915},'testers' => {'pass' => 2},'uses' => ['5.005_62','Exporter','POSIX','strict','warnings']},'Cisco-Reconfig-0.6.tar.gz' => {'author' => 'MUIR','description' => 'Parse and generate Cisco configuration files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 778,'pod' => 221,'pod_errors' => 0,'total' => 999,'with_comments' => 44},'releases' => 6,'requires' => ['Scalar-List-Utils-1.11.tar.gz'],'requires_module' => {'Scalar::Util' => '1.07'},'requires_recursive' => ['Scalar-List-Utils-1.11.tar.gz'],'size' => {'packed' => 16406,'unpacked' => 71583},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','IO::File','Scalar::Util','Text::Tabs','strict']},'Cisco-ShowIPRoute-Parser-1.01.tar.gz' => {'author' => 'MARKPF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1627,'pod' => 589,'pod_errors' => 1,'total' => 2216,'with_comments' => 345},'releases' => 1,'size' => {'packed' => 98970,'unpacked' => 1521614},'testers' => {'pass' => 1},'uses' => ['5.006','AutoLoader','Data::Dumper','DynaLoader','ExecCmds::Utility','Exporter','Net::Telnet::Cisco','POSIX','Socket','strict','vars','warnings']},'Clamd-1.04.tar.gz' => {'author' => 'MSERGEANT','description' => 'Connect to a local clamd service and send commands','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 98,'pod_errors' => 0,'total' => 320,'with_comments' => 13},'releases' => 3,'size' => {'packed' => 5746,'unpacked' => 14607},'testers' => {},'uses' => ['File::Find','IO::Socket','strict','vars']},'Class-Accessor-0.18.tar.gz' => {'author' => 'KASEI','description' => 'Automated accessor generation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 359,'pod' => 401,'pod_errors' => 0,'total' => 760,'with_comments' => 8},'releases' => 8,'requires' => ['Class-Fields-0.16.tar.gz'],'requires_module' => {'base' => '1.01'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10083,'unpacked' => 37689},'testers' => {'pass' => 4},'uses' => ['5.00502','Carp','strict','vars']},'Class-AccessorMaker-1.0.tar.gz' => {'author' => 'SINISTER','description' => 'generate accessor methods with default values.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 230,'pod' => 163,'pod_errors' => 0,'total' => 393,'with_comments' => 25},'releases' => 2,'size' => {'packed' => 12035,'unpacked' => 33408},'testers' => {'pass' => 7},'uses' => ['Carp','strict']},'Class-ActsLike-0.01.tar.gz' => {'author' => 'CHROMATIC','description' => 'Perl extension for identifying class behavior similarities','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 73,'pod_errors' => 0,'total' => 158,'with_comments' => 0},'releases' => 1,'requires' => ['Scalar-List-Utils-1.11.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Scalar::Util' => '1.02','Test::More' => '0.45'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2902,'unpacked' => 5810},'testers' => {'pass' => 1},'uses' => ['Scalar::Util','strict','vars']},'Class-AlzaboWrapper-0.01.tar.gz' => {'author' => 'DROLSKY','description' => 'Higher level wrapper around Alzabo Row objects','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 336,'pod' => 187,'pod_errors' => 0,'total' => 523,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 12990,'unpacked' => 36139},'testers' => {},'uses' => ['Exception::Class','Params::Validate','strict','vars']},'Class-ArrayObjects-1.01.tar.gz' => {'author' => 'RBERJON','description' => 'Utility class for array based objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 190,'pod' => 161,'pod_errors' => 0,'total' => 351,'with_comments' => 30},'releases' => 3,'size' => {'packed' => 6401,'unpacked' => 16262},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Class-Autouse-0.7.tar.gz' => {'author' => 'ADAMK','description' => 'Defer loading of one or more classes.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 521,'pod' => 145,'pod_errors' => 0,'total' => 666,'with_comments' => 114},'releases' => 7,'size' => {'packed' => 17007,'unpacked' => 46747},'testers' => {'fail' => 2,'pass' => 6},'uses' => ['5.004','Carp','Exporter','UNIVERSAL','strict','vars']},'Class-Base-0.03.tar.gz' => {'author' => 'ABW','description' => 'useful base class for deriving other modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 386,'pod' => 406,'pod_errors' => 0,'total' => 792,'with_comments' => 100},'releases' => 3,'size' => {'packed' => 14932,'unpacked' => 54524},'testers' => {'pass' => 16},'uses' => ['strict']},'Class-Bits-0.01.tar.gz' => {'author' => 'SALVA','description' => 'Class wrappers around bit vectors','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 114,'pod' => 110,'pod_errors' => 0,'total' => 224,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 3107,'unpacked' => 6114},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','strict','warnings','warnings::register']},'Class-BlackHole-0.03.tar.gz' => {'author' => 'SBURKE','description' => 'treat unhandled method calls as no-op','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 47,'pod' => 71,'pod_errors' => 0,'total' => 118,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 3590,'unpacked' => 8487},'testers' => {'pass' => 11},'uses' => ['5','strict','vars']},'Class-Class-0.18.tar.gz' => {'author' => 'BINKLEY','description' => 'Adds data members to Perl packages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 432,'pod' => 159,'pod_errors' => 0,'total' => 591,'with_comments' => 100},'releases' => 1,'requires' => ['Class-ISA-0.32.tar.gz','Pragmatic-1.6.tar.gz'],'requires_module' => {'Class::ISA' => 0,'Pragmatic' => 0},'requires_recursive' => ['Class-ISA-0.32.tar.gz','Pragmatic-1.6.tar.gz'],'size' => {'packed' => 9291,'unpacked' => 32712},'testers' => {'fail' => 1,'pass' => 5,'tests' => '66'},'uses' => ['5.005','Class::ISA','Pragmatic','strict']},'Class-Classgen-classgen-3.03.tar.gz' => {'author' => 'MSCHLUE','description' => 'script that generates a class-module from a control file.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1788,'pod' => 1010,'pod_errors' => 1,'total' => 2798,'with_comments' => 218},'releases' => 4,'size' => {'packed' => 24670,'unpacked' => 103185},'testers' => {'tests' => '0','unknown' => 30},'uses' => ['City_gs','Country_gs','Point_gs','Polygon_gs','strict']},'Class-Classless-1.34.tar.gz' => {'author' => 'SBURKE','description' => 'Framework for classless OOP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1055,'pod' => 442,'pod_errors' => 0,'total' => 1497,'with_comments' => 194},'releases' => 5,'size' => {'packed' => 22075,'unpacked' => 64633},'testers' => {'pass' => 12},'uses' => ['5','Carp','strict','vars']},'Class-Composite-0.2.tar.gz' => {'author' => 'PDENIS','description' => 'Implements Composite patterns','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 362,'pod' => 252,'pod_errors' => 0,'total' => 614,'with_comments' => 6},'releases' => 2,'requires' => ['Class-Base-0.03.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Base' => '0.03','Scalar::Util' => '0.01','Test::Simple' => '0.01'},'requires_recursive' => ['Class-Base-0.03.tar.gz','File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5427,'unpacked' => 19073},'testers' => {'pass' => 1},'uses' => ['','Class::Base','FOO','Scalar::Util','lib','strict','warnings::register']},'Class-CompoundMethods-0.01.tar.gz' => {'author' => 'JJORE','description' => 'Create methods from components','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 124,'pod' => 108,'pod_errors' => 0,'total' => 232,'with_comments' => 16},'releases' => 1,'size' => {'packed' => 4153,'unpacked' => 14738},'testers' => {'pass' => 3},'uses' => ['5.006','Exporter','strict','vars','warnings']},'Class-Constructor-1.0.0.tar.gz' => {'author' => 'MGRAHAM','description' => 'Simplify the creation of object constructors','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1704,'pod' => 940,'pod_errors' => 0,'total' => 2644,'with_comments' => 86},'releases' => 1,'requires' => ['Class-Accessor-0.18.tar.gz'],'requires_module' => {'Class::Accessor' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 25586,'unpacked' => 75814},'testers' => {'pass' => 2},'uses' => ['5.005','Carp','File::Spec','strict','vars']},'Class-Container-0.10.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Glues object frameworks together transparently','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 651,'pod' => 208,'pod_errors' => 0,'total' => 859,'with_comments' => 50},'releases' => 9,'requires' => ['Params-Validate-0.64.tar.gz'],'requires_module' => {'Params::Validate' => '0.23'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Params-Validate-0.64.tar.gz'],'size' => {'packed' => 18366,'unpacked' => 64474},'testers' => {'pass' => 13},'uses' => ['B::Deparse','Carp','Scalar::Util','strict']},'Class-Contract-1.00.tar.gz' => {'author' => 'DCONWAY','description' => 'Design-by-Contract OO in Perl.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1915,'pod' => 914,'pod_errors' => 0,'total' => 2829,'with_comments' => 69},'releases' => 6,'size' => {'packed' => 27156,'unpacked' => 102496},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['Carp','Exporter','strict','vars']},'Class-Contract-1.14.tar.gz' => {'author' => 'GGOEBEL','description' => 'Design-by-Contract OO in Perl.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2148,'pod' => 942,'pod_errors' => 0,'total' => 3090,'with_comments' => 111},'releases' => 6,'size' => {'packed' => 39692,'unpacked' => 138703},'testers' => {'pass' => 8},'uses' => ['Carp','Data::Dumper','Exporter','strict','vars']},'Class-DBI-0.93.tar.gz' => {'author' => 'TMTM','description' => 'Simple Database Abstraction','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2495,'pod' => 1207,'pod_errors' => 0,'total' => 3702,'with_comments' => 141},'releases' => 27,'requires' => ['Class-Accessor-0.18.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Trigger-0.08.tar.gz','File-Temp-0.12.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Accessor' => '0.16','Class::Data::Inheritable' => '0.02','Class::Trigger' => '0.07','File::Temp' => '0.12','Ima::DBI' => '0.29','Storable' => '2.04','Test::More' => '0.47'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 55320,'unpacked' => 180187},'testers' => {'pass' => 2},'uses' => ['5.00502','Carp','Class::Accessor','Class::DBI::Query::Base','Class::DBI::__::Base','Class::Data::Inheritable','Class::Trigger','Ima::DBI','Storable','overload','strict','vars']},'Class-DBI-AbstractSearch-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Abstract Class::DBI\'s SQL with SQL::Abstract','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 60,'pod_errors' => 0,'total' => 103,'with_comments' => 1},'releases' => 2,'requires' => ['Class-DBI-0.93.tar.gz','SQL-Abstract-1.13.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::DBI' => '0.9','SQL::Abstract' => '1.1','Test::More' => '0.32'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','SQL-Abstract-1.13.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2255,'unpacked' => 3733},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','SQL::Abstract','strict','vars']},'Class-DBI-BaseDSN-1.21.tar.gz' => {'author' => 'RCLAMP','description' => 'DSN sensitive base class','files' => ['Makefile.PL','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 65,'pod' => 38,'pod_errors' => 0,'total' => 103,'with_comments' => 3},'releases' => 1,'requires' => ['Class-DBI-0.93.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::DBI' => '0','Test::More' => '0'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3273,'unpacked' => 5556},'testers' => {'pass' => 2},'uses' => ['Class::DBI','strict','vars']},'Class-DBI-Extension-0.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Some extension for Class::DBI','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 127,'pod' => 86,'pod_errors' => 0,'total' => 213,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2351,'unpacked' => 4751},'testers' => {'fail' => 1},'uses' => ['Class::DBI','strict','vars']},'Class-DBI-FromCGI-0.92.tar.gz' => {'author' => 'TMTM','description' => 'Update Class::DBI data using CGI::Untaint','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 115,'pod_errors' => 0,'total' => 289,'with_comments' => 2},'releases' => 6,'requires' => ['CGI-Untaint-0.90.tar.gz','Class-DBI-0.93.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'CGI::Untaint' => '0.8','Class::DBI' => '0.9','Test::More' => '0.17'},'requires_recursive' => ['CGI-Untaint-0.90.tar.gz','Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5312,'unpacked' => 15326},'testers' => {'fail' => 1,'pass' => 5,'tests' => '72'},'uses' => ['Exporter','strict','vars']},'Class-DBI-Loader-0.01.tar.gz' => {'author' => 'IKEBE','description' => 'dynamic definition of Class::DBI sub classes.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 184,'pod' => 183,'pod_errors' => 0,'total' => 367,'with_comments' => 5},'releases' => 1,'requires' => ['Class-DBI-0.93.tar.gz','DBI-1.37.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::DBI' => '0.89','DBI' => '1.3','Test::More' => '0.32'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3682,'unpacked' => 16040},'testers' => {'pass' => 3},'uses' => ['Carp','Class::Accessor','Class::DBI::Pg','Class::DBI::SQLite','Class::DBI::mysql','DBI','strict','vars']},'Class-DBI-Oracle-0.51.tar.gz' => {'author' => 'DANIEL','description' => 'Class::DBI extension for Oracle','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 124,'pod' => 51,'pod_errors' => 0,'total' => 175,'with_comments' => 20},'releases' => 3,'requires' => ['Class-DBI-0.93.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::DBI' => '0.36','Test::More' => '0.05'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3041,'unpacked' => 5483},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','Class::DBI','strict','vars']},'Class-DBI-Pager-0.04.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Pager utility for Class::DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 71,'pod' => 81,'pod_errors' => 0,'total' => 152,'with_comments' => 0},'releases' => 3,'requires' => ['Class-DBI-0.93.tar.gz','Data-Page-0.18.tar.gz','Exporter-Lite-0.01.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::DBI' => '0.9','Data::Page' => '0.13','Exporter::Lite' => '0.01','Test::More' => '0.32'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','Data-Page-0.18.tar.gz','Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3605,'unpacked' => 9718},'testers' => {'pass' => 8},'uses' => ['Carp','Class::DBI','Data::Page','strict','vars']},'Class-DBI-Pg-0.02.tar.gz' => {'author' => 'IKEBE','description' => 'Class::DBI extension for Postgres','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 66,'pod' => 61,'pod_errors' => 0,'total' => 127,'with_comments' => 5},'releases' => 2,'requires' => ['DBD-Pg-1.22.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DBD::Pg' => '1.13','Test::More' => '0.32'},'requires_recursive' => ['DBD-Pg-1.22.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2601,'unpacked' => 6423},'testers' => {'fail' => 1,'tests' => '6'},'uses' => ['Carp','Class::DBI','strict','vars']},'Class-DBI-Replication-0.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Class::DBI for replicated database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 80,'pod_errors' => 0,'total' => 227,'with_comments' => 8},'releases' => 1,'requires' => ['Class-DBI-0.93.tar.gz'],'requires_module' => {'Class::DBI' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3519,'unpacked' => 9243},'testers' => {'fail' => 2,'tests' => '2'},'uses' => ['Carp::Assert','Class::DBI','Class::Data::Inheritable','strict','vars']},'Class-DBI-SAK-1.3.tar.gz' => {'author' => 'CWEST','description' => 'Class::DBI Swiss Army Knife (SAK)','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 109,'pod' => 93,'pod_errors' => 1,'total' => 202,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 3736,'unpacked' => 9079},'testers' => {},'uses' => ['Carp','strict','vars','warnings']},'Class-DBI-SQLite-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Extension to Class::DBI for sqlite','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 91,'pod' => 37,'pod_errors' => 0,'total' => 128,'with_comments' => 2},'releases' => 2,'requires' => ['Class-DBI-0.93.tar.gz','DBD-SQLite-0.25.tar.gz','Ima-DBI-0.29.tar.gz','SQL-Statement-1.005.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::DBI' => '0.85','DBD::SQLite' => '0.07','Ima::DBI' => '0.27','SQL::Parser' => '1.004','Test::More' => '0.32'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBD-SQLite-0.25.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','SQL-Statement-1.005.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2458,'unpacked' => 4298},'testers' => {'pass' => 1},'uses' => ['Class::DBI','SQL::Statement','strict','vars']},'Class-DBI-ToSax-0.09.tar.gz' => {'author' => 'SEMANTICO','description' => 'turn database objects to SAX events','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 305,'pod' => 75,'pod_errors' => 0,'total' => 380,'with_comments' => 26},'releases' => 9,'requires' => ['Class-Accessor-0.18.tar.gz','Class-Data-Inheritable-0.02.tar.gz','NEXT-0.50.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'Class::Accessor' => 0,'Class::Data::Inheritable' => 0,'NEXT' => 0,'XML::SAX::Writer' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','NEXT-0.50.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6052,'unpacked' => 15709},'testers' => {'pass' => 1},'uses' => ['','5.006001','Carp','Class::Accessor','Class::Data::Inheritable','NEXT','TestClass::Base','strict','vars','warnings']},'Class-DBI-View-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Virtual table for Class::DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 296,'pod' => 162,'pod_errors' => 0,'total' => 458,'with_comments' => 4},'releases' => 2,'requires' => ['Class-DBI-0.93.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'requires_module' => {'Class::DBI' => '0.9','Test::More' => '0.32','UNIVERSAL::require' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4676,'unpacked' => 13717},'testers' => {'fail' => 5,'tests' => '1'},'uses' => ['Carp','UNIVERSAL::require','strict','vars']},'Class-DBI-mysql-0.15.tar.gz' => {'author' => 'TMTM','description' => 'Extensions to Class::DBI for MySQL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 155,'pod' => 90,'pod_errors' => 0,'total' => 245,'with_comments' => 0},'releases' => 11,'requires' => ['Class-DBI-0.93.tar.gz','DBD-mysql-2.9002.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::DBI' => '0.91','DBD::mysql' => 0,'Test::More' => '0.45'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5885,'unpacked' => 15447},'testers' => {'pass' => 1},'uses' => ['Carp','Class::DBI','strict','vars']},'Class-DBI-mysql-FullTextSearch-0.03.tar.gz' => {'author' => 'TMTM','description' => 'Full Text Indexing for Class::DBI::mysql','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 49,'pod_errors' => 0,'total' => 146,'with_comments' => 0},'releases' => 3,'requires' => ['Class-DBI-mysql-0.15.tar.gz','DBIx-FullTextSearch-0.73.tar.gz','Lingua-Stem-0.60.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::DBI::mysql' => '0.10','DBIx::FullTextSearch' => '0.57','Lingua::Stem' => '0.50','Test::Simple' => '0.17'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-DBI-mysql-0.15.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','DBIx-FullTextSearch-0.73.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','Parse-RecDescent-1.94.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-German-0.03.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3230,'unpacked' => 7264},'testers' => {'pass' => 2},'uses' => ['DBIx::FullTextSearch','DBIx::FullTextSearch::StopList','Exporter','strict','vars']},'Class-Data-Inheritable-0.02.tar.gz' => {'author' => 'MSCHWERN','description' => 'Inheritable, overridable class data','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 54,'pod' => 89,'pod_errors' => 0,'total' => 143,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3307,'unpacked' => 6802},'testers' => {'pass' => 62},'uses' => ['strict','vars']},'Class-Data-TIN-0.02.tar.gz' => {'author' => 'DOMM','description' => 'Translucent Inheritable Nonpolluting Class Data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 154,'pod_errors' => 1,'total' => 330,'with_comments' => 43},'releases' => 1,'size' => {'packed' => 4999,'unpacked' => 14808},'testers' => {'pass' => 4},'uses' => ['5.006','Carp','Data::Dumper','Exporter','strict','warnings']},'Class-Date-1.1.6.tar.gz' => {'author' => 'DLUX','description' => 'A full-featured date and time class for perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 958,'pod' => 599,'pod_errors' => 0,'total' => 1557,'with_comments' => 38},'releases' => 24,'size' => {'packed' => 27855,'unpacked' => 104566},'testers' => {'pass' => 4},'uses' => ['5.005_03','Carp','DynaLoader','Exporter','POSIX','Time::Local','UNIVERSAL','constant','overload','strict','vars']},'Class-Declare-0.05.tar.gz' => {'author' => 'IBB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2793,'pod' => 839,'pod_errors' => 0,'total' => 3632,'with_comments' => 842},'releases' => 5,'requires' => ['Storable-2.07.tar.gz','Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Storable' => 0,'Test::Exception' => '0.15','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 67158,'unpacked' => 286694},'testers' => {'pass' => 2},'uses' => ['','Class::Declare::Read','Exporter','strict','vars']},'Class-Declare-Attributes-0.03.tar.gz' => {'author' => 'IBB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1123,'pod' => 282,'pod_errors' => 0,'total' => 1405,'with_comments' => 349},'releases' => 3,'requires' => ['Attribute-Handlers-0.78.tar.gz','Class-Declare-0.05.tar.gz','Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => 0,'Class::Declare' => '0.03','Test::Exception' => '0.15','Test::More' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Class-Declare-0.05.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 16410,'unpacked' => 75693},'testers' => {'pass' => 2},'uses' => ['','5.006','Class::Declare','strict','vars','warnings']},'Class-Decorator-0.99.tar.gz' => {'author' => 'NWETTERS','description' => 'Adds additional responsibilites to an object','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 90,'pod_errors' => 0,'total' => 266,'with_comments' => 14},'releases' => 4,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => undef},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 4382,'unpacked' => 12465},'testers' => {'pass' => 5},'uses' => ['Carp','strict','vars']},'Class-Default-0.2.tar.gz' => {'author' => 'ADAMK','description' => 'Static calls apply to a default instantiation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 107,'pod' => 158,'pod_errors' => 0,'total' => 265,'with_comments' => 15},'releases' => 2,'requires' => ['Class-Inspector-1.tar.gz'],'requires_module' => {'Class::Inspector' => 0},'requires_recursive' => ['Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 12454,'unpacked' => 37394},'testers' => {'pass' => 18},'uses' => ['5.005','Carp','strict','vars']},'Class-Delegate-0.06.tar.gz' => {'author' => 'KSTAR','description' => 'Easy-to-use object delegation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 171,'pod' => 104,'pod_errors' => 0,'total' => 275,'with_comments' => 14},'releases' => 2,'size' => {'packed' => 4266,'unpacked' => 10531},'testers' => {'pass' => 12},'uses' => ['strict','vars']},'Class-Delegation-1.06.tar.gz' => {'author' => 'DCONWAY','description' => 'Object-oriented delegation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 580,'pod' => 525,'pod_errors' => 0,'total' => 1105,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 14201,'unpacked' => 46892},'testers' => {'fail' => 1,'pass' => 14},'uses' => ['Carp','Data::Dumper','strict','vars']},'Class-DispatchToAll-0.10.tar.gz' => {'author' => 'DOMM','description' => 'dispatch a method call to all inherited methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 127,'pod' => 162,'pod_errors' => 0,'total' => 289,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 4541,'unpacked' => 12964},'testers' => {'pass' => 4},'uses' => ['5.006','Exporter','strict','warnings']},'Class-Dynamic-1.01.tar.gz' => {'author' => 'SIMON','description' => 'Rudimentary support for coderefs in @ISA','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 40,'pod' => 31,'pod_errors' => 0,'total' => 71,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 2464,'unpacked' => 4272},'testers' => {'pass' => 6},'uses' => ['5.006','Carp']},'Class-Eroot-19960603.tar.gz' => {'author' => 'DMR','description' => 'Struct/member template builder','files' => ['README'],'lines' => {'nonpod' => 628,'pod' => 140,'pod_errors' => 1,'total' => 768,'with_comments' => 93},'releases' => 2,'size' => {'packed' => 6718,'unpacked' => 19657},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.000','5.002','Carp','Exporter','strict']},'Class-Exporter-0.03.tar.gz' => {'author' => 'SPLICE','description' => 'Export class methods as regular subroutines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1462,'pod' => 1041,'pod_errors' => 0,'total' => 2503,'with_comments' => 61},'releases' => 1,'size' => {'packed' => 20687,'unpacked' => 62318},'testers' => {'pass' => 5},'uses' => ['5.005','Carp','strict']},'Class-Facade-0.01.tar.gz' => {'author' => 'ABW','description' => 'Interface to one or more delegates','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 102,'pod' => 61,'pod_errors' => 0,'total' => 163,'with_comments' => 24},'releases' => 1,'requires' => ['Class-Base-0.03.tar.gz'],'requires_module' => {'Class::Base' => '0.01'},'requires_recursive' => ['Class-Base-0.03.tar.gz'],'size' => {'packed' => 3289,'unpacked' => 12008},'testers' => {'pass' => 8},'uses' => ['','Class::Base','strict']},'Class-Factory-1.00.tar.gz' => {'author' => 'CWINTERS','description' => 'Base class for dynamic factory classes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 285,'pod' => 317,'pod_errors' => 0,'total' => 602,'with_comments' => 14},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.4'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7888,'unpacked' => 24869},'testers' => {'pass' => 13},'uses' => ['','strict']},'Class-Factory-Util-1.4.tar.gz' => {'author' => 'DROLSKY','description' => 'Provide utility methods for factory classes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 67,'pod' => 29,'pod_errors' => 0,'total' => 96,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 1720,'unpacked' => 2523},'testers' => {'pass' => 14},'uses' => ['Carp','strict','vars']},'Class-Fields-0.16.tar.gz' => {'author' => 'MSCHWERN','description' => 'Inspect the fields of a class.','files' => ['Makefile.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 1004,'pod' => 760,'pod_errors' => 0,'total' => 1764,'with_comments' => 99},'releases' => 10,'requires' => ['Carp-Assert-0.17.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Carp::Assert' => 0,'constant' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 23695,'unpacked' => 94076},'testers' => {'fail' => 1,'pass' => 4,'tests' => '107'},'uses' => ['5.005','Carp','Carp::Assert','Exporter','Hash::Util','constant','strict','vars','warnings::register']},'Class-Generate-1.06.tar.gz' => {'author' => 'SWARTIK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3386,'pod' => 1293,'pod_errors' => 0,'total' => 4679,'with_comments' => 332},'releases' => 4,'size' => {'packed' => 50511,'unpacked' => 191905},'testers' => {'pass' => 14},'uses' => ['5.004','Carp','Exporter','Symbol','strict','vars']},'Class-Handle-0.4.tar.gz' => {'author' => 'ADAMK','description' => 'Supply object methods to classes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 307,'pod' => 158,'pod_errors' => 0,'total' => 465,'with_comments' => 69},'releases' => 4,'requires' => ['Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::ISA' => 0,'Class::Inspector' => '0.2','Test::More' => 0},'requires_recursive' => ['Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 14068,'unpacked' => 49749},'testers' => {'pass' => 2},'uses' => ['5.005','strict','vars']},'Class-Handler-1.03.tar.gz' => {'author' => 'NWIGER','description' => 'Make Apache-like pseudoclass event handlers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 146,'pod' => 141,'pod_errors' => 0,'total' => 287,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 5042,'unpacked' => 16134},'testers' => {'pass' => 11},'uses' => ['5.003','Exporter','strict','vars']},'Class-Holon-0.03.tar.gz' => {'author' => 'GSLONDON','description' => 'Declare hierarchical classes with one line','files' => [],'lines' => {'nonpod' => 1052,'pod' => 312,'pod_errors' => 0,'total' => 1364,'with_comments' => 201},'releases' => 3,'size' => {'packed' => 12206,'unpacked' => 41283},'testers' => {'fail' => 10},'uses' => ['5.005_62','Atom::Hydrogen','Atom::Oxygen','Carp','Data::Dumper','WeakRef','strict','warnings']},'Class-Hook-0.01.tar.gz' => {'author' => 'PDENIS','description' => 'Add hooks on methods from other classes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 185,'pod' => 139,'pod_errors' => 0,'total' => 324,'with_comments' => 8},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'Test::Simple' => '0.01','Time::HiRes' => '0.01'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 4342,'unpacked' => 16242},'testers' => {'fail' => 3,'pass' => 5},'uses' => ['Carp','Data::Dumper','Time::HiRes','strict','warnings::register']},'Class-ISA-0.32.tar.gz' => {'author' => 'SBURKE','description' => 'Report the search path thru an ISA tree','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 126,'pod' => 88,'pod_errors' => 0,'total' => 214,'with_comments' => 32},'releases' => 3,'size' => {'packed' => 5341,'unpacked' => 15408},'testers' => {'pass' => 25},'uses' => ['5','strict','vars']},'Class-Inner-0.1.tar.gz' => {'author' => 'PDCAWLEY','description' => 'A perlish implementation of Java like inner classes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 108,'pod' => 91,'pod_errors' => 0,'total' => 199,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 3252,'unpacked' => 6823},'testers' => {'fail' => 1,'pass' => 18,'tests' => '13'},'uses' => ['Carp','strict','vars']},'Class-Inspector-1.tar.gz' => {'author' => 'ADAMK','description' => 'Provides information about Classes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 301,'pod' => 123,'pod_errors' => 0,'total' => 424,'with_comments' => 62},'releases' => 3,'requires' => ['Class-ISA-0.32.tar.gz','File-Spec-0.82.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::ISA' => 0,'File::Spec' => '0.82','Test::Simple' => 0},'requires_recursive' => ['Class-ISA-0.32.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 15639,'unpacked' => 48534},'testers' => {'pass' => 12},'uses' => ['Class::ISA','File::Spec','vars']},'Class-Listener-0.01.04.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 63,'pod_errors' => 0,'total' => 95,'with_comments' => 0},'releases' => 2,'requires' => ['Class-Maker-0.5.14.tar.gz'],'requires_module' => {'Class::Maker' => 0},'requires_recursive' => ['Class-Maker-0.5.14.tar.gz','Data-Dumper-2.101.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz'],'size' => {'packed' => 2098,'unpacked' => 3754},'testers' => {'pass' => 9},'uses' => ['5.006','strict','warnings']},'Class-Loader-2.02.tar.gz' => {'author' => 'VIPUL','description' => 'Load modules and create objects on demand.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 166,'pod' => 90,'pod_errors' => 0,'total' => 256,'with_comments' => 18},'releases' => 8,'size' => {'packed' => 5972,'unpacked' => 17108},'testers' => {'pass' => 14},'uses' => ['Data::Dumper','vars']},'Class-MVC-0.01.06.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 175,'pod' => 174,'pod_errors' => 1,'total' => 349,'with_comments' => 8},'releases' => 1,'requires' => ['Class-Listener-0.01.04.tar.gz','Class-Maker-0.5.14.tar.gz','Class-Observable-1.00.tar.gz'],'requires_module' => {'Class::Listener' => 0,'Class::Maker' => 0,'Class::Observable' => 0},'requires_recursive' => ['Class-ISA-0.32.tar.gz','Class-Listener-0.01.04.tar.gz','Class-Maker-0.5.14.tar.gz','Class-Observable-1.00.tar.gz','Data-Dumper-2.101.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','IO-Extended-0.06.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3350,'unpacked' => 9742},'testers' => {'pass' => 8},'uses' => ['5.006','Class::Listener','Class::Maker','Class::Observable','strict','warnings']},'Class-MakeMethods-1.0.14.tar.gz' => {'author' => 'EVO','description' => 'Generate common types of methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9674,'pod' => 9367,'pod_errors' => 10,'total' => 19041,'with_comments' => 376},'releases' => 7,'size' => {'packed' => 144326,'unpacked' => 667493},'testers' => {'pass' => 1},'uses' => ['5.0','5.00','5.00307','5.006','Attribute::Handlers','AutoLoader','Carp','Class::MakeMethods','Class::MakeMethods::Composite','Class::MakeMethods::Composite::Hash','Class::MakeMethods::Standard','Class::MakeMethods::Template','Class::MakeMethods::Template::Array','Class::MakeMethods::Template::ClassInherit','Class::MakeMethods::Template::DiskCache','Class::MakeMethods::Template::Generic','Class::MakeMethods::Template::TextBuilder','Exporter','File::Path','File::Spec','strict','vars']},'Class-MakeMethods-1.000016.tar.gz' => {'author' => 'EVO','description' => 'Generate common types of methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10319,'pod' => 10090,'pod_errors' => 10,'total' => 20409,'with_comments' => 432},'releases' => 7,'size' => {'packed' => 148207,'unpacked' => 690031},'testers' => {'pass' => 4},'uses' => ['5.0','5.00','5.00307','5.006','Attribute::Handlers','AutoLoader','Carp','Class::MakeMethods','Class::MakeMethods::Composite','Class::MakeMethods::Composite::Hash','Class::MakeMethods::Standard','Class::MakeMethods::Template','Class::MakeMethods::Template::Array','Class::MakeMethods::Template::ClassInherit','Class::MakeMethods::Template::DiskCache','Class::MakeMethods::Template::Generic','Class::MakeMethods::Template::TextBuilder','Class::MakeMethods::Utility::ArraySplicer','Class::MakeMethods::Utility::Inheritable','Class::MakeMethods::Utility::Ref','Exporter','File::Path','File::Spec','constant','strict','vars']},'Class-MakeMethods-1.006.tar.gz' => {'author' => 'EVO','description' => 'Generate common types of methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10575,'pod' => 9830,'pod_errors' => 6,'total' => 20405,'with_comments' => 465},'releases' => 7,'size' => {'packed' => 164666,'unpacked' => 773060},'testers' => {'fail' => 1,'pass' => 11},'uses' => ['5.0','5.00','5.00307','5.006','Attribute::Handlers','AutoLoader','Carp','Class::MakeMethods::Template::Array','Exporter','File::Path','File::Spec','constant','strict','vars']},'Class-Maker-0.02.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1430,'pod' => 486,'pod_errors' => 2,'total' => 1916,'with_comments' => 133},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz','IO-Extended-0.06.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'IO::Extended' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','IO-Extended-0.06.tar.gz'],'size' => {'packed' => 17958,'unpacked' => 57945},'testers' => {'pass' => 24},'uses' => ['5.005_62','Bugfix::ref','Carp','Class::Maker::Basic::Constructor','Class::Maker::Basic::Fields','Class::Maker::Basic::Handler::Attributes','Class::Maker::Examples::Array','Class::Maker::Examples::Basket','Class::Maker::Examples::Human','Class::Maker::Examples::User','Data::DumpXML','Exporter','IO::Extended','Object::Debugable','Set::Bag','XML::Dumper','strict','subs','warnings']},'Class-Maker-0.5.14.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1061,'pod' => 555,'pod_errors' => 2,'total' => 1616,'with_comments' => 129},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Error' => '0.15','IO::Extended' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz'],'size' => {'packed' => 21146,'unpacked' => 62465},'testers' => {'pass' => 17},'uses' => ['5.005_62','Data::Dumper','Error','Exporter','attributes','strict','subs','warnings']},'Class-MethodMaker-1.10.tar.gz' => {'author' => 'FLUFFY','description' => 'Create generic class methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2655,'pod' => 1062,'pod_errors' => 4,'total' => 3717,'with_comments' => 238},'releases' => 16,'size' => {'packed' => 36853,'unpacked' => 139085},'testers' => {'pass' => 12},'uses' => ['5.00307','5.005','AutoLoader','Carp','Config','Exporter','ExtUtils::MakeMaker','File::Find','File::Spec','constant','happy','strict','vars']},'Class-MethodMapper-1.0.tar.gz' => {'author' => 'LENZO','description' => 'Abstract Class wrapper for AutoLoader','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 426,'pod' => 131,'pod_errors' => 0,'total' => 557,'with_comments' => 23},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz'],'requires_module' => {'Data::Dumper' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 5291,'unpacked' => 13345},'testers' => {'pass' => 15},'uses' => ['AutoLoader','Cwd','Data::Dumper','English','Exporter','IO::File','Sys::Hostname','UNIVERSAL','strict']},'Class-Methods-0.062.tar.gz' => {'author' => 'RSOD','description' => 'Object methods for working with classes','files' => ['Makefile.PL','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 108,'pod' => 43,'pod_errors' => 0,'total' => 151,'with_comments' => 34},'releases' => 2,'requires' => ['Devel-Pointer-1.00.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Devel::Pointer' => 0,'warnings' => 0},'requires_recursive' => ['Devel-Pointer-1.00.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3417,'unpacked' => 6942},'testers' => {'pass' => 3},'uses' => ['"','$_','\',','.','5.005_62','@_)','Exporter','join(\'','map','ref($_)','strict','warnings','{','||','}']},'Class-Multimethods-1.70.tar.gz' => {'author' => 'DCONWAY','description' => 'A multiple dispatch mechanism for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 879,'pod' => 550,'pod_errors' => 0,'total' => 1429,'with_comments' => 75},'releases' => 4,'size' => {'packed' => 28316,'unpacked' => 106424},'testers' => {'pass' => 19},'uses' => ['Carp','Data::Dumper','Exporter','strict','vars']},'Class-Mutator-0.04.tar.gz' => {'author' => 'GMCCAR','description' => 'Dynamic polymorphism implemented in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 114,'pod_errors' => 0,'total' => 247,'with_comments' => 6},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3634,'unpacked' => 11638},'testers' => {'pass' => 5},'uses' => ['strict']},'Class-NamedParms-1.04.tar.gz' => {'author' => 'SNOWHARE','description' => 'A named parameter accessor base class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 225,'pod' => 165,'pod_errors' => 0,'total' => 390,'with_comments' => 18},'releases' => 2,'size' => {'packed' => 4056,'unpacked' => 11858},'testers' => {'pass' => 16},'uses' => ['Carp','strict','vars']},'Class-Null-1.02.tar.gz' => {'author' => 'MARCEL','description' => 'Implements the Null Class design pattern','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 143,'pod_errors' => 0,'total' => 185,'with_comments' => 0},'releases' => 4,'requires' => ['Test-Distribution-1.02.tar.gz'],'requires_module' => {'Test::Distribution' => '1.02'},'requires_recursive' => ['File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Distribution-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 3763,'unpacked' => 12516},'testers' => {'pass' => 2},'uses' => ['vars']},'Class-OOorNO-0.011.tar.gz' => {'author' => 'TOMMY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 200,'pod' => 520,'pod_errors' => 0,'total' => 720,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 7840,'unpacked' => 24070},'testers' => {'pass' => 6},'uses' => ['Exporter','strict','vars']},'Class-Object-0.01.tar.gz' => {'author' => 'MSCHWERN','description' => 'each object is its own class','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 766,'pod' => 535,'pod_errors' => 0,'total' => 1301,'with_comments' => 50},'releases' => 1,'size' => {'packed' => 12565,'unpacked' => 33920},'testers' => {'pass' => 4},'uses' => ['strict']},'Class-ObjectTemplate-0.7.tar.gz' => {'author' => 'JASONS','description' => 'Optimized template builder base class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 239,'pod' => 78,'pod_errors' => 0,'total' => 317,'with_comments' => 79},'releases' => 7,'size' => {'packed' => 6278,'unpacked' => 16492},'testers' => {'pass' => 9},'uses' => ['Carp','Exporter','strict','vars']},'Class-ObjectTemplate-DB-0.27.tar.gz' => {'author' => 'JASONS','description' => 'Template base class for database objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 84,'pod_errors' => 1,'total' => 233,'with_comments' => 44},'releases' => 6,'requires' => ['Class-ObjectTemplate-0.7.tar.gz'],'requires_module' => {'Class::ObjectTemplate' => '0.7'},'requires_recursive' => ['Class-ObjectTemplate-0.7.tar.gz'],'size' => {'packed' => 6926,'unpacked' => 18697},'testers' => {'pass' => 6},'uses' => ['Carp','Class::ObjectTemplate','Exporter','strict','vars']},'Class-Observable-1.00.tar.gz' => {'author' => 'CWINTERS','description' => 'Allow other classes and objects to respond to events in yours','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 377,'pod' => 424,'pod_errors' => 1,'total' => 801,'with_comments' => 28},'releases' => 4,'requires' => ['Class-ISA-0.32.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::ISA' => '0.32','Test::More' => '0.4'},'requires_recursive' => ['Class-ISA-0.32.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8708,'unpacked' => 29216},'testers' => {'pass' => 3},'uses' => ['','Class::ISA','strict']},'Class-PObject-1.8.tar.gz' => {'author' => 'SHERZODR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1437,'pod' => 614,'pod_errors' => 0,'total' => 2051,'with_comments' => 154},'releases' => 4,'requires' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'File::Spec' => 0,'IO::Dir' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz'],'size' => {'packed' => 25966,'unpacked' => 97719},'testers' => {'pass' => 1},'uses' => ['Carp','DBI','Data::Dumper','Exporter','Fcntl','File::Path','File::Spec','IO::Dir','Safe','diagnostics','strict','vars']},'Class-ParamParser-1.041.tar.gz' => {'author' => 'DUNCAND','description' => 'Provides complex parameter list parsing','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 264,'pod' => 186,'pod_errors' => 5,'total' => 450,'with_comments' => 80},'releases' => 7,'size' => {'packed' => 13517,'unpacked' => 46918},'testers' => {'pass' => 5,'tests' => '0','unknown' => 9},'uses' => ['5.004','vars','warnings']},'Class-ParmList-1.03.tar.gz' => {'author' => 'SNOWHARE','description' => 'A named parameter list processor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 345,'pod' => 253,'pod_errors' => 0,'total' => 598,'with_comments' => 40},'releases' => 2,'size' => {'packed' => 7571,'unpacked' => 34732},'testers' => {'pass' => 13},'uses' => ['Carp','Exporter','strict','vars']},'Class-Phrasebook-0.88.tar.gz' => {'author' => 'RANI','description' => 'Implements the Phrasebook pattern','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1160,'pod' => 290,'pod_errors' => 0,'total' => 1450,'with_comments' => 227},'releases' => 9,'requires' => ['ANSIColor-1.07.tar.gz','IO-LockedFile-0.23.tar.gz','Log-LogLite-0.82.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'IO::LockedFile' => '0.1','Log::LogLite' => '0.2','Term::ANSIColor' => '1.03','XML::Parser' => '2.3'},'requires_recursive' => ['ANSIColor-1.07.tar.gz','IO-1.20.tar.gz','IO-LockedFile-0.23.tar.gz','Log-LogLite-0.82.tar.gz','XML-Parser-2.31.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18532,'unpacked' => 66765},'testers' => {'pass' => 7},'uses' => ['Log::NullLogLite','Term::ANSIColor','XML::Parser','bytes','strict']},'Class-Prevayler-0.02.tar.gz' => {'author' => 'NATHANAEL','description' => 'prl-implementation of the prevayler-concept','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 560,'pod' => 229,'pod_errors' => 0,'total' => 789,'with_comments' => 29},'releases' => 2,'requires' => ['Class-MethodMaker-1.10.tar.gz','File-Spec-0.82.tar.gz','File-Sync-0.09.tar.gz'],'requires_module' => {'Class::MethodMaker' => 0,'File::Spec' => 0,'File::Sync' => 0},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','File-Spec-0.82.tar.gz','File-Sync-0.09.tar.gz'],'size' => {'packed' => 13009,'unpacked' => 45426},'testers' => {'pass' => 6},'uses' => ['Carp','Data::Dumper','File::Spec','File::Sync','strict','vars','warnings']},'Class-Privacy-0.03.tar.gz' => {'author' => 'JHI','description' => 'object data privacy','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 62,'pod' => 41,'pod_errors' => 0,'total' => 103,'with_comments' => 6},'releases' => 3,'size' => {'packed' => 2418,'unpacked' => 4119},'testers' => {'pass' => 7},'uses' => ['5.006001','P','strict']},'Class-Protected-0.01.02.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 131,'pod_errors' => 0,'total' => 213,'with_comments' => 3},'releases' => 1,'requires' => ['Class-Maker-0.5.14.tar.gz','Class-Proxy-0.01.04.tar.gz','Decision-ACL-0.02.tar.gz','IO-Extended-0.06.tar.gz'],'requires_module' => {'Class::Maker' => '','Class::Proxy' => 0,'Decision::ACL' => '0.02','IO::Extended' => '0.05'},'requires_recursive' => ['Class-Listener-0.01.04.tar.gz','Class-Maker-0.5.14.tar.gz','Class-Proxy-0.01.04.tar.gz','Data-Dumper-2.101.tar.gz','Decision-ACL-0.02.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz'],'size' => {'packed' => 3055,'unpacked' => 10191},'testers' => {'pass' => 4},'uses' => ['5.006','Carp','Class::Maker','Class::Proxy','Decision::ACL','Decision::ACL::Constants','Decision::ACL::Rule','IO::Extended','strict','warnings']},'Class-Prototyped-0.90.tar.gz' => {'author' => 'TEVERETT','description' => 'Fast prototype-based OO programming in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1463,'pod' => 544,'pod_errors' => 0,'total' => 2007,'with_comments' => 78},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz','Test-1.24.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => undef,'Data::Dumper' => undef,'Test' => undef},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 36880,'unpacked' => 135536},'testers' => {'pass' => 3},'uses' => ['Data::Dumper','GraphViz','IO::File','strict']},'Class-Proxy-0.01.02.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 229,'pod' => 95,'pod_errors' => 0,'total' => 324,'with_comments' => 15},'releases' => 3,'requires' => ['Class-Maker-0.5.14.tar.gz','IO-Extended-0.06.tar.gz'],'requires_module' => {'Class::Maker' => 0,'IO::Extended' => 0},'requires_recursive' => ['Class-Maker-0.5.14.tar.gz','Data-Dumper-2.101.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz'],'size' => {'packed' => 3444,'unpacked' => 7520},'testers' => {'fail' => 1},'uses' => ['5.005_62','5.006','Carp','Class::Listener','Class::Maker','Data::Dumper','IO::Extended','strict','vars','warnings']},'Class-Proxy-0.01.04.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 109,'pod' => 67,'pod_errors' => 0,'total' => 176,'with_comments' => 8},'releases' => 3,'requires' => ['Class-Listener-0.01.04.tar.gz','Class-Maker-0.5.14.tar.gz','IO-Extended-0.06.tar.gz'],'requires_module' => {'Class::Listener' => 0,'Class::Maker' => 0,'IO::Extended' => 0},'requires_recursive' => ['Class-Listener-0.01.04.tar.gz','Class-Maker-0.5.14.tar.gz','Data-Dumper-2.101.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz'],'size' => {'packed' => 2645,'unpacked' => 5214},'testers' => {'fail' => 6,'pass' => 5},'uses' => ['5.005_62','Carp','Class::Listener','Class::Maker','strict','vars','warnings']},'Class-Proxy-Lite-1.00.tar.gz' => {'author' => 'NKUITSE','description' => 'Simple, lightweight object proxies','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 110,'pod' => 108,'pod_errors' => 0,'total' => 218,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 5277,'unpacked' => 11452},'testers' => {'pass' => 3},'uses' => ['constant','strict','vars']},'Class-PseudoHash-1.01.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Emulates Pseudo-Hash behaviour via overload','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 139,'pod' => 58,'pod_errors' => 0,'total' => 197,'with_comments' => 4},'releases' => 4,'size' => {'packed' => 4039,'unpacked' => 10029},'testers' => {'pass' => 8},'uses' => ['5.005','Carp','constant','strict','vars']},'Class-PublicPrivate-0.80.tar.gz' => {'author' => 'MIKO','description' => 'Class with public keys with any name and a separate set of private keys','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 107,'pod' => 61,'pod_errors' => 0,'total' => 168,'with_comments' => 25},'releases' => 1,'size' => {'packed' => 2737,'unpacked' => 7940},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'Class-Random-0.2.tar.gz' => {'author' => 'PMH','description' => 'Random behaviour for instances','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 98,'pod' => 52,'pod_errors' => 0,'total' => 150,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 2924,'unpacked' => 5999},'testers' => {'pass' => 2},'uses' => ['Carp','overload','strict','vars']},'Class-ReturnValue-0.51.tar.gz' => {'author' => 'JESSE','description' => 'A return-value object that lets you treat it as as a boolean, array or object','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 251,'pod' => 174,'pod_errors' => 1,'total' => 425,'with_comments' => 5},'releases' => 7,'requires' => ['Devel-StackTrace-1.03.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Devel::StackTrace' => undef,'Test::Inline' => undef,'Test::More' => undef},'requires_recursive' => ['Devel-StackTrace-1.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5015,'unpacked' => 15264},'testers' => {'pass' => 12},'uses' => ['Carp','Data::Dumper','Devel::StackTrace','Exporter','vars']},'Class-Runtime-0.1.tar.gz' => {'author' => 'STATHY','description' => 'API for dynamic class loading/unloading/status','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 268,'pod' => 321,'pod_errors' => 0,'total' => 589,'with_comments' => 0},'releases' => 1,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Spec' => '0.8','Symbol' => '1.02'},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3830,'unpacked' => 13942},'testers' => {'pass' => 2},'uses' => ['5.005','strict']},'Class-SelfMethods-1.07.tar.gz' => {'author' => 'TEVERETT','description' => 'a Module for supporting instance-defined methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 193,'pod' => 144,'pod_errors' => 0,'total' => 337,'with_comments' => 20},'releases' => 3,'size' => {'packed' => 8428,'unpacked' => 29724},'testers' => {'pass' => 9},'uses' => ['Carp','strict','vars']},'Class-Singleton-1.03.tar.gz' => {'author' => 'ABW','description' => 'Implementation of a "Singleton" class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 143,'pod' => 209,'pod_errors' => 0,'total' => 352,'with_comments' => 56},'releases' => 3,'size' => {'packed' => 7136,'unpacked' => 28156},'testers' => {'pass' => 26},'uses' => ['5.004','strict','vars']},'Class-Skin-0.05.tar.gz' => {'author' => 'RANI','description' => 'Class for creating text out of text templates.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 319,'pod' => 286,'pod_errors' => 0,'total' => 605,'with_comments' => 73},'releases' => 5,'requires' => ['Log-LogLite-0.82.tar.gz'],'requires_module' => {'Log::LogLite' => '0.2'},'requires_recursive' => ['IO-1.20.tar.gz','IO-LockedFile-0.23.tar.gz','Log-LogLite-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 29490,'unpacked' => 1473827},'testers' => {'pass' => 5},'uses' => ['5.006','AutoLoader','Carp','Cwd','DynaLoader','Exporter','Log::NullLogLite','bytes','strict','warnings']},'Class-Struct-FIELDS-1.1.tar.gz' => {'author' => 'BINKLEY','description' => 'Combine Class::Struct, base and fields','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1256,'pod' => 553,'pod_errors' => 0,'total' => 1809,'with_comments' => 114},'releases' => 5,'requires' => ['Class-Fields-0.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Class::Struct' => 0,'base' => 0,'fields' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19062,'unpacked' => 84155},'testers' => {'pass' => 1},'uses' => ['5.005_64','@isa','AutoLoader','Carp','Exporter','Tie::Array','Tie::Hash','fields','strict','warnings','warnings::register']},'Class-StructTemplate-0.01.tar.gz' => {'author' => 'HEIKOWU','description' => 'Facilitates creation of public class-data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1007,'pod' => 0,'pod_errors' => 0,'total' => 1007,'with_comments' => 33},'releases' => 1,'requires' => ['DBI-1.37.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'DBI' => 0,'Exporter' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5919,'unpacked' => 23467},'testers' => {'fail' => 5},'uses' => ['Carp','DBI','Data::Dumper','Exporter']},'Class-Structured-0.1.tar.gz' => {'author' => 'ROBWALKER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 311,'pod' => 77,'pod_errors' => 0,'total' => 388,'with_comments' => 59},'releases' => 1,'requires' => ['Set-Scalar-1.17.tar.gz'],'requires_module' => {'Set::Scalar' => '1.06'},'requires_recursive' => ['Set-Scalar-1.17.tar.gz'],'size' => {'packed' => 4279,'unpacked' => 11560},'testers' => {'pass' => 5},'uses' => ['Carp','Set::Scalar','strict','warnings']},'Class-Tangram-1.13.tar.gz' => {'author' => 'SAMV','description' => 'Automated class accessors, Tangram friendly','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1161,'pod' => 485,'pod_errors' => 0,'total' => 1646,'with_comments' => 115},'releases' => 11,'requires' => ['DateManip-5.42a.tar.gz','Set-Object-1.03a.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Date::Manip' => '5.21','Set::Object' => '1.02','Test::Simple' => '0.18'},'requires_recursive' => ['DateManip-5.42a.tar.gz','File-Spec-0.82.tar.gz','Set-Object-1.03a.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 23170,'unpacked' => 73555},'testers' => {'fail' => 2,'pass' => 1,'tests' => '80'},'uses' => ['Carp','Set::Object','Tangram::Relational','strict','vars']},'Class-Tom-3.02.tar.gz' => {'author' => 'JDUNCAN','description' => 'The Transportable Object Model for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 279,'pod' => 74,'pod_errors' => 1,'total' => 353,'with_comments' => 26},'releases' => 5,'requires' => ['Data-Dumper-2.101.tar.gz','Devel-Symdump-2.03.tar.gz','Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'Data::Dumper' => '2.08','Devel::Symdump' => 2,'Digest::MD5' => '2.09','MIME::Base64' => '2.11'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Devel-Symdump-2.03.tar.gz','Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 3685,'unpacked' => 8323},'testers' => {'tests' => '0','unknown' => 30},'uses' => ['','5.005','B','B::Deparse','Data::Dumper','Devel::Symdump','Digest::MD5','Exporter','MIME::Base64','strict','vars']},'Class-Translucent-1.18.tar.gz' => {'author' => 'GED','description' => 'Translucent (ala perltootc) method creation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 757,'pod' => 189,'pod_errors' => 0,'total' => 946,'with_comments' => 201},'releases' => 5,'requires' => ['Data-Dumper-2.101.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15609,'unpacked' => 53818},'testers' => {'pass' => 10},'uses' => ['5.006','Carp','Data::Dumper','strict','vars']},'Class-Tree-1.23.tgz' => {'author' => 'RSAVAGE','description' => 'C++ class hierarchies & disk directories','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 473,'pod' => 125,'pod_errors' => 0,'total' => 598,'with_comments' => 73},'releases' => 8,'size' => {'packed' => 9038,'unpacked' => 33882},'testers' => {'fail' => 1},'uses' => ['Carp','Config','Cwd','Exporter','File::Find','strict','vars']},'Class-Trigger-0.08.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Mixin to add / call inheritable triggers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 164,'pod' => 146,'pod_errors' => 0,'total' => 310,'with_comments' => 10},'releases' => 6,'requires' => ['Class-Data-Inheritable-0.02.tar.gz','IO-stringy-2.108.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Data::Inheritable' => '0.02','IO::Scalar' => 0,'Test::More' => '0.32'},'requires_recursive' => ['Class-Data-Inheritable-0.02.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5331,'unpacked' => 16493},'testers' => {'pass' => 11},'uses' => ['Class::Data::Inheritable','strict','vars']},'Class-Virtual-0.03.tar.gz' => {'author' => 'MSCHWERN','description' => 'Base class for virtual base classes.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 217,'pod' => 121,'pod_errors' => 0,'total' => 338,'with_comments' => 13},'releases' => 3,'requires' => ['Carp-Assert-0.17.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-ISA-0.32.tar.gz'],'requires_module' => {'Carp::Assert' => '0.1','Class::Data::Inheritable' => '0.02','Class::ISA' => '0.31'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-ISA-0.32.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5556,'unpacked' => 18056},'testers' => {'pass' => 23},'uses' => ['Carp','Carp::Assert','Class::Data::Inheritable','Class::ISA','strict','vars']},'Class-Visitor-0.02.tar.gz' => {'author' => 'KMACLEOD','description' => 'Visitor and Iterator extensions to Class::Template','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 355,'pod' => 127,'pod_errors' => 0,'total' => 482,'with_comments' => 40},'releases' => 2,'size' => {'packed' => 6290,'unpacked' => 18555},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['5.000','Class::Template','Exporter','strict','vars']},'Class-Void-0.05.tar.gz' => {'author' => 'MALTEU','description' => 'A class that stringifies to nothing for whatever you do with it','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 54,'pod' => 54,'pod_errors' => 0,'total' => 108,'with_comments' => 8},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Simple' => '0.45'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2782,'unpacked' => 5184},'testers' => {'pass' => 2},'uses' => ['strict','vars','warnings']},'Class-WeakSingleton-1.02.tar.gz' => {'author' => 'JJORE','description' => 'A Singleton that expires when all the references to it expire','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 114,'pod' => 172,'pod_errors' => 0,'total' => 286,'with_comments' => 35},'releases' => 3,'size' => {'packed' => 5732,'unpacked' => 21149},'testers' => {'pass' => 1},'uses' => ['strict','vars']},'Class-WhiteHole-0.04.tar.gz' => {'author' => 'MSCHWERN','description' => 'Treat unhandled method calls as errors','files' => ['Makefile.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 39,'pod_errors' => 0,'total' => 89,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 3279,'unpacked' => 5994},'testers' => {'pass' => 1},'uses' => ['5','strict','vars']},'Class-Wrap-1.0.tar.gz' => {'author' => 'SIMON','description' => 'Proxy an entire class\'s methods.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 37,'pod' => 36,'pod_errors' => 0,'total' => 73,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2462,'unpacked' => 4148},'testers' => {'pass' => 5},'uses' => ['Exporter','strict','warnings']},'Class-Wrapper-0.22.tar.gz' => {'author' => 'HEMA','description' => 'Decorator base class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 104,'pod_errors' => 0,'total' => 233,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 3904,'unpacked' => 10159},'testers' => {'pass' => 5},'uses' => ['5.008','Carp','Switch','strict','warnings']},'Class-XPath-1.1.tar.gz' => {'author' => 'SAMTREGAR','description' => 'adds xpath matching to object trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 327,'pod' => 227,'pod_errors' => 0,'total' => 554,'with_comments' => 39},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Test::More' => '0.47'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9319,'unpacked' => 29876},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','constant','strict','warnings']},'ClassEHierarchy-0.6.tar.gz' => {'author' => 'CORLISS','description' => 'Base class aggregating several OO aspects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 712,'pod' => 460,'pod_errors' => 0,'total' => 1172,'with_comments' => 67},'releases' => 1,'size' => {'packed' => 18460,'unpacked' => 55737},'testers' => {'pass' => 10},'uses' => ['Carp','Exporter','strict','vars']},'ClearCase-Argv-1.18.tar.gz' => {'author' => 'DSB','description' => 'ClearCase-specific subclass of Argv','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 623,'pod' => 190,'pod_errors' => 0,'total' => 813,'with_comments' => 70},'releases' => 24,'requires' => ['Argv-1.10.tar.gz'],'requires_module' => {'Argv' => '1.09'},'requires_recursive' => ['Argv-1.10.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 32915,'unpacked' => 96341},'testers' => {'pass' => 1},'uses' => ['Argv','Win32::OLE','strict']},'ClearCase-Attache-0.01.tar.gz' => {'author' => 'ALFO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 209,'pod' => 134,'pod_errors' => 0,'total' => 343,'with_comments' => 35},'releases' => 1,'requires' => ['libwin32-0.191.zip','perl-5.8.0.tar.gz'],'requires_module' => {'Symbol' => '0.0','Win32' => '0.0'},'requires_recursive' => ['libwin32-0.191.zip','perl-5.8.0.tar.gz'],'size' => {'packed' => 4855,'unpacked' => 13572},'testers' => {},'uses' => ['Carp','Symbol','Win32','strict','vars']},'ClearCase-CRDB-0.10.tar.gz' => {'author' => 'DSB','description' => 'base class for ClearCase config-record analysis','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 482,'pod' => 214,'pod_errors' => 0,'total' => 696,'with_comments' => 19},'releases' => 8,'requires' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz'],'requires_module' => {'Data::Dumper' => '2.101','File::Spec' => '0.82'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 17285,'unpacked' => 59241},'testers' => {'fail' => 1,'tests' => '1'},'uses' => ['Clone','Data::Denter','Data::Dumper','File::Spec','Storable','strict']},'ClearCase-ClearPrompt-1.31.tar.gz' => {'author' => 'DSB','description' => 'Handle clearprompt in a portable, convenient way','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 846,'pod' => 254,'pod_errors' => 0,'total' => 1100,'with_comments' => 143},'releases' => 14,'size' => {'packed' => 19775,'unpacked' => 51605},'testers' => {'pass' => 1},'uses' => ['5.001','Carp','Cwd','Exporter','File::Spec','Sys::Hostname','strict']},'ClearCase-Region-1.01.tar.gz' => {'author' => 'LESPAUL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1010,'pod' => 0,'pod_errors' => 0,'total' => 1010,'with_comments' => 138},'releases' => 2,'requires' => ['Log-Log4perl-0.35.tar.gz'],'requires_module' => {'Log::Log4perl' => '0.31'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Log-Log4perl-0.35.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 275410,'unpacked' => 528825},'testers' => {'pass' => 1},'uses' => ['Carp','ClearCase::Region','Log::Log4perl','Win32::Registry','strict','vars']},'ClearCase-SyncTree-0.30.tar.gz' => {'author' => 'DSB','description' => 'Synchronize a tree of files with a tree of elements','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1001,'pod' => 241,'pod_errors' => 2,'total' => 1242,'with_comments' => 64},'releases' => 18,'requires' => ['Argv-1.10.tar.gz','ClearCase-Argv-1.18.tar.gz','File-Spec-0.82.tar.gz'],'requires_module' => {'Argv' => 1,'ClearCase::Argv' => 1,'File::Spec' => '0.82'},'requires_recursive' => ['Argv-1.10.tar.gz','ClearCase-Argv-1.18.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 29824,'unpacked' => 84559},'testers' => {'pass' => 1},'uses' => ['5.004','ClearCase::Argv','Clone','Cwd','File::Basename','File::Compare','File::Copy','File::Find','File::Path','File::Spec','Win32::TieRegistry','strict','vars']},'ClearCase-Wrapper-1.09.tar.gz' => {'author' => 'DSB','description' => 'general-purpose wrapper for B<cleartool>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1087,'pod' => 158,'pod_errors' => 0,'total' => 1245,'with_comments' => 192},'releases' => 19,'requires' => ['Argv-1.10.tar.gz','ClearCase-Argv-1.18.tar.gz','ClearCase-ClearPrompt-1.31.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz'],'requires_module' => {'Argv' => '1.06','ClearCase::Argv' => '1.06','ClearCase::ClearPrompt' => '1.24','File::Spec' => '0.82','Getopt::Long' => '2.17'},'requires_recursive' => ['Argv-1.10.tar.gz','ClearCase-Argv-1.18.tar.gz','ClearCase-ClearPrompt-1.31.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 72288,'unpacked' => 111164},'testers' => {'pass' => 1},'uses' => ['5.006','AutoLoader','ClearCase::ClearPrompt','Config','Cwd','File::Basename','File::Spec','Getopt::Long','strict','vars']},'ClearCase-Wrapper-DSB-1.09.tar.gz' => {'author' => 'DSB','description' => 'David Boyce\'s contributed cleartool wrapper functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1210,'pod' => 189,'pod_errors' => 0,'total' => 1399,'with_comments' => 103},'releases' => 8,'requires' => ['ClearCase-Wrapper-1.09.tar.gz'],'requires_module' => {'ClearCase::Wrapper' => 1},'requires_recursive' => ['Argv-1.10.tar.gz','ClearCase-Argv-1.18.tar.gz','ClearCase-ClearPrompt-1.31.tar.gz','ClearCase-Wrapper-1.09.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 17468,'unpacked' => 46931},'testers' => {'pass' => 1},'uses' => ['AutoLoader','ClearCase::ClearPrompt','Cwd','File::Basename','File::Copy','File::Spec','Win32::TieRegistry','strict','vars']},'Clone-0.13.tar.gz' => {'author' => 'RDF','description' => 'Recursive copy of nested objects','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 35,'pod' => 53,'pod_errors' => 0,'total' => 88,'with_comments' => 6},'releases' => 7,'size' => {'packed' => 8529,'unpacked' => 27458},'testers' => {'fail' => 1,'pass' => 33,'tests' => '48'},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Closures-1.2.tgz' => {'author' => 'ABIGAIL','description' => 'Object Oriented Programming using Closures.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 151,'pod' => 168,'pod_errors' => 0,'total' => 319,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 4496,'unpacked' => 12779},'testers' => {'pass' => 3},'uses' => ['Carp']},'Cluster-Init-0.211.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2908,'pod' => 287,'pod_errors' => 1,'total' => 3195,'with_comments' => 346},'releases' => 6,'requires' => ['Carp-Assert-0.17.tar.gz','Data-Dump-0.04.tar.gz','Event-0.87.tar.gz','Event-Stats-0.7.tar.gz','IPC-LDT-2.03.tgz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'Carp::Assert' => 0,'Data::Dump' => 0,'Event' => 0,'Event::Stats' => 0,'IPC::LDT' => 0,'Time::HiRes' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Data-Dump-0.04.tar.gz','Event-0.87.tar.gz','Event-Stats-0.7.tar.gz','File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','IPC-LDT-2.03.tgz','Storable-2.07.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'testers' => {'fail' => 2,'tests' => '228'},'uses' => ['Carp','Carp::Assert','Data::Dump','Event','Event::Stats','Exporter','IO::Socket','IPC::LDT','NetServer::Portal','POSIX','Storable','Time::HiRes','constant','strict','warnings']},'Cmenu-1.1.tgz' => {'author' => 'DREWF','description' => 'Curses-based menu and data entry functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2812,'pod' => 134,'pod_errors' => 0,'total' => 2946,'with_comments' => 1131},'releases' => 2,'size' => {'packed' => 79104,'unpacked' => 335675},'testers' => {'fail' => 1,'tests' => '0','unknown' => 3},'uses' => ['Curses','Exporter','Text::Wrap','strict','vars']},'Code-Perl-0.03.tar.gz' => {'author' => 'FDALY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 797,'pod' => 280,'pod_errors' => 1,'total' => 1077,'with_comments' => 23},'releases' => 3,'requires' => ['Class-MethodMaker-1.10.tar.gz','Test-Deep-0.06.tar.gz'],'requires_module' => {'Class::MethodMaker' => 0,'Test::Deep' => '0.05'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Deep-0.06.tar.gz','Test-NoWarnings-0.05.tar.gz','Test-Tester-0.06.tar.gz'],'size' => {'packed' => 17580,'unpacked' => 51931},'testers' => {'pass' => 1},'uses' => ['','Carp','Data::Dumper','Exporter','Test::Deep','Test::More','strict','warnings']},'CodeBase-0.86.tar.gz' => {'author' => 'ANDREWF','description' => 'Perl module for accessing dBASE files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 370,'pod' => 771,'pod_errors' => 0,'total' => 1141,'with_comments' => 67},'releases' => 1,'size' => {'packed' => 30862,'unpacked' => 112157},'testers' => {},'uses' => ['DynaLoader','Exporter','strict','vars']},'Color-Calc-0.1.tar.gz' => {'author' => 'CFAERBER','description' => 'Simple calculations with RGB colors.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 134,'pod_errors' => 0,'total' => 301,'with_comments' => 2},'releases' => 2,'requires' => ['Graphics-ColorNames-0.32.tar.gz'],'requires_module' => {'Graphics::ColorNames' => '0.32'},'requires_recursive' => ['Graphics-ColorNames-0.32.tar.gz'],'size' => {'packed' => 3142,'unpacked' => 7124},'testers' => {'pass' => 3},'uses' => ['Exporter','Graphics::ColorNames','strict']},'Color-Rgb-1.4.tar.gz' => {'author' => 'SHERZODR','description' => 'Simple rgb.txt parsing class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 247,'pod' => 96,'pod_errors' => 0,'total' => 343,'with_comments' => 37},'releases' => 4,'size' => {'packed' => 10348,'unpacked' => 34127},'testers' => {'pass' => 3},'uses' => ['5.003','Carp','Fcntl','strict','vars']},'Color-Spectrum-1.00.tar.gz' => {'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 109,'pod' => 53,'pod_errors' => 0,'total' => 162,'with_comments' => 8},'releases' => 2,'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','POSIX','strict','vars']},'CompBio-0.47.tar.gz' => {'author' => 'SEANQ','description' => 'Core library for some basic methods useful in computational biology/bioinformatics.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2071,'pod' => 708,'pod_errors' => 0,'total' => 2779,'with_comments' => 274},'releases' => 8,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.07'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 63798,'unpacked' => 215278},'testers' => {'fail' => 1,'pass' => 6},'uses' => ['5.005_62','Carp','DBI','Exporter','Tie::Array','diagnostics','strict','vars','warnings']},'Compress-Bzip2-1.00.tar.gz' => {'author' => 'AZEMGI','description' => 'Interface to the Bzip2 compression library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 55,'pod' => 55,'pod_errors' => 1,'total' => 110,'with_comments' => 6},'releases' => 4,'size' => {'packed' => 11136,'unpacked' => 27657},'testers' => {'fail' => 4,'pass' => 3},'uses' => ['5.003_05','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Compress-LZF-0.1045.tar.gz' => {'author' => 'MLEHMANN','description' => 'Fast/Free/Small data compression library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 81,'pod_errors' => 0,'total' => 131,'with_comments' => 0},'releases' => 13,'size' => {'packed' => 19626,'unpacked' => 59200},'testers' => {'pass' => 7},'uses' => ['DynaLoader','Exporter']},'Compress-LZO-1.08.tar.gz' => {'author' => 'MFX','description' => 'Interface to the LZO compression library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 103,'pod' => 82,'pod_errors' => 1,'total' => 185,'with_comments' => 37},'releases' => 2,'size' => {'packed' => 12480,'unpacked' => 36501},'testers' => {},'uses' => ['5.003_05','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Compress-LZV1-0.04.tar.gz' => {'author' => 'MLEHMANN','description' => 'Leight-weight Lev-Zimpel-Vogt compression','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 53,'pod_errors' => 0,'total' => 96,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 15767,'unpacked' => 48838},'testers' => {'pass' => 12},'uses' => ['DynaLoader','Exporter']},'Compress-LZW-0.01.tar.gz' => {'author' => 'MHOWARD','description' => 'Pure perl implementation of LZW','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 62,'pod_errors' => 0,'total' => 178,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 3106,'unpacked' => 8569},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Exporter','strict','vars','warnings']},'Compress-LeadingBlankSpaces-0.01.tar.gz' => {'author' => 'SLAVA','description' => 'Perl class to compress leading blank spaces in (HTML, JavaScript, etc.) web content.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 67,'pod' => 53,'pod_errors' => 0,'total' => 120,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 2787,'unpacked' => 6833},'testers' => {'pass' => 8},'uses' => ['5.004','strict','vars']},'Compress-PPMd-0.08.tar.gz' => {'author' => 'SALVA','description' => 'Interface to PPMd compression library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 163,'pod_errors' => 0,'total' => 239,'with_comments' => 0},'releases' => 7,'requires' => ['ExtUtils-MakeMaker-6.05.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'ExtUtils::MakeMaker' => '6.05','Test::More' => 0},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 28207,'unpacked' => 91458},'testers' => {'fail' => 1,'pass' => 1,'tests' => '64'},'uses' => ['5.006','Exporter','XSLoader','constant','strict','warnings']},'Compress-SelfExtracting-0.04.tgz' => {'author' => 'SEANO','description' => '- create compressed scripts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 767,'pod' => 97,'pod_errors' => 0,'total' => 864,'with_comments' => 28},'releases' => 4,'requires' => ['Digest-MD5-2.26.tar.gz','Filter-Simple-0.78.tar.gz'],'requires_module' => {'Digest::MD5' => '0.01','Filter::Simple' => '0.01'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 8000,'unpacked' => 22886},'testers' => {'pass' => 3},'uses' => ['Digest::MD5','Exporter','vars']},'Compress-Zlib-1.22.tar.gz' => {'author' => 'PMQS','description' => 'Interface to the Info-Zip zlib library','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 607,'pod' => 564,'pod_errors' => 1,'total' => 1171,'with_comments' => 29},'releases' => 26,'size' => {'packed' => 36781,'unpacked' => 133584},'testers' => {'pass' => 5},'uses' => ['5.004','AutoLoader','Carp','DynaLoader','Exporter','IO::Handle','constant','strict','vars','warnings']},'Concurrent-Object-1.07.tar.gz' => {'author' => 'VIPUL','description' => 'Concurrent Objects in Perl.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 731,'pod' => 120,'pod_errors' => 0,'total' => 851,'with_comments' => 90},'releases' => 3,'requires' => ['Class-Loader-2.02.tar.gz','Data-Dumper-2.101.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'Class::Loader' => '2.00','Data::Dumper' => 0,'MIME::Base64' => 0,'Storable' => 0},'requires_recursive' => ['Class-Loader-2.02.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10397,'unpacked' => 37270},'testers' => {'fail' => 2,'pass' => 2,'tests' => '62'},'uses' => ['Class::Loader','Data::Dumper','Exporter','IO::Handle','IO::Pipe','MIME::Base64','Storable','lib','overload','strict','vars']},'ConfInt-1.0.1.tar.gz' => {'author' => 'CGERNHAR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 381,'pod' => 45,'pod_errors' => 0,'total' => 426,'with_comments' => 57},'releases' => 2,'size' => {'packed' => 4136,'unpacked' => 18708},'testers' => {'pass' => 7},'uses' => ['Exporter']},'Config-Abstract-0.12.tar.gz' => {'author' => 'AVAJADI','description' => 'Abstractions for configfiles in many formats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 422,'pod' => 264,'pod_errors' => 2,'total' => 686,'with_comments' => 113},'releases' => 4,'size' => {'packed' => 8477,'unpacked' => 27610},'testers' => {'pass' => 11},'uses' => ['5.006','AutoLoader','Data::Dumper','Exporter','strict','warnings']},'Config-Access-0.02.tar.gz' => {'author' => 'TIMPOTTER','description' => 'Perform simple access control','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 525,'pod' => 161,'pod_errors' => 0,'total' => 686,'with_comments' => 112},'releases' => 2,'size' => {'packed' => 6232,'unpacked' => 20167},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['constant','vars']},'Config-ApacheFormat-1.1.tar.gz' => {'author' => 'SAMTREGAR','description' => 'use Apache format config files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 446,'pod' => 282,'pod_errors' => 1,'total' => 728,'with_comments' => 61},'releases' => 2,'requires' => ['Class-MethodMaker-1.10.tar.gz','File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Class::MethodMaker' => '1.08','File::Spec' => '0.82','Scalar::Util' => '1.07','Text::Balanced' => '1.89'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 36188,'unpacked' => 603572},'testers' => {'pass' => 1},'uses' => ['5.006001','Carp','File::Spec','Scalar::Util','Text::Balanced','strict','warnings']},'Config-Auto-0.03.tar.gz' => {'author' => 'SIMON','description' => 'Magical config file parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 269,'pod' => 90,'pod_errors' => 0,'total' => 359,'with_comments' => 22},'releases' => 3,'requires' => ['Config-IniFiles-2.38.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'Config::IniFiles' => 0,'XML::Simple' => 0},'requires_recursive' => ['Config-IniFiles-2.38.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz'],'size' => {'packed' => 5709,'unpacked' => 16412},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Config::IniFiles','File::Spec::Functions','XML::Simple','strict','warnings']},'Config-Cfe-1.50.tar.gz' => {'author' => 'JHAGG','description' => 'File configuration module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 959,'pod' => 241,'pod_errors' => 0,'total' => 1200,'with_comments' => 28},'releases' => 1,'size' => {'packed' => 9770,'unpacked' => 32665},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','strict','vars']},'Config-Crontab-1.02.tar.gz' => {'author' => 'SCOTTW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1366,'pod' => 1384,'pod_errors' => 0,'total' => 2750,'with_comments' => 121},'releases' => 2,'size' => {'packed' => 31427,'unpacked' => 135987},'testers' => {'pass' => 2},'uses' => ['Carp','Fcntl','File::Temp','constant','strict','vars']},'Config-Directory-0.04.tar.gz' => {'author' => 'GAVINC','description' => 'OO hash-based interface to directories of files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 241,'pod' => 134,'pod_errors' => 0,'total' => 375,'with_comments' => 28},'releases' => 4,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Basename' => 0,'File::Spec' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8542,'unpacked' => 20377},'testers' => {'pass' => 2},'uses' => ['5.000','File::Basename','File::Spec','strict','vars']},'Config-Fast-1.03.tar.gz' => {'author' => 'NWIGER','description' => 'extremely fast configuration file reader / parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 109,'pod' => 102,'pod_errors' => 0,'total' => 211,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 5922,'unpacked' => 16562},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','strict','vars']},'Config-Find-0.08.tar.gz' => {'author' => 'SALVA','description' => 'Find configuration files in the native OS fashion','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 654,'pod' => 572,'pod_errors' => 0,'total' => 1226,'with_comments' => 12},'releases' => 10,'requires' => ['File-HomeDir-0.05.tar.gz','File-Spec-0.82.tar.gz','File-Which-0.05.tar.gz'],'requires_module' => {'File::HomeDir' => 0,'File::Spec' => 0,'File::Which' => 0},'requires_recursive' => ['File-HomeDir-0.05.tar.gz','File-Spec-0.82.tar.gz','File-Which-0.05.tar.gz'],'size' => {'packed' => 7835,'unpacked' => 37406},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Config::Find::Any','Config::Find::Unix','Config::Find::Win2k','Config::Find::Win95','Config::Find::Win98','Config::Find::WinCE','Config::Find::WinME','Config::Find::WinNT','Config::Find::WinXP','File::HomeDir','File::Spec','File::Which','IO::File','Win32','strict','warnings']},'Config-Find-0.10.tar.gz' => {'author' => 'SALVA','description' => 'Find configuration files in the native OS fashion','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 882,'pod' => 650,'pod_errors' => 0,'total' => 1532,'with_comments' => 15},'releases' => 10,'requires' => ['File-HomeDir-0.05.tar.gz','File-Spec-0.82.tar.gz','File-Which-0.05.tar.gz'],'requires_module' => {'File::HomeDir' => 0,'File::Spec' => 0,'File::Which' => 0},'requires_recursive' => ['File-HomeDir-0.05.tar.gz','File-Spec-0.82.tar.gz','File-Which-0.05.tar.gz'],'size' => {'packed' => 8069,'unpacked' => 34334},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','Config::Find::Win2k3','File::HomeDir','File::Spec','File::Which','IO::File','Win32','strict','warnings']},'Config-Framework-1.05.tar.gz' => {'author' => 'AHICOX','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 540,'pod' => 346,'pod_errors' => 0,'total' => 886,'with_comments' => 98},'releases' => 6,'requires' => ['Crypt-CBC-2.08.tar.gz','Data-DumpXML-1.05.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Crypt::CBC' => '2.02','Data::DumpXML::Parser' => '1.01','File::Copy' => '2.03'},'requires_recursive' => ['Array-RefElem-0.02.tar.gz','Crypt-CBC-2.08.tar.gz','Data-DumpXML-1.05.tar.gz','Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz','XML-Parser-2.31.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12719,'unpacked' => 38338},'testers' => {'pass' => 3},'uses' => ['5.6.0','AutoLoader','Carp','Crypt::CBC','Data::DumpXML::Parser','Data::DumpXML::dump_xml','Exporter','File::Copy']},'Config-FreeForm-0.01.tar.gz' => {'author' => 'BTROTT','description' => 'Provide in-memory configuration data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 181,'pod' => 109,'pod_errors' => 0,'total' => 290,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 5355,'unpacked' => 12928},'testers' => {'pass' => 10},'uses' => ['Carp','Data::Dumper','strict','vars']},'Config-General-2.19.tar.gz' => {'author' => 'TLINDEN','description' => 'Generic Config Module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1756,'pod' => 945,'pod_errors' => 0,'total' => 2701,'with_comments' => 339},'releases' => 39,'size' => {'packed' => 33863,'unpacked' => 107734},'testers' => {'pass' => 3},'uses' => ['Carp','Config::General','Config::General::Interpolated','Exporter','File::Spec::Functions','FileHandle','strict','vars']},'Config-General-2.21.tar.gz' => {'author' => 'TLINDEN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1806,'pod' => 963,'pod_errors' => 0,'total' => 2769,'with_comments' => 347},'releases' => 39,'size' => {'packed' => 34707,'unpacked' => 110374},'testers' => {'pass' => 2},'uses' => ['Carp','Config::General::Extended','Exporter','File::Spec::Functions','FileHandle','strict','vars']},'Config-IniFiles-2.38.tar.gz' => {'author' => 'WADG','description' => 'Read/Write INI-Style configuration files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1715,'pod' => 664,'pod_errors' => 0,'total' => 2379,'with_comments' => 393},'releases' => 28,'size' => {'packed' => 36846,'unpacked' => 125616},'testers' => {'pass' => 4},'uses' => ['5.004','Carp','Symbol','strict','vars']},'Config-IniFiles-Import-1.000.tar.gz' => {'author' => 'JVBSOFT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 364,'pod' => 415,'pod_errors' => 1,'total' => 779,'with_comments' => 115},'releases' => 5,'requires' => ['Config-IniFiles-2.38.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Config::IniFiles' => '2.29','Date::Language' => 0,'FindBin' => 0},'requires_recursive' => ['Config-IniFiles-2.38.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11154,'unpacked' => 61409},'testers' => {'pass' => 1},'uses' => ['Carp','Config::IniFiles','Date::Language','FindBin','strict','vars']},'Config-IniHash-2.3.tar.gz' => {'author' => 'JENDA','description' => 'Perl extension for reading and writing INI files version 2.3','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 269,'pod' => 105,'pod_errors' => 0,'total' => 374,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 4077,'unpacked' => 10873},'testers' => {'fail' => 2,'pass' => 3},'uses' => ['Carp','Exporter','Hash::Case::Lower','Hash::Case::Preserve','Hash::Case::Upper','Hash::WithDefaults','IO::Scalar','Symbol','strict','vars']},'Config-Manager-1.7.tar.gz' => {'author' => 'STBEY','description' => 'Configuration Manager','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 3950,'pod' => 1984,'pod_errors' => 0,'total' => 5934,'with_comments' => 410},'releases' => 8,'requires' => ['Digest-MD5-2.26.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Digest::MD5' => '0.0','Fcntl' => '0.0','File::Compare' => '0.0','File::Copy' => '0.0','Net::SMTP' => '0.0','Symbol' => '0.0'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 311261,'unpacked' => 593219},'testers' => {'pass' => 2},'uses' => ['Digest::MD5','Exporter','Fcntl','File::Compare','File::Copy','Net::SMTP','Symbol','strict','vars']},'Config-Merge-0.02.tar.gz' => {'author' => 'HASANT','description' => 'Merge configurations from various sources','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 199,'pod' => 185,'pod_errors' => 0,'total' => 384,'with_comments' => 17},'releases' => 2,'requires' => ['Sub-Usage-0.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Sub::Usage' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Sub-Usage-0.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6960,'unpacked' => 21928},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Exporter','Sub::Usage','Text::ParseWords','strict','warnings']},'Config-Objective-0.9.1.tar.gz' => {'author' => 'ROTH','description' => 'Perl module for parsing object-oriented config files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1586,'pod' => 706,'pod_errors' => 0,'total' => 2292,'with_comments' => 319},'releases' => 6,'requires' => ['Parse-Yapp-1.05.tar.gz','ParseLex-2.15.tar.gz'],'requires_module' => {'Parse::Lex' => '2.15','Parse::Yapp::Driver' => '1.05'},'requires_recursive' => ['Parse-Yapp-1.05.tar.gz','ParseLex-2.15.tar.gz'],'size' => {'packed' => 17633,'unpacked' => 81170},'testers' => {},'uses' => ['5.006','Config::Objective::DataType','Config::Objective::List','Config::Objective::Parser','Parse::Lex','integer','overload','strict','warnings']},'Config-Objective-0.9.tar.gz' => {'author' => 'ROTH','description' => 'Perl module for parsing object-oriented config files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1586,'pod' => 706,'pod_errors' => 0,'total' => 2292,'with_comments' => 319},'releases' => 6,'requires' => ['Parse-Yapp-1.05.tar.gz','ParseLex-2.15.tar.gz'],'requires_module' => {'Parse::Lex' => '2.15','Parse::Yapp::Driver' => '1.05'},'requires_recursive' => ['Parse-Yapp-1.05.tar.gz','ParseLex-2.15.tar.gz'],'size' => {'packed' => 17598,'unpacked' => 80931},'testers' => {},'uses' => ['5.006','Config::Objective::Parser','Parse::Lex','integer','overload','strict','warnings']},'Config-PkgConfig-0.01.tar.gz' => {'author' => 'AMBS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 36,'pod_errors' => 0,'total' => 100,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 1952,'unpacked' => 3496},'testers' => {},'uses' => ['5.006001','Exporter','strict','warnings']},'Config-Pod-0.01.tar.gz' => {'author' => 'JSMITH','description' => 'Configuration files in POD format','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 120,'pod_errors' => 1,'total' => 236,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2825,'unpacked' => 8418},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','strict']},'Config-Properties-0.51.tar.gz' => {'author' => 'SALVA','description' => 'Configuration using Java style properties','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 337,'pod' => 70,'pod_errors' => 0,'total' => 407,'with_comments' => 45},'releases' => 13,'requires' => ['File-Temp-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'requires_module' => {'File::Temp' => 0,'Test::More' => 0,'Text::Wrap' => '2001.0929'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7558,'unpacked' => 21171},'testers' => {'pass' => 2},'uses' => ['Carp','IO::Handle','Text::Wrap','strict','warnings']},'Config-Properties-Simple-0.07.tar.gz' => {'author' => 'SALVA','description' => 'Perl extension to manage configuration files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 201,'pod' => 183,'pod_errors' => 0,'total' => 384,'with_comments' => 1},'releases' => 7,'requires' => ['Config-Find-0.10.tar.gz','Config-Properties-0.51.tar.gz'],'requires_module' => {'Config::Find' => '0.06','Config::Properties' => '0.43'},'requires_recursive' => ['Config-Find-0.10.tar.gz','Config-Properties-0.51.tar.gz','File-HomeDir-0.05.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','File-Which-0.05.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4463,'unpacked' => 11765},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Config::Find','Config::Properties','strict','warnings']},'Config-ReadAndCheck-0.03.tar.gz' => {'author' => 'TPABA','description' => 'Perl module for parsing generic config files conforms to predefined line-by-line-based format. I<Version 0.03>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 637,'pod' => 304,'pod_errors' => 0,'total' => 941,'with_comments' => 27},'releases' => 3,'size' => {'packed' => 8006,'unpacked' => 26776},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','IO::File','Tie::IxHash','strict','vars']},'Config-Secure-0.0.1.tar.gz' => {'author' => 'SUAVEANT','description' => 'Perl extension for scripts run with PSC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 194,'pod' => 64,'pod_errors' => 0,'total' => 258,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 19549,'unpacked' => 59022},'testers' => {'pass' => 2},'uses' => ['5.00503','AutoLoader','Exporter','Fcntl','strict','vars']},'Config-Simple-4.55.tar.gz' => {'author' => 'SHERZODR','description' => 'simple configuration file class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1063,'pod' => 471,'pod_errors' => 0,'total' => 1534,'with_comments' => 92},'releases' => 37,'size' => {'packed' => 22911,'unpacked' => 75847},'testers' => {'pass' => 6},'uses' => ['AutoLoader','Carp','Data::Dumper','Fcntl','Text::ParseWords','diagnostics','strict','vars']},'Config-Tiny-1.tar.gz' => {'author' => 'ADAMK','description' => 'Read/Write .ini style files with as little code as possible','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 131,'pod' => 106,'pod_errors' => 0,'total' => 237,'with_comments' => 18},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'FindBin' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11837,'unpacked' => 33206},'testers' => {'pass' => 3},'uses' => ['5.005','strict','vars']},'Config-Vars-0.01.tar.gz' => {'author' => 'ROODE','description' => 'A module for keeping configuration variables in a central perl file.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 255,'pod' => 153,'pod_errors' => 0,'total' => 408,'with_comments' => 37},'releases' => 1,'size' => {'packed' => 7489,'unpacked' => 20256},'testers' => {'pass' => 2},'uses' => ['Carp','Filter::Simple','strict','vars']},'Config-Yacp-1.15.tar.gz' => {'author' => 'TSTANLEY','description' => 'Yet Another Configuration file Parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 301,'pod' => 149,'pod_errors' => 0,'total' => 450,'with_comments' => 6},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz','Parse-RecDescent-1.94.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => 0,'Fcntl' => 0,'Parse::RecDescent' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5649,'unpacked' => 17454},'testers' => {'pass' => 5},'uses' => ['Carp','Data::Dumper','Fcntl','Parse::RecDescent','strict','vars']},'ConfigReader-0.5.tar.gz' => {'author' => 'AMW','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 756,'pod' => 232,'pod_errors' => 2,'total' => 988,'with_comments' => 97},'releases' => 1,'size' => {'packed' => 17592,'unpacked' => 56203},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','strict']},'ConfigReader-Simple-1.16.tar.gz' => {'author' => 'PETDANCE','description' => 'Read simple configuration file formats','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 415,'pod' => 162,'pod_errors' => 0,'total' => 577,'with_comments' => 12},'releases' => 11,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7313,'unpacked' => 21896},'testers' => {'pass' => 3},'uses' => ['Carp','strict','subs','vars']},'Continuus-0.1.tar.gz' => {'author' => 'HENKE','description' => 'Interface to Continuus Code Management tool','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 229,'pod' => 127,'pod_errors' => 0,'total' => 356,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 8561,'unpacked' => 31599},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['strict']},'ControlX10-CM11-2.09.tar.gz' => {'author' => 'BBIRTH','description' => 'Perl extension for X10 \'ActiveHome\' Controller','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 497,'pod' => 186,'pod_errors' => 0,'total' => 683,'with_comments' => 90},'releases' => 4,'size' => {'packed' => 15182,'unpacked' => 50395},'testers' => {'pass' => 8},'uses' => ['Exporter','vars']},'ControlX10-CM17-0.07.tar.gz' => {'author' => 'BBIRTH','description' => 'inexpensive RF transmit-only X10','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 157,'pod' => 92,'pod_errors' => 0,'total' => 249,'with_comments' => 25},'releases' => 2,'size' => {'packed' => 8507,'unpacked' => 26432},'testers' => {'pass' => 9},'uses' => ['Exporter','strict','vars']},'Convert-ASCII-Armour-1.4.tar.gz' => {'author' => 'VIPUL','description' => 'Convert binary octets to ASCII armoured msg.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 173,'pod' => 111,'pod_errors' => 0,'total' => 284,'with_comments' => 18},'releases' => 3,'requires' => ['Compress-Zlib-1.22.tar.gz','Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'Compress::Zlib' => 0,'Digest::MD5' => 0,'MIME::Base64' => 0},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 6002,'unpacked' => 21813},'testers' => {'pass' => 15},'uses' => ['Compress::Zlib','Digest::MD5','MIME::Base64','lib','strict','vars']},'Convert-ASN1-0.17.tar.gz' => {'author' => 'GBARR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3036,'pod' => 354,'pod_errors' => 0,'total' => 3390,'with_comments' => 272},'releases' => 14,'size' => {'packed' => 44378,'unpacked' => 164901},'testers' => {'pass' => 4},'uses' => ['5.004','Carp','Convert::ASN1::IO','Convert::ASN1::_encode','Encode','Exporter','POSIX','Socket','Time::Local','strict','utf8','vars']},'Convert-AcrossLite-0.06.tar.gz' => {'author' => 'DSPARLING','description' => 'Convert binary AcrossLite puzzle files to text.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 781,'pod' => 252,'pod_errors' => 0,'total' => 1033,'with_comments' => 141},'releases' => 5,'size' => {'packed' => 8004,'unpacked' => 45211},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'Convert-BER-1.3101.tar.gz' => {'author' => 'GBARR','description' => 'Class for encoding/decoding BER messages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2146,'pod' => 756,'pod_errors' => 0,'total' => 2902,'with_comments' => 170},'releases' => 13,'size' => {'packed' => 25362,'unpacked' => 101120},'testers' => {'fail' => 3,'pass' => 19,'tests' => '401'},'uses' => ['Carp','Math::BigInt','Math::BigInteger','POSIX','Socket','Time::Local','bytes','integer','strict','vars']},'Convert-Base32-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Encoding and decoding of base32 strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 115,'pod' => 43,'pod_errors' => 0,'total' => 158,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 2358,'unpacked' => 5594},'testers' => {'pass' => 11},'uses' => ['Exporter','strict','vars']},'Convert-Bencode-1.02-20032506.tar.gz' => {'author' => 'ORCLEV','description' => 'conversion to/from bencoded strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 45,'pod_errors' => 0,'total' => 170,'with_comments' => 1},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.45'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10445,'unpacked' => 28716},'testers' => {'pass' => 2},'uses' => ['strict','warnings']},'Convert-BinHex-1.119.tar.gz' => {'author' => 'ERYQ','description' => 'Convert to/from RFC1741 HQX7 (Mac BinHex)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1301,'pod' => 473,'pod_errors' => 0,'total' => 1774,'with_comments' => 271},'releases' => 1,'size' => {'packed' => 84573,'unpacked' => 225436},'testers' => {'pass' => 13},'uses' => ['Carp','Exporter','FileHandle','integer','strict','vars']},'Convert-Binary-C-0.42.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1266,'pod' => 2468,'pod_errors' => 0,'total' => 3734,'with_comments' => 55},'releases' => 17,'testers' => {'pass' => 3},'uses' => ['Carp','DynaLoader','strict','vars']},'Convert-Braille-0.05.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 841,'pod' => 156,'pod_errors' => 0,'total' => 997,'with_comments' => 71},'releases' => 5,'size' => {'packed' => 7803,'unpacked' => 28420},'testers' => {'pass' => 2},'uses' => ['5.006','Convert::Number::Ethiopic','Exporter','strict','utf','vars']},'Convert-BulkDecoder-1.02.tar.gz' => {'author' => 'JV','description' => 'Extract (binary) data from mail and news messages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 654,'pod' => 140,'pod_errors' => 0,'total' => 794,'with_comments' => 71},'releases' => 3,'requires' => ['Digest-MD5-2.26.tar.gz','MIME-tools-5.411a.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Digest::MD5' => 0,'MIME::Parser' => 0,'Test::More' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19006,'unpacked' => 68403},'testers' => {'pass' => 3},'uses' => ['Digest::MD5','MIME::Parser','integer','strict']},'Convert-CEGH-0.02.tar.gz' => {'author' => 'DYACOB','description' => 'Coptic/Ethiopic/Greek/Hebrew Gematria.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 288,'pod' => 114,'pod_errors' => 0,'total' => 402,'with_comments' => 47},'releases' => 2,'requires' => ['Regexp-Ethiopic-0.12.tar.gz'],'requires_module' => {'Regexp::Ethiopic' => '0.10'},'requires_recursive' => ['Regexp-Ethiopic-0.12.tar.gz'],'size' => {'packed' => 6311,'unpacked' => 16769},'testers' => {'pass' => 1},'uses' => ['','Exporter','Regexp::Ethiopic','utf','vars']},'Convert-CharMap-0.01.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Conversion between Unicode Character Maps','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 33,'pod_errors' => 0,'total' => 163,'with_comments' => 11},'releases' => 1,'requires' => ['XML-Simple-2.08.tar.gz','YAML-0.35.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'XML::Simple' => 0,'YAML' => 0,'charnames' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz','YAML-0.35.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3863,'unpacked' => 8535},'testers' => {'pass' => 1},'uses' => ['Convert::CharMap::$subclass','XML::Simple','YAML','charnames','strict']},'Convert-Context-0.501.tar.gz' => {'author' => 'MSCHWARTZ','description' => 'an Attributed Text data type - ALPHA - release $Revision: 1.77 $ $Date: 1998/10/03 22:21:23 $','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 861,'pod' => 355,'pod_errors' => 0,'total' => 1216,'with_comments' => 156},'releases' => 2,'size' => {'packed' => 16129,'unpacked' => 53208},'testers' => {'pass' => 6},'uses' => ['strict']},'Convert-Cyr.tar.gz' => {'author' => 'KDOULEPOV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 35,'pod_errors' => 0,'total' => 124,'with_comments' => 14},'releases' => 1,'size' => {'packed' => 5516,'unpacked' => 17449},'testers' => {'fail' => 1},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Convert-DUDE-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Conversion between Unicode and DUDE','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 223,'pod' => 122,'pod_errors' => 0,'total' => 345,'with_comments' => 5},'releases' => 2,'requires' => ['Unicode-String-2.07.tar.gz'],'requires_module' => {'Unicode::String' => '2.06'},'requires_recursive' => ['MIME-Base64-2.20.tar.gz','Unicode-String-2.07.tar.gz'],'size' => {'packed' => 4384,'unpacked' => 11578},'testers' => {'pass' => 8},'uses' => ['Carp','Exporter','Unicode::String','strict','vars']},'Convert-EBCDIC-0.06.tar.gz' => {'author' => 'CXL','description' => 'ASCII to/from EBCDIC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 118,'pod' => 70,'pod_errors' => 0,'total' => 188,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 4885,'unpacked' => 13084},'testers' => {'pass' => 9},'uses' => ['Exporter','strict','vars']},'Convert-EastAsianWidth-0.02.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Convert between full- and half-width characters','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 542,'pod' => 45,'pod_errors' => 0,'total' => 587,'with_comments' => 24},'releases' => 2,'requires' => ['Unicode-EastAsianWidth-1.01.tar.gz'],'requires_module' => {'Unicode::EastAsianWidth' => '0'},'requires_recursive' => ['Unicode-EastAsianWidth-1.01.tar.gz'],'size' => {'packed' => 7548,'unpacked' => 20991},'testers' => {'pass' => 3},'uses' => ['$self->{path}::$self->{dispatch}','5.006','CPAN','CPANPLUS','Encode','Exporter','ExtUtils::MM_Unix','ExtUtils::MakeMaker','File::Find','Module::Install','Module::Install::Base','Unicode::EastAsianWidth','charnames','inc::Module::Install','strict','vars']},'Convert-Ethiopic-0.12.tar.gz' => {'author' => 'DYACOB','description' => 'Perl extension for the Ethiopic information processing library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 914,'pod' => 160,'pod_errors' => 0,'total' => 1074,'with_comments' => 184},'releases' => 7,'size' => {'packed' => 15460,'unpacked' => 53106},'testers' => {},'uses' => ['5.000','AutoLoader','Convert::Ethiopic','DynaLoader','Exporter','HTML::Entities','strict','vars']},'Convert-Ethiopic-0.20-210102.tar.gz' => {'author' => 'DYACOB','description' => 'Perl extension for the Ethiopic information processing library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1714,'pod' => 366,'pod_errors' => 0,'total' => 2080,'with_comments' => 265},'releases' => 1,'size' => {'packed' => 22020,'unpacked' => 86888},'testers' => {},'uses' => ['5.000','AutoLoader','DynaLoader','Exporter','SafePaths','strict','vars']},'Convert-GeekCode-0.5.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Convert and generate geek code sequences','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 181,'pod' => 45,'pod_errors' => 0,'total' => 226,'with_comments' => 4},'releases' => 1,'requires' => ['Text-Tabs+Wrap-2001.0929.tar.gz','YAML-0.35.tar.gz'],'requires_module' => {'Text::Wrap' => '0','YAML' => '0'},'requires_recursive' => ['Text-Tabs+Wrap-2001.0929.tar.gz','YAML-0.35.tar.gz'],'size' => {'packed' => 21368,'unpacked' => 72906},'testers' => {'pass' => 5},'uses' => ['5.001','Exporter','strict','vars']},'Convert-IBM390-0.15.tar.gz' => {'author' => 'GROMMEL','description' => 'Convert data from/to S/390 representations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 141,'pod_errors' => 0,'total' => 247,'with_comments' => 6},'releases' => 14,'size' => {'packed' => 23351,'unpacked' => 96492},'testers' => {'pass' => 7},'uses' => []},'Convert-IBM390p-0.07.tar.gz' => {'author' => 'GROMMEL','description' => '- OBSOLETE','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 18,'pod' => 13,'pod_errors' => 0,'total' => 31,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 1412,'unpacked' => 2000},'testers' => {'pass' => 4},'uses' => ['Carp','strict','vars']},'Convert-Morse-0.03.tar.gz' => {'author' => 'TELS','description' => 'Convert from/to Morse code (.--. . .-. .-..)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 228,'pod' => 90,'pod_errors' => 0,'total' => 318,'with_comments' => 57},'releases' => 2,'size' => {'packed' => 4406,'unpacked' => 10293},'testers' => {'pass' => 11},'uses' => ['5.6.0','Exporter','strict','vars']},'Convert-Number-Coptic-0.13.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 200,'pod' => 70,'pod_errors' => 0,'total' => 270,'with_comments' => 19},'releases' => 2,'size' => {'packed' => 4404,'unpacked' => 11538},'testers' => {'pass' => 2},'uses' => ['5.000','strict','utf','vars']},'Convert-Number-Digits-0.03.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 158,'pod' => 126,'pod_errors' => 1,'total' => 284,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 4939,'unpacked' => 11854},'testers' => {'pass' => 2},'uses' => ['strict','utf','vars']},'Convert-Number-Ethiopic-0.16.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 284,'pod' => 50,'pod_errors' => 0,'total' => 334,'with_comments' => 83},'releases' => 2,'size' => {'packed' => 4945,'unpacked' => 12028},'testers' => {'pass' => 2},'uses' => ['5.000','strict','utf','vars']},'Convert-Number-Roman-0.01.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 320,'pod' => 75,'pod_errors' => 0,'total' => 395,'with_comments' => 25},'releases' => 1,'size' => {'packed' => 4564,'unpacked' => 12711},'testers' => {'pass' => 2},'uses' => ['5.000','strict','utf','vars']},'Convert-PEM-0.06.tar.gz' => {'author' => 'BTROTT','description' => 'Read/write encrypted ASN.1 PEM files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 460,'pod' => 337,'pod_errors' => 0,'total' => 797,'with_comments' => 3},'releases' => 5,'requires' => ['Convert-ASN1-0.17.tar.gz','Crypt-DES_EDE3-0.01.tar.gz','Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'Convert::ASN1' => '0.10','Crypt::DES_EDE3' => 0,'Digest::MD5' => 0,'MIME::Base64' => 0},'requires_recursive' => ['Convert-ASN1-0.17.tar.gz','Crypt-DES-2.03.tar.gz','Crypt-DES_EDE3-0.01.tar.gz','Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 9332,'unpacked' => 28775},'testers' => {'pass' => 9},'uses' => ['','Carp','Convert::ASN1','Digest::MD5','MIME::Base64','strict','vars']},'Convert-RACE-0.07.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Conversion between Unicode and RACE','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 221,'pod' => 89,'pod_errors' => 0,'total' => 310,'with_comments' => 23},'releases' => 7,'requires' => ['Convert-Base32-0.02.tar.gz'],'requires_module' => {'Convert::Base32' => '0.02'},'requires_recursive' => ['Convert-Base32-0.02.tar.gz'],'size' => {'packed' => 4388,'unpacked' => 12376},'testers' => {'pass' => 8},'uses' => ['Convert::Base32','Exporter','constant','strict','vars']},'Convert-Recode-1.03.tar.gz' => {'author' => 'GAAS','description' => 'Mapping functions between character sets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 25,'pod_errors' => 0,'total' => 107,'with_comments' => 5},'releases' => 3,'size' => {'packed' => 2183,'unpacked' => 4059},'testers' => {'fail' => 3,'pass' => 1},'uses' => ['Carp','strict','vars']},'Convert-Scalar-0.1e.tar.gz' => {'author' => 'MLEHMANN','description' => 'convert between different representations of perl scalars','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 132,'pod_errors' => 0,'total' => 195,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 5566,'unpacked' => 19294},'testers' => {'pass' => 1},'uses' => ['Exporter','XSLoader']},'Convert-SciEng-0.90.tar.gz' => {'author' => 'COLINK','description' => 'Convert numbers with scientific notation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 104,'pod_errors' => 0,'total' => 233,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 4098,'unpacked' => 9235},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['5.004_04','Carp','strict','vars']},'Convert-TNEF-0.17.tar.gz' => {'author' => 'DOUGW','description' => 'Perl module to read TNEF files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 516,'pod' => 218,'pod_errors' => 0,'total' => 734,'with_comments' => 61},'releases' => 16,'requires' => ['MIME-tools-5.411a.tar.gz'],'requires_module' => {'MIME::Body' => '4.109'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12173,'unpacked' => 38803},'testers' => {'pass' => 5},'uses' => ['Carp','File::Spec','IO::Wrap','MIME::Body','integer','strict','vars']},'Convert-Transcribe-0.02.tar.gz' => {'author' => 'TWID','description' => 'Perl extension for transcribing natural languages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 68,'pod_errors' => 0,'total' => 203,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 3700,'unpacked' => 9253},'testers' => {'pass' => 3},'uses' => ['5.005','Carp','Exporter','strict','vars']},'Convert-Translit-1.03.tar.gz' => {'author' => 'GENJISCH','description' => 'String conversion among many character sets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 729,'pod' => 104,'pod_errors' => 0,'total' => 833,'with_comments' => 204},'releases' => 4,'size' => {'packed' => 80253,'unpacked' => 357503},'testers' => {'pass' => 9},'uses' => ['Exporter','File::Basename','integer','strict','vars']},'Convert-UU-0.52.tar.gz' => {'author' => 'ANDK','description' => 'UUencode and UUdecode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 146,'pod' => 30,'pod_errors' => 0,'total' => 176,'with_comments' => 24},'releases' => 9,'size' => {'packed' => 6292,'unpacked' => 15702},'testers' => {'pass' => 11},'uses' => ['Carp','Exporter','strict','vars']},'Convert-UUlib-0.31.tar.gz' => {'author' => 'MLEHMANN','description' => 'Intelligent de- and encode (B64, UUE...)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 402,'pod_errors' => 0,'total' => 540,'with_comments' => 4},'releases' => 13,'size' => {'packed' => 236507,'unpacked' => 632856},'testers' => {'pass' => 7},'uses' => ['Carp','DynaLoader','Exporter']},'Convert-Units-0.43.tar.gz' => {'author' => 'RRWO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 415,'pod' => 98,'pod_errors' => 0,'total' => 513,'with_comments' => 30},'releases' => 3,'size' => {'packed' => 6386,'unpacked' => 21033},'testers' => {'pass' => 13,'tests' => '0','unknown' => 3},'uses' => ['5.004','Carp','Exporter','vars']},'Convert-yEnc-1.00.tar.gz' => {'author' => 'SWMCD','description' => 'yEnc decoder','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 981,'pod' => 578,'pod_errors' => 0,'total' => 1559,'with_comments' => 2},'releases' => 2,'requires' => ['Set-IntSpan-1.07.tar.gz'],'requires_module' => {'Set::IntSpan' => '1.07'},'requires_recursive' => ['Set-IntSpan-1.07.tar.gz'],'size' => {'packed' => 56527,'unpacked' => 130461},'testers' => {'fail' => 3,'pass' => 4,'tests' => '101'},'uses' => ['5.008','IO::File','Set::IntSpan','constant','strict']},'CookBookA-19960430.tar.gz' => {'author' => 'DMR','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 302,'pod' => 358,'pod_errors' => 0,'total' => 660,'with_comments' => 28},'releases' => 1,'size' => {'packed' => 17181,'unpacked' => 56310},'testers' => {},'uses' => ['DynaLoader','Exporter','strict','vars']},'CookBookB-19960430.tar.gz' => {'author' => 'DMR','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 240,'pod' => 279,'pod_errors' => 0,'total' => 519,'with_comments' => 41},'releases' => 1,'size' => {'packed' => 21314,'unpacked' => 69372},'testers' => {'fail' => 1},'uses' => ['DynaLoader','Exporter','strict','vars']},'Coro-0.652.tar.gz' => {'author' => 'MLEHMANN','description' => 'coroutine process abstraction','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 1792,'pod' => 898,'pod_errors' => 0,'total' => 2690,'with_comments' => 82},'releases' => 26,'requires' => ['Event-0.87.tar.gz','Scalar-List-Utils-1.11.tar.gz'],'requires_module' => {'Event' => '0.86','Scalar::Util' => 0},'requires_recursive' => ['Event-0.87.tar.gz','File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 49739,'unpacked' => 152231},'testers' => {'pass' => 7},'uses' => ['Carp','Config','Event','Event::Watcher','Exporter','Net::DNS::Resolver','POSIX','Socket','XSLoader']},'Coy-0.05.tar.gz' => {'author' => 'DCONWAY','description' => 'Syllable based hyphenation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2412,'pod' => 330,'pod_errors' => 0,'total' => 2742,'with_comments' => 133},'releases' => 1,'size' => {'packed' => 19942,'unpacked' => 63810},'testers' => {'pass' => 4,'tests' => '0','unknown' => 30},'uses' => ['Env','Exporter','Lingua::EN::Inflect','Text::Wrap','strict','vars']},'Crypt-Anubis-1.0.4.tar.gz' => {'author' => 'JCDUQUE','description' => 'A variable-length key, 128-bit block cipher','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 113,'pod_errors' => 0,'total' => 142,'with_comments' => 1},'releases' => 5,'size' => {'packed' => 68388,'unpacked' => 477984},'testers' => {'pass' => 2},'uses' => ['Exporter','XSLoader','strict','warnings']},'Crypt-Blowfish-2.09.tar.gz' => {'author' => 'DPARIS','description' => 'XS-based implementation of Blowfish','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 91,'pod_errors' => 0,'total' => 207,'with_comments' => 10},'releases' => 7,'size' => {'packed' => 17497,'unpacked' => 45862},'testers' => {'fail' => 1,'pass' => 25,'tests' => '0','unknown' => 3},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Crypt-Blowfish_PP-1.12.tar.gz' => {'author' => 'MATTBM','description' => 'Blowfish encryption algorithm in Pure Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 472,'pod' => 47,'pod_errors' => 0,'total' => 519,'with_comments' => 11},'releases' => 5,'size' => {'packed' => 10482,'unpacked' => 22421},'testers' => {'pass' => 14},'uses' => ['strict','vars']},'Crypt-CAST5-0.03.tar.gz' => {'author' => 'BOBMATH','description' => 'CAST5 block cipher','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 79,'pod_errors' => 0,'total' => 113,'with_comments' => 1},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.47'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 25417,'unpacked' => 66665},'testers' => {'pass' => 3},'uses' => ['5.004','DynaLoader','strict','vars']},'Crypt-CAST5_PP-1.02.tar.gz' => {'author' => 'BOBMATH','description' => 'CAST5 block cipher in pure Perl','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 550,'pod' => 77,'pod_errors' => 0,'total' => 627,'with_comments' => 12},'releases' => 6,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.47'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 19515,'unpacked' => 43088},'testers' => {'pass' => 4},'uses' => ['5.004','AutoLoader','Carp','Crypt::CAST5_PP::Tables','integer','strict','vars']},'Crypt-CBC-1.00.tar.gz' => {'author' => 'LDS','description' => 'Encrypt Data with Cipher Block Chaining Mode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 178,'pod' => 98,'pod_errors' => 0,'total' => 276,'with_comments' => 15},'releases' => 14,'size' => {'packed' => 5392,'unpacked' => 14809},'testers' => {'fail' => 2,'pass' => 1,'tests' => '5'},'uses' => ['Carp','MD5','strict','vars']},'Crypt-CBC-2.08.tar.gz' => {'author' => 'LDS','description' => 'Cipherblock chaining for Crypt::DES/IDEA','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 362,'pod' => 168,'pod_errors' => 0,'total' => 530,'with_comments' => 28},'releases' => 14,'requires' => ['Digest-MD5-2.26.tar.gz'],'requires_module' => {'Digest::MD5' => '2.00'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 9495,'unpacked' => 26695},'testers' => {'pass' => 10},'uses' => ['Carp','Digest::MD5','strict','vars']},'Crypt-CBCeasy-0.24.tar.gz' => {'author' => 'MBLAZ','description' => 'Easy things make really easy with Crypt::CBC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 199,'pod_errors' => 0,'total' => 351,'with_comments' => 19},'releases' => 3,'requires' => ['Crypt-CBC-2.08.tar.gz','MD5-2.02.tar.gz'],'requires_module' => {'Crypt::CBC' => '1.20','MD5' => 0},'requires_recursive' => ['Crypt-CBC-2.08.tar.gz','Digest-MD5-2.26.tar.gz','MD5-2.02.tar.gz'],'size' => {'packed' => 11022,'unpacked' => 36093},'testers' => {'fail' => 3,'pass' => 8},'uses' => ['5.003','Carp','Crypt::CBC','Symbol','strict','vars']},'Crypt-CFB-0.01.tar.gz' => {'author' => 'BAUERM','description' => 'Encrypt Data in Cipher Feedback Mode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 233,'pod' => 51,'pod_errors' => 0,'total' => 284,'with_comments' => 46},'releases' => 1,'size' => {'packed' => 8572,'unpacked' => 17039},'testers' => {'pass' => 5},'uses' => ['Exporter','UNIVERSAL','vars']},'Crypt-Caesar-0.01.tar.gz' => {'author' => 'JUERD','description' => 'Decrypt rot-N strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 24,'pod_errors' => 0,'total' => 67,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1974,'unpacked' => 3440},'testers' => {'pass' => 5},'uses' => ['Exporter','strict','vars']},'Crypt-Camellia-1.0.2.tar.gz' => {'author' => 'JCDUQUE','description' => 'Crypt::CBC-compliant block cipher','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 28,'pod' => 117,'pod_errors' => 0,'total' => 145,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 19703,'unpacked' => 66609},'testers' => {'pass' => 2},'uses' => ['Exporter','XSLoader','strict','warnings']},'Crypt-Cipher-0.03.tar.gz' => {'author' => 'CHIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 27,'pod' => 36,'pod_errors' => 1,'total' => 63,'with_comments' => 8},'releases' => 3,'requires' => ['Text-Cipher-1.00.tar.gz'],'requires_module' => {'Text::Cipher' => 1},'requires_recursive' => ['Regexp-Tr-0.05.tar.gz','Text-Cipher-1.00.tar.gz'],'size' => {'packed' => 1798,'unpacked' => 3025},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','Text::Cipher','strict','warnings']},'Crypt-CipherSaber-0.61.tar.gz' => {'author' => 'CHROMATIC','description' => 'OO module for CS-1 and CS-2 encryption','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 182,'pod' => 85,'pod_errors' => 0,'total' => 267,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 8915,'unpacked' => 16708},'testers' => {'pass' => 11},'uses' => ['Carp','strict','vars']},'Crypt-Cracklib-0.01.tar.gz' => {'author' => 'DANIEL','description' => 'Perl interface to Alec Muffett\'s Cracklib.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 70,'pod' => 41,'pod_errors' => 0,'total' => 111,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 3022,'unpacked' => 8159},'testers' => {'pass' => 1},'uses' => ['DynaLoader','Exporter','strict','vars']},'Crypt-Ctr-0.01.tar.gz' => {'author' => 'BAUERM','description' => 'Encrypt Data in Counter Mode','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 65,'pod' => 55,'pod_errors' => 0,'total' => 120,'with_comments' => 8},'releases' => 1,'requires' => ['Crypt-CFB-0.01.tar.gz'],'requires_module' => {'Crypt::CFB' => 0},'requires_recursive' => ['Crypt-CFB-0.01.tar.gz'],'size' => {'packed' => 7253,'unpacked' => 12679},'testers' => {'pass' => 4},'uses' => ['Crypt::CFB','vars']},'Crypt-DES-1.0.tar.gz' => {'author' => 'GARY','description' => 'DES encryption (libdes)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 67,'pod_errors' => 0,'total' => 159,'with_comments' => 7},'releases' => 5,'size' => {'packed' => 12695,'unpacked' => 39178},'testers' => {'fail' => 1},'uses' => ['Carp','DynaLoader','Exporter','strict']},'Crypt-DES-2.03.tar.gz' => {'author' => 'DPARIS','description' => 'DES encryption (libdes)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 77,'pod_errors' => 0,'total' => 172,'with_comments' => 8},'releases' => 5,'size' => {'packed' => 15274,'unpacked' => 50504},'testers' => {'fail' => 2,'pass' => 29,'tests' => '0','unknown' => 3},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Crypt-DES_EDE3-0.01.tar.gz' => {'author' => 'BTROTT','description' => 'Triple-DES EDE encryption/decryption','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 55,'pod_errors' => 0,'total' => 118,'with_comments' => 1},'releases' => 1,'requires' => ['Crypt-DES-2.03.tar.gz'],'requires_module' => {'Crypt::DES' => 0},'requires_recursive' => ['Crypt-DES-2.03.tar.gz'],'size' => {'packed' => 2328,'unpacked' => 4701},'testers' => {'pass' => 10},'uses' => ['Crypt::DES','strict','vars']},'Crypt-DES_PP-1.00.tar.gz' => {'author' => 'GUIDO','description' => 'Perl extension for DES encryption','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 599,'pod' => 43,'pod_errors' => 0,'total' => 642,'with_comments' => 35},'releases' => 3,'size' => {'packed' => 34796,'unpacked' => 120573},'testers' => {'pass' => 11},'uses' => ['Carp','Exporter','constant','integer','strict','vars']},'Crypt-DH-0.03.tar.gz' => {'author' => 'BTROTT','description' => 'Diffie-Hellman key exchange system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 89,'pod_errors' => 0,'total' => 205,'with_comments' => 1},'releases' => 3,'requires' => ['Crypt-Random-1.13.tar.gz','Math-Pari-2.010500.tar.gz'],'requires_module' => {'Crypt::Random' => '0.33','Math::Pari' => '2.001804'},'requires_recursive' => ['Class-Loader-2.02.tar.gz','Crypt-Random-1.13.tar.gz','Math-Pari-2.010500.tar.gz'],'size' => {'packed' => 3479,'unpacked' => 7556},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Crypt::Random','Math::Pari','strict','vars']},'Crypt-DSA-0.12.tar.gz' => {'author' => 'BTROTT','description' => 'DSA Signatures and Key Generation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 643,'pod' => 391,'pod_errors' => 0,'total' => 1034,'with_comments' => 12},'releases' => 5,'requires' => ['Crypt-Random-1.13.tar.gz','Digest-SHA1-2.04.tar.gz','Math-Pari-2.010500.tar.gz'],'requires_module' => {'Crypt::Random' => '0.33','Digest::SHA1' => 0,'Math::Pari' => '2.001804'},'requires_recursive' => ['Class-Loader-2.02.tar.gz','Crypt-Random-1.13.tar.gz','Digest-SHA1-2.04.tar.gz','Math-Pari-2.010500.tar.gz'],'size' => {'packed' => 11336,'unpacked' => 34398},'testers' => {'fail' => 1,'pass' => 6},'uses' => ['','Carp','Convert::PEM','Crypt::Random','Data::Buffer','Digest::SHA1','Exporter','MIME::Base64','Math::Pari','constant','strict','vars']},'Crypt-ECB-1.1-2.tar.gz' => {'author' => 'APPEL','description' => 'ECB mode for Crypt::DES, Blowfish, etc.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 590,'pod' => 178,'pod_errors' => 0,'total' => 768,'with_comments' => 103},'releases' => 1,'size' => {'packed' => 14203,'unpacked' => 42789},'testers' => {'fail' => 3,'pass' => 11,'tests' => '30'},'uses' => ['Exporter','constant','strict','vars']},'Crypt-Enigma-1.1.tar.gz' => {'author' => 'JBLAKEY','description' => 'Perl extension for emulating a World War II Enigma','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 317,'pod' => 40,'pod_errors' => 0,'total' => 357,'with_comments' => 70},'releases' => 6,'size' => {'packed' => 5782,'unpacked' => 14759},'testers' => {'pass' => 5},'uses' => ['5.006','Exporter','strict','warnings']},'Crypt-GOST-1.00.tar.gz' => {'author' => 'AMS','description' => 'GOST encryption algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 171,'pod' => 65,'pod_errors' => 0,'total' => 236,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 8935,'unpacked' => 25942},'testers' => {'pass' => 11},'uses' => ['Carp','DynaLoader','strict','vars']},'Crypt-GOST_PP-1.10.tar.gz' => {'author' => 'SIFUKURT','description' => 'Pure Perl implementation of the GOST encryption algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 30,'pod_errors' => 0,'total' => 135,'with_comments' => 11},'releases' => 3,'size' => {'packed' => 3068,'unpacked' => 5965},'testers' => {'pass' => 4},'uses' => ['Exporter','integer','strict','vars']},'Crypt-GPG-1.42.tar.gz' => {'author' => 'AGUL','description' => 'Object-oriented interface to GnuPG','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 922,'pod' => 317,'pod_errors' => 0,'total' => 1239,'with_comments' => 28},'releases' => 13,'requires' => ['Expect-1.15.tar.gz','File-Temp-0.12.tar.gz','Time-HiRes-1.49.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Date::Parse' => 0,'Expect' => '1.15','Fcntl' => 0,'File::Path' => 0,'File::Temp' => 0,'Time::HiRes' => 0},'requires_recursive' => ['Expect-1.15.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-Tty-1.02.tar.gz','Time-HiRes-1.49.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18920,'unpacked' => 58071},'testers' => {},'uses' => ['Carp','Date::Parse','English','Expect','Fcntl','File::Path','File::Temp','Time::HiRes','strict','vars']},'Crypt-GeneratePassword-0.02.tar.gz' => {'author' => 'JWALT','description' => 'generate secure random pronounceable passwords','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 335,'pod' => 91,'pod_errors' => 0,'total' => 426,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 192931,'unpacked' => 2038494},'testers' => {'pass' => 3},'uses' => ['Data::Dumper','Exporter','strict','vars']},'Crypt-HCE_MD5-0.60.tar.gz' => {'author' => 'EESTABROO','description' => 'Perl extension implementing one way hash chaining encryption using MD5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 419,'pod' => 42,'pod_errors' => 0,'total' => 461,'with_comments' => 27},'releases' => 5,'requires' => ['Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'Digest::MD5' => 2,'MIME::Base64' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 5579,'unpacked' => 23635},'testers' => {'fail' => 1,'pass' => 9},'uses' => ['AutoLoader','Carp','Digest::MD5','Exporter','IO::Select','IO::Socket','MIME::Base64','Sys::Syslog','strict','vars']},'Crypt-HCE_SHA-0.60.tar.gz' => {'author' => 'EESTABROO','description' => 'Perl extension implementing one way hash chaining encryption using SHA','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 407,'pod' => 37,'pod_errors' => 0,'total' => 444,'with_comments' => 27},'releases' => 5,'requires' => ['Digest-SHA1-2.04.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'Digest::SHA1' => 0,'MIME::Base64' => 2},'requires_recursive' => ['Digest-SHA1-2.04.tar.gz','MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 5276,'unpacked' => 22457},'testers' => {'fail' => 1,'pass' => 10},'uses' => ['AutoLoader','Carp','Digest::SHA1','Exporter','IO::Select','IO::Socket','MIME::Base64','Sys::Syslog','strict','vars']},'Crypt-IDEA-1.0.tar.gz' => {'author' => 'GARY','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 69,'pod_errors' => 0,'total' => 166,'with_comments' => 10},'releases' => 3,'size' => {'packed' => 5284,'unpacked' => 12034},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict']},'Crypt-IDEA-1.02.tar.gz' => {'author' => 'DPARIS','description' => 'International Data Encryption Algorithm','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 98,'pod' => 71,'pod_errors' => 0,'total' => 169,'with_comments' => 10},'releases' => 3,'size' => {'packed' => 5366,'unpacked' => 12194},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','DynaLoader','Exporter','strict']},'Crypt-Keys-0.06.tar.gz' => {'author' => 'BTROTT','description' => 'On-disk management of public and private keyfiles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 902,'pod' => 268,'pod_errors' => 0,'total' => 1170,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 16766,'unpacked' => 49876},'testers' => {'fail' => 1,'pass' => 2,'tests' => '221'},'uses' => ['','Convert::PEM','Crypt::CBC','Crypt::DES','Data::Buffer','Digest::MD5','Exporter','MIME::Base64','Math::Pari','constant','strict','vars']},'Crypt-Khazad-1.0.3.tar.gz' => {'author' => 'JCDUQUE','description' => 'A 64-bit block cipher using a 128-bit key','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 113,'pod_errors' => 0,'total' => 142,'with_comments' => 1},'releases' => 4,'size' => {'packed' => 42106,'unpacked' => 144791},'testers' => {'pass' => 2},'uses' => ['Exporter','XSLoader','strict','warnings']},'Crypt-License-2.02.tar.gz' => {'author' => 'MIKER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 614,'pod' => 606,'pod_errors' => 1,'total' => 1220,'with_comments' => 72},'releases' => 3,'requires' => ['Filter-1.29.tar.gz'],'requires_module' => {'Filter::Util::Call' => '1.04'},'requires_recursive' => ['Filter-1.29.tar.gz'],'size' => {'packed' => 37822,'unpacked' => 108791},'testers' => {'fail' => 2,'tests' => '63'},'uses' => ['Crypt::CapnMidNite','Exporter','Filter::Util::Call','Time::Local','diagnostics','strict','vars']},'Crypt-Loki97-1.0.1.tar.gz' => {'author' => 'JCDUQUE','description' => 'A Crypt::CBC compliant 128-bit block cipher','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 113,'pod_errors' => 0,'total' => 142,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 40756,'unpacked' => 102125},'testers' => {'pass' => 1},'uses' => ['Exporter','XSLoader','strict','warnings']},'Crypt-Memfrob-1.00.tar.gz' => {'author' => 'KNAGANO','description' => 'memfrob implementation in pure Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 24,'pod' => 45,'pod_errors' => 0,'total' => 69,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2705,'unpacked' => 5921},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'Crypt-Mimetic-0.02.tar.gz' => {'author' => 'ERICH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 816,'pod' => 491,'pod_errors' => 3,'total' => 1307,'with_comments' => 9},'releases' => 2,'requires' => ['Error-0.15.tar.gz','TermReadKey-2.21.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Error' => '0.15','File::Copy' => '0','File::Find' => '0','Term::ReadKey' => '0'},'requires_recursive' => ['Error-0.15.tar.gz','TermReadKey-2.21.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8635,'unpacked' => 37147},'testers' => {'pass' => 4},'uses' => ['Error','File::Copy','Term::ReadKey','strict','vars']},'Crypt-Misty1-1.1.3.tar.gz' => {'author' => 'JCDUQUE','description' => 'NESSIE winner for 128-bit key, 64-bit cipher','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 111,'pod_errors' => 0,'total' => 143,'with_comments' => 1},'releases' => 5,'size' => {'packed' => 27700,'unpacked' => 93768},'testers' => {'pass' => 2},'uses' => ['Exporter','XSLoader','strict','warnings']},'Crypt-MySQL-0.01.tar.gz' => {'author' => 'IKEBE','description' => 'emulate MySQL PASSWORD() function.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 28,'pod' => 25,'pod_errors' => 0,'total' => 53,'with_comments' => 5},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2206,'unpacked' => 3467},'testers' => {'fail' => 1,'pass' => 2,'tests' => '4'},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Crypt-NULL-1.02.tar.gz' => {'author' => 'AMS','description' => 'NULL Encryption Algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 47,'pod' => 57,'pod_errors' => 0,'total' => 104,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 2043,'unpacked' => 5418},'testers' => {'pass' => 10},'uses' => ['Carp','strict','vars']},'Crypt-Noekeon-1.0.2.tar.gz' => {'author' => 'JCDUQUE','description' => 'A 128-bit block cipher using a 128-bit key','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 113,'pod_errors' => 0,'total' => 142,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 20773,'unpacked' => 68205},'testers' => {'pass' => 2},'uses' => ['Exporter','XSLoader','strict','warnings']},'Crypt-OOEnigma-0.3.tar.gz' => {'author' => 'SJBAKER','description' => 'A World War II Enigma machine in a flexible OO framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 749,'pod' => 426,'pod_errors' => 0,'total' => 1175,'with_comments' => 114},'releases' => 3,'requires' => ['Storable-2.07.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Storable' => '','Test::More' => '0.41'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10670,'unpacked' => 52939},'testers' => {'pass' => 3},'uses' => ['Carp','Storable','vars']},'Crypt-OTP-2.00.tar.gz' => {'author' => 'SIFUKURT','description' => 'Implements One Time Pad encryption','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 49,'pod_errors' => 0,'total' => 124,'with_comments' => 12},'releases' => 3,'size' => {'packed' => 3242,'unpacked' => 6782},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'Crypt-OpenPGP-1.03.tar.gz' => {'author' => 'BTROTT','description' => 'Pure-Perl OpenPGP implementation','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 5868,'pod' => 2367,'pod_errors' => 0,'total' => 8235,'with_comments' => 129},'releases' => 14,'size' => {'packed' => 96872,'unpacked' => 338265},'testers' => {'fail' => 2,'pass' => 1,'tests' => '102'},'uses' => ['','CPAN','CPANPLUS::Backend','Carp','Compress::Zlib','Crypt::DSA','Crypt::DSA::Key','Crypt::RIPEMD160','Crypt::RSA::Key','Crypt::RSA::Key::Private','Crypt::RSA::Key::Public','Crypt::RSA::Primitives','Crypt::Random','Cwd','Data::Buffer','Digest::MD5','Digest::SHA1','Exporter','ExtUtils::Manifest','File::Spec','LWP::UserAgent','MIME::Base64','Math::Pari','Term::ReadKey','URI::Escape','constant','strict','vars']},'Crypt-OpenSSL-Bignum-0.03.tar.gz' => {'author' => 'IROBERTS','description' => 'OpenSSL\'s multiprecision integer arithmetic','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 117,'pod' => 157,'pod_errors' => 0,'total' => 274,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 5898,'unpacked' => 19858},'testers' => {'pass' => 2},'uses' => ['5.005','Carp','DynaLoader','strict','vars']},'Crypt-OpenSSL-DSA-0.11.tar.gz' => {'author' => 'TJMATHER','description' => 'Digital Signature Algorithm using OpenSSL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 35,'pod' => 211,'pod_errors' => 1,'total' => 246,'with_comments' => 0},'releases' => 6,'size' => {'packed' => 5415,'unpacked' => 20416},'testers' => {'pass' => 5},'uses' => ['DynaLoader','strict','vars','warnings']},'Crypt-OpenSSL-RSA-0.19.tar.gz' => {'author' => 'IROBERTS','description' => 'Interface to OpenSSL RSA methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 236,'pod' => 180,'pod_errors' => 0,'total' => 416,'with_comments' => 2},'releases' => 12,'requires' => ['Crypt-OpenSSL-Random-0.03.tar.gz'],'requires_module' => {'Crypt::OpenSSL::Random' => 0},'requires_recursive' => ['Crypt-OpenSSL-Random-0.03.tar.gz'],'size' => {'packed' => 11227,'unpacked' => 38850},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','Crypt::OpenSSL::Bignum','DynaLoader','Exporter','strict','vars']},'Crypt-OpenSSL-Random-0.03.tar.gz' => {'author' => 'IROBERTS','description' => 'Interface to OpenSSL PRNG methods','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 72,'pod_errors' => 1,'total' => 111,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 3245,'unpacked' => 7447},'testers' => {'pass' => 19},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Crypt-OpenSSL-SMIME-0.02.tar.gz' => {'author' => 'DEEMON','description' => 'signing and encrypting messages with S/MIME standard using OpenSSL libraries.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 84,'pod_errors' => 0,'total' => 174,'with_comments' => 14},'releases' => 2,'size' => {'packed' => 25723,'unpacked' => 47075},'testers' => {'pass' => 5},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Crypt-PGP2-0.03.tar.gz' => {'author' => 'JBRIGGS','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 108,'pod' => 98,'pod_errors' => 0,'total' => 206,'with_comments' => 23},'releases' => 2,'size' => {'packed' => 3483,'unpacked' => 7226},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Exporter','IPC::Open3','diagnostics','strict','vars']},'Crypt-PGP5-1.38.tar.gz' => {'author' => 'AGUL','description' => 'Object-oriented interface to PGP v5.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 454,'pod' => 173,'pod_errors' => 0,'total' => 627,'with_comments' => 12},'releases' => 6,'requires' => ['Expect-1.15.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Expect' => 0,'Fcntl' => 0,'POSIX' => 0,'Time::HiRes' => 0},'requires_recursive' => ['Expect-1.15.tar.gz','IO-Tty-1.02.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6221,'unpacked' => 19922},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['5.005','Carp','Expect','Fcntl','POSIX','Time::HiRes','strict','vars']},'Crypt-PGPSimple-0.13.tar.gz' => {'author' => 'JHINKLE','description' => 'Basic interface to PGP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 330,'pod' => 104,'pod_errors' => 0,'total' => 434,'with_comments' => 69},'releases' => 2,'size' => {'packed' => 4427,'unpacked' => 14609},'testers' => {'pass' => 6},'uses' => ['5.000']},'Crypt-PassGen-0.03.tar.gz' => {'author' => 'TJENNESS','description' => 'Generate pronouncable passwords','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 470,'pod' => 70,'pod_errors' => 0,'total' => 540,'with_comments' => 96},'releases' => 3,'requires' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-1.24.tar.gz'],'requires_module' => {'File::Spec' => 0,'Storable' => 0,'Test' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7079,'unpacked' => 18796},'testers' => {'pass' => 4},'uses' => ['Config','Exporter','File::Spec','Storable','constant','integer','strict','vars']},'Crypt-Passwd-0.03.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Perl wrapper around the UFC Crypt','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 62,'pod' => 32,'pod_errors' => 0,'total' => 94,'with_comments' => 14},'releases' => 3,'requires' => ['MD5-2.02.tar.gz'],'requires_module' => {'MD5' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','MD5-2.02.tar.gz'],'size' => {'packed' => 4199,'unpacked' => 8963},'testers' => {'fail' => 3,'pass' => 3,'tests' => '3'},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Crypt-PasswdMD5-1.2.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Interoperable MD5-based crypt() function','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 140,'pod' => 22,'pod_errors' => 0,'total' => 162,'with_comments' => 41},'releases' => 5,'size' => {'packed' => 2793,'unpacked' => 7245},'testers' => {'pass' => 10},'uses' => ['5.000','Digest::MD5','Exporter']},'Crypt-Primes-0.50.tar.gz' => {'author' => 'VIPUL','description' => 'Provable Prime Number Generator suitable for Cryptographic Applications.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 763,'pod' => 138,'pod_errors' => 1,'total' => 901,'with_comments' => 20},'releases' => 4,'requires' => ['Crypt-Random-1.13.tar.gz','Math-Pari-2.010500.tar.gz'],'requires_module' => {'Crypt::Random' => '0.33','Math::Pari' => '2.001804'},'requires_recursive' => ['Class-Loader-2.02.tar.gz','Crypt-Random-1.13.tar.gz','Math-Pari-2.010500.tar.gz'],'size' => {'packed' => 136299,'unpacked' => 431985},'testers' => {'pass' => 3},'uses' => ['Crypt::Random','Exporter','Math::Pari','integer','vars']},'Crypt-RC4-2.02.tar.gz' => {'author' => 'SIFUKURT','description' => 'Implements the RC4 encryption algorithm','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 46,'pod_errors' => 0,'total' => 165,'with_comments' => 11},'releases' => 6,'size' => {'packed' => 4173,'unpacked' => 9923},'testers' => {'pass' => 9},'uses' => ['Exporter','strict','vars']},'Crypt-RC5-2.00.tar.gz' => {'author' => 'SIFUKURT','description' => 'Perl implementation of the RC5 encryption algorithm.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 31,'pod_errors' => 0,'total' => 151,'with_comments' => 15},'releases' => 3,'size' => {'packed' => 2966,'unpacked' => 6064},'testers' => {'pass' => 5},'uses' => ['Exporter','integer','strict','vars']},'Crypt-RC6-1.0.tar.gz' => {'author' => 'JHUGHES','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 25,'pod' => 32,'pod_errors' => 0,'total' => 57,'with_comments' => 0},'releases' => 7,'size' => {'packed' => 11411,'unpacked' => 31931},'testers' => {'fail' => 1,'pass' => 2,'tests' => '13'},'uses' => ['DynaLoader']},'Crypt-RIPEMD160-0.04.tar.gz' => {'author' => 'CHGEUER','description' => 'Perl extension for the RIPEMD-160 Hash function','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 264,'pod' => 178,'pod_errors' => 0,'total' => 442,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 57548,'unpacked' => 210594},'testers' => {'pass' => 7},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Crypt-RSA-1.50.tar.gz' => {'author' => 'VIPUL','description' => 'RSA public-key cryptosystem.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2127,'pod' => 1050,'pod_errors' => 0,'total' => 3177,'with_comments' => 152},'releases' => 20,'requires' => ['Class-Loader-2.02.tar.gz','Convert-ASCII-Armour-1.4.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Crypt-Primes-0.50.tar.gz','Crypt-Random-1.13.tar.gz','Data-Buffer-0.04.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD2-2.02.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','Math-Pari-2.010500.tar.gz','Sort-Versions-1.4.tar.gz','Tie-EncryptedHash-1.21.tar.gz'],'requires_module' => {'Class::Loader' => '2.00','Convert::ASCII::Armour' => 0,'Crypt::Blowfish' => 0,'Crypt::CBC' => 0,'Crypt::Primes' => '0.38','Crypt::Random' => '0.34','Data::Buffer' => 0,'Data::Dumper' => 0,'Digest::MD2' => 0,'Digest::MD5' => 0,'Digest::SHA1' => 0,'Math::Pari' => '2.001804','Sort::Versions' => 0,'Tie::EncryptedHash' => 0},'requires_recursive' => ['Class-Loader-2.02.tar.gz','Compress-Zlib-1.22.tar.gz','Convert-ASCII-Armour-1.4.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Crypt-DES-2.03.tar.gz','Crypt-Primes-0.50.tar.gz','Crypt-Random-1.13.tar.gz','Data-Buffer-0.04.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD2-2.02.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','MIME-Base64-2.20.tar.gz','Math-Pari-2.010500.tar.gz','Sort-Versions-1.4.tar.gz','Tie-EncryptedHash-1.21.tar.gz'],'size' => {'packed' => 32763,'unpacked' => 129968},'testers' => {'pass' => 2},'uses' => ['','Carp','Class::Loader','Convert::ASCII::Armour','Crypt::CBC','Crypt::Primes','Crypt::Random','Data::Buffer','Data::Dumper','Digest::MD2','Digest::MD5','Digest::SHA1','Exporter','Math::Pari','Sort::Versions','Tie::EncryptedHash','constant','lib','strict','vars']},'Crypt-Rainbow-1.0.0.tar.gz' => {'author' => 'JCDUQUE','description' => 'A Crypt::CBC compliant block cipher','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 115,'pod_errors' => 0,'total' => 149,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 38286,'unpacked' => 95089},'testers' => {'pass' => 1},'uses' => ['Exporter','XSLoader','strict','warnings']},'Crypt-RandPasswd-0.02.tar.gz' => {'author' => 'JDPORTER','description' => 'Random password generator based on FIPS-181','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2320,'pod' => 206,'pod_errors' => 0,'total' => 2526,'with_comments' => 356},'releases' => 2,'size' => {'packed' => 17044,'unpacked' => 98555},'testers' => {'pass' => 7},'uses' => ['Getopt::Long','constant','strict','vars']},'Crypt-Random-1.13.tar.gz' => {'author' => 'VIPUL','description' => 'Cryptographically Secure, True Random Number Generator.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 490,'pod' => 95,'pod_errors' => 0,'total' => 585,'with_comments' => 55},'releases' => 12,'requires' => ['Class-Loader-2.02.tar.gz','Math-Pari-2.010500.tar.gz'],'requires_module' => {'Class::Loader' => '2.00','Math::Pari' => '2.001804'},'requires_recursive' => ['Class-Loader-2.02.tar.gz','Math-Pari-2.010500.tar.gz'],'size' => {'packed' => 7072,'unpacked' => 24290},'testers' => {'fail' => 1,'pass' => 4,'tests' => '26'},'uses' => ['Carp','Class::Loader','Data::Dumper','Exporter','IO::Socket','Math::Pari','lib','strict','vars']},'Crypt-Rijndael-0.05.tar.gz' => {'author' => 'DIDO','description' => 'AES/Rijndael Encryption Module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 66,'pod_errors' => 0,'total' => 97,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 23676,'unpacked' => 69433},'testers' => {'fail' => 1,'pass' => 16,'tests' => '41'},'uses' => ['DynaLoader']},'Crypt-Rijndael_PP-0.04.tar.gz' => {'author' => 'DELTA','description' => 'pure perl implementation of Rijndael (AES)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2562,'pod' => 106,'pod_errors' => 0,'total' => 2668,'with_comments' => 703},'releases' => 3,'size' => {'packed' => 31000,'unpacked' => 129543},'testers' => {'pass' => 9},'uses' => ['5.004','Carp','Exporter','integer','strict','vars']},'Crypt-Rot13-0.04.tar.gz' => {'author' => 'AYRNIEU','description' => 'simple encryption often seen on usenet','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 58,'pod_errors' => 0,'total' => 147,'with_comments' => 16},'releases' => 4,'size' => {'packed' => 2694,'unpacked' => 5309},'testers' => {'pass' => 14},'uses' => ['Carp','strict']},'Crypt-SEAL2-1.0.4.tar.gz' => {'author' => 'JCDUQUE','description' => 'The stream cipher, SEAL v 2.0','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 105,'pod_errors' => 0,'total' => 150,'with_comments' => 1},'releases' => 5,'size' => {'packed' => 33634,'unpacked' => 67744},'testers' => {},'uses' => ['Exporter','XSLoader','strict','warnings']},'Crypt-SKey-0.06.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Perl S/Key calculator','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 307,'pod' => 108,'pod_errors' => 0,'total' => 415,'with_comments' => 10},'releases' => 6,'size' => {'packed' => 12266,'unpacked' => 27344},'testers' => {'pass' => 8},'uses' => ['Digest::MD4','Digest::MD5','Term::ReadKey','strict','vars']},'Crypt-SSLeay-0.51.tar.gz' => {'author' => 'CHAMAS','description' => 'Glue that enables LWP to access https URIs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 659,'pod' => 301,'pod_errors' => 0,'total' => 960,'with_comments' => 49},'releases' => 33,'size' => {'packed' => 117555,'unpacked' => 323938},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['Carp','DynaLoader','IO::Socket','MIME::Base64','Socket','strict','vars']},'Crypt-SecurID-0.03.tgz' => {'author' => 'PLIAM','description' => 'module for generating and verifying SecurID time hash codes','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 199,'pod' => 63,'pod_errors' => 0,'total' => 262,'with_comments' => 22},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.01'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 21877,'unpacked' => 75420},'testers' => {'pass' => 1},'uses' => ['5.006','DynaLoader','Exporter','strict','vars','warnings']},'Crypt-Serpent-1.01.tar.gz' => {'author' => 'JHUGHES','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 36,'pod' => 30,'pod_errors' => 0,'total' => 66,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 19010,'unpacked' => 68931},'testers' => {'fail' => 2,'pass' => 3,'tests' => '13'},'uses' => ['DynaLoader']},'Crypt-Shark-1.0.1.tar.gz' => {'author' => 'JCDUQUE','description' => 'A 64-bit block cipher that accepts a 128-bit','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 30,'pod' => 113,'pod_errors' => 0,'total' => 143,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 82403,'unpacked' => 176372},'testers' => {'pass' => 2},'uses' => ['Exporter','XSLoader','strict','warnings']},'Crypt-Simple-0.06.tar.gz' => {'author' => 'KASEI','description' => 'encrypt stuff simply','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 136,'pod' => 71,'pod_errors' => 0,'total' => 207,'with_comments' => 0},'releases' => 3,'requires' => ['Compress-Zlib-1.22.tar.gz','Crypt-Blowfish-2.09.tar.gz','Digest-MD5-2.26.tar.gz','FreezeThaw-0.43.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'Compress::Zlib' => '1.11','Crypt::Blowfish' => '2.06','Digest::MD5' => '2.13','FreezeThaw' => '0.41','MIME::Base64' => '2.11'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Crypt-Blowfish-2.09.tar.gz','Digest-MD5-2.26.tar.gz','FreezeThaw-0.43.tar.gz','MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 4336,'unpacked' => 12792},'testers' => {'pass' => 3},'uses' => ['Carp','Compress::Zlib','Crypt::Blowfish','Digest::MD5','FreezeThaw','MIME::Base64','strict']},'Crypt-Skipjack-1.0.2.tar.gz' => {'author' => 'JCDUQUE','description' => 'Crypt::CBC-compliant block cipher','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 30,'pod' => 115,'pod_errors' => 0,'total' => 145,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 18567,'unpacked' => 52607},'testers' => {'pass' => 2},'uses' => ['Exporter','XSLoader','strict','warnings']},'Crypt-SmbHash-0.02.tar.gz' => {'author' => 'BJKUIT','description' => 'LM/NT hashing, for Samba\'s smbpasswd entries','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 498,'pod' => 75,'pod_errors' => 0,'total' => 573,'with_comments' => 80},'releases' => 2,'size' => {'packed' => 7940,'unpacked' => 21742},'testers' => {'pass' => 6},'uses' => ['5.005','Digest::MD4','Exporter','strict','vars']},'Crypt-Solitaire-2.0.tar.gz' => {'author' => 'SIFUKURT','description' => 'A very simple encryption system','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 136,'pod' => 56,'pod_errors' => 0,'total' => 192,'with_comments' => 14},'releases' => 2,'size' => {'packed' => 3143,'unpacked' => 6509},'testers' => {'pass' => 7},'uses' => ['Exporter','strict','vars']},'Crypt-Square-1.0.0.tar.gz' => {'author' => 'JCDUQUE','description' => 'Crypt::CBC-compliant block cipher','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 30,'pod' => 113,'pod_errors' => 0,'total' => 143,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 54025,'unpacked' => 161605},'testers' => {'pass' => 1},'uses' => ['Exporter','XSLoader','strict','warnings']},'Crypt-TEA-1.25.tar.gz' => {'author' => 'AMS','description' => 'Tiny Encryption Algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 61,'pod' => 75,'pod_errors' => 0,'total' => 136,'with_comments' => 2},'releases' => 9,'size' => {'packed' => 7786,'unpacked' => 21565},'testers' => {'pass' => 8},'uses' => ['Carp','DynaLoader','strict','vars']},'Crypt-Tea-1.43.tar.gz' => {'author' => 'PJB','description' => 'The Tiny Encryption Algorithm in Perl and JavaScript','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 592,'pod' => 73,'pod_errors' => 0,'total' => 665,'with_comments' => 58},'releases' => 11,'size' => {'packed' => 25479,'unpacked' => 82416},'testers' => {'pass' => 3},'uses' => ['Exporter','Tea','integer']},'Crypt-TripleDES-0.24.tar.gz' => {'author' => 'VIPUL','description' => 'Triple DES encyption.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 615,'pod' => 39,'pod_errors' => 0,'total' => 654,'with_comments' => 51},'releases' => 3,'size' => {'packed' => 6179,'unpacked' => 21917},'testers' => {'pass' => 11},'uses' => ['vars']},'Crypt-Twofish-2.12.tar.gz' => {'author' => 'AMS','description' => 'The Twofish Encryption Algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 69,'pod_errors' => 0,'total' => 159,'with_comments' => 9},'releases' => 4,'size' => {'packed' => 13194,'unpacked' => 38256},'testers' => {'pass' => 15},'uses' => ['Carp','Crypt::CBC','DynaLoader','strict','vars']},'Crypt-Twofish2-0.06.tar.gz' => {'author' => 'MLEHMANN','description' => 'Crypt::CBC compliant Twofish encryption','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 40,'pod' => 76,'pod_errors' => 0,'total' => 116,'with_comments' => 0},'releases' => 6,'size' => {'packed' => 30622,'unpacked' => 98241},'testers' => {'pass' => 10},'uses' => ['DynaLoader']},'Crypt-UnixCrypt-1.0.tar.gz' => {'author' => 'MVORL','description' => 'Perl-only implementation of crypt(3)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 699,'pod' => 50,'pod_errors' => 0,'total' => 749,'with_comments' => 33},'releases' => 1,'size' => {'packed' => 7972,'unpacked' => 26933},'testers' => {'pass' => 13},'uses' => ['5.004','Config','Exporter','strict','vars']},'Crypt-Vigenere-0.07.tar.gz' => {'author' => 'ALIZTA','description' => 'Perl implementation of the Vigenere cipher','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 81,'pod' => 29,'pod_errors' => 0,'total' => 110,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 2174,'unpacked' => 4035},'testers' => {'pass' => 6},'uses' => ['strict']},'Crypt-xDBM_File-0.80.tar.gz' => {'author' => 'EESTABROO','description' => 'encrypt almost any kind of dbm file','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 136,'pod' => 37,'pod_errors' => 0,'total' => 173,'with_comments' => 16},'releases' => 1,'size' => {'packed' => 3228,'unpacked' => 8499},'testers' => {'fail' => 3},'uses' => ['strict','vars']},'Cstools-3.42.tar.gz' => {'author' => 'JANPAZ','description' => 'Charset reencoding','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 969,'pod' => 175,'pod_errors' => 0,'total' => 1144,'with_comments' => 65},'releases' => 30,'size' => {'packed' => 30650,'unpacked' => 101735},'testers' => {'pass' => 7},'uses' => ['Exporter','Getopt::Long','integer','strict','vars']},'CtCmd-1.03.tar.gz' => {'author' => 'RATL','description' => 'Perl extension for Rational ClearCase','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2568,'pod' => 243,'pod_errors' => 0,'total' => 2811,'with_comments' => 706},'releases' => 4,'size' => {'packed' => 34195,'unpacked' => 168247},'testers' => {'fail' => 3},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','Trace','strict','vars']},'Curses-1.06.tar.gz' => {'author' => 'WPS','description' => 'terminal screen handling and optimization','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1160,'pod' => 769,'pod_errors' => 0,'total' => 1929,'with_comments' => 44},'releases' => 6,'size' => {'packed' => 75923,'unpacked' => 376406},'testers' => {'fail' => 3,'pass' => 3,'tests' => '0','unknown' => 18},'uses' => ['5.005','Carp','DynaLoader','Exporter','lib']},'Curses-Devkit-4.9.3.tar.gz' => {'author' => 'GLOVER','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 5598,'pod' => 0,'pod_errors' => 0,'total' => 5598,'with_comments' => 1254},'releases' => 2,'size' => {'packed' => 86241,'unpacked' => 630732},'testers' => {'fail' => 1},'uses' => ['AutoLoader','DynaLoader','Exporter']},'Curses-UI-0.73.tar.gz' => {'author' => 'MARCUS','description' => 'A curses based user user interface framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11213,'pod' => 3705,'pod_errors' => 3,'total' => 14918,'with_comments' => 1447},'releases' => 14,'requires' => ['Curses-1.06.tar.gz','TermReadKey-2.21.tar.gz'],'requires_module' => {'Curses' => 0,'Term::ReadKey' => 0},'requires_recursive' => ['Curses-1.06.tar.gz','TermReadKey-2.21.tar.gz'],'size' => {'packed' => 100971,'unpacked' => 437780},'testers' => {'pass' => 2},'uses' => ['Carp','Curses','Curses::UI::Common','Curses::UI::Container','Curses::UI::Dialog::Basic','Curses::UI::Label','Curses::UI::Listbox','Curses::UI::Searchable','Curses::UI::TextEditor','Curses::UI::TextEntry','Curses::UI::TextViewer','Curses::UI::Widget','Curses::UI::Window','Cwd','Exporter','FileHandle','Term::ReadKey','strict','vars']},'Curses-UI-0.74.tar.gz' => {'author' => 'MARCUS','description' => 'A curses based user user interface framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11214,'pod' => 3705,'pod_errors' => 3,'total' => 14919,'with_comments' => 1447},'releases' => 14,'requires' => ['Curses-1.06.tar.gz','TermReadKey-2.21.tar.gz'],'requires_module' => {'Curses' => 0,'Term::ReadKey' => 0},'requires_recursive' => ['Curses-1.06.tar.gz','TermReadKey-2.21.tar.gz'],'size' => {'packed' => 101250,'unpacked' => 437819},'testers' => {'pass' => 2},'uses' => ['Carp','Curses','Curses::UI::Language','Cwd','Exporter','FileHandle','Term::ReadKey','strict','vars']},'Curses-UI-DelimitedTextViewer-0.10.tar.gz' => {'author' => 'GSAINIO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 219,'pod' => 55,'pod_errors' => 0,'total' => 274,'with_comments' => 57},'releases' => 1,'requires' => ['Curses-UI-0.74.tar.gz'],'requires_module' => {'Curses::UI' => 0},'requires_recursive' => ['Curses-1.06.tar.gz','Curses-UI-0.74.tar.gz','TermReadKey-2.21.tar.gz'],'size' => {'packed' => 3889,'unpacked' => 12318},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Curses','Curses::UI::Common','Curses::UI::TextViewer','strict','vars','warnings']},'CursesApplication-0.2.tar.gz' => {'author' => 'CORLISS','description' => 'Application UI framework for Curses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 492,'pod' => 226,'pod_errors' => 0,'total' => 718,'with_comments' => 70},'releases' => 1,'size' => {'packed' => 17833,'unpacked' => 56041},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Curses','Curses::Forms','Curses::Forms::Dialog','Curses::Forms::Dialog::Input','Curses::Forms::Dialog::Logon','Curses::Widgets','Exporter','strict','vars']},'CursesForms-1.997.tar.gz' => {'author' => 'CORLISS','description' => 'Curses Forms Framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1132,'pod' => 498,'pod_errors' => 0,'total' => 1630,'with_comments' => 202},'releases' => 2,'size' => {'packed' => 19390,'unpacked' => 68338},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Curses','Curses::Widgets','Exporter','constant','strict','vars']},'CursesWidgets-1.997.tar.gz' => {'author' => 'CORLISS','description' => 'Base widget class for use with the Curses::Application framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3468,'pod' => 1748,'pod_errors' => 0,'total' => 5216,'with_comments' => 697},'releases' => 5,'size' => {'packed' => 40526,'unpacked' => 168532},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Curses','Exporter','strict','vars']},'Cvs-0.01.tar.gz' => {'author' => 'RSOLIV','description' => 'Object oriented interface to the CVS command','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2970,'pod' => 861,'pod_errors' => 0,'total' => 3831,'with_comments' => 102},'releases' => 1,'requires' => ['Class-Accessor-0.18.tar.gz','File-Temp-0.12.tar.gz','IPC-Run-0.75.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Class::Accessor' => '0.17','Cwd' => '2.04','File::Temp' => '0.12','FileHandle' => '2.0','IPC::Run' => '0.74'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IPC-Run-0.75.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21901,'unpacked' => 120211},'testers' => {'fail' => 1,'pass' => 6,'tests' => '42'},'uses' => ['Carp','Class::Accessor','Cvs::Command::${name}','Cwd','File::Path','File::Temp','FileHandle','IPC::Run','strict','vars']},'CyberSource-0.01.tar.gz' => {'author' => 'PSMIRNOV','description' => 'Perl extension for ICS2 E-Commerce API library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 48,'pod_errors' => 0,'total' => 77,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2658,'unpacked' => 5496},'testers' => {},'uses' => ['5.006','AutoLoader','DynaLoader','Exporter','strict','warnings']},'CzFast-0.10.tar.gz' => {'author' => 'TRIPIE','description' => 'Perl module for czech charsets manipulation>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 251,'pod' => 83,'pod_errors' => 0,'total' => 334,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 7097,'unpacked' => 16875},'testers' => {'pass' => 2},'uses' => ['Carp','DynaLoader','Exporter','integer','strict','vars','warnings']},'D-oh-0.05.tar.gz' => {'author' => 'CNANDOR','description' => 'Debug module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 46,'pod' => 56,'pod_errors' => 0,'total' => 102,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 3077,'unpacked' => 5611},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','File::Basename','IO::Handle','strict','vars']},'D-oh-Year-0.04.tar.gz' => {'author' => 'MSCHWERN','description' => 'Catch stupid mistakes when mucking with years, like Y2K bugs','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 245,'pod' => 118,'pod_errors' => 0,'total' => 363,'with_comments' => 8},'releases' => 1,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'overload' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 4990,'unpacked' => 11722},'testers' => {'fail' => 1,'pass' => 5,'tests' => '119'},'uses' => ['5.005','Carp','fields','strict','vars']},'DB-Appgen-0.5.tar.gz' => {'author' => 'AMALTSEV','description' => 'Perl interface to APPGEN databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 203,'pod_errors' => 0,'total' => 640,'with_comments' => 107},'releases' => 2,'requires' => ['Error-0.15.tar.gz'],'requires_module' => {'Error' => '0.13'},'requires_recursive' => ['Error-0.15.tar.gz'],'size' => {'packed' => 8348,'unpacked' => 26100},'testers' => {},'uses' => ['5.005_62','AutoLoader','Carp','DB::appgen','DynaLoader','Error','Exporter','strict','warnings']},'DB-Ent-1.63.tar.gz' => {'author' => 'ECALDER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 719,'pod' => 403,'pod_errors' => 0,'total' => 1122,'with_comments' => 89},'releases' => 1,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => 0},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 20580,'unpacked' => 58863},'testers' => {'fail' => 1},'uses' => ['5.006','DBI','Digest::MD5','Exporter','String::Canonical','strict','vars','warnings']},'DB-Objects-0.02.tar.gz' => {'author' => 'ISAAC','description' => 'Framework for developing database-bound obje','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 398,'pod' => 90,'pod_errors' => 1,'total' => 488,'with_comments' => 75},'releases' => 2,'size' => {'packed' => 7320,'unpacked' => 21151},'testers' => {},'uses' => ['strict','vars','warnings']},'DB2-db-0.17.tar.gz' => {'author' => 'DMCBRIDE','description' => 'Framework wrapper around DBD::DB2 for a specific database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1702,'pod' => 504,'pod_errors' => 0,'total' => 2206,'with_comments' => 56},'releases' => 2,'requires' => [''],'requires_module' => {'DBD::DB2' => '0.76'},'requires_recursive' => [''],'size' => {'packed' => 18763,'unpacked' => 59468},'testers' => {'pass' => 1},'uses' => ['Carp','DBI','diagnostics','strict']},'DBD-ADO-2.6.tar.gz' => {'author' => 'TLOWERY','description' => 'Database interface modules of MS ADO for DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2518,'pod' => 231,'pod_errors' => 1,'total' => 2749,'with_comments' => 371},'releases' => 4,'size' => {'packed' => 42428,'unpacked' => 160502},'testers' => {},'uses' => ['Carp','DBI','Data::Dumper','Text::ParseWords','Win32::OLE','Win32::OLE::Const','Win32::OLE::NLS','Win32::OLE::Variant','constant','strict','vars']},'DBD-ASAny-1.12.tar.gz' => {'author' => 'SMIRNIOS','description' => 'Adaptive Server Anywhere Driver for DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 264,'pod' => 0,'pod_errors' => 0,'total' => 264,'with_comments' => 27},'releases' => 8,'size' => {'packed' => 29623,'unpacked' => 97287},'testers' => {},'uses' => ['5.002','strict']},'DBD-Adabas-0.2003.tar.gz' => {'author' => 'JWIED','description' => 'Adabas Driver for DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 384,'pod' => 185,'pod_errors' => 1,'total' => 569,'with_comments' => 76},'releases' => 7,'size' => {'packed' => 134443,'unpacked' => 349001},'testers' => {},'uses' => ['5.004','DBI','strict']},'DBD-AnyData-0.05.tar.gz' => {'author' => 'JZUCKER','description' => '- DBI access to XML, CSV and other formats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 653,'pod' => 937,'pod_errors' => 0,'total' => 1590,'with_comments' => 103},'releases' => 2,'size' => {'packed' => 19955,'unpacked' => 64946},'testers' => {'fail' => 5},'uses' => ['AnyData','DBD::File','Data::Dumper','SQL::Eval','SQL::Statement','strict','vars']},'DBD-CSV-0.1030.tar.gz' => {'author' => 'JWIED','description' => 'DBI driver for CSV files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 965,'pod' => 628,'pod_errors' => 0,'total' => 1593,'with_comments' => 94},'releases' => 21,'size' => {'packed' => 42280,'unpacked' => 168967},'testers' => {'fail' => 1,'pass' => 6,'tests' => '245'},'uses' => ['5.004','DBI','DynaLoader','IO::File','SQL::Eval','SQL::Statement','strict','vars']},'DBD-CSV-0.2002.tar.gz' => {'author' => 'JZUCKER','description' => 'SQL engine and DBI driver for CSV files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 987,'pod' => 631,'pod_errors' => 0,'total' => 1618,'with_comments' => 98},'releases' => 21,'size' => {'packed' => 39046,'unpacked' => 173390},'testers' => {'pass' => 34},'uses' => ['5.004','DBD::File','DBI','DynaLoader','IO::File','SQL::Eval','SQL::Statement','strict','vars']},'DBD-Chart-0.80.tar.gz' => {'author' => 'DARNOLD','description' => 'DBI driver abstraction for Rendering Charts and Graphs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7725,'pod' => 473,'pod_errors' => 0,'total' => 8198,'with_comments' => 1660},'releases' => 20,'size' => {'packed' => 217368,'unpacked' => 533373},'testers' => {'pass' => 1},'uses' => ['Carp','DBI','GD','GD::Text','GD::Text::Align','Time::Local','constant','old','strict']},'DBD-DB2-0.71a.tar.gz' => {'author' => 'MHM','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1782,'pod' => 106,'pod_errors' => 0,'total' => 1888,'with_comments' => 30},'releases' => 1,'size' => {'packed' => 54981,'unpacked' => 325023},'testers' => {},'uses' => ['AutoLoader','Carp','DBI','DynaLoader','Exporter','strict','vars']},'DBD-DBMaker-0.13.tar.gz' => {'author' => 'DBMAKER','description' => 'DBD driver to access DBMaker database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 488,'pod' => 912,'pod_errors' => 1,'total' => 1400,'with_comments' => 86},'releases' => 1,'size' => {'packed' => 57072,'unpacked' => 196702},'testers' => {},'uses' => ['5.003','strict','vars']},'DBD-DtfSQLmac-0.3201.tar.gz' => {'author' => 'TWEGNER','description' => 'Perl interface to the dtF/SQL DB engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6472,'pod' => 3882,'pod_errors' => 14,'total' => 10354,'with_comments' => 2192},'releases' => 3,'size' => {'packed' => 232149,'unpacked' => 863492},'testers' => {},'uses' => ['5.004','Carp','DBI','DynaLoader','Exporter','strict','vars']},'DBD-Empress-0.52.tar.gz' => {'author' => 'SWILLIAM','description' => 'Empress RDBMS Driver','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 0,'pod_errors' => 0,'total' => 177,'with_comments' => 77},'releases' => 1,'size' => {'packed' => 23122,'unpacked' => 77377},'testers' => {'fail' => 3},'uses' => ['strict']},'DBD-EmpressNet-0.52.tar.gz' => {'author' => 'SWILLIAM','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 0,'pod_errors' => 0,'total' => 177,'with_comments' => 77},'releases' => 1,'size' => {'packed' => 21945,'unpacked' => 73447},'testers' => {},'uses' => ['strict']},'DBD-Excel-0.06.tar.gz' => {'author' => 'KWITKNR','description' => 'Excel database driver for the DBI module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 934,'pod' => 197,'pod_errors' => 1,'total' => 1131,'with_comments' => 231},'releases' => 5,'requires' => ['DBI-1.37.tar.gz','SQL-Statement-1.005.tar.gz','Spreadsheet-ParseExcel-0.2602.tar.gz','Spreadsheet-WriteExcel-0.41.tar.gz'],'requires_module' => {'DBI' => 1,'SQL::Statement' => undef,'Spreadsheet::ParseExcel' => '0.22','Spreadsheet::WriteExcel' => '0.31'},'requires_recursive' => ['DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','OLE-Storage_Lite-0.11.tar.gz','Parse-RecDescent-1.94.tar.gz','SQL-Statement-1.005.tar.gz','Spreadsheet-ParseExcel-0.2602.tar.gz','Spreadsheet-WriteExcel-0.41.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19022,'unpacked' => 115243},'testers' => {'pass' => 6},'uses' => ['5.004','DBI','DynaLoader','SQL::Eval','SQL::Statement','Spreadsheet::ParseExcel::SaveParser','strict','vars']},'DBD-Fulcrum-0.20.tar.gz' => {'author' => 'SHARI','description' => 'Fulcrum SearchServer database driver for the DBI module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 217,'pod' => 84,'pod_errors' => 0,'total' => 301,'with_comments' => 33},'releases' => 6,'size' => {'packed' => 23005,'unpacked' => 67552},'testers' => {},'uses' => ['Fulcrum::Constants','strict']},'DBD-Illustra-0.04.tar.gz' => {'author' => 'PMH','description' => 'Illustra Driver for DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 378,'pod' => 389,'pod_errors' => 2,'total' => 767,'with_comments' => 52},'releases' => 4,'size' => {'packed' => 38186,'unpacked' => 138693},'testers' => {},'uses' => ['1','5.004','Symbol','strict','vars']},'DBD-Informix-1.04.PC1.tar.gz' => {'author' => 'JOHNL','description' => 'Informix Database Driver for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2341,'pod' => 1400,'pod_errors' => 0,'total' => 3741,'with_comments' => 402},'releases' => 3,'requires' => ['DBI-1.37.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'DBI' => '1.14','Time::HiRes' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 230704,'unpacked' => 805835},'testers' => {'fail' => 1},'uses' => ['Config','DBD::Informix','DBD::Informix::Defaults','DBD::Informix::TestHarness','DBI','DynaLoader','Exporter','strict','vars']},'DBD-Informix-2003.04.tar.gz' => {'author' => 'JOHNL','description' => 'IBM Informix Database Driver for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3284,'pod' => 1594,'pod_errors' => 0,'total' => 4878,'with_comments' => 786},'releases' => 26,'size' => {'packed' => 255163,'unpacked' => 911403},'testers' => {'pass' => 2},'uses' => ['Carp','Config','DBD::Informix::Configuration','DBD::Informix::Defaults','DBI','DBI::Const::GetInfoReturn','DBI::Const::GetInfoType','DynaLoader','Exporter','strict','vars']},'DBD-Informix4-0.23.tar.gz' => {'author' => 'GTHYNI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 0,'pod_errors' => 0,'total' => 137,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 11049,'unpacked' => 36305},'testers' => {},'uses' => ['5.003','strict']},'DBD-Ingres-0.39.tar.gz' => {'author' => 'HTOUG','description' => 'Ingres Driver for DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 630,'pod' => 645,'pod_errors' => 0,'total' => 1275,'with_comments' => 67},'releases' => 30,'requires' => ['DBI-1.37.tar.gz','Getopt-Long-2.33.tar.gz'],'requires_module' => {'DBI' => 1,'Getopt::Long' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 40585,'unpacked' => 131148},'testers' => {},'uses' => ['5.004','Carp','DBI','Exporter','strict','vars']},'DBD-InterBase-0.41.tar.gz' => {'author' => 'EDPRATOMO','description' => 'DBI driver for Firebird and InterBase RDBMS server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 992,'pod' => 911,'pod_errors' => 0,'total' => 1903,'with_comments' => 257},'releases' => 12,'size' => {'packed' => 77085,'unpacked' => 343335},'testers' => {},'uses' => ['5.004','Carp','DynaLoader','Exporter','strict','vars']},'DBD-JDBC-0.64.tar.gz' => {'author' => 'VIZDOM','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1839,'pod' => 554,'pod_errors' => 0,'total' => 2393,'with_comments' => 346},'releases' => 3,'size' => {'packed' => 152169,'unpacked' => 684227},'testers' => {'fail' => 3,'tests' => '5'},'uses' => ['5.004','Convert::BER','DBI','IO::Socket','strict','vars']},'DBD-LDAP-0.05.tar.gz' => {'author' => 'TURNERJW','description' => 'Perl extension for DBI, providing an SQL/Perl DBI interface to Ldap databases. LDAP stands for the "Lightweight Directory Access Protocol". For more information, see: http://www.ogre.com/ldap/docs.html','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1871,'pod' => 333,'pod_errors' => 0,'total' => 2204,'with_comments' => 252},'releases' => 3,'requires' => ['perl-ldap-0.29.tar.gz'],'requires_module' => {'Net::LDAP' => '0.01'},'requires_recursive' => ['Convert-ASN1-0.17.tar.gz','perl-ldap-0.29.tar.gz'],'size' => {'packed' => 25565,'unpacked' => 76423},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['5.002','DBI','Exporter','Fcntl','Net::LDAP','Net::LDAP::Entry','strict','vars']},'DBD-Multiplex-1.9.tar.gz' => {'author' => 'TKISHEL','description' => 'Spreading database load across servers','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 688,'pod' => 186,'pod_errors' => 0,'total' => 874,'with_comments' => 169},'releases' => 3,'size' => {'packed' => 9193,'unpacked' => 32398},'testers' => {'pass' => 17},'uses' => ['DBI','strict','subs','vars']},'DBD-NET-0.1.tgz' => {'author' => 'EDLIU','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 115,'pod' => 0,'pod_errors' => 0,'total' => 115,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 31854,'unpacked' => 114494},'testers' => {},'uses' => ['DBI','DynaLoader','strict']},'DBD-ODBC-1.06.tar.gz' => {'author' => 'JURL','description' => 'ODBC Driver for DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 799,'pod' => 295,'pod_errors' => 1,'total' => 1094,'with_comments' => 150},'releases' => 34,'size' => {'packed' => 90106,'unpacked' => 313433},'testers' => {},'uses' => ['5.004','DBI','strict']},'DBD-Oracle-1.14.tar.gz' => {'author' => 'TIMB','description' => 'Oracle Driver for DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1612,'pod' => 1184,'pod_errors' => 0,'total' => 2796,'with_comments' => 199},'releases' => 44,'size' => {'packed' => 199667,'unpacked' => 626628},'testers' => {},'uses' => ['5.003','5.004','DBI','Exporter','Tie::Registry','Win32::Registry','Win32::TieRegistry','sigtrap','strict']},'DBD-Ovrimos-0.12.tgz' => {'author' => 'DSOUFLIS','description' => 'DBI Driver for Ovrimos (formerly Altera SQL Server)','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1984,'pod' => 158,'pod_errors' => 0,'total' => 2142,'with_comments' => 46},'releases' => 1,'size' => {'packed' => 13140,'unpacked' => 56769},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.003','IO::Socket','strict','vars']},'DBD-Pg-1.22.tar.gz' => {'author' => 'DWHEELER','description' => 'PostgreSQL database driver for the DBI module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3009,'pod' => 2479,'pod_errors' => 2,'total' => 5488,'with_comments' => 320},'releases' => 36,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Simple' => '0.17'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 80896,'unpacked' => 303787},'testers' => {},'uses' => ['5.004','strict']},'DBD-PgPP-0.04.tar.gz' => {'author' => 'OYAMA','description' => 'Pure Perl PostgreSQL driver for the DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1648,'pod' => 140,'pod_errors' => 0,'total' => 1788,'with_comments' => 21},'releases' => 1,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => 0},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 13016,'unpacked' => 51063},'testers' => {'pass' => 6},'uses' => ['5.004','Carp','DBD::PgPP::AuthenticationCryptPassword','DBD::PgPP::ErrorResponse','DBD::PgPP::PacketStream','DBD::PgPP::Response','DBI','Digest::MD5','IO::Socket','constant','integer','strict','vars']},'DBD-PgSPI-0.01.tar.gz' => {'author' => 'APILOS','description' => 'PostgreSQL database driver for the DBI module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 258,'pod' => 423,'pod_errors' => 1,'total' => 681,'with_comments' => 32},'releases' => 1,'size' => {'packed' => 22094,'unpacked' => 76889},'testers' => {},'uses' => ['5.003','strict']},'DBD-PrimeBase-1.4002.tar.gz' => {'author' => 'PRIMEBASE','description' => 'A primeBase database interface','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 283,'pod' => 263,'pod_errors' => 1,'total' => 546,'with_comments' => 20},'releases' => 2,'size' => {'packed' => 378595,'unpacked' => 1562608},'testers' => {},'uses' => ['strict']},'DBD-QBase-0.03.tgz' => {'author' => 'BENLI','description' => 'QBase Driver for DBI','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 147,'pod' => 0,'pod_errors' => 0,'total' => 147,'with_comments' => 40},'releases' => 1,'size' => {'packed' => 24167,'unpacked' => 68976},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['DBI','DynaLoader','strict']},'DBD-RAM-0.072.tar.gz' => {'author' => 'JZUCKER','description' => 'a DBI driver for files and data structures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1460,'pod' => 816,'pod_errors' => 0,'total' => 2276,'with_comments' => 107},'releases' => 8,'size' => {'packed' => 29864,'unpacked' => 94179},'testers' => {'pass' => 8},'uses' => ['DBD::File','Data::Dumper','IO::File','LWP::UserAgent','SQL::Eval','SQL::Statement','strict','vars']},'DBD-SQLite-0.25.tar.gz' => {'author' => 'MSERGEANT','description' => 'Self Contained RDBMS in a DBI Driver','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 290,'pod' => 103,'pod_errors' => 0,'total' => 393,'with_comments' => 13},'releases' => 21,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.03'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 308644,'unpacked' => 1373001},'testers' => {'fail' => 2,'pass' => 9,'tests' => '261'},'uses' => ['DBI','strict','vars']},'DBD-SQLrelay-0.1.tar.gz' => {'author' => 'DMOW','description' => 'perl DBI driver for SQL Relay','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 233,'pod' => 73,'pod_errors' => 1,'total' => 306,'with_comments' => 23},'releases' => 1,'size' => {'packed' => 3317,'unpacked' => 8595},'testers' => {},'uses' => ['Firstworks::SQLRClient','strict','vars']},'DBD-SearchServer-0.21.tar.gz' => {'author' => 'SHARI','description' => 'PCDOCS/Fulcrum SearchServer Driver for DB','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 232,'pod' => 86,'pod_errors' => 0,'total' => 318,'with_comments' => 28},'releases' => 1,'size' => {'packed' => 24514,'unpacked' => 71961},'testers' => {},'uses' => ['SearchServer::Constants','strict']},'DBD-Solid-0.11a.tar.gz' => {'author' => 'TWENRICH','description' => 'DBD driver to access Solid database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 953,'pod' => 175,'pod_errors' => 0,'total' => 1128,'with_comments' => 65},'releases' => 3,'size' => {'packed' => 53188,'unpacked' => 228742},'testers' => {},'uses' => ['5.003','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'DBD-Solid-0.20a.tar.gz' => {'author' => 'JSLAGEL','description' => 'Solid Driver for DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 975,'pod' => 175,'pod_errors' => 0,'total' => 1150,'with_comments' => 70},'releases' => 3,'size' => {'packed' => 52816,'unpacked' => 235346},'testers' => {},'uses' => ['5.003','AutoLoader','Carp','DBD::Solid::Const','DynaLoader','Exporter','strict','vars']},'DBD-Sprite-0.44.tar.gz' => {'author' => 'TURNERJW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4235,'pod' => 852,'pod_errors' => 1,'total' => 5087,'with_comments' => 742},'releases' => 15,'size' => {'packed' => 65291,'unpacked' => 214259},'testers' => {'fail' => 3,'pass' => 7},'uses' => ['5.002','Cwd','DBI','Exporter','Fcntl','File::DosGlob','MIME::Base64','XML::Simple','strict','vars']},'DBD-Sybase-1.00.tar.gz' => {'author' => 'MEWP','description' => 'Sybase Driver for DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1070,'pod' => 1333,'pod_errors' => 2,'total' => 2403,'with_comments' => 77},'releases' => 27,'size' => {'packed' => 165041,'unpacked' => 376207},'testers' => {},'uses' => ['Carp','DBI','strict']},'DBD-Template-0.01.tar.gz' => {'author' => 'KWITKNR','description' => 'A template/sample class for DBI drivers. This is still B<alpha version>.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 904,'pod' => 210,'pod_errors' => 0,'total' => 1114,'with_comments' => 241},'releases' => 1,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => 1},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 10484,'unpacked' => 54397},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['5.004','DBI','SQL::Eval','SQL::Statement','strict','vars']},'DBD-Teradata-1.13.tar.gz' => {'author' => 'DARNOLD','description' => 'a DBI driver for Teradata','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 3797,'pod' => 129,'pod_errors' => 0,'total' => 3926,'with_comments' => 720},'releases' => 4,'size' => {'packed' => 60091,'unpacked' => 238528},'testers' => {'fail' => 1},'uses' => ['5.005','DBI','DBI::DBD','IO::Socket','Socket','strict','vars']},'DBD-Trini-0.01.tar.gz' => {'author' => 'MIKO','description' => 'Pure Perl DBMS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2122,'pod' => 204,'pod_errors' => 0,'total' => 2326,'with_comments' => 757},'releases' => 1,'requires' => ['Data-Taxi-0.94.tar.gz','SQL-YASP-0.11.tar.gz'],'requires_module' => {'Data::Taxi' => '0.01','SQL::YASP' => '0.01'},'requires_recursive' => ['Data-Taxi-0.94.tar.gz','SQL-YASP-0.11.tar.gz'],'size' => {'packed' => 21157,'unpacked' => 73740},'testers' => {},'uses' => ['Carp','DBI','Data::Taxi','Debug::ShowStuff','FileHandle','SQL::YASP','Symbol','constant','strict','vars']},'DBD-Unify-0.26.tgz' => {'author' => 'HMBRAND','description' => 'DBI driver for Unify database systems','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 564,'pod' => 179,'pod_errors' => 0,'total' => 743,'with_comments' => 85},'releases' => 14,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.13'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 32153,'unpacked' => 113324},'testers' => {},'uses' => ['5.005','Carp','DBI','Exporter','strict','vars']},'DBD-XBase-0.234.tar.gz' => {'author' => 'JANPAZ','description' => 'Read/write interface to XBase files','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 5283,'pod' => 838,'pod_errors' => 1,'total' => 6121,'with_comments' => 577},'releases' => 46,'size' => {'packed' => 110581,'unpacked' => 429507},'testers' => {'pass' => 2},'uses' => ['5.004','Data::Dumper','Exporter','Fcntl','IO::File','SDBM_File','Time::JulianDay','strict','vars']},'DBD-mysql-2.1028.tar.gz' => {'author' => 'JWIED','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1436,'pod' => 1908,'pod_errors' => 0,'total' => 3344,'with_comments' => 26},'releases' => 34,'size' => {'packed' => 98007,'unpacked' => 367640},'testers' => {},'uses' => ['5.004','Carp','DBD::mysql','DBI','DynaLoader','Exporter','strict','vars']},'DBD-mysql-2.9002.tar.gz' => {'author' => 'RUDY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1902,'pod' => 1948,'pod_errors' => 1,'total' => 3850,'with_comments' => 277},'releases' => 34,'size' => {'packed' => 112563,'unpacked' => 403530},'testers' => {'pass' => 1},'uses' => ['5.004','Carp','DBI','DBI::Const::GetInfoReturn','DBI::Const::GetInfoType','DynaLoader','Exporter','Mysql::Statement','strict','vars']},'DBD-mysqlPP-0.04.tar.gz' => {'author' => 'OYAMA','description' => 'Pure Perl MySQL driver for the DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 507,'pod' => 347,'pod_errors' => 0,'total' => 854,'with_comments' => 2},'releases' => 3,'requires' => ['DBI-1.37.tar.gz','Net-MySQL-0.08.tar.gz'],'requires_module' => {'DBI' => 1,'Net::MySQL' => '0.08'},'requires_recursive' => ['DBI-1.37.tar.gz','IO-1.20.tar.gz','Net-MySQL-0.08.tar.gz'],'size' => {'packed' => 7444,'unpacked' => 20934},'testers' => {'pass' => 1},'uses' => ['Carp','DBI','Net::MySQL','strict','vars']},'DBD-pNET-0.1003.tar.gz' => {'author' => 'JWIED','description' => 'DBD proxy driver','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 276,'pod' => 101,'pod_errors' => 0,'total' => 377,'with_comments' => 42},'releases' => 3,'size' => {'packed' => 38749,'unpacked' => 153300},'testers' => {'fail' => 1},'uses' => ['5.002','strict']},'DBD_SQLFLEX_8.2.tar.gz' => {'author' => 'INFOFLEX','description' => 'Access to Sqlflex Databases','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 967,'pod' => 623,'pod_errors' => 0,'total' => 1590,'with_comments' => 127},'releases' => 1,'size' => {'packed' => 79009,'unpacked' => 321742},'testers' => {},'uses' => ['DBI','DynaLoader','Exporter','strict']},'DBI-1.25.tar.gz' => {'author' => 'TIMB','description' => 'Database independent interface for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10242,'pod' => 5712,'pod_errors' => 0,'total' => 15954,'with_comments' => 1104},'releases' => 66,'size' => {'packed' => 247689,'unpacked' => 810636},'testers' => {'fail' => 1,'pass' => 12},'uses' => ['5.004','5.005_03','Benchmark','Carp','Config','DBI','DBI::Format','Data::Dumper','FileHandle','Getopt::Long','Math::BigInt','RPC::PlClient','RPC::PlServer','Symbol','Term::ReadLine','Text::Abbrev','VMS::Filespec','Win32::ODBC','constant','strict','vars']},'DBI-1.37.tar.gz' => {'author' => 'TIMB','description' => 'Database independent interface for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11652,'pod' => 6910,'pod_errors' => 0,'total' => 18562,'with_comments' => 1536},'releases' => 66,'size' => {'packed' => 294495,'unpacked' => 968138},'testers' => {'fail' => 2,'pass' => 11,'tests' => '1320'},'uses' => ['$module','5.004','5.005_03','Apache','Benchmark','Carp','Config','Data::Dumper','DynaLoader','Exporter','File::Spec','FileHandle','Math::BigInt','RPC::PlClient','RPC::PlServer','Symbol','VMS::Filespec','Win32::ODBC','constant','strict','threads','vars']},'DBI-Shell-11.91.tar.gz' => {'author' => 'TLOWERY','description' => 'Defined display formats for data from DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4622,'pod' => 375,'pod_errors' => 0,'total' => 4997,'with_comments' => 627},'releases' => 2,'requires' => ['IO-Tee-0.64.tar.gz','Test-Simple-0.47.tar.gz','Text-Reform-1.11.tar.gz'],'requires_module' => {'IO::Tee' => 0,'Test::More' => 0,'Text::Reform' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-Tee-0.64.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Reform-1.11.tar.gz'],'size' => {'packed' => 47175,'unpacked' => 177943},'testers' => {'pass' => 12},'uses' => ['Benchmark','Carp','DBI','Data::Dumper','File::Basename','File::Spec','FileHandle','Getopt::Long','IO::File','IO::Tee','Term::ReadLine','Text::Abbrev','Text::ParseWords','Text::Reform','Text::Wrap','constant','strict','vars']},'DBI-Wrap-1.00.tar.gz' => {'author' => 'EMRYS','description' => 'Object oriented wrapper around DBI.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 780,'pod' => 211,'pod_errors' => 1,'total' => 991,'with_comments' => 33},'releases' => 1,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.3'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 6899,'unpacked' => 27749},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['DBI','Time::Local','strict','vars']},'DBIx-Abstract-1.005.tar.gz' => {'author' => 'TURNERA','description' => 'Wrapper for DBI that generates SQL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2656,'pod' => 1436,'pod_errors' => 1,'total' => 4092,'with_comments' => 175},'releases' => 13,'requires' => ['DBI-1.37.tar.gz','Scalar-List-Utils-1.11.tar.gz'],'requires_module' => {'DBI' => 0,'Scalar::Util' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Scalar-List-Utils-1.11.tar.gz'],'size' => {'packed' => 38086,'unpacked' => 126669},'testers' => {'pass' => 4},'uses' => ['5.004','Carp','Config','DBI','Exporter','Scalar::Util','Test::Builder','strict','threads::shared','vars']},'DBIx-AbstractLite-0.02.tar.gz' => {'author' => 'ILIAL','description' => 'Lightweight DBI SQL abstraction in a hybrid interface','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 219,'pod' => 62,'pod_errors' => 0,'total' => 281,'with_comments' => 8},'releases' => 2,'requires' => ['DBI-1.37.tar.gz','Error-Dumb-0.02.tar.gz','LogCarp-1.12.tar.gz'],'requires_module' => {'CGI::LogCarp' => 0,'DBI' => 0,'Error::Dumb' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Error-Dumb-0.02.tar.gz','LogCarp-1.12.tar.gz'],'size' => {'packed' => 3411,'unpacked' => 7775},'testers' => {'pass' => 6},'uses' => ['CGI::LogCarp','DBI','Error::Dumb','strict','vars']},'DBIx-AnyDBD-2.01.tar.gz' => {'author' => 'MSERGEANT','description' => 'Module to make cross db applications easier','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1296,'pod' => 172,'pod_errors' => 0,'total' => 1468,'with_comments' => 99},'releases' => 11,'size' => {'packed' => 11019,'unpacked' => 41149},'testers' => {'fail' => 1,'pass' => 12,'tests' => '2'},'uses' => ['Carp','DBI','Digest::MD5','Time::Object','Time::Seconds','constant','strict','vars']},'DBIx-BLOB-Handle-0.2.tar.gz' => {'author' => 'MSOUTHERN','description' => 'Read Database Large Object Binaries from file handles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 208,'pod_errors' => 1,'total' => 446,'with_comments' => 14},'releases' => 2,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => undef},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 6355,'unpacked' => 20620},'testers' => {'pass' => 3},'uses' => ['','DBI','IO::Handle','IO::Seekable','Symbol','strict','vars','warnings']},'DBIx-BabelKit-1.07.tgz' => {'author' => 'JGORMAN','description' => 'Universal Multilingual Database Code Table','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 599,'pod' => 107,'pod_errors' => 0,'total' => 706,'with_comments' => 32},'releases' => 5,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => 0},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 49101,'unpacked' => 263895},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars','warnings']},'DBIx-Broker-1.14.tar.gz' => {'author' => 'XOMINA','description' => 'a little layer somewhere between top-level code and raw DBI calls','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 629,'pod' => 146,'pod_errors' => 0,'total' => 775,'with_comments' => 61},'releases' => 1,'size' => {'packed' => 14337,'unpacked' => 44712},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['Carp','DBI','Exporter','strict','vars']},'DBIx-Browse-2.09.tar.gz' => {'author' => 'EJDRS','description' => 'A class to browse related tables via CGI/Web','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1472,'pod' => 339,'pod_errors' => 0,'total' => 1811,'with_comments' => 201},'releases' => 6,'requires' => ['DBI-1.37.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DBI' => '1.00','Test::More' => '0.45'},'requires_recursive' => ['DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 25116,'unpacked' => 81115},'testers' => {'pass' => 2},'uses' => ['CGI','CGI::Carp','Carp','DBI','Exporter','diagnostics','strict','vars']},'DBIx-CGI-0.06.tar.gz' => {'author' => 'HORNBURG','description' => 'Easy to Use DBI interface for CGI scripts','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 147,'pod' => 86,'pod_errors' => 0,'total' => 233,'with_comments' => 38},'releases' => 6,'size' => {'packed' => 7826,'unpacked' => 23542},'testers' => {'tests' => '0','unknown' => 24},'uses' => ['DBI','DBIx::Easy','Exporter','HTML::Entities','strict','vars']},'DBIx-CGITables-0.001.tar.gz' => {'author' => 'TOBIX','description' => 'Easy DB access from a CGI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1118,'pod' => 284,'pod_errors' => 0,'total' => 1402,'with_comments' => 203},'releases' => 3,'size' => {'packed' => 20821,'unpacked' => 57550},'testers' => {'pass' => 5,'tests' => '0','unknown' => 18},'uses' => ['Carp','Exporter','strict','vars']},'DBIx-Chart-0.01.tar.gz' => {'author' => 'DARNOLD','description' => 'extends DBI & SQL w/ charting capabilities','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 696,'pod' => 166,'pod_errors' => 0,'total' => 862,'with_comments' => 148},'releases' => 1,'size' => {'packed' => 284871,'unpacked' => 485153},'testers' => {},'uses' => ['5.6.0','Carp','DBD::Chart','DBI','strict']},'DBIx-CodeKit-1.07.tgz' => {'author' => 'JGORMAN','description' => 'Universal Database Code Table','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 488,'pod' => 100,'pod_errors' => 0,'total' => 588,'with_comments' => 32},'releases' => 5,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => 0},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 32651,'unpacked' => 149270},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars','warnings']},'DBIx-Connect-1.9.tar.gz' => {'author' => 'TBONE','description' => 'DBI, DBIx::AnyDBD, and Alzabo database connection (info) via AppConfig','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 143,'pod' => 89,'pod_errors' => 0,'total' => 232,'with_comments' => 11},'releases' => 11,'requires' => ['AppConfig-Std-1.07.tar.gz','DBI-1.37.tar.gz','TermReadKey-2.21.tar.gz'],'requires_module' => {'AppConfig::Std' => '1.05','DBI' => '1.19','Term::ReadKey' => '2.18'},'requires_recursive' => ['AppConfig-1.55.tar.gz','AppConfig-Std-1.07.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4142,'unpacked' => 8065},'testers' => {'fail' => 1},'uses' => ['5.005_62','AppConfig','AppConfig::Std','DBI','Data::Dumper','Exporter','Term::ReadKey','strict','warnings']},'DBIx-Copy-0.02.tar.gz' => {'author' => 'TOBIX','description' => 'Copying databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 157,'pod' => 98,'pod_errors' => 0,'total' => 255,'with_comments' => 27},'releases' => 2,'size' => {'packed' => 4907,'unpacked' => 11585},'testers' => {'pass' => 9},'uses' => ['Carp','DBI','strict','vars']},'DBIx-Cursor-0.14.tar.gz' => {'author' => 'TMAEK','description' => 'Perl extension for easy DBI-access to a single table.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 398,'pod' => 205,'pod_errors' => 0,'total' => 603,'with_comments' => 34},'releases' => 2,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.15'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 5734,'unpacked' => 17053},'testers' => {'pass' => 3},'uses' => ['5.6.0','Carp','strict','warnings']},'DBIx-DBCluster-0.01.tar.gz' => {'author' => 'ARAK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 571,'pod' => 141,'pod_errors' => 0,'total' => 712,'with_comments' => 23},'releases' => 1,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.37'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 6735,'unpacked' => 21710},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','DBI','Data::Dumper','strict','warnings']},'DBIx-DBO2-0.006.tar.gz' => {'author' => 'EVO','description' => 'Objects mapping to SQL relational structures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3149,'pod' => 2108,'pod_errors' => 0,'total' => 5257,'with_comments' => 208},'releases' => 6,'requires' => ['Class-MakeMethods-1.006.tar.gz','DBIx-SQLEngine-0.009.tar.gz'],'requires_module' => {'Class::MakeMethods' => '1.001','DBIx::SQLEngine' => '0.005'},'requires_recursive' => ['Class-MakeMethods-1.006.tar.gz','DBI-1.37.tar.gz','DBIx-AnyDBD-2.01.tar.gz','DBIx-SQLEngine-0.009.tar.gz'],'size' => {'packed' => 33212,'unpacked' => 144038},'testers' => {'fail' => 2},'uses' => ['','$qclass','5.005','Carp','Class::MakeMethods','Class::MakeMethods::Composite::Inheritable','Class::MakeMethods::Standard::Hash','Class::MakeMethods::Standard::Universal','Class::MakeMethods::Template','DBIx::SQLEngine','DBIx::SQLEngine::Criteria','DBIx::SQLEngine::Criteria::And','DBIx::SQLEngine::Criteria::StringEquality','Data::Dumper','Data::Quantity::Finance::CreditCardNumber','Data::Quantity::Finance::Currency','Data::Quantity::Time::Date','Data::Quantity::Time::Timestamp','Data::Sorting','MIME::Base64','Net::DNS','Storable','String::Escape','Time::JulianDay','integer','strict','vars']},'DBIx-DBSchema-0.21.tar.gz' => {'author' => 'IVAN','description' => 'Database-independent schema objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1203,'pod' => 676,'pod_errors' => 1,'total' => 1879,'with_comments' => 102},'releases' => 11,'requires' => ['DBI-1.37.tar.gz','FreezeThaw-0.43.tar.gz'],'requires_module' => {'DBI' => 0,'FreezeThaw' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','FreezeThaw-0.43.tar.gz'],'size' => {'packed' => 14153,'unpacked' => 51105},'testers' => {'pass' => 4},'uses' => ['Carp','DBI','DBIx::DBSchema::DBD::$driver','Exporter','FreezeThaw','strict','vars']},'DBIx-DBStag-0.01.tar.gz' => {'author' => 'CMUNGALL','description' => 'Automatic database to Stag/XML mapping','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2433,'pod' => 374,'pod_errors' => 0,'total' => 2807,'with_comments' => 604},'releases' => 1,'requires' => ['DBI-1.37.tar.gz','Data-Stag-0.03.tar.gz'],'requires_module' => {'DBI' => 0,'Data::Stag' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Data-Stag-0.03.tar.gz','File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz','XML-Parser-2.31.tar.gz','libxml-perl-0.07.tar.gz'],'size' => {'packed' => 476322,'unpacked' => 11189211},'testers' => {},'uses' => ['Carp','DBI','DBIx::DBSchema','Data::Dumper','Data::Stag','Exporter','Parse::RecDescent','SQL::Statement','Test','Text::Balanced','strict','that','vars']},'DBIx-DWIW-0.32.tar.gz' => {'author' => 'JZAWODNY','description' => 'Robust and simple DBI wrapper to Do What I Want (DWIW)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1945,'pod' => 630,'pod_errors' => 1,'total' => 2575,'with_comments' => 202},'releases' => 21,'requires' => ['DBI-1.37.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'DBI' => '1.12','Time::HiRes' => '0.01'},'requires_recursive' => ['DBI-1.37.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 20087,'unpacked' => 65136},'testers' => {'pass' => 3},'uses' => ['5.005','Carp','DBI','Sys::Hostname','Time::HiRes','strict','vars']},'DBIx-DataLookup-0.02.tar.gz' => {'author' => 'VLADB','description' => 'Perl extension for database view lookup table.','files' => [],'lines' => {'nonpod' => 274,'pod' => 80,'pod_errors' => 0,'total' => 354,'with_comments' => 115},'releases' => 3,'size' => {'packed' => 6667,'unpacked' => 15873},'testers' => {'pass' => 3},'uses' => ['5.006','AutoLoader','Exporter','strict','warnings']},'DBIx-DataLookup-0.03.tar.gz' => {'author' => 'VLADB','description' => 'Perl extension for database view lookup table.','files' => [],'lines' => {'nonpod' => 299,'pod' => 126,'pod_errors' => 0,'total' => 425,'with_comments' => 114},'releases' => 3,'size' => {'packed' => 7419,'unpacked' => 18380},'testers' => {'fail' => 1},'uses' => ['5.006','AutoLoader','DataLookup','Exporter','strict','warnings']},'DBIx-DataSource-0.02.tar.gz' => {'author' => 'IVAN','description' => 'Database-independant create and drop functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 204,'pod_errors' => 0,'total' => 356,'with_comments' => 8},'releases' => 1,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => 0},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 3432,'unpacked' => 11096},'testers' => {'pass' => 8},'uses' => ['DBI','DBIx::DataSource::$driver','Exporter','strict','vars']},'DBIx-Dump-0.04.tar.gz' => {'author' => 'ISTERIN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 170,'pod' => 33,'pod_errors' => 0,'total' => 203,'with_comments' => 13},'releases' => 4,'size' => {'packed' => 3440,'unpacked' => 7607},'testers' => {'pass' => 3},'uses' => ['5.006','AutoLoader','Exporter','IO::File','Spreadsheet::WriteExcel','Text::CSV_XS','strict','warnings']},'DBIx-Ease-0.07.tar.gz' => {'author' => 'ALPO','description' => 'less-code DBI interactions for all drivers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 55,'pod' => 57,'pod_errors' => 0,'total' => 112,'with_comments' => 1},'releases' => 5,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 1851,'unpacked' => 4925},'testers' => {'pass' => 1},'uses' => ['DBI','strict','vars']},'DBIx-Easy-0.15.tar.gz' => {'author' => 'HORNBURG','description' => 'Easy to Use DBI interface','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1014,'pod' => 249,'pod_errors' => 0,'total' => 1263,'with_comments' => 205},'releases' => 7,'size' => {'packed' => 26656,'unpacked' => 102159},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['DBI','Exporter','strict','vars']},'DBIx-FetchLoop-0.41.tar.gz' => {'author' => 'BITS','description' => 'Fetch with change detection and aggregates','files' => ['Makefile.PL'],'lines' => {'nonpod' => 332,'pod' => 242,'pod_errors' => 0,'total' => 574,'with_comments' => 15},'releases' => 3,'size' => {'packed' => 5447,'unpacked' => 27083},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','DBI','strict','vars']},'DBIx-FileSystem-1.07.tar.gz' => {'author' => 'AFRIKA','description' => 'manage tables like a filesystem','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1771,'pod' => 394,'pod_errors' => 0,'total' => 2165,'with_comments' => 342},'releases' => 3,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => 1},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 30438,'unpacked' => 103407},'testers' => {'pass' => 1},'uses' => ['DBI','Exporter','Fcntl','POSIX','Term::ReadLine','strict','vars']},'DBIx-Formatter-0.01.tar.gz' => {'author' => 'FABRVEC','description' => 'Module to perform report generation via query DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 741,'pod' => 380,'pod_errors' => 0,'total' => 1121,'with_comments' => 150},'releases' => 1,'size' => {'packed' => 15128,'unpacked' => 78510},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['DBI','Exporter','vars']},'DBIx-FullTextSearch-0.73.tar.gz' => {'author' => 'TJMATHER','description' => 'Indexing documents with MySQL as storage','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1988,'pod' => 519,'pod_errors' => 1,'total' => 2507,'with_comments' => 99},'releases' => 19,'requires' => ['Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Parse::RecDescent' => 0},'requires_recursive' => ['Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 81907,'unpacked' => 295205},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Dumper','LWP::UserAgent','Parse::RecDescent','locale','strict','vars']},'DBIx-HTML-ClientDB-1.03.tgz' => {'author' => 'RSAVAGE','description' => 'Convert SQL into a JavaScript database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 413,'pod' => 277,'pod_errors' => 0,'total' => 690,'with_comments' => 67},'releases' => 4,'size' => {'packed' => 12389,'unpacked' => 54999},'testers' => {'pass' => 1},'uses' => ['5.005_62','Carp','Exporter','Image::MagickWrapper','strict','warnings']},'DBIx-HTML-LinkedMenus-1.05.tgz' => {'author' => 'RSAVAGE','description' => 'Convert db data to 2 linked HTML popup menus','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 396,'pod' => 320,'pod_errors' => 0,'total' => 716,'with_comments' => 56},'releases' => 6,'size' => {'packed' => 11979,'unpacked' => 57217},'testers' => {'pass' => 2},'uses' => ['5.005_62','Carp','Exporter','Image::MagickWrapper','strict','warnings']},'DBIx-HTML-PopupRadio-1.08.tgz' => {'author' => 'RSAVAGE','description' => 'Convert db data to popup menu or radio group','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 336,'pod' => 250,'pod_errors' => 0,'total' => 586,'with_comments' => 65},'releases' => 9,'size' => {'packed' => 12549,'unpacked' => 54816},'testers' => {'pass' => 2},'uses' => ['5.005_62','Carp','Exporter','Image::MagickWrapper','strict','warnings']},'DBIx-HTMLTable-0.22.tar.gz' => {'author' => 'RKIES','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 138,'pod' => 113,'pod_errors' => 0,'total' => 251,'with_comments' => 5},'releases' => 3,'size' => {'packed' => 11901,'unpacked' => 33140},'testers' => {'pass' => 3},'uses' => []},'DBIx-HTMLView-0.2.tar.gz' => {'author' => 'HAKANARDO','description' => 'For creating web userinterfaces to DBI databases.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 812,'pod' => 306,'pod_errors' => 0,'total' => 1118,'with_comments' => 80},'releases' => 8,'size' => {'packed' => 18134,'unpacked' => 53990},'testers' => {'fail' => 2},'uses' => ['CGI','DBI','DBIx::HTMLView','DBIx::HTMLView::CGIView']},'DBIx-HTMLView-LATEST.tar.gz' => {'author' => 'HAKANARDO','description' => 'For handling DBI relation databases and web interfaces','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6127,'pod' => 1316,'pod_errors' => 0,'total' => 7443,'with_comments' => 892},'releases' => 1,'size' => {'packed' => 72116,'unpacked' => 283626},'testers' => {'fail' => 3},'uses' => ['Apache::Constants','Apache::DBI','CGI','Carp','DBI','Data::Dumper','Exporter','URI::Escape','strict','vars']},'DBIx-HTMLinterface-0.11.tar.gz' => {'author' => 'JFURNESS','description' => 'Class for creating a CGI interface to a database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1411,'pod' => 359,'pod_errors' => 0,'total' => 1770,'with_comments' => 231},'releases' => 2,'size' => {'packed' => 16335,'unpacked' => 62002},'testers' => {'pass' => 6},'uses' => ['5.004','CGI','DBI','strict','vars']},'DBIx-Hash2Table-1.03.tgz' => {'author' => 'RSAVAGE','description' => 'Save a hash into a database table','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 246,'pod' => 205,'pod_errors' => 0,'total' => 451,'with_comments' => 56},'releases' => 4,'size' => {'packed' => 8305,'unpacked' => 32978},'testers' => {'pass' => 1},'uses' => ['5.005_62','Carp','Exporter','strict','warnings']},'DBIx-Informix-Perform-0.01.tar.gz' => {'author' => 'WEAV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2031,'pod' => 154,'pod_errors' => 0,'total' => 2185,'with_comments' => 260},'releases' => 1,'requires' => ['CursesApplication-0.2.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'Curses::Application' => 0,'DBI' => 0},'requires_recursive' => ['CursesApplication-0.2.tar.gz','DBI-1.37.tar.gz'],'size' => {'packed' => 21899,'unpacked' => 65219},'testers' => {},'uses' => ['5.6.0','Carp','Curses','Curses::Application','Curses::Forms','Curses::Widgets','Curses::Widgets::ButtonSet','Curses::Widgets::TextField','DBI','DBIx::Informix::Perform::Widgets','Data::Dumper','Exporter','POSIX','constant','strict','vars','warnings']},'DBIx-KwIndex-0.03.tar.gz' => {'author' => 'SHARYANTO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 635,'pod' => 215,'pod_errors' => 0,'total' => 850,'with_comments' => 61},'releases' => 3,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => 0},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 11556,'unpacked' => 36351},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['Carp','strict','vars']},'DBIx-Librarian-0.3.tar.gz' => {'author' => 'JMAY','description' => 'Manage SQL in repository outside code','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 981,'pod' => 571,'pod_errors' => 4,'total' => 1552,'with_comments' => 49},'releases' => 3,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.13'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 12129,'unpacked' => 41263},'testers' => {'fail' => 2},'uses' => ['$classpath','5.004','5.005','Carp','DBI','strict','vars','warnings']},'DBIx-Lookup-Field-1.21.tar.gz' => {'author' => 'MARCEL','description' => 'Create a lookup hash from a database table','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 94,'pod_errors' => 0,'total' => 172,'with_comments' => 0},'releases' => 3,'requires' => ['Test-Distribution-1.02.tar.gz'],'requires_module' => {'Test::Distribution' => '1.02'},'requires_recursive' => ['File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Distribution-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 3086,'unpacked' => 8003},'testers' => {'fail' => 2,'pass' => 3},'uses' => ['5.005_62','Carp','Exporter','strict','warnings']},'DBIx-MSSQLReporter-1.02.tgz' => {'author' => 'RSAVAGE','description' => 'Interface to MS SQL Server & MS Data Engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 536,'pod' => 209,'pod_errors' => 0,'total' => 745,'with_comments' => 162},'releases' => 3,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.13'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 9295,'unpacked' => 41231},'testers' => {'pass' => 1},'uses' => ['Carp','DBI','Exporter','strict','vars']},'DBIx-MySQLSequence-0.1.tar.gz' => {'author' => 'ADAMK','description' => 'Emulate sequences in MySQL.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 218,'pod_errors' => 0,'total' => 655,'with_comments' => 63},'releases' => 1,'size' => {'packed' => 8150,'unpacked' => 32048},'testers' => {'pass' => 4},'uses' => ['5.005','DBI','UNIVERSAL','constant','diagnostics','strict','vars','warnings']},'DBIx-Namespace-0.04.tar.gz' => {'author' => 'CPWILLMOT','description' => 'Provide directory-like table names','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 371,'pod' => 364,'pod_errors' => 0,'total' => 735,'with_comments' => 11},'releases' => 1,'requires' => ['DBI-1.37.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'DBI' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8162,'unpacked' => 24141},'testers' => {'pass' => 2},'uses' => ['Carp','DBI','strict','warnings']},'DBIx-OracleLogin-0.02.tar.gz' => {'author' => 'DBEN','description' => 'takes a string and splits out individual login information (user id, Oracle sid, and password) to be used in a DBI->connect() statement when connecting to an Oracle database.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 42,'pod_errors' => 0,'total' => 127,'with_comments' => 10},'releases' => 2,'requires' => ['TermReadKey-2.21.tar.gz'],'requires_module' => {'Term::ReadKey' => '2.0'},'requires_recursive' => ['TermReadKey-2.21.tar.gz'],'size' => {'packed' => 2170,'unpacked' => 4802},'testers' => {'pass' => 3},'uses' => ['Exporter','Term::ReadKey','strict','vars']},'DBIx-OracleSequence-0.04.tar.gz' => {'author' => 'BLABES','description' => 'OO access to Oracle sequences via DBD-Oracle','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 294,'pod' => 117,'pod_errors' => 0,'total' => 411,'with_comments' => 3},'releases' => 4,'requires' => ['DBD-Oracle-1.14.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'DBD::Oracle' => '1','DBI' => '1'},'requires_recursive' => ['DBD-Oracle-1.14.tar.gz','DBI-1.37.tar.gz'],'size' => {'packed' => 4795,'unpacked' => 15490},'testers' => {},'uses' => ['5.003','DBD::Oracle','strict','vars']},'DBIx-Pager-0.02.tar.gz' => {'author' => 'IKEBE','description' => 'SQL paging helper.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 104,'pod' => 122,'pod_errors' => 0,'total' => 226,'with_comments' => 1},'releases' => 2,'requires' => ['Class-Accessor-0.18.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Accessor' => '0.17','Test::More' => '0.32'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2827,'unpacked' => 7423},'testers' => {'pass' => 1},'uses' => ['Carp','Class::Accessor','DBI','strict','vars']},'DBIx-Password-1.8.tar.gz' => {'author' => 'KROW','description' => 'Abstration layer for database passwords','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 56,'pod_errors' => 0,'total' => 162,'with_comments' => 0},'releases' => 7,'size' => {'packed' => 5372,'unpacked' => 18418},'testers' => {'pass' => 7},'uses' => ['strict']},'DBIx-Perform-0.01.tar.gz' => {'author' => 'WEAV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2028,'pod' => 150,'pod_errors' => 0,'total' => 2178,'with_comments' => 260},'releases' => 1,'requires' => ['CursesApplication-0.2.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'Curses::Application' => 0,'DBI' => 0},'requires_recursive' => ['CursesApplication-0.2.tar.gz','DBI-1.37.tar.gz'],'size' => {'packed' => 21533,'unpacked' => 63980},'testers' => {'fail' => 1,'tests' => '3'},'uses' => ['5.6.0','Carp','Curses','Curses::Application','Curses::Forms','Curses::Widgets','Curses::Widgets::ButtonSet','Curses::Widgets::TextField','DBI','DBIx::Perform::Widgets','Data::Dumper','Exporter','POSIX','constant','strict','vars','warnings']},'DBIx-Procedure-Oracle-0.2.tar.gz' => {'author' => 'MSOUTHERN','description' => 'Call PL/SQL stored procedures and functions without writing SQL or needing to know about data types or bindings.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 159,'pod' => 72,'pod_errors' => 0,'total' => 231,'with_comments' => 18},'releases' => 2,'requires' => ['DBD-Oracle-1.14.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'DBD::Oracle' => undef,'DBI' => undef},'requires_recursive' => ['DBD-Oracle-1.14.tar.gz','DBI-1.37.tar.gz'],'size' => {'packed' => 4083,'unpacked' => 9401},'testers' => {},'uses' => ['DBD::Oracle','DBI']},'DBIx-Profile-1.0.tar.gz' => {'author' => 'JLATHAN','description' => 'DBI query profiler Version 1.0 Copyright (c) 1999,2000 Jeff Lathan, Kerry Clendinning. All rights reserved. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 428,'pod' => 74,'pod_errors' => 0,'total' => 502,'with_comments' => 110},'releases' => 4,'size' => {'packed' => 4736,'unpacked' => 13308},'testers' => {'pass' => 1,'tests' => '0','unknown' => 18},'uses' => ['DBI','Time::HiRes','strict','vars']},'DBIx-Record-0.09.tar.gz' => {'author' => 'MIKO','description' => 'Middle tier system for representing database records as objects.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3416,'pod' => 1001,'pod_errors' => 0,'total' => 4417,'with_comments' => 995},'releases' => 2,'size' => {'packed' => 39382,'unpacked' => 159072},'testers' => {'pass' => 4},'uses' => ['Carp','DBI','DBIx::Record','Dev::ShowStuff','Exporter','constant','re','strict','vars']},'DBIx-Record-0.10.tar.gz' => {'author' => 'MIKO','description' => 'Middle tier system for representing database records as objects.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3137,'pod' => 994,'pod_errors' => 0,'total' => 4131,'with_comments' => 912},'releases' => 2,'size' => {'packed' => 38028,'unpacked' => 152082},'testers' => {'pass' => 4},'uses' => ['Carp','DBI','Dev::ShowStuff','Exporter','constant','re','strict','vars']},'DBIx-Recordset-0.24.tar.gz' => {'author' => 'GRICHTER','description' => 'Perl extension for DBI recordsets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6949,'pod' => 2234,'pod_errors' => 4,'total' => 9183,'with_comments' => 1152},'releases' => 4,'size' => {'packed' => 92611,'unpacked' => 440230},'testers' => {'fail' => 24,'pass' => 1},'uses' => ['Carp','Cwd','DBI','DBIx::Database','Exporter','File::Spec','Text::ParseWords','constant','strict','vars']},'DBIx-Renderer-0.01.tar.gz' => {'author' => 'MARCEL','description' => 'talk SQL by using Perl data structures','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 353,'pod' => 344,'pod_errors' => 0,'total' => 697,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 8413,'unpacked' => 27622},'testers' => {'pass' => 5},'uses' => ['Exporter','strict','warnings']},'DBIx-SQLEngine-0.006.tar.gz' => {'author' => 'EVO','description' => 'Extends DBI with high-level operations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2086,'pod' => 1726,'pod_errors' => 0,'total' => 3812,'with_comments' => 177},'releases' => 7,'requires' => ['Class-MakeMethods-1.006.tar.gz','DBI-1.37.tar.gz','DBIx-AnyDBD-2.01.tar.gz'],'requires_module' => {'Class::MakeMethods' => '1.003','Class::MakeMethods::Template' => '1.003','DBI' => 1,'DBIx::AnyDBD' => 2},'requires_recursive' => ['Class-MakeMethods-1.006.tar.gz','DBI-1.37.tar.gz','DBIx-AnyDBD-2.01.tar.gz'],'size' => {'packed' => 25923,'unpacked' => 115565},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Class::MakeMethods','DBI','DBIx::AnyDBD','DBIx::SQLEngine::Criteria::Comparison','DBIx::SQLEngine::Criteria::HashGroup','DBIx::SQLEngine::Default','constant','strict','vars']},'DBIx-SQLEngine-0.008.tar.gz' => {'author' => 'EVO','description' => 'Extends DBI with high-level operations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2309,'pod' => 1978,'pod_errors' => 0,'total' => 4287,'with_comments' => 199},'releases' => 7,'requires' => ['Class-MakeMethods-1.006.tar.gz','DBI-1.37.tar.gz','DBIx-AnyDBD-2.01.tar.gz'],'requires_module' => {'Class::MakeMethods' => '1.003','Class::MakeMethods::Template' => '1.003','DBI' => 1,'DBIx::AnyDBD' => 2},'requires_recursive' => ['Class-MakeMethods-1.006.tar.gz','DBI-1.37.tar.gz','DBIx-AnyDBD-2.01.tar.gz'],'size' => {'packed' => 30330,'unpacked' => 133326},'testers' => {'pass' => 2},'uses' => ['Carp','Class::MakeMethods','DBI','DBIx::AnyDBD','DBIx::SQLEngine::Criteria','DBIx::SQLEngine::Criteria::And','DBIx::SQLEngine::Criteria::Comparison','DBIx::SQLEngine::Criteria::Compound','DBIx::SQLEngine::Criteria::HashGroup','DBIx::SQLEngine::Criteria::Or','DBIx::SQLEngine::Criteria::StringEquality','DBIx::SQLEngine::Mixin::SeqTable','constant','strict','vars']},'DBIx-SQLEngine-0.009.tar.gz' => {'author' => 'EVO','description' => 'Extends DBI with high-level operations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2527,'pod' => 1791,'pod_errors' => 0,'total' => 4318,'with_comments' => 218},'releases' => 7,'requires' => ['Class-MakeMethods-1.006.tar.gz','DBI-1.37.tar.gz','DBIx-AnyDBD-2.01.tar.gz'],'requires_module' => {'Class::MakeMethods' => '1.003','Class::MakeMethods::Template' => '1.003','DBI' => 1,'DBIx::AnyDBD' => 2},'requires_recursive' => ['Class-MakeMethods-1.006.tar.gz','DBI-1.37.tar.gz','DBIx-AnyDBD-2.01.tar.gz'],'size' => {'packed' => 31411,'unpacked' => 135595},'testers' => {'fail' => 1,'pass' => 8},'uses' => ['Carp','Class::MakeMethods','DBI','DBIx::AnyDBD','DBIx::SQLEngine::Criteria','DBIx::SQLEngine::Criteria::And','DBIx::SQLEngine::Criteria::Compound','DBIx::SQLEngine::Criteria::Or','DBIx::SQLEngine::Criteria::StringEquality','DBIx::SQLEngine::Mixin::SeqTable','constant','strict','vars']},'DBIx-Schema-0.07.tar.gz' => {'author' => 'JMAC','description' => '- An SQL Abstration layer for working with whole schemas','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1416,'pod' => 528,'pod_errors' => 0,'total' => 1944,'with_comments' => 194},'releases' => 4,'requires' => ['DBIx-Abstract-1.005.tar.gz'],'requires_module' => {'DBIx::Abstract' => '0.9'},'requires_recursive' => ['DBI-1.37.tar.gz','DBIx-Abstract-1.005.tar.gz','Scalar-List-Utils-1.11.tar.gz'],'size' => {'packed' => 24234,'unpacked' => 75300},'testers' => {'fail' => 2,'tests' => '12'},'uses' => ['Carp','Config','DBIx::Abstract','Exporter','File::Basename','File::Path','IO::File','strict','vars']},'DBIx-SearchBuilder-0.88.tar.gz' => {'author' => 'JESSE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 3481,'pod' => 734,'pod_errors' => 0,'total' => 4215,'with_comments' => 502},'releases' => 44,'requires' => ['Class-ReturnValue-0.51.tar.gz'],'requires_module' => {'Class::ReturnValue' => '0.40'},'requires_recursive' => ['Class-ReturnValue-0.51.tar.gz','Devel-StackTrace-1.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 28138,'unpacked' => 97910},'testers' => {'pass' => 3},'uses' => ['Carp','Class::ReturnValue','DBI','strict','vars']},'DBIx-Sequence-1.4.tar.gz' => {'author' => 'BBEAUSEJ','description' => 'Database independent ID generation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 456,'pod' => 209,'pod_errors' => 0,'total' => 665,'with_comments' => 0},'releases' => 8,'size' => {'packed' => 11920,'unpacked' => 53092},'testers' => {'fail' => 2,'pass' => 5,'tests' => '1'},'uses' => ['Carp','DBI','constant','strict','vars']},'DBIx-ShowCaller-0.80.tar.gz' => {'author' => 'JANPAZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 37,'pod_errors' => 0,'total' => 96,'with_comments' => 0},'releases' => 1,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.13'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 1784,'unpacked' => 2974},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['DBI','strict','vars']},'DBIx-Simple-1.11.tar.gz' => {'author' => 'JUERD','description' => 'Easy-to-use OO interface to DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 358,'pod' => 330,'pod_errors' => 0,'total' => 688,'with_comments' => 9},'releases' => 11,'requires' => ['Attribute-Property-1.04.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'Attribute::Property' => '1.03','DBI' => '1.21'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Attribute-Property-1.04.tar.gz','DBI-1.37.tar.gz'],'size' => {'packed' => 9201,'unpacked' => 34198},'testers' => {'pass' => 2},'uses' => ['5.006','Attribute::Property','Carp','DBI','strict']},'DBIx-Table-0.04.tar.gz' => {'author' => 'DLOWE','description' => 'OO access to DBI database tables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1472,'pod' => 442,'pod_errors' => 0,'total' => 1914,'with_comments' => 345},'releases' => 3,'size' => {'packed' => 16275,'unpacked' => 68552},'testers' => {'pass' => 5},'uses' => ['5.005','integer','strict','vars']},'DBIx-Table-Dup-0.02.tar.gz' => {'author' => 'TBONE','description' => 'Perl module to (return SQL to) create duplicate copy of table','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 52,'pod_errors' => 0,'total' => 147,'with_comments' => 8},'releases' => 2,'requires' => ['DBIx-DBSchema-0.21.tar.gz'],'requires_module' => {'DBIx::DBSchema' => '0.21'},'requires_recursive' => ['DBI-1.37.tar.gz','DBIx-DBSchema-0.21.tar.gz','FreezeThaw-0.43.tar.gz'],'size' => {'packed' => 2807,'unpacked' => 5431},'testers' => {'pass' => 1},'uses' => ['5.006','DBIx::DBSchema','Exporter','strict','warnings']},'DBIx-Table2Hash-1.12.tgz' => {'author' => 'RSAVAGE','description' => 'Read a database table into a hash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 321,'pod' => 253,'pod_errors' => 0,'total' => 574,'with_comments' => 52},'releases' => 4,'size' => {'packed' => 9971,'unpacked' => 42735},'testers' => {'pass' => 1},'uses' => ['5.005_62','Carp','DBIx::Hash2Table','Data::Dumper','Exporter','strict','warnings']},'DBIx-TableHash-1.04.tar.gz' => {'author' => 'CHTHORMAN','description' => 'Tie a hash to a mysql table + SQL utils','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1044,'pod' => 380,'pod_errors' => 0,'total' => 1424,'with_comments' => 168},'releases' => 4,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => 0},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 17209,'unpacked' => 68841},'testers' => {'pass' => 3},'uses' => ['Carp','DBI','strict','vars']},'DBIx-TextIndex-0.12.tar.gz' => {'author' => 'DKOCH','description' => 'Creates fulltext indexes of SQL text columns','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2736,'pod' => 408,'pod_errors' => 0,'total' => 3144,'with_comments' => 111},'releases' => 10,'requires' => ['Bit-Vector-6.3.tar.gz','DBI-1.37.tar.gz','Exception-Class-1.14.tar.gz','HTML-Parser-3.28.tar.gz','Text-Unaccent-1.01.tar.gz'],'requires_module' => {'Bit::Vector' => '6.3','DBI' => '1.15','Exception::Class' => '1.11','HTML::Entities' => '1.22','Text::Unaccent' => '1.07'},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Class-Data-Inheritable-0.02.tar.gz','DBI-1.37.tar.gz','Devel-StackTrace-1.03.tar.gz','Exception-Class-1.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Unaccent-1.01.tar.gz'],'size' => {'packed' => 87085,'unpacked' => 248309},'testers' => {},'uses' => ['$db','$stopfile','Carp','Text::Unaccent','strict']},'DBIx-TextSearch-0.2.tar.gz' => {'author' => 'SRPATT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 752,'pod' => 224,'pod_errors' => 0,'total' => 976,'with_comments' => 185},'releases' => 2,'requires' => ['DBI-1.37.tar.gz','HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz','perlSGML.1997Sep18.tar.gz'],'requires_module' => {'DBI' => 'Carp','Env' => 'English','HTML::TokeParser' => 'Socket','LWP::UserAgent' => 'HTTP::Response','Net::FTP' => 'LWP::Simple','SGML::StripParser' => 'Text::Query','Sys::Hostname' => undef,'URI' => 'File::Basename'},'requires_recursive' => ['DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz','perlSGML.1997Sep18.tar.gz'],'size' => {'packed' => 11035,'unpacked' => 38828},'testers' => {'fail' => 2,'tests' => '3'},'uses' => ['Carp','DBI','Digest::MD5','English','Env','File::Basename','HTML::TokeParser','HTTP::Response','LWP::Simple','LWP::UserAgent','Net::FTP','SGML::StripParser','Socket','Sys::Hostname','Text::Query','URI','strict','warnings']},'DBIx-Tree-1.9.tar.gz' => {'author' => 'BJEPS','description' => 'Expand self-referential table into a tree','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 464,'pod' => 227,'pod_errors' => 0,'total' => 691,'with_comments' => 67},'releases' => 3,'requires' => ['DBD-mysql-2.9002.tar.gz'],'requires_module' => {'DBD::mysql' => '0'},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz'],'size' => {'packed' => 11816,'unpacked' => 39324},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','is','strict','vars']},'DBIx-Wrapper-0.04.tar.gz' => {'author' => 'DOWENS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 794,'pod' => 217,'pod_errors' => 0,'total' => 1011,'with_comments' => 46},'releases' => 4,'size' => {'packed' => 6852,'unpacked' => 28766},'testers' => {'pass' => 2},'uses' => ['DBI','strict','vars']},'DBIx-XHTML_Table-1.30.tar.gz' => {'author' => 'JEFFA','description' => 'SQL query result set to XML-based HTML table','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 948,'pod' => 588,'pod_errors' => 0,'total' => 1536,'with_comments' => 65},'releases' => 25,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.2'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 18249,'unpacked' => 52826},'testers' => {'pass' => 2},'uses' => ['Carp','DBI','strict','vars']},'DBIx-XML-DataLoader-1.1b.tar.gz' => {'author' => 'CBERNING','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2071,'pod' => 597,'pod_errors' => 1,'total' => 2668,'with_comments' => 347},'releases' => 2,'requires' => ['DBI-1.37.tar.gz','XML-Simple-2.08.tar.gz','XML-XPath-1.13.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'DBI' => '0','LWP::UserAgent' => '0','XML::Simple' => '1.05','XML::XPath' => '1.0'},'requires_recursive' => ['DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','XML-Simple-2.08.tar.gz','XML-XPath-1.13.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 25640,'unpacked' => 114645},'testers' => {'pass' => 4},'uses' => ['DBD::Oracle','DBI','LWP::UserAgent','Storable','XML::Simple','XML::XPath','strict','warnings']},'DBIx-XMLMessage-0.05.tar.gz' => {'author' => 'ANDREIN','description' => 'XML Message exchange between DBI data sources','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1689,'pod' => 366,'pod_errors' => 0,'total' => 2055,'with_comments' => 479},'releases' => 5,'requires' => ['DBI-1.37.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'DBI' => '1.00','XML::Parser' => '2.23'},'requires_recursive' => ['DBI-1.37.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 26190,'unpacked' => 113766},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['5.003','Carp','DBI','Data::Dumper','Exporter','POSIX','XML::Parser','strict','vars']},'DBIx-XML_RDB-0.05.tar.gz' => {'author' => 'MSERGEANT','description' => 'Creates XML from DBI datasources','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 140,'pod' => 76,'pod_errors' => 0,'total' => 216,'with_comments' => 3},'releases' => 4,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.00'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 6512,'unpacked' => 16347},'testers' => {'pass' => 9},'uses' => ['DBI','Exporter','strict','vars']},'DBIx-YAWM-2.2.4.tar.gz' => {'author' => 'AHICOX','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 379,'pod' => 163,'pod_errors' => 0,'total' => 542,'with_comments' => 70},'releases' => 8,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI::DBD' => '11.02'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 6554,'unpacked' => 18976},'testers' => {'pass' => 3},'uses' => ['5.6.0','AutoLoader','Exporter','warnings']},'DBIx-glueHTML-0.20.tar.gz' => {'author' => 'JFURNESS','description' => 'CGI interface to DBI databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1560,'pod' => 497,'pod_errors' => 0,'total' => 2057,'with_comments' => 246},'releases' => 1,'size' => {'packed' => 18204,'unpacked' => 72237},'testers' => {'pass' => 3},'uses' => ['5.004','CGI','DBI','strict','vars']},'DBM-Any-0.1.tar.gz' => {'author' => 'TMONROE','description' => 'object-oriented interface to AnyDBM_File','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 115,'pod' => 54,'pod_errors' => 0,'total' => 169,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 3698,'unpacked' => 12949},'testers' => {'fail' => 1,'pass' => 5,'tests' => '59'},'uses' => ['Carp','constant','strict','vars']},'DBM-DBass-0.54.tar.gz' => {'author' => 'SPIDERBOY','description' => 'DBM with hashes, locking and XML records','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 542,'pod' => 162,'pod_errors' => 0,'total' => 704,'with_comments' => 23},'releases' => 1,'size' => {'packed' => 5166,'unpacked' => 27502},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.004','DB_File','Fcntl','strict','vars']},'DBO-0.01.tar.gz' => {'author' => 'ABW','description' => 'Database Objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1204,'pod' => 204,'pod_errors' => 0,'total' => 1408,'with_comments' => 192},'releases' => 1,'size' => {'packed' => 13202,'unpacked' => 63250},'testers' => {'fail' => 1,'tests' => '34'},'uses' => ['.status','Carp','Class::Multimethods','DBI','DBO::Column','DBO::Column::Base','DBO::Column::Char','DBO::Column::Integer','DBO::Column::Modifier','DBO::Column::Number','DBO::Column::String','DBO::Column::Unsigned','DBO::Handle','DBO::Handle::DBI','DBO::Visitor','Exporter','HTML::FromText','UNIVERSAL','strict','vars']},'DBSchema-Normalizer-0.08.tgz' => {'author' => 'GMAX','description' => 'database normalization. - Convert a table from 1st to 2nd normal form','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 523,'pod' => 956,'pod_errors' => 0,'total' => 1479,'with_comments' => 60},'releases' => 2,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'DBD::mysql' => 0,'DBI' => 0},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz'],'size' => {'packed' => 33487,'unpacked' => 146093},'testers' => {'pass' => 4},'uses' => ['5.004','Carp','DBD::mysql','DBI','Data::Dumper','Exporter','strict','warnings']},'DBX-0.1.tar.gz' => {'author' => 'BATKINS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 231,'pod' => 184,'pod_errors' => 0,'total' => 415,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3829,'unpacked' => 9172},'testers' => {'pass' => 7},'uses' => ['DBI','Exporter','strict','warnings']},'DBZ_File_1.1.tar.gz' => {'author' => 'WAYNEDAV','description' => 'Tie to dbz files (mainly for news history)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 49,'pod' => 60,'pod_errors' => 0,'total' => 109,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3365,'unpacked' => 6375},'testers' => {},'uses' => ['Carp','DynaLoader','strict','vars']},'DB_File-1.806.tar.gz' => {'author' => 'PMQS','description' => 'Tie to DB files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 965,'pod' => 1326,'pod_errors' => 0,'total' => 2291,'with_comments' => 44},'releases' => 35,'size' => {'packed' => 80078,'unpacked' => 345625},'testers' => {'pass' => 12},'uses' => ['5.00404','AutoLoader','Carp','DynaLoader','Exporter','Fcntl','Tie::Hash','strict','warnings']},'DB_File-DB_Database-0.031.tar.gz' => {'author' => 'RANN','description' => 'DB_File to MultiField Table with Index','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1030,'pod' => 328,'pod_errors' => 3,'total' => 1358,'with_comments' => 135},'releases' => 2,'size' => {'packed' => 17338,'unpacked' => 70415},'testers' => {'pass' => 9},'uses' => ['5.004','DB_File','Data::Dumper','Fcntl','strict','vars']},'DB_File-Lock-0.05.tar.gz' => {'author' => 'DHARRIS','description' => 'DB_File wrapper with flock-based locking','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 217,'pod' => 147,'pod_errors' => 0,'total' => 364,'with_comments' => 29},'releases' => 5,'size' => {'packed' => 7646,'unpacked' => 22346},'testers' => {'fail' => 2,'pass' => 8},'uses' => ['5.004','Carp','Fcntl','strict','vars']},'DB_File-SV18x-kit-0.06.tar.gz' => {'author' => 'ANDK','description' => 'Co-existence of berkeley db 1.85, 1.86 and 2+','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 21,'pod' => 35,'pod_errors' => 0,'total' => 56,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 8315,'unpacked' => 20293},'testers' => {},'uses' => []},'DBass-0.53.tar.gz' => {'author' => 'SPIDERBOY','description' => 'DBM with associative arrays, file locking and XML records','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 541,'pod' => 158,'pod_errors' => 0,'total' => 699,'with_comments' => 23},'releases' => 2,'size' => {'packed' => 5054,'unpacked' => 27072},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['5.004','DB_File','Fcntl','strict','vars']},'DBedit-1.96.tar.gz' => {'author' => 'GNALABS','description' => 'Class to handle database editing','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1620,'pod' => 63,'pod_errors' => 0,'total' => 1683,'with_comments' => 23},'releases' => 1,'size' => {'packed' => 11642,'unpacked' => 44260},'testers' => {'fail' => 3,'tests' => '12'},'uses' => ['Carp','DBI','Data::Dumper','HTML::FillInForm','IO::File','Symbol','strict']},'DCE-Perl-0.21.tar.gz' => {'author' => 'PHENSON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 622,'pod' => 580,'pod_errors' => 1,'total' => 1202,'with_comments' => 53},'releases' => 7,'size' => {'packed' => 35629,'unpacked' => 168757},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','Tie::Scalar','strict','vars']},'DCE-Perl-RPC-0.01.tar.gz' => {'author' => 'UMVUE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 295,'pod' => 63,'pod_errors' => 0,'total' => 358,'with_comments' => 74},'releases' => 1,'size' => {'packed' => 5376,'unpacked' => 19306},'testers' => {'pass' => 5},'uses' => ['Carp','DynaLoader','Exporter','constant','strict','vars']},'DDL-Oracle-1.11.tar.gz' => {'author' => 'RVSUTHERL','description' => 'Reverse engineers object DDL; also defrags','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8413,'pod' => 219,'pod_errors' => 0,'total' => 8632,'with_comments' => 805},'releases' => 22,'size' => {'packed' => 56132,'unpacked' => 323969},'testers' => {'pass' => 8},'uses' => ['5.004','strict']},'DFA-Command-1.97.tgz' => {'author' => 'RSAVAGE','description' => 'Discrete Finite Automata command processor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1024,'pod' => 220,'pod_errors' => 0,'total' => 1244,'with_comments' => 238},'releases' => 6,'size' => {'packed' => 18999,'unpacked' => 115455},'testers' => {'pass' => 1},'uses' => ['5.000','Carp','Exporter','Getopt::Std','strict','vars']},'DFA-Kleene-1.0.tar.gz' => {'author' => 'STBEY','description' => 'Kleene\'s Algorithm for DFA','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 275,'pod' => 328,'pod_errors' => 0,'total' => 603,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 5353,'unpacked' => 15759},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','strict','vars']},'DFA-Simple-0.0.tar.gz' => {'author' => 'RANDYM','description' => '- A PERL module to implement simple Discrete Finite Automata','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 204,'pod' => 149,'pod_errors' => 0,'total' => 353,'with_comments' => 26},'releases' => 5,'size' => {'packed' => 11906,'unpacked' => 36196},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp']},'DFA-Simple-0.32.tar.gz' => {'author' => 'RANDYM','description' => 'An "augmented transition network"','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 566,'pod' => 291,'pod_errors' => 0,'total' => 857,'with_comments' => 100},'releases' => 5,'size' => {'packed' => 11815,'unpacked' => 32509},'testers' => {'pass' => 12},'uses' => ['AutoLoader','Carp','Thread::Queue','Thread::Semaphore','vars']},'DFS-Perl-0.50.tar.gz' => {'author' => 'PHENSON','description' => 'DCE Distributed File System interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 549,'pod' => 146,'pod_errors' => 1,'total' => 695,'with_comments' => 9},'releases' => 4,'size' => {'packed' => 16132,'unpacked' => 115503},'testers' => {},'uses' => ['AutoLoader','Carp','DCE::ACL','DCE::Registry','DynaLoader','Exporter','strict','vars']},'DNA-0.02.tar.gz' => {'author' => 'MSCHWERN','description' => 'Encodes your Perl program into an Nucleic Acid sequence','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 171,'pod' => 43,'pod_errors' => 0,'total' => 214,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 3717,'unpacked' => 7716},'testers' => {'pass' => 4},'uses' => ['strict','vars']},'DNS-Config-0.66.tar.gz' => {'author' => 'WOLF','description' => 'Generic config with specific file adaptor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2163,'pod' => 337,'pod_errors' => 0,'total' => 2500,'with_comments' => 305},'releases' => 2,'size' => {'packed' => 14961,'unpacked' => 63048},'testers' => {'pass' => 9},'uses' => ['5.6.0','Data::Dumper','strict','vars','warnings']},'DNS-EasyDNS-0.02.tar.gz' => {'author' => 'GBROCK','description' => 'Update your EasyDNS dynamic DNS entries','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 104,'pod' => 76,'pod_errors' => 1,'total' => 180,'with_comments' => 8},'releases' => 2,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request::Common' => '1.19','LWP::UserAgent' => '2.001'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4782,'unpacked' => 12937},'testers' => {'pass' => 3},'uses' => ['CGI::Util','Carp','HTTP::Request::Common','LWP::UserAgent','constant','strict','warnings']},'DNS-TinyDNS-0.20.1.tar.gz' => {'author' => 'ANARION','description' => 'Perl extension for manipulating djbdns','files' => [],'lines' => {'nonpod' => 740,'pod' => 416,'pod_errors' => 0,'total' => 1156,'with_comments' => 12},'releases' => 9,'size' => {'packed' => 8037,'unpacked' => 38308},'testers' => {'pass' => 4},'uses' => ['Carp','Cwd','Fcntl','strict','warnings']},'DNS-Zone-0.85.tar.gz' => {'author' => 'WOLF','description' => 'DNS Zone','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1226,'pod' => 173,'pod_errors' => 0,'total' => 1399,'with_comments' => 126},'releases' => 1,'size' => {'packed' => 8560,'unpacked' => 31237},'testers' => {'pass' => 11},'uses' => ['5.6.0','Data::Dumper','strict','vars','warnings']},'DNS-ZoneFile-0.92.tar.gz' => {'author' => 'MATTBM','description' => 'Object management of a DNS Zone','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 462,'pod' => 170,'pod_errors' => 0,'total' => 632,'with_comments' => 6},'releases' => 4,'size' => {'packed' => 6750,'unpacked' => 21002},'testers' => {'pass' => 8},'uses' => ['strict']},'DNS-ZoneFile-0.95.tar.gz' => {'author' => 'MATTBM','description' => 'Object-Oriented Management of a Master File','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 766,'pod' => 88,'pod_errors' => 0,'total' => 854,'with_comments' => 104},'releases' => 4,'size' => {'packed' => 6817,'unpacked' => 19260},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['strict','vars']},'DNS-ZoneParse-0.90.tar.gz' => {'author' => 'SIMONFLK','description' => 'Parse and manipulate DNS Zone files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 325,'pod' => 149,'pod_errors' => 0,'total' => 474,'with_comments' => 25},'releases' => 15,'requires' => ['Storable-2.07.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Storable' => '0.407','Test::More' => '0.31'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8271,'unpacked' => 24033},'testers' => {'pass' => 2},'uses' => ['5.005','Carp','POSIX','Storable','strict','vars']},'DPKG-Tools-0.1.tar.gz' => {'author' => 'SHARRISON','description' => 'cleanly generate an Debian package (.dpkg)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 508,'pod' => 337,'pod_errors' => 0,'total' => 845,'with_comments' => 68},'releases' => 1,'size' => {'packed' => 7478,'unpacked' => 24110},'testers' => {},'uses' => ['Getopt::Long','strict','vars']},'DProf-19990108.tar.gz' => {'author' => 'ILYAZ','description' => 'Execution profiler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 124,'pod_errors' => 0,'total' => 257,'with_comments' => 11},'releases' => 8,'size' => {'packed' => 20710,'unpacked' => 60913},'testers' => {'pass' => 8},'uses' => ['5.003','DynaLoader','Exporter','Getopt::Std']},'DWH_File-0.21.tar.gz' => {'author' => 'SUMUS','description' => 'data and object persistence in deep and wide hashes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1788,'pod' => 672,'pod_errors' => 0,'total' => 2460,'with_comments' => 33},'releases' => 6,'size' => {'packed' => 18533,'unpacked' => 79764},'testers' => {'pass' => 5},'uses' => ['DWH_File::Cache','DWH_File::Cached','DWH_File::ID_Mill','DWH_File::Kernel','DWH_File::Log','DWH_File::Reference','DWH_File::Registry','DWH_File::Slot','DWH_File::Subscript','DWH_File::Tie','DWH_File::Tie::Array','DWH_File::Tie::Array::Node','DWH_File::Tie::Hash','DWH_File::Tie::Hash::Node','DWH_File::Tie::Scalar','DWH_File::Tie::Subscripted','DWH_File::Value::Factory','DWH_File::Value::Plain','DWH_File::Value::Undef','DWH_File::Work','UNIVERSAL','strict','vars','warnings']},'DWH_File-0.24.tar.gz' => {'author' => 'SUMUS','description' => 'data and object persistence in deep and wide hashes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2171,'pod' => 817,'pod_errors' => 0,'total' => 2988,'with_comments' => 34},'releases' => 6,'requires' => ['URI-1.24.tar.gz'],'requires_module' => {'URI' => 0},'requires_recursive' => ['URI-1.24.tar.gz'],'size' => {'packed' => 23426,'unpacked' => 97167},'testers' => {'pass' => 2},'uses' => ['DWH_File::Registry','DWH_File::Work','UNIVERSAL','URI::file','strict','vars','warnings']},'Data-ACL-0.02.tar.gz' => {'author' => 'ROBAU','description' => 'Perl extension for simple ACL lists','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 145,'pod' => 74,'pod_errors' => 0,'total' => 219,'with_comments' => 0},'releases' => 2,'requires' => ['Set-NestedGroups-0.01.tar.gz'],'requires_module' => {'Set::NestedGroups' => '0.01'},'requires_recursive' => ['Set-NestedGroups-0.01.tar.gz'],'size' => {'packed' => 2844,'unpacked' => 8614},'testers' => {'pass' => 6},'uses' => ['Carp','Data::ACL::Realm','strict','vars']},'Data-BFDump-0.3.tar.gz' => {'author' => 'YVES','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1531,'pod' => 384,'pod_errors' => 0,'total' => 1915,'with_comments' => 95},'releases' => 1,'requires' => ['Algorithm-Diff-1.15.tar.gz','Carp-Assert-0.17.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Quote-0.3.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Algorithm::Diff' => '1.11','B::Deparse' => '0.6','Carp::Assert' => '0.13','Test::Harness' => '2.01','Test::More' => '0.41','Text::Quote' => '0.2'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Carp-Assert-0.17.tar.gz','Compress-Zlib-1.22.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Quote-0.3.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 25681,'unpacked' => 93915},'testers' => {'fail' => 1,'pass' => 3,'tests' => '273'},'uses' => ['Exporter','Text::Quote','constant','strict','vars','warnings','warnings::register']},'Data-BT-PhoneBill-0.94.tar.gz' => {'author' => 'TMTM','description' => 'Parse a BT Phone Bill from their web site','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 83,'pod' => 83,'pod_errors' => 0,'total' => 166,'with_comments' => 1},'releases' => 4,'requires' => ['Date-Simple-1.03.tar.gz','HTML-TableExtract-1.08.tar.gz','IO-1.20.tar.gz','Test-Simple-0.47.tar.gz','Text-CSV_XS-0.23.tar.gz'],'requires_module' => {'Date::Simple' => 0,'HTML::TableExtract' => 0,'IO::File' => 0,'Test::More' => '0.17','Text::CSV_XS' => 0},'requires_recursive' => ['Date-Simple-1.03.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableExtract-1.08.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-CSV_XS-0.23.tar.gz'],'size' => {'packed' => 2803,'unpacked' => 5919},'testers' => {'pass' => 7},'uses' => ['Date::Simple','HTML::TableExtract','IO::File','Text::CSV_XS','strict']},'Data-BenchmarkResults-0.01.tar.gz' => {'author' => 'JTITUS','description' => 'Perl extension for averaging and comparing multiple benchmark runs.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 314,'pod' => 81,'pod_errors' => 0,'total' => 395,'with_comments' => 37},'releases' => 1,'requires' => ['Statistics-Lite-1.02.tar.gz'],'requires_module' => {'Statistics::Lite' => '1.02'},'requires_recursive' => ['Statistics-Lite-1.02.tar.gz'],'size' => {'packed' => 9165,'unpacked' => 25352},'testers' => {'pass' => 2},'uses' => ['5.005_62','Exporter','Statistics::Lite','strict','warnings']},'Data-Binder-1.tar.gz' => {'author' => 'HALLEY','description' => 'map of key-values for simple unification','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 108,'pod_errors' => 0,'total' => 282,'with_comments' => 26},'releases' => 1,'size' => {'packed' => 4286,'unpacked' => 12204},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars','warnings']},'Data-Buffer-0.04.tar.gz' => {'author' => 'BTROTT','description' => 'Read/write buffer class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 274,'pod' => 191,'pod_errors' => 0,'total' => 465,'with_comments' => 2},'releases' => 4,'size' => {'packed' => 5497,'unpacked' => 15698},'testers' => {'pass' => 12},'uses' => ['strict','vars']},'Data-CGIForm-0.2.tar.gz' => {'author' => 'CREIN','description' => 'Form Data Interface.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 492,'pod' => 299,'pod_errors' => 0,'total' => 791,'with_comments' => 5},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 11363,'unpacked' => 39211},'testers' => {'pass' => 2},'uses' => ['5.006','strict','warnings']},'Data-CHEF-1.01.tar.gz' => {'author' => 'CHRISJ','description' => 'Complex Hash Exchange Format','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 467,'pod' => 227,'pod_errors' => 0,'total' => 694,'with_comments' => 41},'releases' => 2,'size' => {'packed' => 5362,'unpacked' => 13889},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Data-CTable-1.01.tar.gz' => {'author' => 'CHTHORMAN','description' => 'Read, write, manipulate tabular data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6412,'pod' => 2534,'pod_errors' => 0,'total' => 8946,'with_comments' => 1076},'releases' => 6,'size' => {'packed' => 155158,'unpacked' => 539044},'testers' => {'pass' => 3},'uses' => ['Carp','Config','Data::Dumper','Data::ShowTable','Exporter','File::Basename','Getopt::Long','IO::File','POSIX','Storable','integer','strict','vars']},'Data-Compare-0.02.tar.gz' => {'author' => 'FTASSIN','description' => 'Compare perl data structures','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 51,'pod_errors' => 0,'total' => 180,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 2916,'unpacked' => 7182},'testers' => {'pass' => 20},'uses' => ['Carp','Exporter','strict','vars']},'Data-DRef-1999.0206.tar.gz' => {'author' => 'EVO','description' => 'Nested data access using delimited strings','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 752,'pod' => 404,'pod_errors' => 0,'total' => 1156,'with_comments' => 137},'releases' => 1,'requires' => ['String-Escape-2002.001.tar.gz'],'requires_module' => {'String::Escape' => 1998},'requires_recursive' => ['String-Escape-2002.001.tar.gz'],'size' => {'packed' => 11553,'unpacked' => 38412},'testers' => {'pass' => 11},'uses' => ['5','Carp','Exporter','String::Escape','strict','vars']},'Data-Denter-0.15.tar.gz' => {'author' => 'INGY','description' => 'An alternative to Data::Dumper and Storable.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 550,'pod' => 289,'pod_errors' => 0,'total' => 839,'with_comments' => 6},'releases' => 5,'requires' => ['YAML-0.35.tar.gz'],'requires_module' => {'YAML' => 0},'requires_recursive' => ['YAML-0.35.tar.gz'],'size' => {'packed' => 9856,'unpacked' => 28432},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['Carp','Exporter','strict','vars']},'Data-Describe-1.03.tar.gz' => {'author' => 'GEOTIGER','description' => 'Perl extension for scanning/describing a text file or array.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 744,'pod' => 374,'pod_errors' => 0,'total' => 1118,'with_comments' => 162},'releases' => 4,'size' => {'packed' => 21261,'unpacked' => 78619},'testers' => {'pass' => 2},'uses' => ['Carp','DataFax','Exporter','Fax::DataFax::DateTime','File::Basename','IO::File','strict','vars','warnings']},'Data-Dimensions-0.04.tar.gz' => {'author' => 'AJGOUGH','description' => 'Strongly type values with physical units','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 683,'pod' => 267,'pod_errors' => 0,'total' => 950,'with_comments' => 44},'releases' => 2,'size' => {'packed' => 11038,'unpacked' => 30145},'testers' => {'pass' => 4},'uses' => ['strict','vars']},'Data-Direct-0.05.tar.gz' => {'author' => 'SCHOP','description' => 'Perl module to emulate seqeuntial access to SQL tables.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 451,'pod' => 167,'pod_errors' => 2,'total' => 618,'with_comments' => 80},'releases' => 5,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.10'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 5811,'unpacked' => 14138},'testers' => {'pass' => 5},'uses' => ['DBI','Exporter','Getopt::Std','POSIX','Text::ParseWords','strict','vars']},'Data-Dump-0.04.tar.gz' => {'author' => 'GAAS','description' => 'Pretty printing of data structures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 403,'pod' => 39,'pod_errors' => 0,'total' => 442,'with_comments' => 30},'releases' => 4,'size' => {'packed' => 6846,'unpacked' => 15991},'testers' => {'pass' => 15},'uses' => ['Data::Dumper','Exporter','strict','utf','vars']},'Data-DumpXML-1.05.tar.gz' => {'author' => 'GAAS','description' => 'Dump arbitrary data structures as XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 353,'pod' => 151,'pod_errors' => 0,'total' => 504,'with_comments' => 12},'releases' => 7,'requires' => ['Array-RefElem-0.02.tar.gz','MIME-Base64-2.20.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Array::RefElem' => '0.01','MIME::Base64' => 2,'XML::Parser' => 2},'requires_recursive' => ['Array-RefElem-0.02.tar.gz','MIME-Base64-2.20.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 7892,'unpacked' => 21777},'testers' => {'pass' => 4},'uses' => ['Array::RefElem','Exporter','MIME::Base64','XML::Parser','strict','vars']},'Data-Dumper-2.101.tar.gz' => {'author' => 'GSAR','description' => 'Convert data structure into perl code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 695,'pod' => 305,'pod_errors' => 0,'total' => 1000,'with_comments' => 98},'releases' => 11,'size' => {'packed' => 38263,'unpacked' => 123688},'testers' => {'fail' => 5,'pass' => 2,'tests' => '163'},'uses' => ['5.004','Carp','DynaLoader','Exporter','overload','utf']},'Data-ENAML-0.03.tar.gz' => {'author' => 'SCHOP','description' => 'Perl extension for ENAML data representation','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 54,'pod_errors' => 1,'total' => 228,'with_comments' => 10},'releases' => 3,'size' => {'packed' => 3392,'unpacked' => 6596},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','strict','vars']},'Data-Encrypted-0.07.tar.gz' => {'author' => 'AMACKEY','description' => 'Transparently store encrypted data via RSA','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 296,'pod' => 225,'pod_errors' => 0,'total' => 521,'with_comments' => 2},'releases' => 4,'requires' => ['Crypt-RSA-1.50.tar.gz','File-HomeDir-0.05.tar.gz','Storable-2.07.tar.gz','Term-ReadPassword-0.01.tar.gz'],'requires_module' => {'Crypt::RSA' => 0,'File::HomeDir' => 0,'Storable' => 0,'Term::ReadPassword' => 0},'requires_recursive' => ['Class-Loader-2.02.tar.gz','Compress-Zlib-1.22.tar.gz','Convert-ASCII-Armour-1.4.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Crypt-DES-2.03.tar.gz','Crypt-Primes-0.50.tar.gz','Crypt-RSA-1.50.tar.gz','Crypt-Random-1.13.tar.gz','Data-Buffer-0.04.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD2-2.02.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-HomeDir-0.05.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','Math-Pari-2.010500.tar.gz','Sort-Versions-1.4.tar.gz','Storable-2.07.tar.gz','Term-ReadPassword-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tie-EncryptedHash-1.21.tar.gz'],'size' => {'packed' => 7238,'unpacked' => 18598},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Carp','Crypt::RSA','Crypt::RSA::Key::Private::SSH','Crypt::RSA::Key::Public::SSH','Exporter','Fcntl','File::HomeDir','Storable','Term::ReadPassword','strict','vars']},'Data-Fallback-0.16.tar.gz' => {'author' => 'EARL','description' => 'fallback through an array of levels till you find your data, cacheing where desired','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1320,'pod' => 347,'pod_errors' => 0,'total' => 1667,'with_comments' => 57},'releases' => 5,'size' => {'packed' => 13396,'unpacked' => 49940},'testers' => {'fail' => 1,'pass' => 3,'tests' => '7'},'uses' => ['$tmp_package','Carp','DBI','Data::Dumper','Data::Fallback::$tmp_package','Exporter','IO::Socket','Net::Server::PreForkSimple','Time::HiRes','strict','vars']},'Data-Favorites-1.tar.gz' => {'author' => 'HALLEY','description' => 'tally a stream for recently dominant items','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 257,'pod' => 108,'pod_errors' => 0,'total' => 365,'with_comments' => 51},'releases' => 1,'size' => {'packed' => 5173,'unpacked' => 14781},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars','warnings']},'Data-FixedFormat-0.02.tar.gz' => {'author' => 'PFAUT','description' => 'convert between fixed-length fields and hashes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 180,'pod' => 175,'pod_errors' => 0,'total' => 355,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 10623,'unpacked' => 30195},'testers' => {'pass' => 4},'uses' => ['strict']},'Data-Flow-0.05.tar.gz' => {'author' => 'JASONS','description' => 'Acquire data based on recipes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 103,'pod_errors' => 0,'total' => 241,'with_comments' => 14},'releases' => 5,'size' => {'packed' => 3908,'unpacked' => 9703},'testers' => {'pass' => 16},'uses' => ['AutoLoader','Exporter','strict','vars']},'Data-FormValidator-3.12.tar.gz' => {'author' => 'MARKSTOS','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 2479,'pod' => 1222,'pod_errors' => 0,'total' => 3701,'with_comments' => 238},'releases' => 26,'size' => {'packed' => 54366,'unpacked' => 180180},'testers' => {'pass' => 4},'uses' => ['5.005','Carp','Date::Calc','Exporter','File::MMagic','Foo','Image::Size','MIME::Types','Regexp::Common','Symbol','UNIVERSAL','strict','vars']},'Data-FormValidator-Tutorial-1.4.tar.gz' => {'author' => 'TBONE','description' => 'Data::FormValidator tutorial','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 68,'pod' => 124,'pod_errors' => 0,'total' => 192,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 3294,'unpacked' => 6747},'testers' => {'pass' => 3},'uses' => []},'Data-Grouper-0.06.tar.gz' => {'author' => 'FERRANCE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 490,'pod' => 283,'pod_errors' => 1,'total' => 773,'with_comments' => 133},'releases' => 4,'size' => {'packed' => 8737,'unpacked' => 24905},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Data-Hash-Flatten-0.03.tar.gz' => {'author' => 'TBONE','description' => 'isomorphic denormalization of nested HoH into AoH','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 77,'pod_errors' => 0,'total' => 150,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 2435,'unpacked' => 4960},'testers' => {'pass' => 4},'uses' => ['5.005_62','Data::Dumper','Exporter','Storable','strict','warnings']},'Data-Hash-Utils-0.03.tar.gz' => {'author' => 'MSCHWERN','description' => 'A selection of general-utility hash subroutines','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 123,'pod_errors' => 0,'total' => 260,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 4904,'unpacked' => 13773},'testers' => {'fail' => 2,'tests' => '68'},'uses' => ['5.7.2','Carp','DynaLoader','Exporter','strict']},'Data-HexDump-0.02.tar.gz' => {'author' => 'FTASSIN','description' => 'Hexadecial Dumper','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 54,'pod_errors' => 0,'total' => 231,'with_comments' => 11},'releases' => 2,'size' => {'packed' => 3525,'unpacked' => 10772},'testers' => {'pass' => 15},'uses' => ['Carp','Exporter','FileHandle','strict','vars']},'Data-Hexdumper-1.0.1.tar.gz' => {'author' => 'DCANTRELL','description' => 'Display binary data in multiple formats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 80,'pod_errors' => 0,'total' => 227,'with_comments' => 22},'releases' => 2,'size' => {'packed' => 4176,'unpacked' => 8697},'testers' => {'pass' => 6},'uses' => ['Exporter','constant','strict']},'Data-Iterator-0.021.zip' => {'author' => 'HCAMP','description' => 'Simple iteration over complex data strucures','files' => [],'lines' => {'nonpod' => 740,'pod' => 775,'pod_errors' => 0,'total' => 1515,'with_comments' => 46},'releases' => 1,'size' => {'packed' => 19641,'unpacked' => 54918},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.000','Carp','FileHandle','strict','vars']},'Data-Iterator-EasyObj-0.01.tar.gz' => {'author' => 'TEEJAY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 122,'pod' => 115,'pod_errors' => 0,'total' => 237,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 3919,'unpacked' => 10797},'testers' => {'pass' => 1},'uses' => ['Data::Dumper','strict','vars']},'Data-JavaScript-1.08.tgz' => {'author' => 'JPIERCE','description' => 'Dumps structures into JavaScript code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 110,'pod' => 55,'pod_errors' => 0,'total' => 165,'with_comments' => 2},'releases' => 9,'size' => {'packed' => 3735,'unpacked' => 8368},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','subs','vars']},'Data-JavaScript-Anon-0.1.tar.gz' => {'author' => 'ADAMK','description' => 'Create big, dumb and/or anonymous data structures in JavaScript','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 276,'pod' => 116,'pod_errors' => 0,'total' => 392,'with_comments' => 43},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 12910,'unpacked' => 35711},'testers' => {'pass' => 2},'uses' => ['UNIVERSAL','strict','vars']},'Data-JavaScript-LiteObject-1.04.tgz' => {'author' => 'JPIERCE','description' => 'lightweight data dumping to JavaScript','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 118,'pod_errors' => 0,'total' => 247,'with_comments' => 1},'releases' => 5,'size' => {'packed' => 6425,'unpacked' => 21944},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'Data-Lazy-0.5.tar.gz' => {'author' => 'JENDA','description' => 'provides "lazy" scalars, arrays and hashes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 188,'pod' => 200,'pod_errors' => 0,'total' => 388,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 4057,'unpacked' => 10942},'testers' => {'pass' => 17},'uses' => ['Carp','Exporter','Tie::Scalar','strict','vars']},'Data-LineBuffer-0.01.tar.gz' => {'author' => 'DJERIUS','description' => 'provide a line oriented data push back facility for input sources','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 124,'pod_errors' => 0,'total' => 253,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 10556,'unpacked' => 27284},'testers' => {'pass' => 4},'uses' => ['strict','warnings']},'Data-Locations-5.2-fixed.tar.gz' => {'author' => 'STBEY','description' => 'Insert data into other data w/o temp files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 932,'pod' => 1013,'pod_errors' => 0,'total' => 1945,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 42379,'unpacked' => 171491},'testers' => {'fail' => 3,'pass' => 12,'tests' => '792'},'uses' => ['5.004','strict','vars']},'Data-MaskPrint-1.0.tar.gz' => {'author' => 'ILYAVERL','description' => 'Allows for exact formatting of data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 159,'pod_errors' => 1,'total' => 596,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 6261,'unpacked' => 38949},'testers' => {'pass' => 8},'uses' => ['Carp','strict','vars']},'Data-Match-0.06.tar.gz' => {'author' => 'KSTEPHENS','description' => 'Complex data structure pattern matching','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1935,'pod' => 404,'pod_errors' => 0,'total' => 2339,'with_comments' => 251},'releases' => 5,'requires' => ['Data-Compare-0.02.tar.gz','Data-Dumper-2.101.tar.gz','String-Escape-2002.001.tar.gz'],'requires_module' => {'Data::Compare' => 0,'Data::Dumper' => 0,'String::Escape' => 0},'requires_recursive' => ['Data-Compare-0.02.tar.gz','Data-Dumper-2.101.tar.gz','String-Escape-2002.001.tar.gz'],'size' => {'packed' => 18898,'unpacked' => 69189},'testers' => {'pass' => 3},'uses' => ['Carp','Data::Compare','Data::Dumper','Exporter','String::Escape','strict','vars','warnings']},'Data-MultiValuedHash-1.081.tar.gz' => {'author' => 'DUNCAND','description' => 'Hash whose keys have multiple ordered values','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 634,'pod' => 312,'pod_errors' => 0,'total' => 946,'with_comments' => 84},'releases' => 2,'size' => {'packed' => 20155,'unpacked' => 95058},'testers' => {'pass' => 6},'uses' => ['5.004','vars','warnings']},'Data-Page-0.18.tar.gz' => {'author' => 'LBROCARD','description' => 'help when paging through sets of results','files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 166,'pod' => 118,'pod_errors' => 0,'total' => 284,'with_comments' => 3},'releases' => 7,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.1'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5741,'unpacked' => 16854},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars']},'Data-Page-Tied-0.03.tar.gz' => {'author' => 'SMUELLER','description' => 'Tied interface for the Data::Page module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 168,'pod' => 83,'pod_errors' => 0,'total' => 251,'with_comments' => 26},'releases' => 3,'requires' => ['Data-Page-0.18.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Data::Page' => '0.12','Test::Simple' => 0},'requires_recursive' => ['Data-Page-0.18.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5034,'unpacked' => 17682},'testers' => {'pass' => 4},'uses' => ['Carp','Data::Page','strict','vars']},'Data-Pageset-Variable-0.01.tar.gz' => {'author' => 'STRYTOAST','description' => 'Variable results on each page of results.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 100,'pod' => 64,'pod_errors' => 0,'total' => 164,'with_comments' => 0},'releases' => 1,'requires' => ['Date-Pageset-0.04.tar.gz'],'requires_module' => {'Data::Pageset' => '0.03'},'requires_recursive' => ['Data-Page-0.18.tar.gz','Date-Pageset-0.04.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2973,'unpacked' => 7884},'testers' => {'pass' => 6},'uses' => ['Carp','Data::Pageset','strict','warnings']},'Data-Pivot-0.04.tar.gz' => {'author' => 'BDULFER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 234,'pod' => 128,'pod_errors' => 0,'total' => 362,'with_comments' => 27},'releases' => 3,'size' => {'packed' => 4032,'unpacked' => 15650},'testers' => {'pass' => 3},'uses' => ['5.005','Exporter','strict','vars']},'Data-Pivoter-0.08.tar.gz' => {'author' => 'MSICKEL','description' => 'Perl extension for pivot / cross tabulation of data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 59,'pod_errors' => 0,'total' => 281,'with_comments' => 20},'releases' => 4,'size' => {'packed' => 5992,'unpacked' => 18635},'testers' => {'pass' => 6},'uses' => ['Carp','Data::Dumper','strict','vars']},'Data-Pointer-0.61.tar.gz' => {'author' => 'BROQ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 697,'pod' => 356,'pod_errors' => 0,'total' => 1053,'with_comments' => 15},'releases' => 8,'requires' => ['Tie-File-0.96.tar.gz','Tie-IxHash-1.21.tar.gz','Want-0.06.tar.gz'],'requires_module' => {'Tie::File' => '0.93','Tie::IxHash' => '1.12','Want' => '0.05'},'requires_recursive' => ['Tie-File-0.96.tar.gz','Tie-IxHash-1.21.tar.gz','Want-0.06.tar.gz'],'size' => {'packed' => 8216,'unpacked' => 29898},'testers' => {'pass' => 8},'uses' => ['Carp','Data::Dumper','Exporter','Tie::File','Tie::IxHash','Want','strict','vars','warnings']},'Data-Presenter-0.62.tar.gz' => {'author' => 'JKEENAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2545,'pod' => 1593,'pod_errors' => 0,'total' => 4138,'with_comments' => 328},'releases' => 2,'requires' => ['List-Compare-0.2.tar.gz'],'requires_module' => {'List::Compare' => '0.15'},'requires_recursive' => ['List-Compare-0.2.tar.gz'],'size' => {'packed' => 59176,'unpacked' => 339596},'testers' => {'pass' => 3},'uses' => ['Carp','List::Compare','lib','strict','warnings']},'Data-Properties-0.02.tar.gz' => {'author' => 'IX','description' => 'persistent properties','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 221,'pod' => 139,'pod_errors' => 0,'total' => 360,'with_comments' => 10},'releases' => 2,'size' => {'packed' => 4434,'unpacked' => 11426},'testers' => {'pass' => 4},'uses' => ['strict']},'Data-PropertyList-1998.1217.tar.gz' => {'author' => 'EVO','description' => 'Convert arbitrary objects to/from strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 391,'pod' => 161,'pod_errors' => 0,'total' => 552,'with_comments' => 80},'releases' => 1,'requires' => ['String-Escape-2002.001.tar.gz'],'requires_module' => {'String::Escape' => '1998.12'},'requires_recursive' => ['String-Escape-2002.001.tar.gz'],'size' => {'packed' => 8277,'unpacked' => 22470},'testers' => {'pass' => 4},'uses' => ['5.003','Exporter','String::Escape','strict','vars']},'Data-Quantity-0.001.tar.gz' => {'author' => 'EVO','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1614,'pod' => 177,'pod_errors' => 0,'total' => 1791,'with_comments' => 184},'releases' => 1,'requires' => ['Class-MakeMethods-1.006.tar.gz','Time-modules-2003.0211.tar.gz'],'requires_module' => {'Class::MakeMethods' => 1,'Time::JulianDay' => 1,'Time::ParseDate' => 1},'requires_recursive' => ['Class-MakeMethods-1.006.tar.gz','Time-modules-2003.0211.tar.gz'],'size' => {'packed' => 11103,'unpacked' => 46017},'testers' => {'pass' => 5},'uses' => ['5','Carp','Class::MakeMethods','Class::MakeMethods::Template::ClassName','Exporter','Time::DaysInMonth','Time::JulianDay','Time::Local','Time::ParseDate','strict','vars','warnings']},'Data-Random-0.05.tar.gz' => {'author' => 'ADEO','description' => 'Perl module to generate random data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 707,'pod' => 328,'pod_errors' => 9,'total' => 1035,'with_comments' => 119},'releases' => 5,'size' => {'packed' => 147055,'unpacked' => 474248},'testers' => {'pass' => 8},'uses' => ['5.005_62','Carp','Exporter','File::Basename','FileHandle','GD','lib','vars']},'Data-Reconciliation-0.07.tar.gz' => {'author' => 'CHATEAU','description' => 'Perl extension for data reconciliation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 457,'pod' => 306,'pod_errors' => 0,'total' => 763,'with_comments' => 35},'releases' => 2,'requires' => ['Data-Table-1.39.tar.gz'],'requires_module' => {'Data::Table' => '1.32'},'requires_recursive' => ['Data-Table-1.39.tar.gz'],'size' => {'packed' => 7697,'unpacked' => 28472},'testers' => {'pass' => 4},'uses' => ['5.005_62','Carp','Data::Table','Exporter','strict','warnings']},'Data-RefQueue-0.2.tar.gz' => {'author' => 'ASKSH','description' => 'Queue system based on references and scalars.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 284,'pod' => 147,'pod_errors' => 0,'total' => 431,'with_comments' => 91},'releases' => 2,'size' => {'packed' => 7191,'unpacked' => 40305},'testers' => {'pass' => 4},'uses' => ['5.006','strict','vars']},'Data-Region-1.0.tar.gz' => {'author' => 'GREGFAST','description' => 'define hierarchical areas with behaviors','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 355,'pod' => 212,'pod_errors' => 0,'total' => 567,'with_comments' => 43},'releases' => 1,'size' => {'packed' => 8251,'unpacked' => 23201},'testers' => {'pass' => 3},'uses' => ['strict']},'Data-Reporter-1.4.tar.gz' => {'author' => 'RVAZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1200,'pod' => 839,'pod_errors' => 15,'total' => 2039,'with_comments' => 72},'releases' => 5,'size' => {'packed' => 27273,'unpacked' => 112510},'testers' => {'pass' => 9},'uses' => ['AutoLoader','Carp','DBI','DynaLoader','English','Exporter','File::Copy','Sybase::DBlib','Sybase::Sybperl','strict','vars']},'Data-SearchReplace-1.01.tar.gz' => {'author' => 'YXES','description' => 'perl extention for searching and replacing entries in complex data structures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 84,'pod' => 91,'pod_errors' => 0,'total' => 175,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 4012,'unpacked' => 9293},'testers' => {'pass' => 2},'uses' => ['5.006','Data::Dumper','Exporter','strict','warnings']},'Data-Serializer-0.17.tar.gz' => {'author' => 'NEELY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1081,'pod' => 578,'pod_errors' => 0,'total' => 1659,'with_comments' => 128},'releases' => 8,'requires' => ['Data-Dumper-2.101.tar.gz'],'requires_module' => {'Data::Dumper' => '2.08'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 13848,'unpacked' => 52154},'testers' => {'pass' => 12},'uses' => ['5.004','AutoLoader','Carp','Config::General','Data::Denter','Data::Dumper','Exporter','FreezeThaw','Storable','YAML','strict','vars']},'Data-ShowTable-3.3.tar.gz' => {'author' => 'AKSTE','description' => 'routines to display tabular data in several formats.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1440,'pod' => 723,'pod_errors' => 1,'total' => 2163,'with_comments' => 273},'releases' => 2,'size' => {'packed' => 94369,'unpacked' => 458495},'testers' => {'fail' => 5,'pass' => 13,'tests' => '12'},'uses' => ['Carp','Exporter']},'Data-Sorting-0.9.tar.gz' => {'author' => 'EVO','description' => 'Multi-key sort using function results','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 612,'pod' => 401,'pod_errors' => 0,'total' => 1013,'with_comments' => 88},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 14841,'unpacked' => 59540},'testers' => {'pass' => 3},'uses' => ['5.003','Carp','Exporter','POSIX','strict','vars']},'Data-Stag-0.03.tar.gz' => {'author' => 'CMUNGALL','description' => 'Structured Tags datastructures','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 4256,'pod' => 1468,'pod_errors' => 0,'total' => 5724,'with_comments' => 419},'releases' => 3,'requires' => ['PodParser-1.23.tar.gz','libxml-perl-0.07.tar.gz'],'requires_module' => {'Pod::Usage' => 0,'XML::Handler::XMLWriter' => 0,'XML::Parser::PerlSAX' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz','XML-Parser-2.31.tar.gz','libxml-perl-0.07.tar.gz'],'size' => {'packed' => 84054,'unpacked' => 278706},'testers' => {'pass' => 1},'uses' => ['$mod','Carp','Data::Dumper','Exporter','FileHandle','Graph','XML::Filter::Base','XML::Handler::XMLWriter','XML::Parser::PerlSAX','strict','vars']},'Data-Str2Num-0.02.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 739,'pod' => 455,'pod_errors' => 1,'total' => 1194,'with_comments' => 54},'releases' => 2,'requires' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz'],'requires_module' => {'File::Package' => '1.1','File::SmartNL' => '1.1','File::TestPath' => '1.1','Test::Tech' => '1.08'},'requires_recursive' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz'],'size' => {'packed' => 9619,'unpacked' => 46078},'testers' => {'pass' => 1},'uses' => ['5.001','Exporter','strict','vars','warnings','warnings::register']},'Data-Swap-0.02.tar.gz' => {'author' => 'XMATH','description' => 'Swap referenced variables, type-agnostic','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 60,'pod_errors' => 0,'total' => 89,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 2757,'unpacked' => 6164},'testers' => {'pass' => 2},'uses' => ['5.006','AutoLoader','DynaLoader','Exporter','strict','warnings']},'Data-Table-1.39.tar.gz' => {'author' => 'EZDB','description' => 'Data type related to database tables, spreadsheets, CSV/TSV files, HTML table displays, etc.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1241,'pod' => 484,'pod_errors' => 1,'total' => 1725,'with_comments' => 102},'releases' => 18,'size' => {'packed' => 34231,'unpacked' => 119295},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','Exporter','GD::Graph::points','strict','vars']},'Data-TableAutoSum-0.08.tar.gz' => {'author' => 'BIGJ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 371,'pod' => 228,'pod_errors' => 0,'total' => 599,'with_comments' => 8},'releases' => 8,'requires' => ['Data-Compare-0.02.tar.gz','Data-Dumper-2.101.tar.gz','Math-Random-0.67.tar.gz','Params-Validate-0.64.tar.gz','Regexp-Common-2.113.tar.gz','Scalar-List-Utils-1.11.tar.gz','Set-CrossProduct-1.4.tar.gz','Set-Scalar-1.17.tar.gz','Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz','Tie-CSV_File-0.21.tar.gz','Tie-File-0.96.tar.gz'],'requires_module' => {'Data::Compare' => 0,'Data::Dumper' => 0,'List::Util' => 0,'Math::Random' => 0,'Params::Validate' => 0,'Regexp::Common' => 0,'Set::CrossProduct' => 0,'Set::Scalar' => 0,'Test::Builder' => '0.13','Test::Exception' => 0,'Test::More' => 0,'Tie::CSV_File' => '0.06','Tie::File' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Array-Compare-1.03.tar.gz','Attribute-Handlers-0.78.tar.gz','Data-Compare-0.02.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Math-Random-0.67.tar.gz','Params-Validate-0.64.tar.gz','Regexp-Common-2.113.tar.gz','Scalar-List-Utils-1.11.tar.gz','Set-CrossProduct-1.4.tar.gz','Set-Scalar-1.17.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-ManyParams-0.10.tar.gz','Test-Simple-0.47.tar.gz','Test-Warn-0.07.tar.gz','Text-CSV_XS-0.23.tar.gz','Text-Diff-0.35.tar.gz','Tie-CSV_File-0.21.tar.gz','Tie-File-0.96.tar.gz','Tree-DAG_Node-1.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10594,'unpacked' => 35286},'testers' => {'pass' => 1},'uses' => ['Data::Compare','Data::Dumper','Exporter','List::Util','Params::Validate','Regexp::Common','Set::CrossProduct','Set::Scalar','Test::Builder','Test::More','Tie::CSV_File','strict','warnings']},'Data-Taxi-0.94.tar.gz' => {'author' => 'MIKO','description' => 'Taint-aware, XML-ish data serialization','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 477,'pod' => 160,'pod_errors' => 1,'total' => 637,'with_comments' => 126},'releases' => 3,'size' => {'packed' => 6431,'unpacked' => 20272},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','constant','strict','vars']},'Data-TemporaryBag-0.06.tar.gz' => {'author' => 'YSAS','description' => 'Handle long size data using temporary file .','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 362,'pod' => 83,'pod_errors' => 0,'total' => 445,'with_comments' => 3},'releases' => 5,'requires' => ['File-Temp-0.12.tar.gz'],'requires_module' => {'File::Temp' => '0.12'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4533,'unpacked' => 12698},'testers' => {'pass' => 6},'uses' => ['Carp','Fcntl','File::Temp','constant','strict']},'Data-Type-0.01.04.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2451,'pod' => 418,'pod_errors' => 0,'total' => 2869,'with_comments' => 49},'releases' => 4,'requires' => ['Class-Maker-0.5.14.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz','PerlQt-3.006.tar.gz','Tie-ListKeyedHash-0.41.tar.gz'],'requires_module' => {'Class::Maker' => '0.05.10','Error' => '0.15','IO::Extended' => '0.05','Iter' => '0','Tie::ListKeyedHash' => '0.41'},'requires_recursive' => ['Class-Maker-0.5.14.tar.gz','Data-Dumper-2.101.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz','PerlQt-3.006.tar.gz','Tie-ListKeyedHash-0.41.tar.gz'],'size' => {'packed' => 23002,'unpacked' => 83602},'testers' => {},'uses' => ['5.005_62','Business::CINS','Business::ISSN','Business::UPC','Carp','Class::Maker','Date::Parse','Email::Valid','Error','Exporter','IO::Extended','Iter','Locale::Language','Net::IPv6Addr','Regexp::Common','Tie::ListKeyedHash','Tie::Scalar','strict','subs','vars','warnings']},'Data-Types-0.04.tar.gz' => {'author' => 'DWHEELER','description' => 'Validate and convert data types.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 236,'pod_errors' => 0,'total' => 397,'with_comments' => 15},'releases' => 3,'size' => {'packed' => 5475,'unpacked' => 18308},'testers' => {'pass' => 7},'uses' => ['Exporter','constant','strict','vars']},'Data-UUID-0.10.tar.gz' => {'author' => 'AGOLOMSH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 60,'pod' => 112,'pod_errors' => 0,'total' => 172,'with_comments' => 10},'releases' => 10,'size' => {'packed' => 13331,'unpacked' => 41630},'testers' => {'pass' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','vars']},'Data-Uniqid-0.11.tar.gz' => {'author' => 'MWX','description' => 'Perl extension for simple genrating of unique id\'s','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 35,'pod_errors' => 0,'total' => 110,'with_comments' => 4},'releases' => 2,'requires' => ['Math-BigInt-1.64.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Math::BigInt' => 0,'Sys::Hostname' => 0,'Time::HiRes' => 0},'requires_recursive' => ['Math-BigInt-1.64.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2181,'unpacked' => 4522},'testers' => {'pass' => 4},'uses' => ['5.006','AutoLoader','Exporter','Math::BigInt','Sys::Hostname','Time::HiRes','strict','warnings']},'Data-Validator-Item-0.75.tar.gz' => {'author' => 'ASTAINES','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 357,'pod' => 382,'pod_errors' => 0,'total' => 739,'with_comments' => 58},'releases' => 2,'size' => {'packed' => 11698,'unpacked' => 36555},'testers' => {'pass' => 4},'uses' => ['Carp']},'Data-VarPrint-1.01.tar.gz' => {'author' => 'VSEGO','description' => 'display complex variables on STDOUT','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 36,'pod_errors' => 0,'total' => 126,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 4681,'unpacked' => 12041},'testers' => {'pass' => 4},'uses' => ['5.000','AutoLoader','Exporter','strict','vars']},'Data-Verify-0.01.25.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1777,'pod' => 232,'pod_errors' => 0,'total' => 2009,'with_comments' => 55},'releases' => 3,'requires' => ['Business-CreditCard-0.27.tar.gz','Class-Maker-0.5.14.tar.gz','Email-Valid-0.14.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz','PerlQt-3.006.tar.gz','Regexp-Common-2.113.tar.gz','Tie-ListKeyedHash-0.41.tar.gz'],'requires_module' => {'Business::CreditCard' => '0.27','Class::Maker' => '0.05.10','Email::Valid' => '0.14','Error' => '0.15','IO::Extended' => '0.05','Iter' => '0','Regexp::Common' => '1.20','Tie::ListKeyedHash' => '0.41'},'requires_recursive' => ['Business-CreditCard-0.27.tar.gz','Class-Maker-0.5.14.tar.gz','Data-Dumper-2.101.tar.gz','Email-Valid-0.14.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz','MailTools-1.58.tar.gz','PerlQt-3.006.tar.gz','Regexp-Common-2.113.tar.gz','Tie-ListKeyedHash-0.41.tar.gz'],'size' => {'packed' => 12202,'unpacked' => 44302},'testers' => {},'uses' => ['5.005_62','Business::CreditCard','Carp','Class::Maker','Email::Valid','Error','Exporter','IO::Extended','Iter','Regexp::Common','Tie::ListKeyedHash','Tie::Scalar','strict','subs','vars','warnings']},'Data-Walker-1.05.tar.gz' => {'author' => 'JNOLAN','description' => 'Navigate through Perl data structures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1360,'pod' => 389,'pod_errors' => 0,'total' => 1749,'with_comments' => 15},'releases' => 12,'size' => {'packed' => 20484,'unpacked' => 80777},'testers' => {'pass' => 5},'uses' => ['Data::Dumper','Exporter','overload','strict','vars']},'Data-XDumper-1.03.tar.gz' => {'author' => 'XMATH','description' => 'Accurate human-readable dumps of perl data structures with labeled cross-references.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1904,'pod' => 1086,'pod_errors' => 0,'total' => 2990,'with_comments' => 70},'releases' => 4,'requires' => ['B-More-1.01.tar.gz','Data-Dumper-2.101.tar.gz'],'requires_module' => {'B::More' => '1.01','Data::Dumper' => 0},'requires_recursive' => ['B-More-1.01.tar.gz','Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 27578,'unpacked' => 83865},'testers' => {'pass' => 6},'uses' => ['5.006','B::More','Carp','Exporter','strict','warnings']},'Data-Xtab-1.01.tar.gz' => {'author' => 'BJEPS','description' => 'Pivot (cross-tabulate) a table of data.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 74,'pod_errors' => 0,'total' => 218,'with_comments' => 49},'releases' => 2,'size' => {'packed' => 3684,'unpacked' => 8605},'testers' => {'pass' => 4},'uses' => ['strict']},'DataPort-DataFile-0.03.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1386,'pod' => 1280,'pod_errors' => 1,'total' => 2666,'with_comments' => 159},'releases' => 3,'requires' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'requires_module' => {'File::Package' => '0','File::SmartNL' => '0','File::TestPath' => '0','Test::Tech' => '1.09','Text::Scrub' => '0'},'requires_recursive' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'size' => {'packed' => 16683,'unpacked' => 98490},'testers' => {'pass' => 2},'uses' => ['5.001','strict','vars','warnings','warnings::register']},'DataPort-FileType-FormDB-0.03.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1666,'pod' => 1839,'pod_errors' => 1,'total' => 3505,'with_comments' => 192},'releases' => 3,'requires' => ['DataPort-DataFile-0.03.tar.gz','File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'requires_module' => {'DataPort::DataFile' => '0','File::Package' => '0','File::SmartNL' => '0','File::TestPath' => '0','Test::Tech' => '1.08','Text::Scrub' => '0'},'requires_recursive' => ['DataPort-DataFile-0.03.tar.gz','File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'size' => {'packed' => 24270,'unpacked' => 158422},'testers' => {'pass' => 2},'uses' => ['5.001','DataPort::DataFile','strict','vars','warnings','warnings::register']},'DataPort-Maker-0.03.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1082,'pod' => 566,'pod_errors' => 1,'total' => 1648,'with_comments' => 100},'releases' => 3,'requires' => ['DataPort-DataFile-0.03.tar.gz','DataPort-FileType-FormDB-0.03.tar.gz','File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'requires_module' => {'DataPort::DataFile' => '0','DataPort::FileType::FormDB' => '0','File::Package' => '0','File::SmartNL' => '0','File::TestPath' => '0','Test::Tech' => '1.08','Text::Scrub' => '1.07'},'requires_recursive' => ['DataPort-DataFile-0.03.tar.gz','DataPort-FileType-FormDB-0.03.tar.gz','File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'size' => {'packed' => 11983,'unpacked' => 56898},'testers' => {'fail' => 2,'tests' => '7'},'uses' => ['Cwd','DataPort::FileType::FormDB','File::Data','File::Package','strict','vars','warnings','warnings::register']},'Date-Baha-i-0.14.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 571,'pod' => 417,'pod_errors' => 0,'total' => 988,'with_comments' => 92},'releases' => 30,'requires' => ['Date-Calc-5.3.tar.gz','Lingua-EN-Numbers-0.01.tar.gz','Lingua-EN-Numbers-Ordinate-0.01.tar.gz'],'requires_module' => {'Date::Calc' => 0,'Lingua::EN::Numbers' => 0,'Lingua::EN::Numbers::Ordinate' => 0},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Date-Calc-5.3.tar.gz','Lingua-EN-Numbers-0.01.tar.gz','Lingua-EN-Numbers-Ordinate-0.01.tar.gz'],'testers' => {'pass' => 1},'uses' => ['Date::Calc','Exporter','Lingua::EN::Numbers','Lingua::EN::Numbers::Ordinate','constant','strict','vars']},'Date-Biorhythm-1.1.tar.gz' => {'author' => 'TBONE','description' => 'calculate biorhythms','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 43,'pod_errors' => 0,'total' => 121,'with_comments' => 2},'releases' => 1,'requires' => ['Date-Business-1.2.tar.gz'],'requires_module' => {'Date::Business' => '1.2'},'requires_recursive' => ['Date-Business-1.2.tar.gz'],'size' => {'packed' => 2203,'unpacked' => 3788},'testers' => {'pass' => 4},'uses' => ['5.005_62','Carp','Data::Dumper','Date::Business','strict','warnings']},'Date-Business-1.2.tar.gz' => {'author' => 'DESIMINER','description' => 'fast calendar and business date calculations','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 331,'pod' => 129,'pod_errors' => 0,'total' => 460,'with_comments' => 39},'releases' => 1,'size' => {'packed' => 8201,'unpacked' => 23335},'testers' => {'pass' => 11},'uses' => ['DynaLoader','Exporter','POSIX','Time::Local','constant','strict','vars']},'Date-Calc-5.3.tar.gz' => {'author' => 'STBEY','description' => 'Gregorian calendar date calculations','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 7861,'pod' => 4374,'pod_errors' => 0,'total' => 12235,'with_comments' => 1631},'releases' => 8,'requires' => ['Bit-Vector-6.3.tar.gz'],'requires_module' => {'Bit::Vector' => '5.7'},'requires_recursive' => ['Bit-Vector-6.3.tar.gz'],'size' => {'packed' => 198831,'unpacked' => 1001083},'testers' => {'fail' => 1,'pass' => 26},'uses' => ['Bit::Vector','DynaLoader','Exporter','strict','vars']},'Date-Chinese-1.03.tar.gz' => {'author' => 'RBOW','description' => 'Calculations in the Chinese calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 54,'pod_errors' => 0,'total' => 118,'with_comments' => 4},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10155,'unpacked' => 27512},'testers' => {'pass' => 9},'uses' => ['strict','vars']},'Date-Christmas-1.02.tar.gz' => {'author' => 'HFB','description' => 'Calculates the day of the week Christmas falls upon given the year.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 156,'pod_errors' => 0,'total' => 190,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 3558,'unpacked' => 7503},'testers' => {'pass' => 7},'uses' => ['AutoLoader','Exporter','integer','strict','vars']},'Date-Convert-French_Rev-0.05.tar.gz' => {'author' => 'JFORGET','description' => 'From/to French Revolutionary Calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 272,'pod_errors' => 1,'total' => 709,'with_comments' => 71},'releases' => 5,'requires' => ['DateConvert-0.16.tar.gz','Roman-1.1.tar.gz'],'requires_module' => {'Date::Convert' => 0,'Roman' => 0},'requires_recursive' => ['DateConvert-0.16.tar.gz','Roman-1.1.tar.gz'],'size' => {'packed' => 37251,'unpacked' => 132624},'testers' => {'pass' => 2},'uses' => ['Carp','Date::Convert','Exporter','Roman','constant','strict','vars']},'Date-Day-1.04.tar.gz' => {'author' => 'ESSENZ','description' => 'Perl extension for converting a date to its respective day.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 73,'pod_errors' => 0,'total' => 146,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 3022,'unpacked' => 8762},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Date-DayOfWeek-1.22.tar.gz' => {'author' => 'RBOW','description' => 'Determine the day of the week for any date.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 264,'pod' => 279,'pod_errors' => 0,'total' => 543,'with_comments' => 18},'releases' => 10,'requires' => ['Date-Leapyear-1.71.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Date::Leapyear' => 0,'Test::More' => '0.40'},'requires_recursive' => ['Date-Leapyear-1.71.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8304,'unpacked' => 23589},'testers' => {'pass' => 11},'uses' => ['Date::Leapyear','Exporter','strict','vars']},'Date-Decade-0.33.tar.gz' => {'author' => 'MIDI','description' => 'Decade calculations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 163,'pod' => 86,'pod_errors' => 1,'total' => 249,'with_comments' => 31},'releases' => 2,'requires' => ['Date-Pcalc-1.2.tar.gz'],'requires_module' => {'Date::Pcalc' => '1.2'},'requires_recursive' => ['Date-Pcalc-1.2.tar.gz'],'size' => {'packed' => 2747,'unpacked' => 8700},'testers' => {'pass' => 5},'uses' => ['5.003_03','Carp','Date::Calc','Date::Pcalc','Exporter','strict','vars']},'Date-Discordian-1.36.tar.gz' => {'author' => 'RBOW','description' => 'Calculate dates in the Discordian calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 281,'pod' => 78,'pod_errors' => 0,'total' => 359,'with_comments' => 45},'releases' => 14,'requires' => ['Date-ICal-1.72.tar.gz','Date-Leapyear-1.71.tar.gz','Memoize-1.01.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'requires_module' => {'Date::ICal' => '1.54','Date::Leapyear' => 0,'Memoize' => 0,'Test::More' => 0,'Time::Local' => 0},'requires_recursive' => ['Date-ICal-1.72.tar.gz','Date-Leapyear-1.71.tar.gz','File-Spec-0.82.tar.gz','Memoize-1.01.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 8888,'unpacked' => 25920},'testers' => {'pass' => 1},'uses' => ['Date::ICal','Date::Leapyear','Exporter','Memoize','Time::Local','strict','vars']},'Date-Easter-1.14.tar.gz' => {'author' => 'RBOW','description' => 'Calculate the date of Easter','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 112,'pod' => 69,'pod_errors' => 0,'total' => 181,'with_comments' => 3},'releases' => 6,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5857,'unpacked' => 17512},'testers' => {'pass' => 6},'uses' => ['Exporter','Time::Local','strict','vars']},'Date-Ethiopic-0.13.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2405,'pod' => 1118,'pod_errors' => 1,'total' => 3523,'with_comments' => 252},'releases' => 4,'requires' => ['Convert-Number-Ethiopic-0.16.tar.gz','Date-ICal-1.72.tar.gz'],'requires_module' => {'Convert::Number::Ethiopic' => '0.15','Date::ICal' => 0},'requires_recursive' => ['Convert-Number-Ethiopic-0.16.tar.gz','Date-ICal-1.72.tar.gz','Date-Leapyear-1.71.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 24893,'unpacked' => 115434},'testers' => {'fail' => 1,'tests' => '3'},'uses' => ['5.000','Convert::Number::Ethiopic','Date::Ethiopic','strict','utf','vars']},'Date-EzDate-1.08.tar.gz' => {'author' => 'MIKO','description' => 'Date and time manipulation made easy','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1529,'pod' => 696,'pod_errors' => 0,'total' => 2225,'with_comments' => 308},'releases' => 9,'size' => {'packed' => 28546,'unpacked' => 109768},'testers' => {'pass' => 2},'uses' => ['Carp','Debug::ShowStuff','POSIX','Tie::Hash','Time::Local','constant','re','strict','vars']},'Date-Gregorian-0.05.tar.gz' => {'author' => 'MHASCH','description' => 'Gregorian calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 542,'pod' => 130,'pod_errors' => 0,'total' => 672,'with_comments' => 70},'releases' => 1,'size' => {'packed' => 10014,'unpacked' => 32928},'testers' => {'pass' => 8},'uses' => ['POSIX','constant','integer','strict','vars']},'Date-Handler-1.1.tar.gz' => {'author' => 'BBEAUSEJ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2649,'pod' => 710,'pod_errors' => 0,'total' => 3359,'with_comments' => 607},'releases' => 15,'size' => {'packed' => 33001,'unpacked' => 168626},'testers' => {'fail' => 1,'pass' => 7,'tests' => '195'},'uses' => ['Carp','Data::Dumper','Exporter','POSIX','Test','Time::Local','constant','strict','vars']},'Date-Horoscope-2.2.tar.gz' => {'author' => 'TBONE','description' => 'Date operations based on the horoscope calendar','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 179,'pod' => 43,'pod_errors' => 0,'total' => 222,'with_comments' => 20},'releases' => 5,'size' => {'packed' => 2899,'unpacked' => 6582},'testers' => {'pass' => 6},'uses' => ['Data::Dumper','Date::Manip','Exporter','strict','vars']},'Date-ICal-1.72.tar.gz' => {'author' => 'RBOW','description' => 'Perl extension for ICalendar date objects.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1378,'pod' => 478,'pod_errors' => 0,'total' => 1856,'with_comments' => 240},'releases' => 25,'requires' => ['Date-Leapyear-1.71.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz'],'requires_module' => {'Date::Leapyear' => '1.03','Storable' => 0,'Test::Harness' => '2.25','Test::More' => '0.45','Time::HiRes' => 0,'Time::Local' => 0},'requires_recursive' => ['Date-Leapyear-1.71.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 43895,'unpacked' => 137163},'testers' => {'pass' => 10},'uses' => ['Carp','Data::Dumper','Date::Leapyear','Time::Local','integer','strict','vars']},'Date-ISO-1.30.tar.gz' => {'author' => 'RBOW','description' => 'Calculate dates in the ISO calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 450,'pod' => 61,'pod_errors' => 0,'total' => 511,'with_comments' => 27},'releases' => 19,'requires' => ['Date-ICal-1.72.tar.gz','Date-Leapyear-1.71.tar.gz','Memoize-1.01.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Date::ICal' => '1.54','Date::Leapyear' => 0,'Memoize' => 0,'Test::Inline' => 0,'Test::More' => 0},'requires_recursive' => ['Date-ICal-1.72.tar.gz','Date-Leapyear-1.71.tar.gz','File-Spec-0.82.tar.gz','Memoize-1.01.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 7928,'unpacked' => 28763},'testers' => {'pass' => 1},'uses' => ['Date::ICal','Date::Leapyear','Exporter','Memoize','strict','vars']},'Date-Jalali-0.01.tar.gz' => {'author' => 'AHMAD','description' => 'Perl extension for converting Gregorian Dates to Jalali','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 98,'pod' => 45,'pod_errors' => 0,'total' => 143,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 2569,'unpacked' => 4897},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Exporter','strict','warnings']},'Date-Japanese-Era-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Conversion between Japanese Era / Gregorian calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 267,'pod' => 296,'pod_errors' => 0,'total' => 563,'with_comments' => 6},'releases' => 3,'requires' => ['Date-Calc-5.3.tar.gz','Jcode-0.83.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Date::Calc' => '4.3','Jcode' => '0.75','Test::More' => 0},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Date-Calc-5.3.tar.gz','File-Spec-0.82.tar.gz','Jcode-0.83.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5986,'unpacked' => 18732},'testers' => {'pass' => 6},'uses' => ['Carp','Date::Calc','Exporter','Jcode','constant','strict','vars']},'Date-Japanese-Holiday-0.02.tar.gz' => {'author' => 'IKEBE','description' => 'Calculate Japanese Holiday.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 29,'pod_errors' => 0,'total' => 149,'with_comments' => 5},'releases' => 2,'requires' => ['Date-Calc-5.3.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz'],'requires_module' => {'Date::Calc' => '5.3','Test::More' => '0.32','Time::JulianDay' => '0.01'},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Date-Calc-5.3.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz'],'size' => {'packed' => 2339,'unpacked' => 6517},'testers' => {'pass' => 1},'uses' => ['Carp','Time::JulianDay','constant','strict','vars']},'Date-LastModified-0.60.tar.gz' => {'author' => 'MLFISHER','description' => 'Return last-modified date from a set of resources','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 360,'pod' => 80,'pod_errors' => 0,'total' => 440,'with_comments' => 96},'releases' => 1,'requires' => ['AppConfig-1.55.tar.gz','DBI-1.37.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'AppConfig' => '1.52','DBI' => '1.2','Date::Format' => 0,'Date::Parse' => 0,'File::Find' => 0,'File::stat' => 0,'Test::More' => 0},'requires_recursive' => ['AppConfig-1.55.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12129,'unpacked' => 46979},'testers' => {'pass' => 2},'uses' => ['5.006','AppConfig','Date::Parse','Exporter','File::Find','File::stat','strict','warnings']},'Date-Leapsecond-0.01.tar.gz' => {'author' => 'FGLOCK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 43,'pod_errors' => 0,'total' => 148,'with_comments' => 9},'releases' => 1,'requires' => ['Time-Local-1.07.tar.gz'],'requires_module' => {'Time::Local' => 0},'requires_recursive' => ['Time-Local-1.07.tar.gz'],'size' => {'packed' => 2463,'unpacked' => 5104},'testers' => {'pass' => 6},'uses' => ['5.006','Exporter','Time::Local','strict','vars','warnings']},'Date-Leapyear-1.71.tar.gz' => {'author' => 'RBOW','description' => 'Is a particular year a leap year?','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 25,'pod' => 26,'pod_errors' => 0,'total' => 51,'with_comments' => 5},'releases' => 8,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6355,'unpacked' => 17886},'testers' => {'fail' => 1,'pass' => 34,'tests' => '764'},'uses' => ['Exporter','strict','vars']},'Date-Lima-1.1.tar.gz' => {'author' => 'JETTERO','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 88,'pod' => 66,'pod_errors' => 0,'total' => 154,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 3013,'unpacked' => 6008},'testers' => {'pass' => 10},'uses' => ['5.005_62','AutoLoader','Exporter','strict','warnings']},'Date-Ordinal-2.9.tgz' => {'author' => 'TBONE','description' => 'Conversion of dates to ordinal numbers and vice versa','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 186,'pod' => 114,'pod_errors' => 0,'total' => 300,'with_comments' => 22},'releases' => 4,'size' => {'packed' => 3927,'unpacked' => 46589},'testers' => {'pass' => 6},'uses' => ['Carp','Exporter','strict','vars']},'Date-Pageset-0.04.tar.gz' => {'author' => 'LLAP','description' => 'Page numbering and page sets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 151,'pod' => 115,'pod_errors' => 0,'total' => 266,'with_comments' => 1},'releases' => 1,'requires' => ['Data-Page-0.18.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Data::Page' => '0.15','Test::More' => '0.1'},'requires_recursive' => ['Data-Page-0.18.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5019,'unpacked' => 17047},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Page','strict','vars']},'Date-Passover-1.03.tar.gz' => {'author' => 'RBOW','description' => 'Calculate date of Passover or Rosh Hashanah','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 84,'pod_errors' => 0,'total' => 204,'with_comments' => 6},'releases' => 3,'requires' => ['Date-DayOfWeek-1.22.tar.gz','Date-ICal-1.72.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Date::DayOfWeek' => 0,'Date::ICal' => 0,'Test::More' => 0},'requires_recursive' => ['Date-DayOfWeek-1.22.tar.gz','Date-ICal-1.72.tar.gz','Date-Leapyear-1.71.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 10047,'unpacked' => 26457},'testers' => {'fail' => 4,'pass' => 2,'tests' => '7'},'uses' => ['Carp','Date::DayOfWeek','Date::GoldenNumber','Date::ICal','strict','vars']},'Date-Passover-1.10.tar.gz' => {'author' => 'RBOW','description' => 'When is Passover? When is Rosh Hashanah?','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 84,'pod_errors' => 0,'total' => 204,'with_comments' => 6},'releases' => 3,'requires' => ['Date-DayOfWeek-1.22.tar.gz','Date-ICal-1.72.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Date::DayOfWeek' => 0,'Date::ICal' => 0,'Test::More' => 0},'requires_recursive' => ['Date-DayOfWeek-1.22.tar.gz','Date-ICal-1.72.tar.gz','Date-Leapyear-1.71.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 10295,'unpacked' => 27873},'testers' => {'fail' => 2,'pass' => 1,'tests' => '7'},'uses' => ['Carp','Date::DayOfWeek','Date::ICal','strict','vars']},'Date-Pcalc-1.2.tar.gz' => {'author' => 'STBEY','description' => 'Gregorian calendar date calculations','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2257,'pod' => 1581,'pod_errors' => 0,'total' => 3838,'with_comments' => 93},'releases' => 2,'size' => {'packed' => 61236,'unpacked' => 277364},'testers' => {'pass' => 17},'uses' => ['Carp','Exporter','strict','vars']},'Date-PeriodParser-0.02.tar.gz' => {'author' => 'SIMON','description' => 'Turns English descriptions into time periods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 181,'pod' => 23,'pod_errors' => 0,'total' => 204,'with_comments' => 25},'releases' => 2,'requires' => ['Lingua-EN-Words2Nums-0.11.tar.gz'],'requires_module' => {'Lingua::EN::Words2Nums' => 0},'requires_recursive' => ['Lingua-EN-Words2Nums-0.11.tar.gz'],'size' => {'packed' => 4157,'unpacked' => 10083},'testers' => {'fail' => 1,'pass' => 7},'uses' => ['5.006','Exporter','Lingua::EN::Words2Nums','Time::Local','strict','warnings']},'Date-Range-1.1.tar.gz' => {'author' => 'TMTM','description' => 'deal with a range of dates','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 101,'pod' => 87,'pod_errors' => 0,'total' => 188,'with_comments' => 0},'releases' => 5,'requires' => ['Date-Simple-1.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Date::Simple' => '0.03','Test::More' => '0.04'},'requires_recursive' => ['Date-Simple-1.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3087,'unpacked' => 8260},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars']},'Date-Range-Birth-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'range of birthday for an age','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 81,'pod_errors' => 0,'total' => 153,'with_comments' => 2},'releases' => 2,'requires' => ['Date-Calc-5.3.tar.gz','Date-Range-1.1.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Date::Calc' => 0,'Date::Range' => '0.01','Test::More' => '0.32'},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Date-Calc-5.3.tar.gz','Date-Range-1.1.tar.gz','Date-Simple-1.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3055,'unpacked' => 8420},'testers' => {'pass' => 5},'uses' => ['Carp','Date::Calc','Date::Range','Date::Simple','strict','vars']},'Date-Roman-1.05.tar.gz' => {'author' => 'HOBBIT','description' => 'Manipulating Roman-style dates','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 802,'pod' => 260,'pod_errors' => 0,'total' => 1062,'with_comments' => 58},'releases' => 2,'requires' => ['Getopt-Long-2.33.tar.gz','Roman-1.1.tar.gz'],'requires_module' => {'Getopt::Long' => 0,'Roman' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz','Roman-1.1.tar.gz'],'size' => {'packed' => 38404,'unpacked' => 180738},'testers' => {'pass' => 7},'uses' => ['Carp','Roman','constant','integer','strict','vars']},'Date-Set-1.27.tar.gz' => {'author' => 'FGLOCK','description' => 'Date set math','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1718,'pod' => 711,'pod_errors' => 5,'total' => 2429,'with_comments' => 412},'releases' => 14,'requires' => ['Date-ICal-1.72.tar.gz','Set-Infinite-0.49.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Date::ICal' => '1.70','Set::Infinite' => '0.43','Test::Harness' => '1.23','Test::More' => '0.31'},'requires_recursive' => ['Date-ICal-1.72.tar.gz','Date-Leapyear-1.71.tar.gz','File-Spec-0.82.tar.gz','Set-Infinite-0.49.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 48955,'unpacked' => 189975},'testers' => {'pass' => 1},'uses' => ['AutoLoader','Carp','Date::ICal','Exporter','Set::Infinite','strict','vars','warnings']},'Date-Set-Timezone-0.04.tar.gz' => {'author' => 'FGLOCK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 563,'pod' => 105,'pod_errors' => 0,'total' => 668,'with_comments' => 180},'releases' => 3,'requires' => ['Date-ICal-1.72.tar.gz','Date-Set-1.27.tar.gz','Set-Infinite-0.49.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Date::ICal' => '1.70','Date::Set' => '1.26','Set::Infinite' => '0.43','Test::Harness' => '1.23','Test::More' => '0.31'},'requires_recursive' => ['Date-ICal-1.72.tar.gz','Date-Leapyear-1.71.tar.gz','Date-Set-1.27.tar.gz','File-Spec-0.82.tar.gz','Set-Infinite-0.49.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 20073,'unpacked' => 66580},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','Date::Set','strict','vars','warnings']},'Date-Simple-1.03.tar.gz' => {'author' => 'KASEI','description' => 'A simple date object','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 158,'pod' => 118,'pod_errors' => 0,'total' => 276,'with_comments' => 8},'releases' => 8,'size' => {'packed' => 3802,'unpacked' => 12500},'testers' => {'fail' => 1,'pass' => 17},'uses' => ['Carp','POSIX','overload','strict']},'Date-SundayLetter-1.10.tar.gz' => {'author' => 'RBOW','description' => 'Calculates the Sunday Letters for a given ye','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 61,'pod_errors' => 0,'total' => 146,'with_comments' => 18},'releases' => 2,'requires' => ['Date-Leapyear-1.71.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Date::Leapyear' => 0,'Test::More' => 0},'requires_recursive' => ['Date-Leapyear-1.71.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 11176,'unpacked' => 29206},'testers' => {'pass' => 7},'uses' => ['Date::Leapyear','strict','vars']},'Date-Tie-0.16.tar.gz' => {'author' => 'FGLOCK','description' => 'ISO dates made easy','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 526,'pod' => 211,'pod_errors' => 0,'total' => 737,'with_comments' => 137},'releases' => 14,'requires' => ['Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'POSIX' => 0,'Tie::Hash' => 0,'Time::Local' => 0},'requires_recursive' => ['Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12290,'unpacked' => 46240},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','POSIX','Tie::Hash','Time::Local','strict','vars']},'Date-Tolkien-Shire-1.12.tar.gz' => {'author' => 'TBRAUN','description' => 'J.R.R. Tolkien\'s hobbit calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 637,'pod' => 131,'pod_errors' => 0,'total' => 768,'with_comments' => 87},'releases' => 9,'requires' => ['Time-Local-1.07.tar.gz'],'requires_module' => {'Time::Local' => 0},'requires_recursive' => ['Time-Local-1.07.tar.gz'],'size' => {'packed' => 13772,'unpacked' => 45505},'testers' => {'pass' => 15},'uses' => ['Time::Local','strict','vars']},'Date-Transform-0.09.tar.gz' => {'author' => 'CTBROWN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1019,'pod' => 88,'pod_errors' => 0,'total' => 1107,'with_comments' => 234},'releases' => 4,'requires' => ['Switch-2.09.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'POSIX' => 0,'Switch' => 0},'requires_recursive' => ['Filter-1.29.tar.gz','Switch-2.09.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13126,'unpacked' => 42890},'testers' => {'fail' => 1},'uses' => ['5.006','AutoLoader','Benchmark','Carp','Data::Dumper','Date::Manip::Transform','Date::Transform::Functions','Exporter','POSIX','Switch','Tie::IXHash','constant','lib','strict','warnings']},'DateConvert-0.16.tar.gz' => {'author' => 'MORTY','description' => 'Conversion between Gregorian, Hebrew, more?','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 647,'pod' => 229,'pod_errors' => 0,'total' => 876,'with_comments' => 63},'releases' => 3,'size' => {'packed' => 10938,'unpacked' => 32912},'testers' => {'pass' => 17},'uses' => ['Carp']},'DateManip-5.42a.tar.gz' => {'author' => 'SBECK','description' => 'Complete date/time manipulation package','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8290,'pod' => 1827,'pod_errors' => 4,'total' => 10117,'with_comments' => 1407},'releases' => 1,'size' => {'packed' => 136302,'unpacked' => 493041},'testers' => {'fail' => 1,'pass' => 6,'tests' => '883'},'uses' => ['5.000','Carp','Exporter','IO::File','integer','strict','vars']},'DateTime-0.12.tar.gz' => {'author' => 'DROLSKY','description' => 'A date and time object','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 2856,'pod' => 1088,'pod_errors' => 0,'total' => 3944,'with_comments' => 171},'releases' => 15,'requires' => ['Class-Factory-Util-1.4.tar.gz','DateTime-LeapSecond-0.02.tar.gz','DateTime-TimeZone-0.25.tar.gz','Params-Validate-0.64.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'requires_module' => {'Class::Factory::Util' => '1.3','DateTime::LeapSecond' => '0.02','DateTime::TimeZone' => '0.15','Params::Validate' => '0.52','Test::More' => 0,'Time::Local' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Class-Factory-Util-1.4.tar.gz','DateTime-LeapSecond-0.02.tar.gz','DateTime-TimeZone-0.25.tar.gz','File-Spec-0.82.tar.gz','Params-Validate-0.64.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 61680,'unpacked' => 237127},'testers' => {'pass' => 4},'uses' => ['Class::Factory::Util','DateTime','DateTime::Duration','DateTime::Infinite','DateTime::Language','DateTime::Language::English','DateTime::LeapSecond','DateTime::TimeZone','DynaLoader','Params::Validate','XSLoader','constant','integer','strict','vars']},'DateTime-0.13.tar.gz' => {'author' => 'DROLSKY','description' => undef,'files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 3079,'pod' => 1176,'pod_errors' => 0,'total' => 4255,'with_comments' => 182},'releases' => 15,'requires' => ['Class-Factory-Util-1.4.tar.gz','DateTime-LeapSecond-0.02.tar.gz','DateTime-TimeZone-0.25.tar.gz','Params-Validate-0.64.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'requires_module' => {'Class::Factory::Util' => '1.3','DateTime::LeapSecond' => '0.02','DateTime::TimeZone' => '0.19','Params::Validate' => '0.52','Test::More' => 0,'Time::Local' => '1.04'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Class-Factory-Util-1.4.tar.gz','DateTime-LeapSecond-0.02.tar.gz','DateTime-TimeZone-0.25.tar.gz','File-Spec-0.82.tar.gz','Params-Validate-0.64.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 67036,'unpacked' => 260460},'testers' => {'fail' => 1,'pass' => 4,'tests' => '1433'},'uses' => ['Class::Factory::Util','DateTime::LeapSecond','DateTime::TimeZone','DateTimePP','DateTimePPExtra','DynaLoader','Params::Validate','XSLoader','constant','integer','strict','vars']},'DateTime-0.1401.tar.gz' => {'files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 2141,'pod' => 1038,'pod_errors' => 0,'total' => 3179,'with_comments' => 112},'releases' => 15,'requires' => ['Class-Factory-Util-1.4.tar.gz','DateTime-LeapSecond-0.02.tar.gz','DateTime-Locale-0.02.tar.gz','DateTime-TimeZone-0.25.tar.gz','Params-Validate-0.64.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'requires_module' => {'Class::Factory::Util' => '1.3','DateTime::LeapSecond' => '0.02','DateTime::Locale' => '0.01','DateTime::TimeZone' => '0.25','Params::Validate' => '0.52','Test::More' => 0,'Time::Local' => '1.04'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Class-Factory-Util-1.4.tar.gz','DateTime-LeapSecond-0.02.tar.gz','DateTime-Locale-0.02.tar.gz','DateTime-TimeZone-0.25.tar.gz','File-Spec-0.82.tar.gz','Params-Validate-0.64.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'testers' => {'fail' => 2,'pass' => 1,'tests' => '1380'},'uses' => ['DateTime::LeapSecond','DateTime::Locale','DateTime::TimeZone','DateTimePP','DateTimePPExtra','DynaLoader','Params::Validate','XSLoader','constant','integer','strict','vars']},'DateTime-Calendar-Christian-0.03.tar.gz' => {'author' => 'PIJLL','description' => 'Dates in the Christian calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 548,'pod' => 104,'pod_errors' => 0,'total' => 652,'with_comments' => 42},'releases' => 3,'requires' => ['DateTime-0.1402.tar.gz','DateTime-Calendar-Julian-0.04.tar.gz','Params-Validate-0.64.tar.gz'],'requires_module' => {'DateTime' => '0.09','DateTime::Calendar::Julian' => '0.04','Params::Validate' => '0.52'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','DateTime-0.1402.tar.gz','DateTime-Calendar-Julian-0.04.tar.gz','Params-Validate-0.64.tar.gz'],'size' => {'packed' => 17527,'unpacked' => 65025},'testers' => {'pass' => 3},'uses' => ['Carp','DateTime','DateTime::Calendar::Julian','Params::Validate','strict','vars']},'DateTime-Calendar-Coptic-0.02.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 824,'pod' => 299,'pod_errors' => 1,'total' => 1123,'with_comments' => 55},'releases' => 1,'requires' => ['Convert-Number-Coptic-0.13.tar.gz','DateTime-0.1402.tar.gz'],'requires_module' => {'Convert::Number::Coptic' => 0,'DateTime' => 0},'requires_recursive' => ['Convert-Number-Coptic-0.13.tar.gz','DateTime-0.1402.tar.gz'],'size' => {'packed' => 10490,'unpacked' => 31705},'testers' => {'pass' => 2},'uses' => ['','5.000','Class::Factory::Util','Convert::Number::Coptic','DateTime','DateTime::Language','Params::Validate','strict','utf','vars']},'DateTime-Calendar-FrenchRevolutionary-0.03.tar.gz' => {'author' => 'JFORGET','description' => 'Dates in the French Revolutionary Calendar','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 882,'pod' => 479,'pod_errors' => 8,'total' => 1361,'with_comments' => 109},'releases' => 3,'requires' => ['DateTime-0.1402.tar.gz','Roman-1.1.tar.gz'],'requires_module' => {'DateTime' => '0.06','Roman' => 0},'requires_recursive' => ['DateTime-0.1402.tar.gz','Roman-1.1.tar.gz'],'size' => {'packed' => 53098,'unpacked' => 182766},'testers' => {'pass' => 2},'uses' => ['DateTime','Params::Validate','Roman','constant','strict','vars']},'DateTime-Calendar-Julian-0.04.tar.gz' => {'author' => 'PIJLL','description' => 'Dates in the Julian calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 123,'pod' => 72,'pod_errors' => 0,'total' => 195,'with_comments' => 5},'releases' => 4,'requires' => ['DateTime-0.1402.tar.gz'],'requires_module' => {'DateTime' => '0.08'},'requires_recursive' => ['DateTime-0.1402.tar.gz'],'size' => {'packed' => 11974,'unpacked' => 32328},'testers' => {'pass' => 4},'uses' => ['DateTime','strict','vars']},'DateTime-Calendar-Mayan-0.05.tar.gz' => {'author' => 'JHOBLITT','description' => 'Mayan Long Count Calendar','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 551,'pod' => 221,'pod_errors' => 0,'total' => 772,'with_comments' => 10},'releases' => 4,'size' => {'packed' => 16071,'unpacked' => 55233},'testers' => {'pass' => 2},'uses' => ['DateTime','Params::Validate','constant','strict','vars']},'DateTime-Calendar-Pataphysical-0.02.tar.gz' => {'author' => 'PIJLL','description' => 'Dates in the pataphysical calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 964,'pod' => 201,'pod_errors' => 0,'total' => 1165,'with_comments' => 20},'releases' => 2,'requires' => ['DateTime-0.13.tar.gz','DateTime-0.1402.tar.gz','Params-Validate-0.64.tar.gz'],'requires_module' => {'DateTime::Duration' => 0,'DateTime::Language' => 0,'Params::Validate' => '0.52'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Class-Factory-Util-1.4.tar.gz','DateTime-0.13.tar.gz','DateTime-0.1402.tar.gz','DateTime-LeapSecond-0.02.tar.gz','DateTime-TimeZone-0.25.tar.gz','File-Spec-0.82.tar.gz','Params-Validate-0.64.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 22500,'unpacked' => 65936},'testers' => {'pass' => 4},'uses' => ['DateTime','DateTime::Duration','DateTime::Language','Params::Validate','strict','vars']},'DateTime-Event-Cron-0.03.tar.gz' => {'author' => 'MSISK','description' => 'DateTime from cron listings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 611,'pod' => 140,'pod_errors' => 1,'total' => 751,'with_comments' => 45},'releases' => 2,'requires' => ['DateTime-0.1402.tar.gz','DateTime-Set-0.08.tar.gz','Set-Crontab-1.00.tar.gz'],'requires_module' => {'DateTime' => '0.07','DateTime::Set' => '0.02','Set::Crontab' => 0},'requires_recursive' => ['DateTime-0.1402.tar.gz','DateTime-Set-0.08.tar.gz','File-Spec-0.82.tar.gz','Set-Crontab-1.00.tar.gz','Set-Infinite-0.49.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 9213,'unpacked' => 44375},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','DateTime','DateTime::Set','Set::Crontab','constant','strict','vars','warnings']},'DateTime-Event-Easter-1.0100.tar.gz' => {'author' => 'RICKM','description' => 'Returns Easter events for DateTime objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 324,'pod' => 172,'pod_errors' => 0,'total' => 496,'with_comments' => 7},'releases' => 4,'requires' => ['DateTime-0.1402.tar.gz','DateTime-Calendar-Julian-0.04.tar.gz','Params-Validate-0.64.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'DateTime' => '0.06','DateTime::Calendar::Julian' => 0,'Params::Validate' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','DateTime-0.1402.tar.gz','DateTime-Calendar-Julian-0.04.tar.gz','Params-Validate-0.64.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18728,'unpacked' => 58954},'testers' => {'fail' => 1,'pass' => 3,'tests' => '517'},'uses' => ['Carp','DateTime','DateTime::Calendar::Julian','Exporter','Params::Validate','strict','vars']},'DateTime-Event-ICal-0.01.tar.gz' => {'author' => 'FGLOCK','description' => 'Perl DateTime extension for computing rfc2445 recurrences.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 609,'pod' => 176,'pod_errors' => 0,'total' => 785,'with_comments' => 73},'releases' => 1,'requires' => ['DateTime-0.1402.tar.gz','DateTime-Event-Recurrence-0.05.tar.gz'],'requires_module' => {'DateTime' => 0,'DateTime::Event::Recurrence' => '0.05'},'requires_recursive' => ['DateTime-0.1402.tar.gz','DateTime-Event-Recurrence-0.05.tar.gz','DateTime-Set-0.08.tar.gz','File-Spec-0.82.tar.gz','Set-Infinite-0.49.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 22280,'unpacked' => 106859},'testers' => {'pass' => 1},'uses' => ['Carp','DateTime','DateTime::Event::Recurrence','DateTime::Set','DateTime::Span','DateTime::SpanSet','Exporter','Params::Validate','strict','vars']},'DateTime-Event-NameDay-0.02.tar.gz' => {'author' => 'BBENNETT','description' => 'Perl DateTime extension to work with namedays from various countries.','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 1767,'pod' => 58,'pod_errors' => 0,'total' => 1825,'with_comments' => 124},'releases' => 2,'size' => {'packed' => 23856,'unpacked' => 60912},'testers' => {'pass' => 2},'uses' => ['Carp','DateTime','DateTime::Calendar::Christian','DateTime::Set','Params::Validate','strict','vars']},'DateTime-Event-Recurrence-0.05.tar.gz' => {'author' => 'FGLOCK','description' => 'Perl DateTime extension for computing basic recurrences.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 972,'pod' => 152,'pod_errors' => 0,'total' => 1124,'with_comments' => 64},'releases' => 5,'requires' => ['DateTime-0.1402.tar.gz','DateTime-Set-0.08.tar.gz'],'requires_module' => {'DateTime' => 0,'DateTime::Set' => '0.07'},'requires_recursive' => ['DateTime-0.1402.tar.gz','DateTime-Set-0.08.tar.gz','File-Spec-0.82.tar.gz','Set-Infinite-0.49.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 20794,'unpacked' => 94552},'testers' => {'pass' => 1},'uses' => ['Carp','DateTime','DateTime::Set','DateTime::Span','Exporter','Params::Validate','integer','strict','vars']},'DateTime-Event-Sunrise-0.04.tar.gz' => {'author' => 'RKHILL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 759,'pod' => 205,'pod_errors' => 2,'total' => 964,'with_comments' => 315},'releases' => 2,'requires' => ['DateTime-0.1402.tar.gz','DateTime-Set-0.08.tar.gz'],'requires_module' => {'DateTime' => '0.12','DateTime::Set' => '0.07'},'requires_recursive' => ['DateTime-0.1402.tar.gz','DateTime-Set-0.08.tar.gz','File-Spec-0.82.tar.gz','Set-Infinite-0.49.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 8320,'unpacked' => 29078},'testers' => {'pass' => 3},'uses' => ['Carp','DateTime','DateTime::Set','Exporter','Math::Trig','POSIX','Params::Validate','Set::Infinite','strict','vars']},'DateTime-Format-Baby-1.0100.tar.gz' => {'author' => 'RICKM','description' => 'Parse and format baby-style time','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 215,'pod' => 88,'pod_errors' => 0,'total' => 303,'with_comments' => 2},'releases' => 6,'requires' => ['DateTime-0.1402.tar.gz','Params-Validate-0.64.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'DateTime' => '0.06','Params::Validate' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','DateTime-0.1402.tar.gz','Params-Validate-0.64.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6262,'unpacked' => 15158},'testers' => {'pass' => 2},'uses' => ['Carp','DateTime','strict','vars']},'DateTime-Format-Bork-0.01.tar.gz' => {'author' => 'JHOBLITT','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 53,'pod_errors' => 0,'total' => 169,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 10556,'unpacked' => 28736},'testers' => {'pass' => 1},'uses' => ['strict','vars']},'DateTime-Format-Builder-0.75.tar.gz' => {'author' => 'SPOON','description' => undef,'files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 6363,'pod' => 1292,'pod_errors' => 0,'total' => 7655,'with_comments' => 549},'releases' => 9,'size' => {'packed' => 76811,'unpacked' => 267333},'testers' => {'pass' => 3},'uses' => ['$self->{path}::$self->{dispatch}','5','5.004','5.005','Carp','Config','DateTime','DateTime::Format::Strptime','Exporter','ExtUtils::MM_Unix','File::Basename','File::Find','File::Path','Module::Install','Module::Install::Base','Module::Signature','Module::Versions::Report','Params::Validate','Socket','Test::Builder','YAML','YAML::Error','YAML::Family','YAML::Node','YAML::Transfer','constant','inc::Module::Install','strict','threads::shared','vars']},'DateTime-Format-DBI-0.03a.tar.gz' => {'author' => 'CFAERBER','description' => 'Find a parser class for a database connection.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 66,'pod' => 92,'pod_errors' => 0,'total' => 158,'with_comments' => 3},'releases' => 1,'requires' => ['DateTime-0.1402.tar.gz'],'requires_module' => {'DateTime' => '0.1'},'requires_recursive' => ['DateTime-0.1402.tar.gz'],'size' => {'packed' => 10194,'unpacked' => 26661},'testers' => {'pass' => 2},'uses' => ['Carp','DBI','strict','vars']},'DateTime-Format-DateManip-0.01.tar.gz' => {'author' => 'BBENNETT','description' => 'Perl DateTime extension to convert Date::Manip dates and durations to DateTimes and vice versa.','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 289,'pod' => 90,'pod_errors' => 1,'total' => 379,'with_comments' => 127},'releases' => 1,'size' => {'packed' => 14242,'unpacked' => 39773},'testers' => {'pass' => 2},'uses' => ['Carp','Date::Manip','DateTime','DateTime::Duration','bytes','strict','vars']},'DateTime-Format-Epoch-0.05.tar.gz' => {'author' => 'PIJLL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 376,'pod' => 248,'pod_errors' => 0,'total' => 624,'with_comments' => 3},'releases' => 4,'requires' => ['DateTime-0.1402.tar.gz'],'requires_module' => {'DateTime' => '0.12'},'requires_recursive' => ['DateTime-0.1402.tar.gz'],'size' => {'packed' => 14294,'unpacked' => 49730},'testers' => {'pass' => 1},'uses' => ['DateTime','DateTime::LeapSecond','Math::BigInt','Params::Validate','strict','vars']},'DateTime-Format-Excel-0.28.tar.gz' => {'author' => 'SPOON','description' => 'Convert between DateTime and Excel dates.','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 172,'pod' => 160,'pod_errors' => 0,'total' => 332,'with_comments' => 4},'releases' => 3,'requires' => ['DateTime-0.1402.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DateTime' => '0.08','DateTime::Duration' => 0,'Test::More' => '0.47'},'requires_recursive' => ['DateTime-0.1402.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 16951,'unpacked' => 43779},'testers' => {'pass' => 3},'uses' => ['5.005','Carp','DateTime','strict','vars']},'DateTime-Format-HTTP-0.34.tar.gz' => {'author' => 'SPOON','description' => 'date conversion routines','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 103,'pod_errors' => 0,'total' => 238,'with_comments' => 2},'releases' => 2,'requires' => ['DateTime-0.1402.tar.gz','DateTime-TimeZone-0.25.tar.gz','Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'DateTime' => '0.13','DateTime::TimeZone' => '0.23','HTTP::Date' => '1.44','Test::More' => '0.47'},'requires_recursive' => ['DateTime-0.1402.tar.gz','DateTime-TimeZone-0.25.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18047,'unpacked' => 47026},'testers' => {'fail' => 1,'tests' => '61'},'uses' => ['DateTime','HTTP::Date','strict','vars','warnings']},'DateTime-Format-IBeat-0.15.tar.gz' => {'author' => 'SPOON','description' => 'Format times in .beat notation','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 154,'pod' => 107,'pod_errors' => 0,'total' => 261,'with_comments' => 0},'releases' => 2,'requires' => ['DateTime-0.1402.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '1.01','DateTime' => '0.09','Test::More' => '0.47'},'requires_recursive' => ['DateTime-0.1402.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15851,'unpacked' => 40047},'testers' => {'pass' => 2},'uses' => ['Carp','DateTime','strict','warnings']},'DateTime-Format-ICal-0.06.tar.gz' => {'author' => 'DROLSKY','description' => 'Parse and format iCal datetime and duration strings','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 291,'pod' => 107,'pod_errors' => 0,'total' => 398,'with_comments' => 15},'releases' => 5,'size' => {'packed' => 13976,'unpacked' => 44024},'testers' => {'pass' => 2},'uses' => ['DateTime','DateTime::Event::ICal','DateTime::Span','Params::Validate','strict','vars']},'DateTime-Format-ISO8601-0.03.tar.gz' => {'author' => 'JHOBLITT','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 730,'pod' => 264,'pod_errors' => 0,'total' => 994,'with_comments' => 96},'releases' => 1,'size' => {'packed' => 14532,'unpacked' => 58673},'testers' => {'pass' => 1},'uses' => ['DateTime','DateTime::Format::Builder','strict','vars']},'DateTime-Format-Mail-0.26.tar.gz' => {'author' => 'SPOON','description' => 'Convert between DateTime and RFC2822/822 formats','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 280,'pod' => 159,'pod_errors' => 0,'total' => 439,'with_comments' => 35},'releases' => 4,'requires' => ['DateTime-0.1402.tar.gz','Params-Validate-0.64.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DateTime' => '0.14','Params::Validate' => '0.64','Test::More' => '0.47'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','DateTime-0.1402.tar.gz','File-Spec-0.82.tar.gz','Params-Validate-0.64.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 172405,'unpacked' => 1074367},'testers' => {'pass' => 1},'uses' => ['5.005','Carp','DateTime','Params::Validate','strict','vars']},'DateTime-Format-MySQL-0.03.tar.gz' => {'author' => 'DROLSKY','description' => 'Parse and format MySQL dates and times','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 113,'pod' => 61,'pod_errors' => 0,'total' => 174,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 10509,'unpacked' => 29353},'testers' => {'pass' => 1},'uses' => ['DateTime','strict','vars']},'DateTime-Format-Pg-0.05.tar.gz' => {'author' => 'CFAERBER','description' => 'Parse and format PostgreSQL dates and times','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 694,'pod' => 247,'pod_errors' => 0,'total' => 941,'with_comments' => 106},'releases' => 3,'requires' => ['DateTime-0.1402.tar.gz','DateTime-Format-Builder-0.75.tar.gz','DateTime-TimeZone-0.25.tar.gz'],'requires_module' => {'DateTime' => '0.1','DateTime::Format::Builder' => '0.72','DateTime::TimeZone' => '0.05'},'requires_recursive' => ['DateTime-0.1402.tar.gz','DateTime-Format-Builder-0.75.tar.gz','DateTime-TimeZone-0.25.tar.gz'],'size' => {'packed' => 17204,'unpacked' => 56552},'testers' => {'pass' => 2},'uses' => ['Carp','DateTime','DateTime::Duration','DateTime::Format::Builder','DateTime::TimeZone','DateTime::TimeZone::Floating','DateTime::TimeZone::UTC','strict','vars']},'DateTime-Format-Roman-0.02.tar.gz' => {'author' => 'PIJLL','description' => 'Roman day numbering for DateTime objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 132,'pod' => 84,'pod_errors' => 0,'total' => 216,'with_comments' => 1},'releases' => 2,'requires' => ['DateTime-0.1402.tar.gz','Roman-1.1.tar.gz'],'requires_module' => {'DateTime' => '0.12','Roman' => 0},'requires_recursive' => ['DateTime-0.1402.tar.gz','Roman-1.1.tar.gz'],'size' => {'packed' => 10554,'unpacked' => 27942},'testers' => {'pass' => 2},'uses' => ['DateTime','Params::Validate','Roman','strict','vars']},'DateTime-Format-Strptime-1.0302.tar.gz' => {'author' => 'RICKM','description' => 'Parse and format strp and strf time patterns','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 814,'pod' => 296,'pod_errors' => 0,'total' => 1110,'with_comments' => 90},'releases' => 10,'requires' => ['DateTime-0.13.tar.gz','DateTime-0.1402.tar.gz','DateTime-TimeZone-0.25.tar.gz','Params-Validate-0.64.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'DateTime' => '0.13','DateTime::Language' => 0,'DateTime::TimeZone' => '0.18','Exporter' => 0,'Params::Validate' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Class-Factory-Util-1.4.tar.gz','DateTime-0.13.tar.gz','DateTime-0.1402.tar.gz','DateTime-LeapSecond-0.02.tar.gz','DateTime-TimeZone-0.25.tar.gz','File-Spec-0.82.tar.gz','Params-Validate-0.64.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 22542,'unpacked' => 73664},'testers' => {'pass' => 5},'uses' => ['Carp','DateTime','DateTime::Language','DateTime::TimeZone','Exporter','Params::Validate','strict','vars']},'DateTime-Format-W3CDTF-0.03.tar.gz' => {'author' => 'KELLAN','description' => 'Parse and format W3CDTF datetime strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 143,'pod' => 58,'pod_errors' => 0,'total' => 201,'with_comments' => 6},'releases' => 2,'requires' => ['DateTime-0.1402.tar.gz'],'requires_module' => {'DateTime' => 0},'requires_recursive' => ['DateTime-0.1402.tar.gz'],'size' => {'packed' => 9844,'unpacked' => 25926},'testers' => {'pass' => 3},'uses' => ['DateTime','strict','vars']},'DateTime-LeapSecond-0.02.tar.gz' => {'author' => 'FGLOCK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 50,'pod_errors' => 0,'total' => 211,'with_comments' => 25},'releases' => 1,'size' => {'packed' => 10587,'unpacked' => 28047},'testers' => {'pass' => 5},'uses' => ['5.005','integer','strict','vars']},'DateTime-Locale-0.01.tar.gz' => {'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 18787,'pod' => 1072,'pod_errors' => 1,'total' => 19859,'with_comments' => 3075},'releases' => 2,'testers' => {'pass' => 2},'uses' => ['Params::Validate','strict','utf8','vars']},'DateTime-Precise-1.05.tar.gz' => {'author' => 'BZAJAC','description' => 'Perform common time and date operations with additional GPS operations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2038,'pod' => 451,'pod_errors' => 4,'total' => 2489,'with_comments' => 650},'releases' => 10,'size' => {'packed' => 35599,'unpacked' => 118681},'testers' => {'pass' => 5},'uses' => ['5.004_04','Carp','Exporter','integer','strict','vars']},'DateTime-Set-0.08.tar.gz' => {'author' => 'FGLOCK','description' => 'Datetime sets and set math','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1186,'pod' => 516,'pod_errors' => 2,'total' => 1702,'with_comments' => 185},'releases' => 7,'requires' => ['DateTime-0.1402.tar.gz','Set-Infinite-0.49.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DateTime' => '0.12','Set::Infinite' => '0.49','Test::More' => 0},'requires_recursive' => ['DateTime-0.1402.tar.gz','File-Spec-0.82.tar.gz','Set-Infinite-0.49.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 24881,'unpacked' => 110000},'testers' => {'pass' => 4},'uses' => ['Carp','DateTime','DateTime::Duration','Params::Validate','Set::Infinite','strict','vars']},'DateTime-TimeZone-0.23.tar.gz' => {'author' => 'DROLSKY','description' => 'Time zone object base class and factory','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 161816,'pod' => 253,'pod_errors' => 1,'total' => 162069,'with_comments' => 2947},'releases' => 24,'size' => {'packed' => 253539,'unpacked' => 1855874},'testers' => {'pass' => 3},'uses' => ['Class::Singleton','DateTime','DateTime::Duration','DateTime::TimeZoneCatalog','File::Spec','Params::Validate','constant','strict','vars']},'DateTime-TimeZone-0.25.tar.gz' => {'author' => 'DROLSKY','description' => 'Time zone object base class and factory','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 173297,'pod' => 255,'pod_errors' => 1,'total' => 173552,'with_comments' => 2968},'releases' => 24,'size' => {'packed' => 277880,'unpacked' => 2019718},'testers' => {'pass' => 2},'uses' => ['Class::Singleton','DateTime','DateTime::Duration','DateTime::TimeZone::Local','DateTime::TimeZoneCatalog','File::Spec','Params::Validate','constant','strict','vars']},'DateTime-TimeZone-Alias-0.05.tar.gz' => {'author' => 'JHOBLITT','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 186,'pod' => 203,'pod_errors' => 0,'total' => 389,'with_comments' => 0},'releases' => 5,'size' => {'packed' => 14010,'unpacked' => 42191},'testers' => {'fail' => 1,'tests' => '2077'},'uses' => ['Carp','DateTime::TimeZoneCatalog','strict','vars']},'Date_Maya-1.1.tgz' => {'author' => 'ABIGAIL','description' => '- Translate between Julian days and Maya days.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 193,'pod' => 55,'pod_errors' => 0,'total' => 248,'with_comments' => 16},'releases' => 1,'size' => {'packed' => 4276,'unpacked' => 11647},'testers' => {'pass' => 7},'uses' => ['Exporter','constant','integer','strict','vars']},'DayOfNthWeek-1.0.tar.gz' => {'author' => 'AMURREN','description' => 'Simple Perl module for finding the first, last or the Nth (Sun .. Sat) of the month.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 189,'pod' => 117,'pod_errors' => 0,'total' => 306,'with_comments' => 34},'releases' => 4,'size' => {'packed' => 5204,'unpacked' => 15533},'testers' => {'pass' => 2},'uses' => ['5.005','Exporter','strict','warnings']},'Db-Ctree-1.1.tar.gz' => {'author' => 'REDEN','description' => 'Faircom\'s CTREE+ database interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1495,'pod' => 91,'pod_errors' => 0,'total' => 1586,'with_comments' => 55},'releases' => 3,'size' => {'packed' => 180544,'unpacked' => 275059},'testers' => {},'uses' => ['Carp','Cterrc.ph','Ctport.ph','DynaLoader','Exporter','strict','vars']},'Db-DFC-0.2.tar.gz' => {'author' => 'MSROTH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13311,'pod' => 0,'pod_errors' => 0,'total' => 13311,'with_comments' => 466},'releases' => 3,'size' => {'packed' => 62759,'unpacked' => 525470},'testers' => {'fail' => 1},'uses' => ['JPL::AutoLoader','JPL::Class','constant']},'Db-DFC-0.4.tar.gz' => {'author' => 'MSROTH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 27988,'pod' => 50,'pod_errors' => 0,'total' => 28038,'with_comments' => 2628},'releases' => 3,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'JNI' => ''},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 81917,'unpacked' => 943490},'testers' => {'pass' => 3},'uses' => ['Db::DFC::DfClient','Db::DFC::DfException','Db::DFC::DfId','Db::DFC::DfList','Db::DFC::DfLoginInfo','Db::DFC::DfProperties','Db::DFC::DfQuery','Db::DFC::DfTime','Db::DFC::DfTrace','Db::DFC::DfUtil','Db::DFC::DfValueContext','Db::DFC::IDfACL','Db::DFC::IDfActivity','Db::DFC::IDfAliasSet','Db::DFC::IDfAssembly','Db::DFC::IDfAttr','Db::DFC::IDfAttrLine','Db::DFC::IDfCancelCheckoutNode','Db::DFC::IDfCancelCheckoutOperation','Db::DFC::IDfChangeDescription','Db::DFC::IDfCheckinNode','Db::DFC::IDfCheckinOperation','Db::DFC::IDfCheckoutNode','Db::DFC::IDfCheckoutOperation','Db::DFC::IDfClient','Db::DFC::IDfCollection','Db::DFC::IDfContainment','Db::DFC::IDfCopyNode','Db::DFC::IDfCopyOperation','Db::DFC::IDfDDInfo','Db::DFC::IDfDeleteNode','Db::DFC::IDfDeleteOperation','Db::DFC::IDfDocbaseMap','Db::DFC::IDfDocument','Db::DFC::IDfEnumeration','Db::DFC::IDfException','Db::DFC::IDfExportNode','Db::DFC::IDfExportOperation','Db::DFC::IDfFile','Db::DFC::IDfFolder','Db::DFC::IDfFormat','Db::DFC::IDfFormatRecognizer','Db::DFC::IDfGroup','Db::DFC::IDfId','Db::DFC::IDfImportNode','Db::DFC::IDfImportOperation','Db::DFC::IDfList','Db::DFC::IDfLoginInfo','Db::DFC::IDfMoveNode','Db::DFC::IDfMoveOperation','Db::DFC::IDfOperation','Db::DFC::IDfOperationError','Db::DFC::IDfOperationMonitor','Db::DFC::IDfOperationNode','Db::DFC::IDfOperationPopulator','Db::DFC::IDfOperationStep','Db::DFC::IDfPackage','Db::DFC::IDfPersistentObject','Db::DFC::IDfProcess','Db::DFC::IDfProperties','Db::DFC::IDfQuery','Db::DFC::IDfQueryFullText','Db::DFC::IDfQueryLocation','Db::DFC::IDfQueryMgr','Db::DFC::IDfQueryResultEvent','Db::DFC::IDfQueryResultItem','Db::DFC::IDfQueryResultListener','Db::DFC::IDfQueueItem','Db::DFC::IDfRelation','Db::DFC::IDfRelationType','Db::DFC::IDfRouter','Db::DFC::IDfSearchable','Db::DFC::IDfSession','Db::DFC::IDfSysObject','Db::DFC::IDfTime','Db::DFC::IDfType','Db::DFC::IDfTypedObject','Db::DFC::IDfUser','Db::DFC::IDfVDMNumberingScheme','Db::DFC::IDfVDMPlatformUtils','Db::DFC::IDfValidator','Db::DFC::IDfValue','Db::DFC::IDfValueAssistance','Db::DFC::IDfVersionLabels','Db::DFC::IDfVersionPolicy','Db::DFC::IDfVersionTreeLabels','Db::DFC::IDfVirtualDocument','Db::DFC::IDfVirtualDocumentNode','Db::DFC::IDfWorkflow','Db::DFC::IDfWorkflowBuilder','Db::DFC::IDfWorkitem','JNI','JPL::AutoLoader','JPL::Class','constant']},'Db-Documentum-1.3.tar.gz' => {'author' => 'BRIANSP','description' => 'Perl extension for Documentum Client Libraries.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 416,'pod' => 102,'pod_errors' => 0,'total' => 518,'with_comments' => 64},'releases' => 12,'size' => {'packed' => 16938,'unpacked' => 52044},'testers' => {},'uses' => ['5.004','AutoLoader','Carp','Config','Db::Documentum','DynaLoader','Exporter','Socket','Sys::Hostname','strict','vars']},'Db-Documentum-1.53.tar.gz' => {'author' => 'MSROTH','description' => 'Documentum EDMS API - Perl interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 480,'pod' => 100,'pod_errors' => 0,'total' => 580,'with_comments' => 88},'releases' => 12,'size' => {'packed' => 296451,'unpacked' => 397415},'testers' => {'fail' => 2},'uses' => ['5.004','AutoLoader','Carp','Config','DynaLoader','Exporter','Socket','Sys::Hostname','strict','vars']},'Db-Mediasurface-0.03.tar.gz' => {'author' => 'NWETTERS','description' => 'API and I/O modules for Mediasurface CMS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 55,'pod_errors' => 0,'total' => 118,'with_comments' => 0},'releases' => 3,'requires' => ['DBI-1.37.tar.gz','Db-Mediasurface-Cache-0.04.tar.gz','Db-Mediasurface-ReadConfig-0.01.tar.gz'],'requires_module' => {'DBI' => '0','Db::Mediasurface::Cache' => '0','Db::Mediasurface::ReadConfig' => '0'},'requires_recursive' => ['DBI-1.37.tar.gz','Db-Mediasurface-Cache-0.04.tar.gz','Db-Mediasurface-ReadConfig-0.01.tar.gz'],'size' => {'packed' => 2333,'unpacked' => 4837},'testers' => {'pass' => 7},'uses' => ['Carp','DBI','Db::Mediasurface::ReadConfig','strict']},'Db-Mediasurface-Cache-0.04.tar.gz' => {'author' => 'NWETTERS','description' => 'caches a specified number of key-value pairs, disgarding underused pairs.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 59,'pod_errors' => 0,'total' => 134,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 2807,'unpacked' => 5882},'testers' => {'pass' => 8},'uses' => ['Carp','constant','strict']},'Db-Mediasurface-ReadConfig-0.01.tar.gz' => {'author' => 'NWETTERS','description' => 'reads, parses, and stores configuration from a Mediasurface ms.properties file.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 55,'pod_errors' => 0,'total' => 128,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2696,'unpacked' => 5242},'testers' => {'pass' => 9},'uses' => ['Carp','Fcntl','strict','vars']},'DbFramework-1.06.tar.gz' => {'author' => 'PSHARPE','description' => 'Attribute data type class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1992,'pod' => 791,'pod_errors' => 1,'total' => 2783,'with_comments' => 287},'releases' => 7,'requires' => ['Alias-2.32.tar.gz','PodParser-1.23.tar.gz'],'requires_module' => {'Alias' => 0,'Pod::Usage' => 0},'requires_recursive' => ['Alias-2.32.tar.gz','File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 24187,'unpacked' => 99065},'testers' => {'fail' => 6,'tests' => '58'},'uses' => ['Alias','CGI','Carp','DBI','DbFramework::Attribute','DbFramework::DataModelObject','DbFramework::DefinitionObject','DbFramework::ForeignKey','DbFramework::Key','DbFramework::Persistent','DbFramework::PrimaryKey','DbFramework::Table','DbFramework::Util','IO::File','strict','vars']},'DbFramework-1.08.tar.gz' => {'author' => 'PSHARPE','description' => 'Key class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2626,'pod' => 1011,'pod_errors' => 0,'total' => 3637,'with_comments' => 424},'releases' => 7,'requires' => ['Alias-2.32.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'Alias' => 0,'DBI' => '1.06'},'requires_recursive' => ['Alias-2.32.tar.gz','DBI-1.37.tar.gz'],'size' => {'packed' => 32567,'unpacked' => 136891},'testers' => {},'uses' => ['Alias','CGI','Carp','DBI','DbFramework::Attribute','DbFramework::Catalog','DbFramework::DataModelObject','DbFramework::DataType::ANSII','DbFramework::DataType::Mysql','DbFramework::DefinitionObject','DbFramework::ForeignKey','DbFramework::Key','DbFramework::Persistent','DbFramework::PrimaryKey','DbFramework::Table','DbFramework::Util','IO::File','Text::FillIn','URI::Escape','strict','vars']},'DbFramework-1.10.tar.gz' => {'author' => 'PSHARPE','description' => 'Key class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2779,'pod' => 1036,'pod_errors' => 0,'total' => 3815,'with_comments' => 426},'releases' => 7,'requires' => ['Alias-2.32.tar.gz','CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','TermReadKey-2.21.tar.gz','Text-FillIn-0.05.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'Alias' => 0,'CGI' => 0,'DBI' => '1.06','Term::ReadKey' => 0,'Text::FillIn' => 0,'URI::Escape' => 0},'requires_recursive' => ['Alias-2.32.tar.gz','CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','TermReadKey-2.21.tar.gz','Text-FillIn-0.05.tar.gz','URI-1.24.tar.gz'],'size' => {'packed' => 37057,'unpacked' => 154206},'testers' => {'fail' => 3},'uses' => ['Alias','CGI','Carp','DBI','IO::File','Term::ReadKey','Text::FillIn','URI::Escape','strict','vars']},'Debarnacle-2002.05.15.tar.gz' => {'author' => 'THEDEVIL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 210,'pod' => 75,'pod_errors' => 0,'total' => 285,'with_comments' => 11},'releases' => 1,'requires' => ['DB_File-1.806.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Cwd' => '2.04','DB_File' => '1.75','Fcntl' => '1.03','File::Glob' => '0.991','FileHandle' => '2.00','Getopt::Std' => '1.02'},'requires_recursive' => ['DB_File-1.806.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17526,'unpacked' => 46903},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['File::Find','File::Glob','FileHandle']},'Debug-FaultAutoBT-0.02.tar.gz' => {'author' => 'STAS','description' => 'Automatic Backtrace Extractor on SIG Faults','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 243,'pod' => 243,'pod_errors' => 0,'total' => 486,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 15864,'unpacked' => 50639},'testers' => {'pass' => 6},'uses' => ['5.00503','Config','DynaLoader','File::Spec::Functions','Symbol','constant','strict','warnings']},'Debug-ShowStuff-1.00.tar.gz' => {'author' => 'MIKO','description' => 'A collection of handy debugging routines for displaying the values of variables with a minimum of coding.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1143,'pod' => 226,'pod_errors' => 0,'total' => 1369,'with_comments' => 276},'releases' => 1,'size' => {'packed' => 10855,'unpacked' => 43150},'testers' => {},'uses' => ['5.005','Carp','Exporter','MemHandle','constant','strict','vars']},'Debug-Trace-0.04.tar.gz' => {'author' => 'JV','description' => 'Trace subroutine calls','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 248,'pod' => 107,'pod_errors' => 0,'total' => 355,'with_comments' => 14},'releases' => 1,'requires' => ['Data-Dumper-2.101.tar.gz'],'requires_module' => {'Data::Dumper' => '2.101'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 5160,'unpacked' => 14710},'testers' => {'pass' => 10},'uses' => ['5.00503','Carp','strict','warnings']},'Decision-ACL-0.02.tar.gz' => {'author' => 'BBEAUSEJ','description' => 'Manage and Build Access Control Lists','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 387,'pod' => 311,'pod_errors' => 0,'total' => 698,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 7749,'unpacked' => 22976},'testers' => {'pass' => 12},'uses' => ['Carp','Data::Dumper','Exporter','constant','strict','vars']},'Decision-Depends-0.15.tar.gz' => {'author' => 'DJERIUS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1399,'pod' => 336,'pod_errors' => 0,'total' => 1735,'with_comments' => 65},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz','Tie-IxHash-1.21.tar.gz','YAML-0.35.tar.gz'],'requires_module' => {'Test::More' => 0,'Tie::IxHash' => 0,'YAML' => '0.35'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tie-IxHash-1.21.tar.gz','YAML-0.35.tar.gz'],'size' => {'packed' => 24710,'unpacked' => 91523},'testers' => {'pass' => 2},'uses' => ['5.005_62','Carp','Digest::MD5','Exporter','IO::File','Tie::IxHash','YAML','strict','warnings']},'Decision-Markov-0.02.tar.gz' => {'author' => 'ALANSZ','description' => 'Build/evaluate Markov models for decisions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 522,'pod' => 197,'pod_errors' => 0,'total' => 719,'with_comments' => 55},'releases' => 2,'size' => {'packed' => 8154,'unpacked' => 25822},'testers' => {'pass' => 6},'uses' => ['5.000','AutoLoader','Carp','Exporter','diagnostics','strict','vars']},'Decode-Source-1.01.tar.gz' => {'author' => 'MAGH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 51,'pod_errors' => 0,'total' => 96,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2276,'unpacked' => 4536},'testers' => {'pass' => 11},'uses' => ['5.008','Encode','Filter::Util::Call','strict','utf']},'DelayLine-0.02.tar.gz' => {'author' => 'LTHEGLER','description' => 'Simple time-delay data stucture','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 114,'pod_errors' => 1,'total' => 247,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 3677,'unpacked' => 10843},'testers' => {'pass' => 8},'uses' => ['Carp','strict','vars']},'DelimMatch-1.06a.tar.gz' => {'author' => 'NWALSH','description' => 'Match (possibly nested) delimited strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 692,'pod' => 183,'pod_errors' => 0,'total' => 875,'with_comments' => 33},'releases' => 1,'size' => {'packed' => 8529,'unpacked' => 30774},'testers' => {'pass' => 6},'uses' => ['5.000','AutoLoader','Exporter','strict','vars']},'Des-perl-a1.tar.gz' => {'author' => 'MICB','description' => 'DES encryption (libdes)','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 74,'pod' => 83,'pod_errors' => 0,'total' => 157,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 10831,'unpacked' => 31831},'testers' => {},'uses' => ['DynaLoader','Exporter']},'DesignPattern-Factory-0.01.tar.gz' => {'author' => 'NWETTERS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 128,'pod_errors' => 0,'total' => 206,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 4279,'unpacked' => 24328},'testers' => {'pass' => 4},'uses' => ['Carp','strict','vars']},'Detect-Module-1.2.tar.gz' => {'author' => 'RPOLZER','description' => 'allows to autodetect Perl modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 132,'pod_errors' => 0,'total' => 337,'with_comments' => 20},'releases' => 3,'size' => {'packed' => 13562,'unpacked' => 36075},'testers' => {'pass' => 6},'uses' => ['5.6.1','Exporter','strict','vars']},'Dev-Bollocks-0.05.tar.gz' => {'author' => 'TELS','description' => 'Arbitrary sized bollocks straight from middle management','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 476,'pod' => 186,'pod_errors' => 0,'total' => 662,'with_comments' => 21},'releases' => 3,'requires' => ['Math-BigInt-1.64.tar.gz','Math-String-1.22.tar.gz'],'requires_module' => {'Math::BigInt' => '1.51','Math::String' => '1.17'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz','Math-String-1.22.tar.gz'],'size' => {'packed' => 8932,'unpacked' => 24120},'testers' => {'pass' => 4},'uses' => ['5.005','Exporter','Math::String','strict','vars']},'Devel-AutoProfiler-1.200.tar.gz' => {'author' => 'GSLONDON','description' => 'Automatically profile subroutine calls in a perl program.','files' => [],'lines' => {'nonpod' => 470,'pod' => 124,'pod_errors' => 1,'total' => 594,'with_comments' => 157},'releases' => 2,'size' => {'packed' => 6139,'unpacked' => 21641},'testers' => {'pass' => 3},'uses' => ['5.005_62','Data::Dumper','Time::HiRes','strict','warnings']},'Devel-CCov-0.20.tar.gz' => {'author' => 'JPRIT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 17,'pod' => 0,'pod_errors' => 0,'total' => 17,'with_comments' => 0},'releases' => 6,'requires' => ['Bit-Vector-6.3.tar.gz','Data-Dumper-2.101.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'Bit::Vector' => '5.0','Data::Dumper' => '2.07','Storable' => '0.5'},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 15749,'unpacked' => 46661},'testers' => {'fail' => 1},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Devel-Caller-0.08.tar.gz' => {'author' => 'RCLAMP','description' => 'meatier versions of C<caller>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 70,'pod' => 94,'pod_errors' => 0,'total' => 164,'with_comments' => 0},'releases' => 7,'requires' => ['PadWalker-0.09.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'PadWalker' => '0.08','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','PadWalker-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5581,'unpacked' => 17939},'testers' => {'pass' => 3},'uses' => ['5.005003','DynaLoader','Exporter']},'Devel-Caller-Perl-1.3.tar.gz' => {'author' => 'CWEST','description' => 'Perl only implementation.','files' => ['README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 33,'pod' => 58,'pod_errors' => 0,'total' => 91,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 2171,'unpacked' => 4399},'testers' => {'pass' => 3},'uses' => ['DB','Exporter::Lite','strict','vars']},'Devel-Carnivore-0.09.tar.gz' => {'author' => 'MALTEU','description' => 'Spy on your hashes (and objects)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 198,'pod' => 124,'pod_errors' => 1,'total' => 322,'with_comments' => 44},'releases' => 3,'requires' => ['Attribute-Handlers-0.78.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.77','Test::Simple' => '0.45'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6805,'unpacked' => 23102},'testers' => {'pass' => 3},'uses' => ['5.6.0','Attribute::Handlers','Carp','Exporter','strict','vars','warnings']},'Devel-Carp-0.04.tar.gz' => {'author' => 'JPRIT','description' => 'warn of errors (from perspective of caller) cluck - warn of errors with stack backtrace (not exported by default) croak - die of errors (from perspective of caller) confess - die of errors with stack backtrace','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 284,'pod' => 33,'pod_errors' => 0,'total' => 317,'with_comments' => 110},'releases' => 4,'size' => {'packed' => 5407,'unpacked' => 12239},'testers' => {'pass' => 4},'uses' => ['Exporter']},'Devel-Constants-0.20.tar.gz' => {'author' => 'CHROMATIC','description' => 'Resolve Constants back to their names','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 131,'pod_errors' => 0,'total' => 269,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 4779,'unpacked' => 10487},'testers' => {'pass' => 8},'uses' => ['constant','strict','subs','vars']},'Devel-CoreStack-1.3.tar.gz' => {'author' => 'ADESC','description' => 'generate a stack dump from a core file','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 136,'pod' => 15,'pod_errors' => 0,'total' => 151,'with_comments' => 25},'releases' => 1,'size' => {'packed' => 7665,'unpacked' => 20531},'testers' => {'pass' => 4,'tests' => '0','unknown' => 21},'uses' => ['5.002','Exporter','strict','vars']},'Devel-Cover-0.20.tar.gz' => {'author' => 'PJCJ','description' => 'Code coverage metrics for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2569,'pod' => 803,'pod_errors' => 0,'total' => 3372,'with_comments' => 166},'releases' => 16,'size' => {'packed' => 34209,'unpacked' => 161134},'testers' => {'pass' => 6},'uses' => ['B','B::Concise','B::Debug','B::Deparse','Carp','Data::Dumper','Devel::Cover::Inc','File::Path','File::Spec','Template','Template::Provider','Test','strict','vars','warnings']},'Devel-Coverage-0.2.tar.gz' => {'author' => 'RJRAY','description' => 'Coverage analysis for Perl code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1016,'pod' => 21,'pod_errors' => 0,'total' => 1037,'with_comments' => 326},'releases' => 2,'size' => {'packed' => 10729,'unpacked' => 39667},'testers' => {'tests' => '0','unknown' => 27},'uses' => ['Cwd','Data::Dumper','Devel::Coverage::prefs','Exporter','File::Spec','IO::File','Symbol','strict','vars']},'Devel-DebugInit-0.3.tar.gz' => {'author' => 'JASONS','description' => 'Perl extension for creating a debugger initialization files from C header file macros','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 720,'pod' => 168,'pod_errors' => 0,'total' => 888,'with_comments' => 107},'releases' => 3,'size' => {'packed' => 11276,'unpacked' => 34125},'testers' => {'fail' => 9,'tests' => '5'},'uses' => ['C::Scan','Carp','English','Exporter','strict','vars']},'Devel-Diagram-1.00.tar.gz' => {'author' => 'GLENNWOOD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 530,'pod' => 123,'pod_errors' => 0,'total' => 653,'with_comments' => 98},'releases' => 1,'size' => {'packed' => 18171,'unpacked' => 247526},'testers' => {'pass' => 3},'uses' => ['FileHandle','XML::XSLT::Wrapper','strict','vars']},'Devel-FakeOSName-0.01.tar.gz' => {'author' => 'STAS','description' => 'Make Perl think it runs on a different OS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 22,'pod_errors' => 0,'total' => 67,'with_comments' => 3},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1551,'unpacked' => 2973},'testers' => {'pass' => 3},'uses' => ['Config','strict','warnings']},'Devel-FindGlobals-0.02.tar.gz' => {'author' => 'CNANDOR','description' => 'Find global variables and their size','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 58,'pod_errors' => 0,'total' => 232,'with_comments' => 12},'releases' => 2,'requires' => ['Devel-Size-0.58.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Devel::Size' => 0,'Test::More' => 0},'requires_recursive' => ['Devel-Size-0.58.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2983,'unpacked' => 6827},'testers' => {'pass' => 3},'uses' => ['Devel::Size','Exporter','strict']},'Devel-GDB-1.22.tar.gz' => {'author' => 'JEZRA','description' => 'open and communicate a gdb session','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 379,'pod' => 132,'pod_errors' => 1,'total' => 511,'with_comments' => 94},'releases' => 5,'size' => {'packed' => 6292,'unpacked' => 16934},'testers' => {'pass' => 3},'uses' => ['5.004','FileHandle','IPC::Open3','integer','strict','vars','warnings']},'Devel-Hints-0.04.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Access compile-time hints at runtime','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 775,'pod' => 102,'pod_errors' => 0,'total' => 877,'with_comments' => 55},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 16765,'unpacked' => 47969},'testers' => {'pass' => 2},'uses' => ['$self->{path}::$self->{dispatch}','5.006','Archive::Zip','CPAN','CPANPLUS','Config','DynaLoader','Exporter','ExtUtils::MM_Unix','ExtUtils::MakeMaker','File::Find','File::Path','File::Spec','Module::Install','Module::Install::Base','YAML','inc::Module::Install','strict','vars']},'Devel-Leak-0.02.tar.gz' => {'author' => 'NI-S','description' => 'Find perl objects that are not reclaimed','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 23,'pod' => 38,'pod_errors' => 0,'total' => 61,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 3260,'unpacked' => 6401},'testers' => {'fail' => 3,'pass' => 18,'tests' => '3'},'uses' => ['5.005','DynaLoader','vars']},'Devel-LeakTrace-0.04.tar.gz' => {'author' => 'RCLAMP','description' => 'indicates where variables are leaking from','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 47,'pod_errors' => 0,'total' => 78,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 3967,'unpacked' => 8467},'testers' => {'fail' => 2,'tests' => '12'},'uses' => ['5.006','DynaLoader','strict']},'Devel-LexAlias-0.04.tar.gz' => {'author' => 'RCLAMP','description' => 'alias lexical variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 38,'pod' => 62,'pod_errors' => 0,'total' => 100,'with_comments' => 0},'releases' => 3,'requires' => ['Devel-Caller-0.08.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Devel::Caller' => '0.03','Test::More' => 0},'requires_recursive' => ['Devel-Caller-0.08.tar.gz','File-Spec-0.82.tar.gz','PadWalker-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2888,'unpacked' => 6860},'testers' => {'pass' => 7},'uses' => ['5.005003','Devel::Caller','DynaLoader']},'Devel-Memo-0.004.tar.gz' => {'author' => 'JGLICK','description' => 'memoize function calls','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 53,'pod' => 53,'pod_errors' => 0,'total' => 106,'with_comments' => 2},'releases' => 2,'requires' => ['FreezeThaw-0.43.tar.gz'],'requires_module' => {'FreezeThaw' => 0},'requires_recursive' => ['FreezeThaw-0.43.tar.gz'],'size' => {'packed' => 3134,'unpacked' => 5790},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['5.004','FreezeThaw']},'Devel-Messenger-0.01.tar.gz' => {'author' => 'KOLIBRIE','description' => 'Let Your Code Talk to You','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 235,'pod' => 259,'pod_errors' => 0,'total' => 494,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 7070,'unpacked' => 20250},'testers' => {'pass' => 6},'uses' => ['Exporter','strict','vars']},'Devel-ModInfo-0.05.tar.gz' => {'author' => 'JTILLMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1807,'pod' => 748,'pod_errors' => 3,'total' => 2555,'with_comments' => 503},'releases' => 2,'requires' => ['Parse-RecDescent-1.94.tar.gz','Template-Toolkit-2.10.tar.gz','XML-DOM-1.42.tar.gz'],'requires_module' => {'Parse::RecDescent' => '0','Template' => '0','XML::DOM' => '0'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Parse-RecDescent-1.94.tar.gz','Template-Toolkit-2.10.tar.gz','Text-Balanced-1.95.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 24521,'unpacked' => 100875},'testers' => {'pass' => 1},'uses' => ['CGI','Data::Dumper','Exporter','File::Spec::Functions','IO::File','IO::Handle','Parse::RecDescent','XML::DOM','strict','vars']},'Devel-Modlist-0.5.tar.gz' => {'author' => 'RJRAY','description' => 'Collect module use information','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 178,'pod' => 94,'pod_errors' => 0,'total' => 272,'with_comments' => 21},'releases' => 5,'size' => {'packed' => 5723,'unpacked' => 12645},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['CPAN','Config']},'Devel-ObjectTracker-0.4.tar.gz' => {'author' => 'JOHNC','description' => 'Track object life to detect memory leaks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 483,'pod' => 307,'pod_errors' => 0,'total' => 790,'with_comments' => 44},'releases' => 3,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Benchmark' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 10753,'unpacked' => 37013},'testers' => {'pass' => 4},'uses' => ['strict','vars']},'Devel-PPPort-1.0007.tar.gz' => {'author' => 'KJALB','description' => 'Portability aid for your XS code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 18,'pod' => 0,'pod_errors' => 0,'total' => 18,'with_comments' => 1},'releases' => 4,'size' => {'packed' => 5571,'unpacked' => 13381},'testers' => {'pass' => 7},'uses' => ['Carp','DynaLoader','Exporter']},'Devel-Peek-0.96.tar.gz' => {'author' => 'ILYAZ','description' => 'Peek at internal representation of Perl data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 118,'pod' => 307,'pod_errors' => 0,'total' => 425,'with_comments' => 6},'releases' => 21,'size' => {'packed' => 15759,'unpacked' => 54045},'testers' => {'fail' => 3,'tests' => '0','unknown' => 3},'uses' => ['DynaLoader','Exporter']},'Devel-PiMPx-0.7.1.tar.gz' => {'author' => 'ASKSH','description' => 'The Perl-inclusive Macro Processor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 489,'pod' => 33,'pod_errors' => 0,'total' => 522,'with_comments' => 125},'releases' => 2,'size' => {'packed' => 15313,'unpacked' => 41732},'testers' => {'pass' => 6},'uses' => ['5.006','strict','vars']},'Devel-Pointer-1.00.tar.gz' => {'author' => 'SIMON','description' => 'Fiddle around with pointers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 37,'pod_errors' => 0,'total' => 73,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 2636,'unpacked' => 4802},'testers' => {'pass' => 5},'uses' => ['5.006','DynaLoader','Exporter','strict','warnings']},'Devel-PreProcessor-1999.0220.tar.gz' => {'author' => 'EVO','description' => 'Module inlining and other Perl source manipulations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 338,'pod' => 154,'pod_errors' => 0,'total' => 492,'with_comments' => 72},'releases' => 3,'size' => {'packed' => 6799,'unpacked' => 17793},'testers' => {'pass' => 3},'uses' => ['IO::File','vars']},'Devel-Profile-1.02.tar.gz' => {'author' => 'JAW','description' => 'tell me why my perl program runs so slowly','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 305,'pod' => 138,'pod_errors' => 0,'total' => 443,'with_comments' => 74},'releases' => 3,'requires' => ['Time-HiRes-1.49.tar.gz'],'requires_module' => {'Time::HiRes' => 0},'requires_recursive' => ['Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 6529,'unpacked' => 15353},'testers' => {'pass' => 2},'uses' => ['Time::HiRes']},'Devel-Profiler-0.04.tar.gz' => {'author' => 'SAMTREGAR','description' => 'a Perl profiler compatible with dprofpp','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1037,'pod' => 272,'pod_errors' => 0,'total' => 1309,'with_comments' => 171},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'B' => 0,'File::Path' => 0,'Test::More' => 0,'Time::HiRes' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 16395,'unpacked' => 52437},'testers' => {'fail' => 2,'pass' => 5,'tests' => '57'},'uses' => ['5.006','B','Exporter','File::Path','Test::More','Time::HiRes','strict','warnings']},'Devel-RegExp-0.1.tar.gz' => {'author' => 'ILYAZ','description' => 'Access perl internal regex functions','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 0,'pod_errors' => 0,'total' => 53,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 3605,'unpacked' => 9484},'testers' => {'fail' => 2},'uses' => ['AutoLoader','DynaLoader','Exporter']},'Devel-SawAmpersand-0.30.tar.gz' => {'author' => 'ANDK','description' => 'Perl extension querying sawampersand variable','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 108,'pod' => 90,'pod_errors' => 0,'total' => 198,'with_comments' => 0},'releases' => 9,'size' => {'packed' => 4436,'unpacked' => 10702},'testers' => {'pass' => 3},'uses' => ['B','Config','DynaLoader','Exporter','strict','vars']},'Devel-Scooby-4.12.tar.gz' => {'author' => 'BARRYPJ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 704,'pod' => 91,'pod_errors' => 0,'total' => 795,'with_comments' => 175},'releases' => 1,'requires' => ['Crypt-RSA-1.50.tar.gz','Data-Dumper-2.101.tar.gz','IO-1.20.tar.gz','PadWalker-0.09.tar.gz','Storable-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Crypt::RSA' => '1.5','Data::Dumper' => 0,'IO::Socket' => 0,'PadWalker' => '0.08','Socket' => 0,'Storable' => '2.04'},'requires_recursive' => ['Class-Loader-2.02.tar.gz','Compress-Zlib-1.22.tar.gz','Convert-ASCII-Armour-1.4.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Crypt-DES-2.03.tar.gz','Crypt-Primes-0.50.tar.gz','Crypt-RSA-1.50.tar.gz','Crypt-Random-1.13.tar.gz','Data-Buffer-0.04.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD2-2.02.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Math-Pari-2.010500.tar.gz','PadWalker-0.09.tar.gz','Sort-Versions-1.4.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tie-EncryptedHash-1.21.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14641,'unpacked' => 50308},'testers' => {'pass' => 2},'uses' => ['Crypt::RSA','Data::Dumper','IO::Socket','PadWalker','Socket','Storable']},'Devel-SearchINC-0.01.tar.gz' => {'author' => 'MARCEL','description' => 'loading Perl modules from their development dirs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 50,'pod_errors' => 0,'total' => 109,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 2693,'unpacked' => 5775},'testers' => {'pass' => 10},'uses' => ['5.005_62','Data::Dumper','strict','warnings']},'Devel-SearchINC-1.2.tar.gz' => {'author' => 'MARCEL','description' => 'loading Perl modules from development dirs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 145,'pod' => 99,'pod_errors' => 0,'total' => 244,'with_comments' => 6},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.45'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4447,'unpacked' => 10966},'testers' => {'pass' => 6},'uses' => ['5.006','strict','warnings']},'Devel-Size-0.58.tar.gz' => {'author' => 'DSUGAL','description' => 'Report amount of memory a variable uses','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 124,'pod' => 97,'pod_errors' => 0,'total' => 221,'with_comments' => 7},'releases' => 13,'size' => {'packed' => 7803,'unpacked' => 20580},'testers' => {'pass' => 2},'uses' => ['DynaLoader','Exporter','strict','vars']},'Devel-SmallProf-1.11.tar.gz' => {'author' => 'SALVA','description' => 'Line-by-line profiler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 224,'pod' => 101,'pod_errors' => 0,'total' => 325,'with_comments' => 8},'releases' => 11,'size' => {'packed' => 8447,'unpacked' => 23386},'testers' => {'pass' => 4},'uses' => ['5.000','Time::HiRes','strict']},'Devel-StackTrace-1.03.tar.gz' => {'author' => 'DROLSKY','description' => 'Stacktrace object w/ info form caller()','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 314,'pod' => 166,'pod_errors' => 3,'total' => 480,'with_comments' => 24},'releases' => 9,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.46'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6468,'unpacked' => 18785},'testers' => {'pass' => 22},'uses' => ['5.005','fields','strict','vars']},'Devel-StealthDebug-1.008.tar.gz' => {'author' => 'AASSAD','description' => 'Simple non-intrusive debug module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 502,'pod' => 140,'pod_errors' => 0,'total' => 642,'with_comments' => 32},'releases' => 8,'requires' => ['Filter-Simple-0.78.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Filter::Simple' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10417,'unpacked' => 28192},'testers' => {'pass' => 7},'uses' => ['Carp','Data::Dumper','Exporter','Filter::Simple','strict']},'Devel-Symdump-2.03.tar.gz' => {'author' => 'ANDK','description' => 'dump symbol names or the symbol table','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 379,'pod' => 112,'pod_errors' => 0,'total' => 491,'with_comments' => 16},'releases' => 7,'size' => {'packed' => 9834,'unpacked' => 25733},'testers' => {'pass' => 42},'uses' => ['5.003','Carp','Exporter','strict','vars']},'Devel-Timer-0.01.tar.gz' => {'author' => 'JMOORE','description' => 'Track and report execution time for parts of code','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 195,'pod' => 88,'pod_errors' => 0,'total' => 283,'with_comments' => 30},'releases' => 1,'size' => {'packed' => 10254,'unpacked' => 28130},'testers' => {'pass' => 8},'uses' => ['strict','vars']},'Devel-Tinderbox-Reporter-0.10.tar.gz' => {'author' => 'MSCHWERN','description' => 'Client to send reports to Tinderbox','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 142,'pod_errors' => 1,'total' => 227,'with_comments' => 1},'releases' => 1,'requires' => ['Class-Accessor-0.18.tar.gz','MailTools-1.58.tar.gz','Test-Simple-0.47.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'Class::Accessor::Fast' => '0.02','Mail::Send' => '1.09','Net::SMTP' => '2.15','Test::More' => '0.18'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3155,'unpacked' => 7374},'testers' => {'pass' => 1},'uses' => ['Class::Accessor::Fast','Mail::Mailer','strict','vars']},'Devel-Tinderclient-1.1.tar.gz' => {'author' => 'ZLIPTON','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 428,'pod' => 0,'pod_errors' => 0,'total' => 428,'with_comments' => 305},'releases' => 7,'size' => {'packed' => 7211,'unpacked' => 31983},'testers' => {},'uses' => ['Exporter','Tinderconfig']},'Devel-Tinderclient-1.2.zip' => {'author' => 'ZLIPTON','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 465,'pod' => 0,'pod_errors' => 0,'total' => 465,'with_comments' => 261},'releases' => 7,'size' => {'packed' => 10771,'unpacked' => 28549},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Exporter','HTTP::Request::Common','LWP::UserAgent','Mail::Mailer']},'Devel-Tokenizer-C-0.03.tar.gz' => {'author' => 'MHX','description' => 'Generate C source for fast keyword tokenizer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 178,'pod' => 144,'pod_errors' => 0,'total' => 322,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 9175,'unpacked' => 27426},'testers' => {'pass' => 2},'uses' => ['5.005_03','Carp','strict','vars']},'Devel-Trace-0.10.tar.gz' => {'author' => 'MJD','description' => 'Print out each line before it is executed (like C<sh -x>)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 87,'pod_errors' => 2,'total' => 150,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2506,'unpacked' => 6524},'testers' => {'pass' => 10},'uses' => ['Carp']},'Devel-TraceCalls-0.03.tar.gz' => {'author' => 'RBS','description' => 'Track calls to subs, classes and object instances','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1206,'pod' => 438,'pod_errors' => 2,'total' => 1644,'with_comments' => 128},'releases' => 4,'size' => {'packed' => 19638,'unpacked' => 76052},'testers' => {'pass' => 7},'uses' => ['Data::Dumper','Exporter','Text::FormatTable','UNIVERSAL','strict','vars']},'Devel-TraceLoad-0.08.zip' => {'author' => 'PVERD','description' => 'Traces the loading of perl source code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 464,'pod' => 207,'pod_errors' => 1,'total' => 671,'with_comments' => 53},'releases' => 8,'size' => {'packed' => 13019,'unpacked' => 25410},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.6.1','strict','vars','warnings']},'Devel-TraceMethods-0.50.tar.gz' => {'author' => 'CHROMATIC','description' => 'Perl module for tracing module calls','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 50,'pod_errors' => 0,'total' => 144,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 3129,'unpacked' => 6417},'testers' => {'pass' => 5},'uses' => ['Carp','strict','vars']},'Devel-TraceSAX-0.021.tar.gz' => {'author' => 'RBS','description' => 'Trace SAX events','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 507,'pod' => 64,'pod_errors' => 0,'total' => 571,'with_comments' => 51},'releases' => 3,'requires' => ['Devel-TraceCalls-0.03.tar.gz','XML-SAX-Machines-0.4.tar.gz'],'requires_module' => {'Devel::TraceCalls' => '0.03','XML::SAX::EventMethodMaker' => 0},'requires_recursive' => ['Devel-TraceCalls-0.03.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Machines-0.4.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5332,'unpacked' => 15484},'testers' => {'pass' => 4},'uses' => ['$what','Devel::TraceCalls','Exporter','UNIVERSAL','XML::SAX::EventMethodMaker','strict','vars']},'Devel-TraceSubs-0.02.zip' => {'author' => 'PARTICLE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 144,'pod_errors' => 0,'total' => 318,'with_comments' => 8},'releases' => 2,'requires' => ['Hook-LexWrap-0.20.tar.gz'],'requires_module' => {'Hook::LexWrap' => '0.2'},'requires_recursive' => ['Hook-LexWrap-0.20.tar.gz'],'size' => {'packed' => 6375,'unpacked' => 13428},'testers' => {'pass' => 6},'uses' => ['5.006001','Carp','Data::Dumper','Hook::LexWrap','strict','warnings']},'Devel-WarnGlobal-0.05.tar.gz' => {'author' => 'STEPHEN','description' => 'Perl extension to aid in eliminating globals','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 249,'pod' => 111,'pod_errors' => 0,'total' => 360,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 5305,'unpacked' => 14763},'testers' => {'pass' => 3},'uses' => ['Carp','fields','strict','vars']},'Devel-WeakRef-0.003.tar.gz' => {'author' => 'JGLICK','description' => 'weak references (not reference-counted)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 52,'pod' => 68,'pod_errors' => 0,'total' => 120,'with_comments' => 1},'releases' => 3,'requires' => ['Test-Helper-0.002.tar.gz'],'requires_module' => {'Test::Helper' => '0.002'},'requires_recursive' => ['Test-Helper-0.002.tar.gz'],'size' => {'packed' => 6698,'unpacked' => 16088},'testers' => {'fail' => 1},'uses' => ['DynaLoader','Tie::Hash','integer','strict']},'Devel-ptkdb-1.1086.tar.gz' => {'author' => 'AEPAGE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3885,'pod' => 446,'pod_errors' => 0,'total' => 4331,'with_comments' => 1124},'releases' => 24,'size' => {'packed' => 38279,'unpacked' => 135250},'testers' => {'fail' => 2,'pass' => 5},'uses' => ['5.004','CPAN','Carp','Config','Data::Dumper','Tk','Tk::Adjuster','Tk::Balloon','Tk::Dialog','Tk::HList','Tk::NoteBook','Tk::ROText','Tk::Table','Tk::TextUndo','strict','vars']},'DevelOpProf-0.2.tar.gz' => {'author' => 'MICB','description' => 'Profile the internals of a Perl program','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 50,'pod' => 49,'pod_errors' => 0,'total' => 99,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2636,'unpacked' => 5157},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Opcode']},'Device-Audiotron-1.02.tar.gz' => {'author' => 'DCRAWFORD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 185,'pod' => 138,'pod_errors' => 1,'total' => 323,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 4130,'unpacked' => 11252},'testers' => {'pass' => 4},'uses' => ['5.6.0','Carp','Exporter','LWP','strict','vars']},'Device-Conrad-RelaisControl-0.11.tar.gz' => {'author' => 'NOHA','description' => 'Perl extension for accessing a Conrad Electronic Relaiscard','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 593,'pod' => 99,'pod_errors' => 0,'total' => 692,'with_comments' => 28},'releases' => 2,'size' => {'packed' => 6186,'unpacked' => 17226},'testers' => {'fail' => 1},'uses' => ['5.006','AutoLoader','Carp','Device::SerialPort','Exporter','Frame','constant','strict','vars','warnings']},'Device-Denon-DN1400F-0.01.tar.gz' => {'author' => 'SHEVEK','description' => 'Control a Denon DN-1400F CD player','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 644,'pod' => 33,'pod_errors' => 0,'total' => 677,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 8150,'unpacked' => 42090},'testers' => {},'uses' => ['5.006','Data::Dumper','Device::SerialPort','Exporter','Time::HiRes','strict','vars','warnings']},'Device-Ericsson-AccessoryMenu-0.6.tar.gz' => {'author' => 'RCLAMP','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 368,'pod' => 115,'pod_errors' => 0,'total' => 483,'with_comments' => 23},'releases' => 2,'requires' => ['Class-Accessor-0.18.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Accessor::Fast' => '0','Test::More' => '0'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7905,'unpacked' => 23156},'testers' => {'pass' => 2},'uses' => ['Class::Accessor::Fast','strict','vars']},'Device-Gsm-1.16.tar.gz' => {'author' => 'COSIMO','description' => 'Perl extension to interface GSM cellular / modems','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 598,'pod' => 187,'pod_errors' => 0,'total' => 785,'with_comments' => 134},'releases' => 5,'requires' => ['Device-Modem-1.28.tar.gz','Device-SerialPort-0.22.tar.gz'],'requires_module' => {'Device::Modem' => 0,'Device::SerialPort' => 0},'requires_recursive' => ['Device-Modem-1.28.tar.gz','Device-SerialPort-0.22.tar.gz','Win32-SerialPort-0.19.tar.gz'],'size' => {'packed' => 11622,'unpacked' => 37230},'testers' => {'pass' => 1},'uses' => ['Device::Modem','strict']},'Device-ISDN-OCLM-0.40.tar.gz' => {'author' => 'MERLIN','description' => 'A perl module to control the 3com OfficeConnect LanModem','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1741,'pod' => 772,'pod_errors' => 0,'total' => 2513,'with_comments' => 104},'releases' => 1,'requires' => ['HTML-Tree-3.17.tar.gz','HTTP-Request-Form-0.952.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::TreeBuilder' => '2.06','HTTP::Request' => '1.26','HTTP::Request::Form' => '0.5','LWP' => '5.47','URI::URL' => '5.02'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','HTTP-Request-Form-0.952.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13027,'unpacked' => 63462},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['HTML::Element','HTML::TreeBuilder','HTTP::Request','HTTP::Request::Common','HTTP::Request::Form','LWP::UserAgent','Time::localtime','UNIVERSAL','URI::URL','strict','vars']},'Device-KeyStroke-Mobile-0.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Calculate key stroke times with mobile phone keypads','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 76,'pod_errors' => 0,'total' => 151,'with_comments' => 5},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2599,'unpacked' => 5924},'testers' => {'pass' => 7},'uses' => ['Carp','Exporter','strict','vars']},'Device-Modem-1.24.tar.gz' => {'author' => 'COSIMO','description' => 'Perl extension to talk to modem devices connected via serial port','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 833,'pod' => 209,'pod_errors' => 0,'total' => 1042,'with_comments' => 157},'releases' => 13,'requires' => ['Win32-SerialPort-0.19.tar.gz'],'requires_module' => {'Win32::SerialPort' => 0},'requires_recursive' => ['Win32-SerialPort-0.19.tar.gz'],'size' => {'packed' => 14903,'unpacked' => 48701},'testers' => {},'uses' => ['Device::SerialPort','Win32::SerialPort','constant','strict']},'Device-Modem-1.28.tar.gz' => {'author' => 'COSIMO','description' => 'Perl extension to talk to modem devices connected via serial port','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1141,'pod' => 654,'pod_errors' => 0,'total' => 1795,'with_comments' => 165},'releases' => 13,'requires' => ['Win32-SerialPort-0.19.tar.gz'],'requires_module' => {'Win32::SerialPort' => 0},'requires_recursive' => ['Win32-SerialPort-0.19.tar.gz'],'size' => {'packed' => 30986,'unpacked' => 95968},'testers' => {'pass' => 1},'uses' => ['Device::SerialPort','Win32::SerialPort','constant','strict']},'Device-ParallelPort-0.03.tar.gz' => {'author' => 'SCOTT','description' => 'Low Level access to Parallel Port','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 334,'pod' => 257,'pod_errors' => 0,'total' => 591,'with_comments' => 15},'releases' => 2,'size' => {'packed' => 8626,'unpacked' => 23509},'testers' => {'pass' => 6},'uses' => ['Carp','strict','vars']},'Device-ParallelPort-JayCar-0.02.tar.gz' => {'author' => 'SCOTT','description' => 'Jaycar controlling device. XXX This is all wrong - need to update...','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 110,'pod' => 39,'pod_errors' => 0,'total' => 149,'with_comments' => 21},'releases' => 2,'size' => {'packed' => 5162,'unpacked' => 11622},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','Device::ParallelPort','strict']},'Device-ParallelPort-drv-linux-0.03.tar.gz' => {'author' => 'SCOTT','description' => 'Standard linux hardware io access','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 35,'pod_errors' => 0,'total' => 94,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 5093,'unpacked' => 11287},'testers' => {'fail' => 3},'uses' => ['Carp','Device::ParallelPort::drv','DynaLoader','Errno','strict','warnings']},'Device-ParallelPort-drv-parport-0.3.tar.gz' => {'author' => 'SCOTT','description' => 'Linux Kernel 2.2+ parport /dev/parport','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 81,'pod' => 25,'pod_errors' => 0,'total' => 106,'with_comments' => 10},'releases' => 3,'size' => {'packed' => 5399,'unpacked' => 12824},'testers' => {'fail' => 1},'uses' => ['Carp','Device::ParallelPort::drv','DynaLoader','strict']},'Device-QuickCam-0.02.tar.gz' => {'author' => 'BEATNIK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 133,'pod_errors' => 0,'total' => 167,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 42142,'unpacked' => 140124},'testers' => {'fail' => 1},'uses' => ['DynaLoader','Exporter','strict','vars','warnings']},'Device-Regulator-Plasmatronic-0.03.tar.gz' => {'author' => 'SCOTT','description' => 'Plasmatronics PL regulator controller','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 409,'pod' => 156,'pod_errors' => 0,'total' => 565,'with_comments' => 72},'releases' => 2,'requires' => ['Time-HiRes-1.49.tar.gz'],'requires_module' => {'Time::HiRes' => 0},'requires_recursive' => ['Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 14164,'unpacked' => 46400},'testers' => {'pass' => 4},'uses' => ['Carp','Device::SerialPort','Fcntl','IO::File','IO::Select','POSIX','Time::HiRes','strict','vars']},'Device-SerialPort-0.22.tar.gz' => {'author' => 'COOK','description' => 'POSIX clone of Win32::SerialPort','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2516,'pod' => 655,'pod_errors' => 2,'total' => 3171,'with_comments' => 277},'releases' => 11,'size' => {'packed' => 116446,'unpacked' => 468901},'testers' => {},'uses' => ['5.006','Carp','Exporter','IO::Handle','POSIX','XSLoader','strict','vars','warnings']},'Device-WS2000-IO-0.01.tar.gz' => {'author' => 'MMBK','description' => 'Perl extension for reading data from the ELV Weatherstation WS2000 PC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 187,'pod' => 51,'pod_errors' => 0,'total' => 238,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 5253,'unpacked' => 13247},'testers' => {'pass' => 2},'uses' => ['5.005_62','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Device-WxM2-1.00.tar.gz' => {'author' => 'MMABRY','description' => 'Device driver - Davis Weather Mon. 2 station','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1409,'pod' => 217,'pod_errors' => 0,'total' => 1626,'with_comments' => 39},'releases' => 1,'requires' => ['Device-SerialPort-0.22.tar.gz'],'requires_module' => {'Device::SerialPort' => '0.09'},'requires_recursive' => ['Device-SerialPort-0.22.tar.gz'],'size' => {'packed' => 22091,'unpacked' => 80498},'testers' => {},'uses' => ['Carp','Device::SerialPort','strict','vars','warnings']},'Dialog-0.03.tar.gz' => {'author' => 'UNCLE','description' => 'interface library to libdialog','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 560,'pod' => 84,'pod_errors' => 0,'total' => 644,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 7736,'unpacked' => 25543},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'DiffLine-0.02.tar.gz' => {'author' => 'ALLEN','description' => 'line # & position of first diff','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 21,'pod' => 37,'pod_errors' => 1,'total' => 58,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2941,'unpacked' => 5594},'testers' => {'pass' => 5},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Digest-1.02.tar.gz' => {'author' => 'GAAS','description' => 'Modules that calculate message digests','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 80,'pod' => 106,'pod_errors' => 0,'total' => 186,'with_comments' => 1},'releases' => 3,'requires' => ['Digest-MD5-2.26.tar.gz'],'requires_module' => {'Digest::MD5' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 3432,'unpacked' => 6899},'testers' => {'pass' => 6},'uses' => ['strict','vars']},'Digest-BubbleBabble-0.01.tar.gz' => {'author' => 'BTROTT','description' => 'Create bubble-babble fingerprints','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 36,'pod_errors' => 0,'total' => 105,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2468,'unpacked' => 4894},'testers' => {'pass' => 9},'uses' => ['Exporter','strict','vars']},'Digest-DMAC-1.1.4.tar.gz' => {'author' => 'JCDUQUE','description' => undef,'files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 112,'pod' => 95,'pod_errors' => 0,'total' => 207,'with_comments' => 0},'releases' => 6,'requires' => ['Crypt-CBC-2.08.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'Crypt::CBC' => '2.08','MIME::Base64' => '0'},'requires_recursive' => ['Crypt-CBC-2.08.tar.gz','Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 10210,'unpacked' => 28271},'testers' => {'pass' => 4},'uses' => ['Carp','Crypt::CBC','Exporter','MIME::Base64','diagnostics','strict','vars','warnings']},'Digest-EMAC-1.1.tar.gz' => {'author' => 'JCDUQUE','description' => 'Uses block ciphers to produce MACs','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 111,'pod' => 91,'pod_errors' => 0,'total' => 202,'with_comments' => 0},'releases' => 2,'requires' => ['Crypt-CBC-2.08.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'Crypt::CBC' => '2.08','MIME::Base64' => '0'},'requires_recursive' => ['Crypt-CBC-2.08.tar.gz','Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 10252,'unpacked' => 28467},'testers' => {'pass' => 2},'uses' => ['Carp','Crypt::CBC','Exporter','MIME::Base64','diagnostics','strict','vars','warnings']},'Digest-Elf-1.4.tar.gz' => {'author' => 'MCKAY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 28,'pod' => 39,'pod_errors' => 1,'total' => 67,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 2678,'unpacked' => 4129},'testers' => {'pass' => 2},'uses' => ['5.006','DynaLoader','Exporter','strict','vars','warnings']},'Digest-HMAC-1.01.tar.gz' => {'author' => 'GAAS','description' => 'Keyed-Hashing for Message Authentication','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 109,'pod_errors' => 0,'total' => 253,'with_comments' => 6},'releases' => 1,'requires' => ['Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz'],'requires_module' => {'Digest::MD5' => 2,'Digest::SHA1' => 1},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz'],'size' => {'packed' => 13623,'unpacked' => 42674},'testers' => {'pass' => 44},'uses' => ['Digest::MD5','Digest::SHA1','Exporter','strict','vars']},'Digest-Haval256-1.0.2.tar.gz' => {'files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 131,'pod_errors' => 0,'total' => 188,'with_comments' => 1},'releases' => 4,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::Base64' => '0'},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'testers' => {'pass' => 2},'uses' => ['Exporter','MIME::Base64','XSLoader','strict','warnings']},'Digest-MD2-2.02.tar.gz' => {'author' => 'GAAS','description' => ' MD2 message digest algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 25,'pod' => 47,'pod_errors' => 0,'total' => 72,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 18290,'unpacked' => 53569},'testers' => {'pass' => 2},'uses' => ['DynaLoader','Exporter','strict','vars']},'Digest-MD4-1.1.tar.gz' => {'author' => 'MIKEM','description' => 'Perl interface to the RSA Data Security Inc.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 126,'pod' => 138,'pod_errors' => 0,'total' => 264,'with_comments' => 14},'releases' => 2,'size' => {'packed' => 10456,'unpacked' => 29725},'testers' => {'pass' => 14},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Digest-MD5-2.26.tar.gz' => {'author' => 'GAAS','description' => ' MD5 message digest algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 221,'pod_errors' => 0,'total' => 346,'with_comments' => 4},'releases' => 26,'size' => {'packed' => 43548,'unpacked' => 179562},'testers' => {'pass' => 5},'uses' => ['Digest::Perl::MD5','DynaLoader','Exporter','strict','vars']},'Digest-Nilsimsa-0.06.tar.gz' => {'author' => 'VIPUL','description' => 'Perl version of Nilsimsa code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 33,'pod_errors' => 0,'total' => 53,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 79065,'unpacked' => 177924},'testers' => {'pass' => 12},'uses' => ['DynaLoader']},'Digest-Perl-MD4-1.3.tar.gz' => {'author' => 'OTAKA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 252,'pod' => 127,'pod_errors' => 0,'total' => 379,'with_comments' => 45},'releases' => 4,'size' => {'packed' => 6421,'unpacked' => 13689},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['DynaLoader','Exporter','Symbol','strict','vars','warnings']},'Digest-Perl-MD5-1.5.tar.gz' => {'author' => 'DELTA','description' => 'Pure perl implementation of MD5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 284,'pod' => 137,'pod_errors' => 0,'total' => 421,'with_comments' => 20},'releases' => 6,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Exporter' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 70543,'unpacked' => 91173},'testers' => {'pass' => 14},'uses' => ['Exporter','Symbol','integer','strict','vars']},'Digest-SHA1-2.04.tar.gz' => {'author' => 'GAAS','description' => ' NIST SHA message digest algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 41,'pod' => 88,'pod_errors' => 0,'total' => 129,'with_comments' => 1},'releases' => 6,'size' => {'packed' => 36755,'unpacked' => 93000},'testers' => {'pass' => 2},'uses' => ['DynaLoader','Exporter','strict','vars']},'Digest-Tiger-0.02.tar.gz' => {'author' => 'CLINTDW','description' => 'a module that implements the tiger hash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 41,'pod' => 44,'pod_errors' => 0,'total' => 85,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 19872,'unpacked' => 52623},'testers' => {'pass' => 8},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Digest-UserSID-1.05.tar.gz' => {'author' => 'XWOLF','description' => 'Managing session-id\'s with Digest::SHA1','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 447,'pod' => 118,'pod_errors' => 0,'total' => 565,'with_comments' => 56},'releases' => 1,'size' => {'packed' => 6603,'unpacked' => 24696},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['5.001','Digest::SHA1','vars']},'Digest-Whirlpool-1.0.1.tar.gz' => {'author' => 'JCDUQUE','description' => 'A 512-bit one-way hash function','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 55,'pod' => 125,'pod_errors' => 0,'total' => 180,'with_comments' => 1},'releases' => 2,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::Base64' => '0'},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 48021,'unpacked' => 183458},'testers' => {'pass' => 2},'uses' => ['Exporter','MIME::Base64','XSLoader','strict','warnings']},'Dir-Purge-1.0.tar.gz' => {'author' => 'JV','description' => 'Delete files in directory based on timestamp','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 224,'pod' => 91,'pod_errors' => 0,'total' => 315,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 5013,'unpacked' => 12276},'testers' => {'pass' => 12},'uses' => ['Carp','strict','vars']},'DirDB-0.04.tar.gz' => {'author' => 'DAVIDNICO','description' => 'Perl extension to use a directory as a database','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 259,'pod' => 52,'pod_errors' => 0,'total' => 311,'with_comments' => 52},'releases' => 2,'size' => {'packed' => 3695,'unpacked' => 9133},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['5.005_62','Carp','strict','warnings']},'Dirgest-0.90.tar.gz' => {'author' => 'MGREAM','description' => 'api class for Directory Digests','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 908,'pod' => 330,'pod_errors' => 0,'total' => 1238,'with_comments' => 76},'releases' => 1,'requires' => ['CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','Getopt-Long-2.33.tar.gz','Test-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI' => 0,'Digest::MD5' => 0,'Fcntl' => 0,'File::Find' => 0,'Getopt::Long' => '2.24','LWP::UserAgent' => 2,'Test' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19328,'unpacked' => 117942},'testers' => {'pass' => 3},'uses' => ['5.004','Digest::MD5','Fcntl','File::Find','LWP::UserAgent','strict','vars','warnings']},'Disassemble-X86-0.13.tar.gz' => {'author' => 'BOBMATH','description' => 'Disassemble Intel x86 binary code','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 2556,'pod' => 453,'pod_errors' => 0,'total' => 3009,'with_comments' => 159},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 24731,'unpacked' => 116239},'testers' => {'pass' => 3},'uses' => ['5.006','AutoLoader','integer','strict','vars','warnings']},'DocSet-0.16.tar.gz' => {'author' => 'STAS','description' => 'documentation projects builder in HTML, PS and PDF formats','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 5269,'pod' => 3444,'pod_errors' => 5,'total' => 8713,'with_comments' => 682},'releases' => 3,'size' => {'packed' => 374372,'unpacked' => 786254},'testers' => {'pass' => 2},'uses' => ['5.004','Carp','Cwd','Data::Dumper','Fcntl','File::Basename','File::Find','File::Path','File::Spec','File::Spec::Functions','HTML::Entities','HTML::Parser','Pod::POM','Pod::POM::View::HTML','Storable','Template','Template::Plugin','URI','constant','strict','vars','warnings']},'Docbook-Table-1.00.tar.gz' => {'author' => 'SKUD','description' => '- create Docbook tables from Perl data structures','files' => ['Makefile.PL'],'lines' => {'nonpod' => 231,'pod' => 100,'pod_errors' => 0,'total' => 331,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 3389,'unpacked' => 9281},'testers' => {'pass' => 4},'uses' => ['Carp','strict','v5.6.0','warnings']},'Docs-US_DOD-STD2167A-0.05.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 12250,'pod' => 10521,'pod_errors' => 13,'total' => 22771,'with_comments' => 182},'releases' => 5,'requires' => ['File-PM2File-0.04.tar.gz'],'requires_module' => {'File::Package' => '0'},'requires_recursive' => ['File-PM2File-0.04.tar.gz'],'size' => {'packed' => 158658,'unpacked' => 749455},'testers' => {'pass' => 2},'uses' => ['strict','vars','warnings','warnings::register']},'Docserver-1.0.tar.gz' => {'author' => 'JANPAZ','description' => 'server module for remote MS format conversions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 716,'pod' => 93,'pod_errors' => 0,'total' => 809,'with_comments' => 81},'releases' => 5,'size' => {'packed' => 23542,'unpacked' => 97156},'testers' => {'fail' => 1,'pass' => 2,'tests' => '1'},'uses' => ['Docserver::Config','Fcntl','IO::File','IO::Handle','RPC::PlClient','Win32','Win32::API','Win32::OLE','Win32::OLE::Const','strict','vars']},'Docserver-1.12.tar.gz' => {'author' => 'JANPAZ','description' => 'server module for remote MS format conversions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 707,'pod' => 93,'pod_errors' => 0,'total' => 800,'with_comments' => 81},'releases' => 5,'requires' => ['PlRPC-0.2017.tar.gz'],'requires_module' => {'RPC::PlClient' => 0},'requires_recursive' => ['PlRPC-0.2017.tar.gz'],'size' => {'packed' => 23862,'unpacked' => 98243},'testers' => {'fail' => 3,'pass' => 1,'tests' => '4'},'uses' => ['Docclient::Config','Fcntl','IO::File','IO::Handle','RPC::PlClient','Win32','Win32::API','Win32::OLE','Win32::OLE::Const','strict','vars']},'Document-Info-0.01.tar.gz' => {'author' => 'MSCHWARTZ','description' => 'determine file type for Office documents','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 501,'pod' => 40,'pod_errors' => 0,'total' => 541,'with_comments' => 89},'releases' => 1,'size' => {'packed' => 5808,'unpacked' => 20153},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['AutoLoader','Exporter','FileHandle','OLE::PropertySet','OLE::Storage','Startup','strict','vars']},'DotICD9-0.04.tar.gz' => {'author' => 'MARTINDT','description' => 'Perl extension for placing decimal points in ICD-9 Codes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 28,'pod_errors' => 0,'total' => 85,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 2084,'unpacked' => 3673},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'DotLock-1.06.tar.gz' => {'author' => 'KBARBER','description' => 'Multi-host advisory queing locking system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 432,'pod' => 135,'pod_errors' => 0,'total' => 567,'with_comments' => 30},'releases' => 1,'size' => {'packed' => 11849,'unpacked' => 46651},'testers' => {'pass' => 7},'uses' => ['5.002','POSIX','vars']},'Dua-2.2.tar.gz' => {'author' => 'SMPILL','description' => 'DUA/Perl interface to an X.500 directory','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 135,'pod_errors' => 0,'total' => 270,'with_comments' => 6},'releases' => 5,'size' => {'packed' => 14882,'unpacked' => 50001},'testers' => {},'uses' => ['DynaLoader','Exporter','strict','vars']},'DumpStack-1.1.tar.gz' => {'author' => 'JACKS','description' => 'Dumping of the current function stack','files' => [],'lines' => {'nonpod' => 103,'pod' => 126,'pod_errors' => 0,'total' => 229,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2306,'unpacked' => 5764},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.001','AutoLoader','Devel::CallerItem','Exporter']},'Dunce-0.02.tar.gz' => {'author' => 'MSCHWERN','description' => 'Protects against sloppy use of files.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 118,'pod_errors' => 0,'total' => 262,'with_comments' => 3},'releases' => 2,'requires' => ['Function-Override-0.01.tar.gz'],'requires_module' => {'Function::Override' => '0.01'},'requires_recursive' => ['Function-Override-0.01.tar.gz'],'size' => {'packed' => 4139,'unpacked' => 9916},'testers' => {'fail' => 2,'pass' => 5},'uses' => ['Carp','Exporter','Function::Override','strict','vars']},'Dunce-time-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Protects against sloppy use of time.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 114,'pod' => 82,'pod_errors' => 0,'total' => 196,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 2956,'unpacked' => 7750},'testers' => {'pass' => 4},'uses' => ['Carp','strict','vars']},'DynScalar-1.02.tar.gz' => {'author' => 'PINYAN','description' => 'closure-in-a-box for simple scalars','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 30,'pod' => 59,'pod_errors' => 0,'total' => 89,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 2216,'unpacked' => 4868},'testers' => {'pass' => 6},'uses' => []},'Dyns-Client-0.6.tar.gz' => {'author' => 'JOHANVDB','description' => 'A client for the dyns.cx dynamic DNS service','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 114,'pod' => 35,'pod_errors' => 0,'total' => 149,'with_comments' => 0},'releases' => 3,'requires' => ['CGI.pm-2.98.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI::Util' => 0,'HTTP::Request' => 0,'LWP::UserAgent' => 0,'Socket' => 0,'Sys::Hostname' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3355,'unpacked' => 6918},'testers' => {'pass' => 1},'uses' => ['5.006','CGI::Util','Carp','HTTP::Request','LWP::UserAgent','Net::hostent','Socket','Sys::Hostname','strict','vars','warnings']},'E2-Interface-0.33.tar.gz' => {'author' => 'JOSEWEEKS','description' => 'A client interface to the everything2.com collaborative database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4769,'pod' => 2118,'pod_errors' => 0,'total' => 6887,'with_comments' => 506},'releases' => 5,'requires' => ['XML-Twig-3.10.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => 0,'XML::Twig' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','XML-Twig-3.10.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 52170,'unpacked' => 195224},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','Encode','HTML::Entities','HTTP::Cookies','HTTP::Request','HTTP::Request::Common','LWP::UserAgent','Thread::Queue','XML::Twig','strict','threads','threads::shared','warnings']},'EMC-WideSky-symmaskdb-0.21.tar.gz' => {'author' => 'LUFI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 124,'pod' => 74,'pod_errors' => 0,'total' => 198,'with_comments' => 5},'releases' => 3,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.31'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 3538,'unpacked' => 9053},'testers' => {'pass' => 2},'uses' => ['XML::Parser']},'EPS-2.00.tar.gz' => {'author' => 'WIHAA','description' => undef,'files' => [],'lines' => {'nonpod' => 753,'pod' => 316,'pod_errors' => 5,'total' => 1069,'with_comments' => 116},'releases' => 1,'size' => {'packed' => 9657,'unpacked' => 34109},'testers' => {'fail' => 1},'uses' => ['Carp','strict','vars']},'ESplit1.00.zip' => {'author' => 'HCAMP','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 223,'pod' => 0,'pod_errors' => 0,'total' => 223,'with_comments' => 124},'releases' => 1,'size' => {'packed' => 10265,'unpacked' => 27858},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.005','Exporter','strict','vars']},'EZDBI-0.13.tgz' => {'author' => 'JPIERCE','description' => 'EZ (Easy) interface to SQL databases (DBI)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 363,'pod' => 344,'pod_errors' => 0,'total' => 707,'with_comments' => 22},'releases' => 14,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => 0},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 18213,'unpacked' => 47106},'testers' => {'pass' => 2},'uses' => ['5','Carp','DBI','strict','vars']},'Earlybird-1.03.tar.gz' => {'author' => 'RFLORENCE','description' => 'Responds to worm attacks with e-mail warnings','files' => ['Makefile.PL'],'lines' => {'nonpod' => 244,'pod' => 47,'pod_errors' => 0,'total' => 291,'with_comments' => 40},'releases' => 1,'requires' => ['Cache-Cache-1.02.tar.gz','Mail-Sendmail-0.79.tar.gz','Net-DNS-0.38.tar.gz','TimeDate-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Constants' => '1.09','Cache::Cache' => '0.08','HTTP::Request' => '1.26','LWP::UserAgent' => '1.66','Mail::Sendmail' => '0.78','Net::DNS' => '0.12','Time::Zone' => '2.2'},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Mail-Sendmail-0.79.tar.gz','Net-DNS-0.38.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3950,'unpacked' => 10044},'testers' => {},'uses' => ['Apache::Constants','Cache::FileCache','HTTP::Request::Common','LWP::UserAgent','Mail::Sendmail','Net::DNS','Time::Zone','lib','strict','vars']},'EasyArgs-1.00.tar.gz' => {'author' => 'GSLONDON','description' => 'Perl module for easily handling command line arguments.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 4874,'pod' => 118,'pod_errors' => 2,'total' => 4992,'with_comments' => 1055},'releases' => 4,'size' => {'packed' => 8446,'unpacked' => 133462},'testers' => {'pass' => 3},'uses' => ['5.005_62','Carp','Data::Dumper','EasyArgs::SingleArgumentLevel','strict','warnings']},'EasyDB.0.5b2.tgz' => {'author' => 'GABY','description' => 'Access a database without writing SQL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1320,'pod' => 1125,'pod_errors' => 0,'total' => 2445,'with_comments' => 251},'releases' => 1,'size' => {'packed' => 22805,'unpacked' => 86196},'testers' => {},'uses' => ['Carp','DBD::mysql','DBI','Exporter','strict','subs']},'EasyTCP-0.24.tar.gz' => {'author' => 'MNAGUIB','description' => 'Easily create secure, bandwidth-friendly TCP/IP clients and servers','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2490,'pod' => 407,'pod_errors' => 0,'total' => 2897,'with_comments' => 596},'releases' => 24,'requires' => ['IO-1.20.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'IO::Select' => 0,'IO::Socket' => 0,'Storable' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 27676,'unpacked' => 102614},'testers' => {},'uses' => ['AutoLoader','Exporter','IO::Select','IO::Socket','Storable','strict','vars']},'Eesh-0.3.tar.gz' => {'author' => 'RBS','description' => 'Enlightenment Window Manager IPC Library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 241,'pod' => 189,'pod_errors' => 0,'total' => 430,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 9701,'unpacked' => 25637},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Emacs-EPL-0.7.tar.gz' => {'author' => 'JTOBEY','description' => 'Redefine Perl\'s system primitives to work inside of Emacs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2538,'pod' => 826,'pod_errors' => 0,'total' => 3364,'with_comments' => 314},'releases' => 7,'size' => {'packed' => 99276,'unpacked' => 326964},'testers' => {'fail' => 3,'pass' => 1,'tests' => '43'},'uses' => ['5.002','5.004','B','Carp','Emacs::EPL::Debug','Exporter','Fcntl','IO::Scalar','overload','strict','vars']},'Email-Filter-1.0.tar.gz' => {'author' => 'SIMON','description' => 'Library for creating easy email filters','files' => ['Makefile.PL'],'lines' => {'nonpod' => 193,'pod' => 147,'pod_errors' => 0,'total' => 340,'with_comments' => 7},'releases' => 1,'requires' => ['Class-Trigger-0.08.tar.gz','Email-LocalDelivery-0.05.tar.gz','Email-Simple-1.5.tar.gz','IPC-Run-0.75.tar.gz'],'requires_module' => {'Class::Trigger' => 0,'Email::LocalDelivery' => '0.04','Email::Simple' => '1.1','IPC::Run' => 0},'requires_recursive' => ['Class-Data-Inheritable-0.02.tar.gz','Class-Trigger-0.08.tar.gz','Email-LocalDelivery-0.05.tar.gz','Email-Simple-1.5.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','IPC-Run-0.75.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6307,'unpacked' => 13652},'testers' => {'fail' => 1,'pass' => 2,'tests' => '1'},'uses' => ['Class::Trigger','Email::LocalDelivery','Email::Simple','IPC::Run','constant','strict']},'Email-Find-0.09.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Find RFC 822 email addresses in plain text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 171,'pod' => 180,'pod_errors' => 0,'total' => 351,'with_comments' => 13},'releases' => 9,'requires' => ['Email-Valid-0.14.tar.gz','MailTools-1.58.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Email::Valid' => 0,'Mail::Address' => 0,'Test::More' => 0},'requires_recursive' => ['Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 39274,'unpacked' => 132162},'testers' => {'pass' => 12},'uses' => ['5.005','Email::Valid','Exporter','Mail::Address','strict','vars']},'Email-Folder-0.8.tar.gz' => {'author' => 'RCLAMP','description' => 'read all the messages from a folder as Email::Simple objects.','files' => ['Makefile.PL','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 271,'pod' => 217,'pod_errors' => 0,'total' => 488,'with_comments' => 19},'releases' => 8,'requires' => ['Email-FolderType-0.5.tar.gz','Email-Simple-1.5.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Email::FolderType' => '0','Email::Simple' => '0','Test::More' => '0'},'requires_recursive' => ['Email-FolderType-0.5.tar.gz','Email-Simple-1.5.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 31036,'unpacked' => 148701},'testers' => {'pass' => 3},'uses' => ['Carp','Email::FolderType','Email::Simple','IO::File','constant','strict','vars']},'Email-FolderType-0.5.tar.gz' => {'author' => 'SIMONW','description' => 'return type of a mail folder','files' => ['Makefile.PL','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 26,'pod' => 44,'pod_errors' => 0,'total' => 70,'with_comments' => 0},'releases' => 6,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 9303,'unpacked' => 31355},'testers' => {'pass' => 1},'uses' => ['Exporter','strict','vars']},'Email-IsFree-0.02.tar.gz' => {'author' => 'TJMATHER','description' => 'Detect whether e-mail is from free provider','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6896,'pod' => 44,'pod_errors' => 0,'total' => 6940,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 37148,'unpacked' => 107223},'testers' => {'pass' => 4},'uses' => ['strict','vars','warnings']},'Email-LocalDelivery-0.04.tar.gz' => {'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 209,'pod' => 26,'pod_errors' => 0,'total' => 235,'with_comments' => 9},'releases' => 5,'requires' => ['Email-FolderType-0.5.tar.gz','Email-Simple-1.5.tar.gz'],'requires_module' => {'Email::FolderType' => '0.11','Email::Simple' => '1.4'},'requires_recursive' => ['Email-FolderType-0.5.tar.gz','Email-Simple-1.5.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'testers' => {'pass' => 2},'uses' => ['5.005_62','Carp','Email::FolderType','Email::Simple','Errno','Fcntl','File::Basename','File::Path','Sys::Hostname','strict','warnings']},'Email-MIME-Encodings-1.0.tar.gz' => {'author' => 'SIMON','description' => 'A unified interface to MIME encoding and decoding','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 39,'pod_errors' => 0,'total' => 81,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1858,'unpacked' => 3264},'testers' => {'pass' => 4},'uses' => ['Carp','MIME::Base64','MIME::QuotedPrint','strict','warnings']},'Email-Simple-1.5.tar.gz' => {'author' => 'RCLAMP','description' => 'Email handling. Simply.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 180,'pod' => 72,'pod_errors' => 0,'total' => 252,'with_comments' => 31},'releases' => 6,'size' => {'packed' => 7608,'unpacked' => 23221},'testers' => {'pass' => 2},'uses' => ['5.00503','Carp','Text::Wrap','strict','vars']},'Email-Thread-0.66.tar.gz' => {'author' => 'SPOON','description' => 'Use JWZ\'s mail threading algorithm with Email::Simple objects','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 41,'pod' => 61,'pod_errors' => 0,'total' => 102,'with_comments' => 0},'releases' => 2,'requires' => ['Mail-Thread-2.3.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Mail::Thread' => '2.1','Test::More' => '0.47'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Mail-Thread-2.3.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 13747,'unpacked' => 34713},'testers' => {'pass' => 4},'uses' => ['Mail::Thread','vars']},'Email-Valid-0.08.tar.gz' => {'author' => 'MAURICE','description' => 'Check validity of Internet e-mail addresses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 356,'pod' => 105,'pod_errors' => 0,'total' => 461,'with_comments' => 18},'releases' => 5,'size' => {'packed' => 6386,'unpacked' => 20597},'testers' => {'pass' => 3},'uses' => ['Carp','IO::File','Mail::Address','UNIVERSAL','strict','vars']},'Email-Valid-0.14.tar.gz' => {'author' => 'MAURICE','description' => 'Check validity of Internet email addresses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 413,'pod' => 139,'pod_errors' => 0,'total' => 552,'with_comments' => 32},'releases' => 5,'requires' => ['MailTools-1.58.tar.gz'],'requires_module' => {'Mail::Address' => 0},'requires_recursive' => ['MailTools-1.58.tar.gz'],'size' => {'packed' => 7865,'unpacked' => 25367},'testers' => {'fail' => 1,'pass' => 26,'tests' => '10'},'uses' => ['Carp','IO::File','Mail::Address','strict','vars']},'Email-Valid-Loose-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Email::Valid which allows dot before at mark','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 31,'pod_errors' => 0,'total' => 84,'with_comments' => 6},'releases' => 2,'requires' => ['Email-Valid-0.14.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Email::Valid' => '0.13','Test::More' => '0.32'},'requires_recursive' => ['Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2040,'unpacked' => 4081},'testers' => {'pass' => 4},'uses' => ['Email::Valid','strict','vars']},'Embedix-DB-0.05.tar.gz' => {'author' => 'BEPPU','description' => 'persistence for ECDs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 980,'pod' => 490,'pod_errors' => 0,'total' => 1470,'with_comments' => 138},'releases' => 2,'requires' => ['DBI-1.37.tar.gz','Embedix-ECD-0.09.tar.gz','PodParser-1.23.tar.gz','Test-1.24.tar.gz'],'requires_module' => {'DBI' => 0,'Embedix::ECD' => 0,'Pod::Usage' => 0,'Test' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Embedix-ECD-0.09.tar.gz','File-Spec-0.82.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Text-Balanced-1.95.tar.gz','Tie-IxHash-1.21.tar.gz'],'size' => {'packed' => 22465,'unpacked' => 79051},'testers' => {'fail' => 1,'pass' => 8},'uses' => ['Carp','DBI','Embedix::ECD','strict','vars']},'Embedix-ECD-0.07.tar.gz' => {'author' => 'BEPPU','description' => 'represent Embedix Component Descriptions as a tree of perl objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1203,'pod' => 693,'pod_errors' => 0,'total' => 1896,'with_comments' => 171},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Tie-IxHash-1.21.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Parse::RecDescent' => 0,'Pod::Usage' => 0,'Tie::IxHash' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Text-Balanced-1.95.tar.gz','Tie-IxHash-1.21.tar.gz'],'size' => {'packed' => 34290,'unpacked' => 139801},'testers' => {'pass' => 6},'uses' => ['Data::Dumper','Embedix::ECD','Embedix::ECD::Autovar','Embedix::ECD::Component','Embedix::ECD::Group','Embedix::ECD::Option','Embedix::ECD::Util','Exporter','Parse::RecDescent','Tie::IxHash','XML::Parser','strict','vars']},'Embedix-ECD-0.09.tar.gz' => {'author' => 'BEPPU','description' => 'Embedix Component Descriptions as objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1457,'pod' => 968,'pod_errors' => 0,'total' => 2425,'with_comments' => 205},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Tie-IxHash-1.21.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Parse::RecDescent' => 0,'Pod::Usage' => 0,'Tie::IxHash' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Text-Balanced-1.95.tar.gz','Tie-IxHash-1.21.tar.gz'],'size' => {'packed' => 41208,'unpacked' => 163071},'testers' => {'fail' => 1,'pass' => 15,'tests' => '16'},'uses' => ['Data::Dumper','Exporter','IO::File','Parse::RecDescent','Tie::IxHash','XML::Parser','strict','vars']},'Embperl-2.0b9.tar.gz' => {'author' => 'GRICHTER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 12131,'pod' => 12429,'pod_errors' => 17,'total' => 24560,'with_comments' => 1235},'releases' => 1,'requires' => ['File-Spec-0.82.tar.gz'],'requires_module' => {'File::Spec' => '0.8'},'requires_recursive' => ['File-Spec-0.82.tar.gz'],'size' => {'packed' => 654860,'unpacked' => 3104215},'testers' => {'pass' => 2},'uses' => ['Apache::Constants','Apache::RequestRec','Apache::RequestUtil','Apache::Server','Apache::ServerUtil','Apache::Session','Apache::SubRequest','CGI','Cwd','DynaLoader','Embperl::Module','Exporter','ExtUtils::XSBuilder::ParseSource','ExtUtils::XSBuilder::WrapXS','File::Basename','File::Spec','File::Spec::Unix','FindBin','Getopt::Long','Net::SMTP','POSIX','Safe','Text::ParseWords','constant','strict','vars','warnings']},'Encode-1.97.tar.gz' => {'author' => 'DANKOGAI','description' => 'character encodings','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 3141,'pod' => 2442,'pod_errors' => 0,'total' => 5583,'with_comments' => 347},'releases' => 64,'size' => {'packed' => 1889801,'unpacked' => 10202838},'testers' => {'pass' => 2},'uses' => ['Carp','Config','Encode::CN::2022_CN','Exporter','Filter::Util::Call','MIME::Base64','XSLoader','bytes','constant','strict','utf','vars','warnings']},'Encode-CNMap-0.20.tar.gz' => {'author' => 'QJZHOU','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 52,'pod' => 60,'pod_errors' => 0,'total' => 112,'with_comments' => 0},'releases' => 7,'requires' => ['Encode-1.97.tar.gz'],'requires_module' => {'Encode' => '1.41'},'requires_recursive' => ['Encode-1.97.tar.gz'],'size' => {'packed' => 568319,'unpacked' => 2353474},'testers' => {'pass' => 3},'uses' => ['Encode','Exporter','XSLoader','vars']},'Encode-HanConvert-0.26.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Traditional and Simplified Chinese mappings','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 158,'pod' => 135,'pod_errors' => 0,'total' => 293,'with_comments' => 5},'releases' => 17,'requires' => ['Encode-1.97.tar.gz'],'requires_module' => {'Encode' => '1.41'},'requires_recursive' => ['Encode-1.97.tar.gz'],'size' => {'packed' => 350409,'unpacked' => 580420},'testers' => {'pass' => 2},'uses' => ['Encode','Encode::CN','Encode::HanConvert::Perl','Encode::TW','Exporter','XSLoader','vars']},'Encode-HanDetect-0.01.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Cross-encoding/variant Chinese decoder','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 52,'pod_errors' => 0,'total' => 121,'with_comments' => 2},'releases' => 1,'requires' => ['Encode-1.97.tar.gz','Encode-HanConvert-0.26.tar.gz','Lingua-ZH-HanDetect-0.04.tar.gz'],'requires_module' => {'Encode' => 0,'Encode::HanConvert' => '0.24','Lingua::ZH::HanDetect' => '0.02'},'requires_recursive' => ['Encode-1.97.tar.gz','Encode-HanConvert-0.26.tar.gz','Lingua-ZH-HanDetect-0.04.tar.gz'],'size' => {'packed' => 3549,'unpacked' => 7138},'testers' => {},'uses' => ['5.008','Encode','Encode::Encoding','Encode::Guess','Encode::HanConvert','Lingua::ZH::HanDetect','strict']},'Encode-HanExtra-0.08.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Extra sets of Chinese encodings','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 141,'pod' => 125,'pod_errors' => 0,'total' => 266,'with_comments' => 6},'releases' => 8,'requires' => ['Encode-1.97.tar.gz'],'requires_module' => {'Encode' => '1.41'},'requires_recursive' => ['Encode-1.97.tar.gz'],'size' => {'packed' => 1259521,'unpacked' => 5926097},'testers' => {'pass' => 1},'uses' => ['5.007003','Encode','Encode::Encoding','XSLoader','strict','vars']},'Encode-InCharset-0.03.tar.gz' => {'author' => 'DANKOGAI','description' => 'defines \\p{InCharset}','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 114079,'pod' => 64,'pod_errors' => 0,'total' => 114143,'with_comments' => 221},'releases' => 3,'size' => {'packed' => 374245,'unpacked' => 854105},'testers' => {'pass' => 2},'uses' => ['5.007003','Carp','Encode::InCharset::Config','strict','warnings']},'Encode-JIS2K-0.01.tar.gz' => {'author' => 'DANKOGAI','description' => 'JIS X 0212 (aka JIS 2000) Encodings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 113,'pod_errors' => 0,'total' => 274,'with_comments' => 11},'releases' => 1,'requires' => ['Encode-1.97.tar.gz'],'requires_module' => {'Encode' => '1.41'},'requires_recursive' => ['Encode-1.97.tar.gz'],'size' => {'packed' => 400365,'unpacked' => 1401535},'testers' => {'pass' => 2},'uses' => ['Encode','Encode::CJKConstants','Encode::Encoding','Encode::JIS2K::2022JP3','Encode::JP::H2Z','XSLoader','strict']},'Encode-Punycode-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Encode plugin for Punycode encodings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 29,'pod_errors' => 0,'total' => 60,'with_comments' => 0},'releases' => 1,'requires' => ['IDNA-Punycode-0.02.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'IDNA::Punycode' => 0,'Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IDNA-Punycode-0.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3823,'unpacked' => 8276},'testers' => {'pass' => 2},'uses' => ['Encode','Encode::Encoding','IDNA::Punycode','strict']},'Encode-compat-0.05.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Encode.pm emulation layer','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 466,'pod' => 105,'pod_errors' => 0,'total' => 571,'with_comments' => 69},'releases' => 5,'size' => {'packed' => 8339,'unpacked' => 22132},'testers' => {'pass' => 2},'uses' => ['Encode::Alias','Exporter','Text::Iconv','constant','strict','utf']},'End-1.2.tgz' => {'author' => 'ABIGAIL','description' => 'Generalized END {}.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 66,'pod' => 54,'pod_errors' => 0,'total' => 120,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 2623,'unpacked' => 4771},'testers' => {'pass' => 9},'uses' => ['Exporter','strict','vars']},'English-Reference-0.03.tgz' => {'author' => 'JPIERCE','description' => 'use words to dereference things','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 56,'pod' => 59,'pod_errors' => 0,'total' => 115,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 2256,'unpacked' => 4007},'testers' => {'pass' => 5},'uses' => ['Exporter','strict','vars']},'Env-C-0.03.tar.gz' => {'author' => 'STAS','description' => 'Get/Set/Unset Environment Variables on the C level','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 40,'pod' => 77,'pod_errors' => 0,'total' => 117,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 8440,'unpacked' => 23372},'testers' => {'pass' => 3},'uses' => ['5.005','DynaLoader','strict','warnings']},'Env-Modulecmd-1.0.tar.gz' => {'author' => 'ISAACSON','description' => 'Interface to modulecmd from Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 98,'pod_errors' => 0,'total' => 272,'with_comments' => 26},'releases' => 1,'size' => {'packed' => 10443,'unpacked' => 28155},'testers' => {'fail' => 6},'uses' => ['Carp','IPC::Open3','strict','vars']},'Env-Path-0.16.tar.gz' => {'author' => 'DSB','description' => 'Advanced operations on path variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 315,'pod' => 188,'pod_errors' => 0,'total' => 503,'with_comments' => 6},'releases' => 13,'size' => {'packed' => 10075,'unpacked' => 27465},'testers' => {'pass' => 1},'uses' => ['5.004','Config','strict']},'Envy-2.48.tar.gz' => {'author' => 'JPRIT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 343,'pod' => 115,'pod_errors' => 0,'total' => 458,'with_comments' => 23},'releases' => 30,'requires' => ['Test-1.24.tar.gz'],'requires_module' => {'Test' => 1},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 35150,'unpacked' => 95375},'testers' => {'pass' => 6},'uses' => ['Carp','Config','Envy::DB','Exporter','File::Basename','Symbol','Sys::Hostname','integer','strict','vars']},'Eobj-0.21.tar.gz' => {'author' => 'BILLAUER','description' => 'Easy Object Oriented programming environment','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 997,'pod' => 393,'pod_errors' => 0,'total' => 1390,'with_comments' => 209},'releases' => 2,'size' => {'packed' => 281201,'unpacked' => 440682},'testers' => {'pass' => 3},'uses' => ['5.004','Eobj::PLerrsys','Exporter','strict','warnings']},'Errno-1.09.tar.gz' => {'author' => 'GBARR','description' => 'Constants from errno.h EACCES, ENOENT etc','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5,'pod' => 0,'pod_errors' => 0,'total' => 5,'with_comments' => 2},'releases' => 10,'size' => {'packed' => 4436,'unpacked' => 9746},'testers' => {'pass' => 8},'uses' => []},'Error-0.15.tar.gz' => {'author' => 'UARUN','description' => 'Error/exception handling in an OO-ish way','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 538,'pod' => 206,'pod_errors' => 0,'total' => 744,'with_comments' => 65},'releases' => 5,'size' => {'packed' => 8188,'unpacked' => 23970},'testers' => {'pass' => 43},'uses' => ['5.004','Carp','strict','vars']},'Error-Dumb-0.02.tar.gz' => {'author' => 'ILIAL','description' => 'simple error management for simple classes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 53,'pod_errors' => 0,'total' => 92,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 1646,'unpacked' => 2597},'testers' => {'pass' => 7},'uses' => ['strict','vars']},'Error-Unhandled-1.02.tar.gz' => {'author' => 'TEVERETT','description' => 'a Module for letting Errors do their own handling','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 39,'pod_errors' => 0,'total' => 121,'with_comments' => 21},'releases' => 2,'size' => {'packed' => 3284,'unpacked' => 8207},'testers' => {'fail' => 1,'pass' => 7},'uses' => ['Error','strict','vars']},'Event-0.01.tar.gz' => {'author' => 'GBARR','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 881,'pod' => 121,'pod_errors' => 0,'total' => 1002,'with_comments' => 39},'releases' => 68,'size' => {'packed' => 9756,'unpacked' => 27202},'testers' => {'fail' => 1},'uses' => ['Carp','DynaLoader','Event','IO::Poll','IPC::Msg','IPC::Semaphore','strict','vars']},'Event-0.87.tar.gz' => {'author' => 'JPRIT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1032,'pod' => 618,'pod_errors' => 0,'total' => 1650,'with_comments' => 39},'releases' => 68,'requires' => ['Test-1.24.tar.gz'],'requires_module' => {'Test' => 1},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 244703,'unpacked' => 442801},'testers' => {'fail' => 3,'pass' => 10,'tests' => '115'},'uses' => ['Carp','Carp::Heavy','Config','DynaLoader','Exporter','IPC::Msg','IPC::Semaphore','Inline','Time::HiRes','attrs','integer','strict','vars']},'Event-File-0.1.1.tar.gz' => {'author' => 'RSD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 614,'pod' => 153,'pod_errors' => 0,'total' => 767,'with_comments' => 139},'releases' => 1,'size' => {'packed' => 7385,'unpacked' => 19533},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['Event','IO::File','strict','vars']},'Event-Stats-0.7.tar.gz' => {'author' => 'JPRIT','description' => 'Collects statistics for Event','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 47,'pod_errors' => 0,'total' => 86,'with_comments' => 1},'releases' => 8,'requires' => ['Event-0.87.tar.gz','Test-1.24.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'Event' => '0.58','Test' => 1,'Time::HiRes' => '1.2'},'requires_recursive' => ['Event-0.87.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 5407,'unpacked' => 15122},'testers' => {'pass' => 10},'uses' => ['Carp','DynaLoader','Event','Exporter','strict','vars']},'Event-tcp-0.14.tar.gz' => {'author' => 'JPRIT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 492,'pod' => 47,'pod_errors' => 0,'total' => 539,'with_comments' => 43},'releases' => 6,'requires' => ['Event-0.87.tar.gz','Test-1.24.tar.gz'],'requires_module' => {'Event' => '0.61','Test' => 1},'requires_recursive' => ['Event-0.87.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 7083,'unpacked' => 17834},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['Carp','Errno','Event','Event::Watcher','Event::io','Fcntl','Ioctl','Socket','Symbol','constant','strict','vars']},'EventServer-2.3.tar.gz' => {'author' => 'JACKS','description' => 'Triggers objects on i/o, timers & interrupts','files' => [],'lines' => {'nonpod' => 2440,'pod' => 931,'pod_errors' => 0,'total' => 3371,'with_comments' => 248},'releases' => 1,'size' => {'packed' => 27601,'unpacked' => 100967},'testers' => {},'uses' => ['Carp','Config','Errno','Sys::Errno','Sys::Wait','Wait','errno.ph','strict','sys::errno.ph','sys::wait.ph','wait.ph']},'Exception-Class-1.14.tar.gz' => {'author' => 'DROLSKY','description' => 'Declare exception class hierarchies','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 474,'pod' => 297,'pod_errors' => 0,'total' => 771,'with_comments' => 21},'releases' => 24,'requires' => ['Class-Data-Inheritable-0.02.tar.gz','Devel-StackTrace-1.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Data::Inheritable' => '0.02','Devel::StackTrace' => '1.03','Test::More' => '0.46'},'requires_recursive' => ['Class-Data-Inheritable-0.02.tar.gz','Devel-StackTrace-1.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 12519,'unpacked' => 35535},'testers' => {'pass' => 4},'uses' => ['$isa','5.005','Class::Data::Inheritable','Devel::StackTrace','strict','vars']},'Exception-Class-DBI-0.90.tar.gz' => {'author' => 'DWHEELER','description' => 'DBI Exception objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 237,'pod' => 323,'pod_errors' => 1,'total' => 560,'with_comments' => 12},'releases' => 3,'requires' => ['DBI-1.37.tar.gz','Exception-Class-1.14.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DBI' => '1.28','Exception::Class' => '1.02','Test::Harness' => '2.03','Test::Simple' => '0.4'},'requires_recursive' => ['Class-Data-Inheritable-0.02.tar.gz','DBI-1.37.tar.gz','Devel-StackTrace-1.03.tar.gz','Exception-Class-1.14.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 9055,'unpacked' => 32650},'testers' => {'pass' => 3},'uses' => ['5.00500','Exception::Class','strict','vars']},'Exception-Cxx-1.001.tar.gz' => {'author' => 'JPRIT','description' => 'Cause perl to longjmp using C++ exceptions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 18,'pod' => 29,'pod_errors' => 0,'total' => 47,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 4393,'unpacked' => 9748},'testers' => {'fail' => 3},'uses' => ['DynaLoader']},'Exception-Handler-1.002.2.tar.gz' => {'author' => 'TOMMY','description' => 'Report exceptions with formatted text call-stack
 
 =head1 VERSION 
 1.00_2 
 =head1 @EXPORT, @EXPORT_OK 
 None.
 
 =head1 Methods new() fail() trace()
 
 =head2 AUTOLOAD-ed methods None.
','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 134,'pod' => 39,'pod_errors' => 0,'total' => 173,'with_comments' => 18},'releases' => 2,'size' => {'packed' => 3242,'unpacked' => 7469},'testers' => {'pass' => 12},'uses' => ['strict','vars']},'Exception-Like-0.03.tar.gz' => {'author' => 'ZIYA','description' => 'Exception-like Error Checking','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 204,'pod' => 117,'pod_errors' => 1,'total' => 321,'with_comments' => 4},'releases' => 3,'size' => {'packed' => 4099,'unpacked' => 13871},'testers' => {'pass' => 3},'uses' => ['5.005_62','AutoLoader','Exporter','strict','vars','warnings']},'Exceptions-0.01.tar.gz' => {'author' => 'PSEIBEL','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 202,'pod' => 0,'pod_errors' => 0,'total' => 202,'with_comments' => 56},'releases' => 2,'size' => {'packed' => 3036,'unpacked' => 5863},'testers' => {'fail' => 3},'uses' => ['Carp','Exporter','lib','strict','vars']},'Expect-1.15.tar.gz' => {'author' => 'RGIERSIG','description' => 'Perl version of Don Libes\' Tcl-Expect','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1971,'pod' => 833,'pod_errors' => 1,'total' => 2804,'with_comments' => 309},'releases' => 7,'requires' => ['IO-Tty-1.02.tar.gz'],'requires_module' => {'IO::Pty' => 1,'IO::Tty' => 1},'requires_recursive' => ['IO-Tty-1.02.tar.gz'],'size' => {'packed' => 51261,'unpacked' => 155049},'testers' => {'fail' => 1,'pass' => 13},'uses' => ['Carp','Exporter','Fcntl','IO::Handle','IO::Pty','IO::Tty','POSIX','strict','vars']},'Expect-Simple-0.02.tar.gz' => {'author' => 'DJERIUS','description' => 'wrapper around the Expect module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 233,'pod' => 133,'pod_errors' => 0,'total' => 366,'with_comments' => 22},'releases' => 1,'requires' => ['Expect-1.15.tar.gz'],'requires_module' => {'Expect' => 0},'requires_recursive' => ['Expect-1.15.tar.gz','IO-Tty-1.02.tar.gz'],'size' => {'packed' => 11100,'unpacked' => 29165},'testers' => {'pass' => 6},'uses' => ['Carp','Expect','strict','vars']},'Exporter-Cluster-0.31.tar.gz' => {'author' => 'DHAGEMAN','description' => 'Extension for easy multiple module imports.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 88,'pod' => 46,'pod_errors' => 0,'total' => 134,'with_comments' => 41},'releases' => 4,'size' => {'packed' => 3082,'unpacked' => 7486},'testers' => {'pass' => 5},'uses' => ['5.005','warnings']},'Exporter-Dispatch-1.01.tar.gz' => {'author' => 'JRYAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 69,'pod_errors' => 0,'total' => 89,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2269,'unpacked' => 6928},'testers' => {'fail' => 2,'tests' => '3'},'uses' => []},'Exporter-Easy-0.15.tar.gz' => {'author' => 'FDALY','description' => 'Takes the drudgery out of Exporting symbols','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 397,'pod' => 166,'pod_errors' => 0,'total' => 563,'with_comments' => 32},'releases' => 6,'size' => {'packed' => 8654,'unpacked' => 27753},'testers' => {'pass' => 11},'uses' => ['5.006','Exporter','strict']},'Exporter-Lite-0.01.tar.gz' => {'author' => 'MSCHWERN','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1474,'pod' => 1015,'pod_errors' => 0,'total' => 2489,'with_comments' => 68},'releases' => 1,'size' => {'packed' => 20650,'unpacked' => 61588},'testers' => {'pass' => 40},'uses' => ['5.004','Carp','strict','vars']},'Exporter-Simple-1.10.tar.gz' => {'author' => 'MARCEL','description' => 'Easier set-up of module exports','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 233,'pod' => 81,'pod_errors' => 0,'total' => 314,'with_comments' => 98},'releases' => 4,'requires' => ['Attribute-Handlers-0.78.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.77'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz'],'size' => {'packed' => 6107,'unpacked' => 16757},'testers' => {'pass' => 3},'uses' => ['5.008','Attribute::Handlers','Exporter','strict','warnings']},'Exporter-Tidy-0.06.tar.gz' => {'author' => 'JUERD','description' => 'Another way of exporting symbols','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1679,'pod' => 1073,'pod_errors' => 0,'total' => 2752,'with_comments' => 69},'releases' => 2,'size' => {'packed' => 23101,'unpacked' => 73899},'testers' => {'pass' => 4},'uses' => ['strict']},'Exporter-VA-1.3.0.1.tar.gz' => {'author' => 'DLUGOSZ','description' => 'Improved Exporter featuring Versioning and Aliasing.','files' => ['Makefile.PL'],'lines' => {'nonpod' => 1005,'pod' => 796,'pod_errors' => 0,'total' => 1801,'with_comments' => 95},'releases' => 4,'size' => {'packed' => 31470,'unpacked' => 92002},'testers' => {'fail' => 1,'pass' => 15},'uses' => ['Carp','strict','utf','vars','warnings']},'ExtUtils-AutoInstall-0.52.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Automatic install of dependencies via CPAN','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 1362,'pod' => 200,'pod_errors' => 0,'total' => 1562,'with_comments' => 83},'releases' => 24,'size' => {'packed' => 22509,'unpacked' => 71697},'testers' => {'fail' => 1,'pass' => 3,'tests' => '7'},'uses' => ['$self->{path}::$self->{dispatch}','CPAN','CPANPLUS','CPANPLUS::Backend','Carp','Config','Cwd','ExtUtils::MM_Unix','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Basename','File::Find','File::Path','File::Spec','FileHandle','LWP::Simple','Module::Install','Module::Install::Base','Net::FTP','Socket','inc::Module::Install','strict','vars']},'ExtUtils-Depends-0.101.tar.gz' => {'author' => 'MLEHMANN','description' => undef,'files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 350,'pod' => 45,'pod_errors' => 0,'total' => 395,'with_comments' => 18},'releases' => 2,'size' => {'packed' => 4205,'unpacked' => 10988},'testers' => {'pass' => 2,'tests' => '0','unknown' => 6},'uses' => ['Carp','Cwd','File::Basename','IO::File','strict','vars']},'ExtUtils-DynaGlue-1.00a.tar.gz' => {'author' => 'DOUGM','description' => 'Methods for generating Perl extension files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 960,'pod' => 19,'pod_errors' => 0,'total' => 979,'with_comments' => 103},'releases' => 1,'size' => {'packed' => 11456,'unpacked' => 33186},'testers' => {'pass' => 12},'uses' => ['C::Scan','Config','ExtUtils::MakeMaker','Mail::Util','strict','vars']},'ExtUtils-Embed-1.14.tar.gz' => {'author' => 'DOUGM','description' => 'Utilities for embedding Perl in C/C++ applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 443,'pod' => 176,'pod_errors' => 0,'total' => 619,'with_comments' => 39},'releases' => 8,'size' => {'packed' => 20117,'unpacked' => 56773},'testers' => {'fail' => 10,'pass' => 1,'tests' => '24','unknown' => 3},'uses' => ['5.002','Carp','Config','Exporter','ExtUtils::Liblist','ExtUtils::MakeMaker','ExtUtils::Miniperl','FileHandle','Getopt::Std','strict','vars']},'ExtUtils-F77-1.14.tar.gz' => {'author' => 'KGB','description' => 'Facilitate use of FORTRAN from Perl/XS code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 522,'pod' => 62,'pod_errors' => 0,'total' => 584,'with_comments' => 80},'releases' => 12,'size' => {'packed' => 8663,'unpacked' => 21654},'testers' => {'pass' => 14},'uses' => ['Config']},'ExtUtils-FakeConfig-0.05.zip' => {'author' => 'MBARBON','description' => 'overrides some configuration values','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 54,'pod' => 27,'pod_errors' => 0,'total' => 81,'with_comments' => 3},'releases' => 3,'requires' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz'],'requires_module' => {'File::Spec' => 0,'Test' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 12061,'unpacked' => 15493},'testers' => {'pass' => 3},'uses' => ['Config','File::Spec','vars']},'ExtUtils-MakeMaker-6.05.tar.gz' => {'author' => 'MSCHWERN','description' => 'Writes Makefiles for extensions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13710,'pod' => 3997,'pod_errors' => 1,'total' => 17707,'with_comments' => 1099},'releases' => 6,'size' => {'packed' => 187528,'unpacked' => 602635},'testers' => {'pass' => 43},'uses' => ['5.00503','5.005_03','AutoSplit','Carp','Config','Cwd','Data::Dumper','DirHandle','Exporter','ExtUtils::Miniperl','ExtUtils::XSSymSet','File::Basename','File::Compare','File::Copy','File::Find','File::Path','File::Spec','File::Spec::Unix','SelfLoader','Test::Harness','Text::ParseWords','VMS::Filespec','strict','vars','vmsish']},'ExtUtils-ModuleMaker-0.204.tar.gz' => {'author' => 'RGEOFFREY','description' => 'A simple replacement for h2xs -XA','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6965,'pod' => 498,'pod_errors' => 0,'total' => 7463,'with_comments' => 123},'releases' => 5,'size' => {'packed' => 80984,'unpacked' => 336762},'testers' => {'pass' => 7},'uses' => ['ExtUtils::MakeMaker','strict','vars']},'ExtUtils-ModuleMaker-0.32.tar.gz' => {'author' => 'RGEOFFREY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7977,'pod' => 642,'pod_errors' => 0,'total' => 8619,'with_comments' => 238},'releases' => 5,'requires' => ['Getopt-Long-2.33.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Basename' => 0,'File::Path' => 0,'Getopt::Long' => 0,'Getopt::Std' => 0,'Test::More' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 85176,'unpacked' => 373497},'testers' => {'pass' => 2},'uses' => ['CPAN','Cwd','ExtUtils::MakeMaker','File::Path','File::Spec','Module::Build','Module::Build::Compat','Test::More','strict','vars']},'ExtUtils-ParseXS-2.02.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Converts Perl XS code into C code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1864,'pod' => 103,'pod_errors' => 0,'total' => 1967,'with_comments' => 271},'releases' => 4,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Cwd' => 0,'Exporter' => 0,'File::Basename' => 0,'File::Spec' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 22037,'unpacked' => 67461},'testers' => {'pass' => 9},'uses' => ['5.006','Config','DynaLoader','Exporter','ExtUtils::XSSymSet','File::Basename','File::Spec','re','strict','vars']},'ExtUtils-PerlPP-0.03.tar.gz' => {'author' => 'JWIED','description' => 'A Perl Preprocessor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 302,'pod' => 266,'pod_errors' => 0,'total' => 568,'with_comments' => 30},'releases' => 3,'size' => {'packed' => 6899,'unpacked' => 24308},'testers' => {'pass' => 11},'uses' => ['Config','Exporter','File::Basename','File::Path','IO::File','strict','vars']},'ExtUtils-SVDmaker-0.01.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4130,'pod' => 4317,'pod_errors' => 3,'total' => 8447,'with_comments' => 446},'releases' => 1,'requires' => ['DataPort-DataFile-0.03.tar.gz','DataPort-FileType-FormDB-0.03.tar.gz','DataPort-Maker-0.03.tar.gz','File-AnySpec-0.03.tar.gz','File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','IO-String-1.02.tar.gz','Text-Column-0.01.tar.gz','Text-Replace-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'requires_module' => {'DataPort::DataFile' => '0.02','DataPort::FileType::FormDB' => '0.02','DataPort::Maker' => '0','File::AnySpec' => '0','File::PM2File' => '0','File::Package' => '0','File::SmartNL' => '0','File::SubPM' => '0','File::TestPath' => '0','IO::String' => '0','Test::Tech' => '1.08','Text::Column' => '0','Text::Replace' => '0','Text::Scrub' => '0'},'requires_recursive' => ['DataPort-DataFile-0.03.tar.gz','DataPort-FileType-FormDB-0.03.tar.gz','DataPort-Maker-0.03.tar.gz','File-AnySpec-0.03.tar.gz','File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','IO-String-1.02.tar.gz','Text-Column-0.01.tar.gz','Text-Replace-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'size' => {'packed' => 48239,'unpacked' => 297566},'testers' => {},'uses' => ['Cwd','DataPort::Maker','ExtUtils::MakeMaker','File::AnySpec','File::Copy','File::Data','File::Package','File::Path','File::Spec','File::Spec::Unix','Pod::Html','Pod::Text','Text::Column','Text::Replace','Text::Scrub','strict','vars','warnings','warnings::register']},'ExtUtils-TBone-1.124.tar.gz' => {'author' => 'ERYQ','description' => 'a "skeleton" for writing "t/*.t" test files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 734,'pod' => 490,'pod_errors' => 0,'total' => 1224,'with_comments' => 100},'releases' => 11,'size' => {'packed' => 19974,'unpacked' => 63205},'testers' => {'pass' => 5},'uses' => ['File::Basename','FileHandle','strict','vars']},'ExtUtils-XSBuilder-0.23.tar.gz' => {'author' => 'GRICHTER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4822,'pod' => 945,'pod_errors' => 1,'total' => 5767,'with_comments' => 412},'releases' => 2,'requires' => ['Parse-RecDescent-1.94.tar.gz','Tie-IxHash-1.21.tar.gz'],'requires_module' => {'Parse::RecDescent' => 0,'Tie::IxHash' => 0},'requires_recursive' => ['Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz','Tie-IxHash-1.21.tar.gz'],'size' => {'packed' => 39282,'unpacked' => 158661},'testers' => {'pass' => 2,'tests' => '0','unknown' => 6},'uses' => ['Carp','Cwd','Data::Dumper','DynaLoader','Exporter','File::Find','File::Path','File::Spec','IO::Handle','Parse::RecDescent','Tie::IxHash','constant','strict','vars','warnings']},'ExtUtils-configPL-1.1.tar.gz' => {'author' => 'PEASE','description' => 'configures .PL files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 107,'pod_errors' => 0,'total' => 202,'with_comments' => 2},'releases' => 1,'requires' => ['Filter-1.29.tar.gz'],'requires_module' => {'Filter::Util::Call' => 0},'requires_recursive' => ['Filter-1.29.tar.gz'],'size' => {'packed' => 3532,'unpacked' => 8948},'testers' => {'pass' => 13},'uses' => ['5.006','Carp','Config','Cwd','File::Basename','Filter::Util::Call','strict','warnings']},'Ezmlm-0.04.tar.gz' => {'author' => 'GHALSE','description' => 'Object methods for ezmlm mailing lists','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 614,'pod' => 191,'pod_errors' => 1,'total' => 805,'with_comments' => 92},'releases' => 5,'size' => {'packed' => 10998,'unpacked' => 35809},'testers' => {},'uses' => ['5.005','Carp','Exporter','strict','vars']},'Ezmlm-Archive-0.12.tar.gz' => {'author' => 'AAR','description' => 'Object Methods for Ezmlm-Idx Archives','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 184,'pod' => 142,'pod_errors' => 1,'total' => 326,'with_comments' => 38},'releases' => 3,'size' => {'packed' => 5567,'unpacked' => 15596},'testers' => {'pass' => 3},'uses' => ['5.002','Carp','strict','vars']},'FAQ-OMatic-2.603.tar.gz' => {'author' => 'JHOWELL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8597,'pod' => 0,'pod_errors' => 0,'total' => 8597,'with_comments' => 2107},'releases' => 26,'size' => {'packed' => 80673,'unpacked' => 317399},'testers' => {},'uses' => ['$meta::config','CGI','Cwd','FAQ::OMatic','FAQ::OMatic::$func','FAQ::OMatic::Appearance','FAQ::OMatic::Auth','FAQ::OMatic::AuthLocal','FAQ::OMatic::ColorPicker','FAQ::OMatic::Groups','FAQ::OMatic::Help','FAQ::OMatic::Intl','FAQ::OMatic::Item','FAQ::OMatic::Log','FAQ::OMatic::Part','FAQ::OMatic::Search','FAQ::OMatic::Words','FAQ::OMatic::buildSearchDB','FAQ::OMatic::maintenance','GD','Socket','Text::Tabs','Time::Local','Words','lib']},'FAQ-OMatic-2.621.tar.gz' => {'author' => 'JHOWELL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13345,'pod' => 0,'pod_errors' => 0,'total' => 13345,'with_comments' => 3362},'releases' => 26,'size' => {'packed' => 124722,'unpacked' => 489434},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['CGI','Config','Cwd','FAQ::OMatic','FAQ::OMatic::$func','FAQ::OMatic::Appearance','FAQ::OMatic::Auth','FAQ::OMatic::AuthLocal','FAQ::OMatic::Bags','FAQ::OMatic::ColorPicker','FAQ::OMatic::Groups','FAQ::OMatic::Help','FAQ::OMatic::ImageData','FAQ::OMatic::ImageRef','FAQ::OMatic::Item','FAQ::OMatic::Log','FAQ::OMatic::Part','FAQ::OMatic::Search','FAQ::OMatic::Set','FAQ::OMatic::Slow','FAQ::OMatic::Versions','FAQ::OMatic::Words','FAQ::OMatic::buildSearchDB','FAQ::OMatic::install','FAQ::OMatic::maintenance','GD','Socket','Text::Tabs','Time::Local','Words','lib','strict','vars']},'FAQ-OMatic-2.702.tar.gz' => {'author' => 'JHOWELL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 16300,'pod' => 91,'pod_errors' => 0,'total' => 16391,'with_comments' => 3695},'releases' => 26,'size' => {'packed' => 161294,'unpacked' => 612321},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['$meta::config','CGI','Config','Cwd','FAQ::OMatic','FAQ::OMatic::$func','FAQ::OMatic::Appearance','FAQ::OMatic::Auth','FAQ::OMatic::AuthLocal','FAQ::OMatic::Bags','FAQ::OMatic::ColorPicker','FAQ::OMatic::Groups','FAQ::OMatic::I18N','FAQ::OMatic::ImageData','FAQ::OMatic::ImageRef','FAQ::OMatic::Item','FAQ::OMatic::Log','FAQ::OMatic::Part','FAQ::OMatic::Set','FAQ::OMatic::Slow','FAQ::OMatic::Versions','FAQ::OMatic::Words','FAQ::OMatic::buildSearchDB','FAQ::OMatic::install','FAQ::OMatic::maintenance','GD','HTTP::Request::Common','LWP::UserAgent','Locale::PGetText','Socket','Text::Tabs','Text::Wrap','Time::Local','URI','Words','lib','strict','vars']},'FAQ-OMatic-2.717.tar.gz' => {'author' => 'JHOWELL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 25313,'pod' => 91,'pod_errors' => 0,'total' => 25404,'with_comments' => 5814},'releases' => 26,'size' => {'packed' => 323560,'unpacked' => 1117491},'testers' => {'pass' => 3},'uses' => ['$meta::config','CGI','Config','Cwd','Digest::MD5','FAQ::OMatic','FAQ::OMatic::$func','FAQ::OMatic::Auth','FAQ::OMatic::AuthLocal','FAQ::OMatic::Bags','FAQ::OMatic::ColorPicker','FAQ::OMatic::Entropy','FAQ::OMatic::Groups','FAQ::OMatic::HelpMod','FAQ::OMatic::ImageData','FAQ::OMatic::ImageRef','FAQ::OMatic::Item','FAQ::OMatic::Log','FAQ::OMatic::SearchMod','FAQ::OMatic::Set','FAQ::OMatic::Versions','FAQ::OMatic::Words','FAQ::OMatic::buildSearchDB','FAQ::OMatic::install','FAQ::OMatic::maintenance','Fcntl','GD','HTTP::Request::Common','LWP::UserAgent','Locale::PGetText','Socket','Text::Tabs','Text::Wrap','Time::Local','URI','Words','lib','locale','strict','vars']},'FAQ-OMatic-2.719.tar.gz' => {'author' => 'JHOWELL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 27527,'pod' => 91,'pod_errors' => 0,'total' => 27618,'with_comments' => 6425},'releases' => 26,'size' => {'packed' => 365206,'unpacked' => 1261064},'testers' => {'pass' => 2},'uses' => ['$meta::config','CGI','Config','Cwd','Digest::MD5','FAQ::OMatic::$func','FAQ::OMatic::Appearance','FAQ::OMatic::I18N','FAQ::OMatic::Part','FAQ::OMatic::Slow','Fcntl','GD','HTTP::Request::Common','Jcode','LWP::UserAgent','Locale::PGetText','MIME::Words','NKF','Socket','Text::ChaSen','Text::Tabs','Text::Wrap','Time::Local','URI','Words','lib','locale','strict','vars']},'FCGI-0.67.tar.gz' => {'author' => 'SKIMO','description' => 'Fast CGI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3,'pod' => 0,'pod_errors' => 0,'total' => 3,'with_comments' => 0},'releases' => 39,'size' => {'packed' => 86238,'unpacked' => 346424},'testers' => {'pass' => 5},'uses' => []},'FCGI-ProcManager-0.17.tar.gz' => {'author' => 'JURACH','description' => 'A FastCGI process manager','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 293,'pod_errors' => 0,'total' => 730,'with_comments' => 36},'releases' => 6,'size' => {'packed' => 18192,'unpacked' => 54064},'testers' => {'pass' => 6},'uses' => ['Exporter','POSIX','strict','vars']},'FFI-1.00.tar.gz' => {'author' => 'PMOORE','description' => 'Access to functions in shared libraries','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 208,'pod' => 131,'pod_errors' => 0,'total' => 339,'with_comments' => 4},'releases' => 3,'size' => {'packed' => 563251,'unpacked' => 2766003},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','Config','DynaLoader','Win32','strict','vars']},'FLTK-0.52.tar.gz' => {'author' => 'MKENNEDY','description' => 'Perl interface to the Fast Light Toolkit Library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1018,'pod' => 36,'pod_errors' => 0,'total' => 1054,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 39196,'unpacked' => 184667},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'FServer.tar.gz' => {'author' => 'JPDURRIOS','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 43,'pod' => 0,'pod_errors' => 0,'total' => 43,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 16849,'unpacked' => 91023},'testers' => {'pass' => 2},'uses' => ['strict']},'FUSE-Client-1.08.tar.gz' => {'author' => 'IAMCAL','description' => 'Custom FUSE client creation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 53,'pod_errors' => 0,'total' => 110,'with_comments' => 0},'releases' => 4,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO::Socket' => 1},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 2329,'unpacked' => 3954},'testers' => {'pass' => 7},'uses' => ['5','Exporter','IO::Socket','strict','vars']},'FUSE-Server-1.19.tar.gz' => {'author' => 'IAMCAL','description' => 'Custom FUSE server creation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 216,'pod' => 111,'pod_errors' => 0,'total' => 327,'with_comments' => 3},'releases' => 9,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO::Select' => 1,'IO::Socket' => 1},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 4176,'unpacked' => 10114},'testers' => {'pass' => 7},'uses' => ['5','Exporter','IO::Select','IO::Socket','strict','vars']},'FakeHash-0.80.tar.gz' => {'author' => 'MJD','description' => 'Draw a C<pic> diagram of the internal structure of a hash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 537,'pod' => 188,'pod_errors' => 0,'total' => 725,'with_comments' => 29},'releases' => 1,'size' => {'packed' => 25722,'unpacked' => 48733},'testers' => {'pass' => 6},'uses' => ['Carp','integer','strict']},'FameHLI-API-1.101.tar.gz' => {'author' => 'DAVEO','description' => 'Perl5 port of Fame C-HLI functions FameHLI::API::HLI - port of Fame hli.h variables FameHLI::API::EXT - helper functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1551,'pod' => 686,'pod_errors' => 0,'total' => 2237,'with_comments' => 160},'releases' => 6,'size' => {'packed' => 68235,'unpacked' => 366181},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','FileHandle','strict','vars','warnings']},'FastGlob-1.3.tar.gz' => {'author' => 'MENGEL','description' => 'A faster glob() implementation','files' => [],'lines' => {'nonpod' => 219,'pod' => 63,'pod_errors' => 0,'total' => 282,'with_comments' => 22},'releases' => 2,'size' => {'packed' => 2938,'unpacked' => 7085},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['5.004','5.005','strict','vars']},'Fax-DataFax-DateTime-0.01.tar.gz' => {'author' => 'GEOTIGER','description' => 'Perl extension for miscellanous methods.','files' => [],'lines' => {'nonpod' => 529,'pod' => 223,'pod_errors' => 0,'total' => 752,'with_comments' => 174},'releases' => 1,'size' => {'packed' => 6465,'unpacked' => 30282},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','Time::Local','strict','vars','warnings']},'FedEx-0.10.tar.gz' => {'author' => 'PTULLY','description' => 'Win32 API Extension for FedEx ShipAPI','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 945,'pod' => 294,'pod_errors' => 0,'total' => 1239,'with_comments' => 118},'releases' => 1,'requires' => ['Tie-IxHash-1.21.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::Simple' => 0,'LWP::UserAgent' => 0,'Tie::IxHash' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Tie-IxHash-1.21.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12306,'unpacked' => 44686},'testers' => {'pass' => 1,'tests' => '0','unknown' => 9},'uses' => ['Business::FedEx','Business::FedEx::Constants','Exporter','LWP::Simple','constant','strict','warnings']},'Festival-Client-1.0.tar.gz' => {'author' => 'GOSSAMER','description' => 'Communicate with a Festival server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 118,'pod' => 51,'pod_errors' => 1,'total' => 169,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 2930,'unpacked' => 5861},'testers' => {'fail' => 6},'uses' => ['Carp','Exporter','Fcntl','IO::Socket','Symbol','strict','vars']},'Festival-Client-Async-0.0303.tar.gz' => {'author' => 'DJHD','description' => 'Festival client blocking or non-blocking','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 429,'pod' => 215,'pod_errors' => 0,'total' => 644,'with_comments' => 22},'releases' => 2,'size' => {'packed' => 30595,'unpacked' => 66577},'testers' => {'pass' => 6,'tests' => '0','unknown' => 3},'uses' => ['Fcntl','IO::Socket','constant','strict','vars']},'Fido-0.02.tar.gz' => {'author' => 'MNAGUIB','description' => 'Perl extension to send SMS messages to phones served by Fido (http://www.fido.ca)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 200,'pod' => 96,'pod_errors' => 0,'total' => 296,'with_comments' => 36},'releases' => 2,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Cookies' => 0,'LWP::UserAgent' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3682,'unpacked' => 8310},'testers' => {'pass' => 4},'uses' => ['AutoLoader','Exporter','HTTP::Cookies','LWP::UserAgent','strict','vars']},'File-AnySpec-0.03.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1310,'pod' => 686,'pod_errors' => 1,'total' => 1996,'with_comments' => 116},'releases' => 4,'requires' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'requires_module' => {'File::PM2File' => '0','File::Package' => '0','File::SmartNL' => '0','File::TestPath' => '0','Test::Tech' => '1.08','Text::Scrub' => '0'},'requires_recursive' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'size' => {'packed' => 18869,'unpacked' => 82708},'testers' => {'pass' => 1},'uses' => ['5.001','File::Glob','File::PM2File','File::Package','File::Spec','SelfLoader','strict','vars','warnings','warnings::register']},'File-Archive-0.53.tar.gz' => {'author' => 'RBOW','description' => 'Figure out what is in an archive file','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 28,'pod_errors' => 0,'total' => 133,'with_comments' => 11},'releases' => 3,'size' => {'packed' => 4127,'unpacked' => 19877},'testers' => {'fail' => 4,'pass' => 4},'uses' => ['Archive::Tar','Compress::Zlib','strict']},'File-BSDGlob-0.94.tar.gz' => {'author' => 'GBACON','description' => 'Secure, csh-compatible filename globbing','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 181,'pod' => 113,'pod_errors' => 1,'total' => 294,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 15366,'unpacked' => 45101},'testers' => {'fail' => 1,'pass' => 7,'tests' => '21'},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'File-Backup-0.02.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Easy file backup & rotation automation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 44,'pod_errors' => 0,'total' => 126,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 3071,'unpacked' => 7359},'testers' => {'fail' => 4,'pass' => 4},'uses' => ['Exporter','strict','vars']},'File-BasicFlock-98.1202.tar.gz' => {'author' => 'MUIR','description' => 'Simple flock() wrapper','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 101,'pod' => 27,'pod_errors' => 0,'total' => 128,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 2544,'unpacked' => 5205},'testers' => {'fail' => 1,'pass' => 6,'tests' => '68'},'uses' => ['Carp','Exporter','Fcntl','strict','vars']},'File-Binary-1.0.tar.gz' => {'author' => 'SIMONW','description' => 'Binary file reading module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 358,'pod' => 119,'pod_errors' => 0,'total' => 477,'with_comments' => 21},'releases' => 3,'size' => {'packed' => 19918,'unpacked' => 123847},'testers' => {'pass' => 5},'uses' => ['Carp','Config','IO::File','strict','vars']},'File-Butler-3.01.tar.gz' => {'author' => 'SIFUKURT','description' => 'Handy collection of file manipulation tools','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 233,'pod' => 89,'pod_errors' => 0,'total' => 322,'with_comments' => 11},'releases' => 3,'size' => {'packed' => 3641,'unpacked' => 11355},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'File-Cache-0.16.tar.gz' => {'author' => 'DCLINTON','description' => 'Share data between processes via filesystem','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2370,'pod' => 421,'pod_errors' => 0,'total' => 2791,'with_comments' => 327},'releases' => 11,'requires' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'Digest::MD5' => '2.09','File::Spec' => '0.82','Storable' => '0.607'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 27646,'unpacked' => 107482},'testers' => {'fail' => 1,'pass' => 10},'uses' => ['Carp','Data::Dumper','Digest::MD5','Exporter','File::Find','File::Path','File::Spec','File::Spec::Functions','Storable','strict','vars']},'File-CacheDir-1.02.tar.gz' => {'author' => 'EARL','description' => 'auto ttl-based file cleanup without a cron','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 249,'pod' => 96,'pod_errors' => 0,'total' => 345,'with_comments' => 3},'releases' => 10,'size' => {'packed' => 5938,'unpacked' => 18497},'testers' => {'fail' => 2,'pass' => 11,'tests' => '6'},'uses' => ['CGI','Exporter','File::Copy','File::Path','strict','vars']},'File-CachingFind-0.63.tar.gz' => {'author' => 'DORNER','description' => 'find files within cached search paths (e.g. include files)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 382,'pod' => 169,'pod_errors' => 0,'total' => 551,'with_comments' => 63},'releases' => 2,'size' => {'packed' => 7707,'unpacked' => 27099},'testers' => {'pass' => 5},'uses' => ['5.000','Carp','Cwd','DirHandle','Exporter','strict','vars']},'File-Cat-1.2.tar.gz' => {'author' => 'FIMM','description' => 'Perl implementation of cat(1)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 40,'pod_errors' => 0,'total' => 118,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2026,'unpacked' => 3757},'testers' => {'pass' => 6},'uses' => ['Carp','Exporter','strict','vars']},'File-Content-0.01.tar.gz' => {'author' => 'RFOLEY','description' => 'Regular expression interface to content of a file.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2326,'pod' => 1181,'pod_errors' => 7,'total' => 3507,'with_comments' => 106},'releases' => 1,'size' => {'packed' => 130243,'unpacked' => 269341},'testers' => {'pass' => 4},'uses' => ['Carp','Data::Dumper','File::stat','FileHandle','strict','vars']},'File-Copy-Link-0.02.tar.gz' => {'author' => 'RMBARKER','description' => 'Perl extension for replacing a link by a copy of the linked file.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 88,'pod_errors' => 0,'total' => 170,'with_comments' => 5},'releases' => 1,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Copy' => 0,'File::Spec' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3643,'unpacked' => 10465},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','strict','warnings']},'File-CounterFile-1.00.tar.gz' => {'author' => 'GAAS','description' => 'Persistent counter class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 41,'pod_errors' => 0,'total' => 246,'with_comments' => 13},'releases' => 3,'size' => {'packed' => 4031,'unpacked' => 11084},'testers' => {'pass' => 11},'uses' => ['5.004','Carp','Fcntl','Symbol','strict','vars']},'File-Data-0.04.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1152,'pod' => 752,'pod_errors' => 2,'total' => 1904,'with_comments' => 80},'releases' => 13,'requires' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'requires_module' => {'File::PM2File' => '0','File::Package' => '0','File::SmartNL' => '0','File::TestPath' => '0','Test::Tech' => '1.08','Text::Scrub' => '0'},'requires_recursive' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'size' => {'packed' => 15146,'unpacked' => 74528},'testers' => {'pass' => 1},'uses' => ['5.001','File::PM2File','File::SmartNL','File::Spec','Symbol','strict','vars','warnings','warnings::register']},'File-Descriptions-0.03.tar.gz' => {'author' => 'LEITE','description' => 'Perl extension for getting file descriptions','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 247,'pod' => 26,'pod_errors' => 0,'total' => 273,'with_comments' => 44},'releases' => 1,'size' => {'packed' => 9007,'unpacked' => 23429},'testers' => {'pass' => 3},'uses' => ['AutoLoader','Exporter','strict','vars']},'File-DirSync-1.11.tar.gz' => {'author' => 'BBB','description' => 'Syncronize two directories rapidly $Id: DirSync.pm,v 1.17 2003/07/03 23:27:18 rob Exp $','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 520,'pod' => 183,'pod_errors' => 0,'total' => 703,'with_comments' => 55},'releases' => 10,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'File::Copy' => 1,'File::Path' => 1},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 12504,'unpacked' => 45003},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','File::Copy','File::Path','strict','vars']},'File-Dircmp-1.20.tar.gz' => {'author' => 'SCHULTE','description' => 'directory comparison','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 142,'pod' => 35,'pod_errors' => 0,'total' => 177,'with_comments' => 19},'releases' => 3,'size' => {'packed' => 2304,'unpacked' => 4482},'testers' => {'pass' => 2},'uses' => ['Exporter','File::Basename','File::Compare','File::Glob','strict']},'File-FDpasser-0.09.tar.gz' => {'author' => 'ADDI','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 226,'pod' => 57,'pod_errors' => 0,'total' => 283,'with_comments' => 11},'releases' => 3,'size' => {'packed' => 8352,'unpacked' => 24022},'testers' => {'pass' => 3},'uses' => ['AutoLoader','DynaLoader','Exporter','Fcntl','IO::Pipe','Socket','strict','vars']},'File-FTS-0.03.tar.gz' => {'author' => 'SHLOMIF','description' => 'Perl extension for File Traversing System','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 29,'pod_errors' => 0,'total' => 82,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 2132,'unpacked' => 3936},'testers' => {'pass' => 3},'uses' => ['File::Spec','strict','vars']},'File-Find-Duplicates-0.05.tar.gz' => {'author' => 'TMTM','description' => 'Find duplicate files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 40,'pod' => 40,'pod_errors' => 0,'total' => 80,'with_comments' => 0},'releases' => 2,'requires' => ['Digest-MD5-2.26.tar.gz','File-Temp-0.12.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Digest::MD5' => 2,'File::Temp' => '0.12','Test::Simple' => '0.02'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2254,'unpacked' => 4452},'testers' => {'pass' => 2},'uses' => ['Digest::MD5','Exporter','File::Find','strict','vars']},'File-Find-Rule-0.10.tar.gz' => {'author' => 'RCLAMP','description' => 'Alternative interface to File::Find','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 495,'pod' => 383,'pod_errors' => 0,'total' => 878,'with_comments' => 10},'releases' => 10,'size' => {'packed' => 12040,'unpacked' => 38385},'testers' => {'fail' => 1,'pass' => 11,'tests' => '40'},'uses' => ['Carp','Cwd','File::Spec','Number::Compare','Text::Glob','strict','vars']},'File-Find-Rule-DIZ-0.01.tar.gz' => {'author' => 'BRICAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 51,'pod' => 38,'pod_errors' => 0,'total' => 89,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2456,'unpacked' => 4349},'testers' => {'pass' => 1},'uses' => ['','Archive::Zip','Archive::Zip::MemberRead','File::Find::Rule','strict','vars']},'File-Find-Rule-Digest-0.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'rules for matchig checksum','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 40,'pod' => 41,'pod_errors' => 0,'total' => 81,'with_comments' => 0},'releases' => 1,'requires' => ['Digest-1.02.tar.gz','File-Find-Rule-0.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Digest' => 0,'File::Find::Rule' => 0,'Test::More' => '0.32'},'requires_recursive' => ['Digest-1.02.tar.gz','Digest-MD5-2.26.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1740,'unpacked' => 3620},'testers' => {'fail' => 1,'pass' => 4,'tests' => '1'},'uses' => ['Digest','File::Find::Rule','FileHandle','strict','vars']},'File-Find-Rule-ImageSize-0.03.tar.gz' => {'author' => 'RCLAMP','description' => 'rules for matching image dimensions','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 37,'pod' => 33,'pod_errors' => 0,'total' => 70,'with_comments' => 1},'releases' => 3,'requires' => ['File-Find-Rule-0.10.tar.gz','Image-Size-2.992.tar.gz','Number-Compare-0.01.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Find::Rule' => '0.07','Image::Size' => 0,'Number::Compare' => 0,'Test::More' => 0},'requires_recursive' => ['File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','Image-Size-2.992.tar.gz','Number-Compare-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 24451,'unpacked' => 26339},'testers' => {'pass' => 3},'uses' => ['','File::Find::Rule','Image::Size','Number::Compare','strict','vars']},'File-Find-Rule-MMagic-0.02.tar.gz' => {'author' => 'RCLAMP','description' => 'rule to match on mime types','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 32,'pod_errors' => 0,'total' => 63,'with_comments' => 1},'releases' => 2,'requires' => ['File-Find-Rule-0.10.tar.gz','File-MMagic-1.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Glob-0.05.tar.gz'],'requires_module' => {'File::Find::Rule' => '0.07','File::MMagic' => 0,'Test::More' => 0,'Text::Glob' => 0},'requires_recursive' => ['File-Find-Rule-0.10.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Glob-0.05.tar.gz'],'size' => {'packed' => 24191,'unpacked' => 25570},'testers' => {'pass' => 3},'uses' => ['','File::Find::Rule','File::MMagic','Text::Glob','strict','vars']},'File-Find-Rule-MP3Info-0.01.tar.gz' => {'author' => 'KAKE','description' => 'rule to match on id3 tags, length, bitrate, etc','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 71,'pod_errors' => 0,'total' => 134,'with_comments' => 2},'releases' => 1,'requires' => ['File-Find-Rule-0.10.tar.gz','MP3-Info-1.02.tar.gz','Number-Compare-0.01.tar.gz'],'requires_module' => {'File::Find::Rule' => '0.07','MP3::Info' => 0,'Number::Compare' => 0},'requires_recursive' => ['File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','MP3-Info-1.02.tar.gz','Number-Compare-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 40646,'unpacked' => 70597},'testers' => {'pass' => 3},'uses' => ['','File::Find::Rule','MP3::Info','Number::Compare','strict','vars']},'File-Find-Rule-Permissions-1.1.tar.gz' => {'author' => 'DCANTRELL','description' => 'rule to match on file permissions and user access','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 140,'pod' => 64,'pod_errors' => 0,'total' => 204,'with_comments' => 22},'releases' => 2,'requires' => ['File-Find-Rule-0.10.tar.gz'],'requires_module' => {'File::Find::Rule' => '0.1'},'requires_recursive' => ['File-Find-Rule-0.10.tar.gz'],'size' => {'packed' => 3861,'unpacked' => 8407},'testers' => {'pass' => 1},'uses' => ['','Data::Dumper','Fcntl','File::Find::Rule','strict','vars']},'File-Find-Rule-SAUCE-0.01.tar.gz' => {'author' => 'BRICAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 56,'pod' => 43,'pod_errors' => 0,'total' => 99,'with_comments' => 1},'releases' => 1,'requires' => ['File-Find-Rule-0.10.tar.gz','File-SAUCE-0.02.tar.gz'],'requires_module' => {'File::Find::Rule' => 0,'File::SAUCE' => '0.02'},'requires_recursive' => ['File-Find-Rule-0.10.tar.gz','File-SAUCE-0.02.tar.gz'],'size' => {'packed' => 2080,'unpacked' => 4221},'testers' => {'pass' => 2},'uses' => ['','File::Find::Rule','File::SAUCE','strict','vars']},'File-Find-Rule-TTMETA-0.02.tar.gz' => {'author' => 'DARREN','description' => 'Find files based on Template Toolkit META directives','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 87,'pod' => 38,'pod_errors' => 0,'total' => 125,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 3268,'unpacked' => 9228},'testers' => {'pass' => 1},'uses' => ['File::Find::Rule','Template::Config','strict','vars']},'File-Find-Rule-WellFormed-0.01.tar.gz' => {'author' => 'DARREN','description' => 'Find well-formed XML documents','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 43,'pod_errors' => 0,'total' => 63,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1542,'unpacked' => 3528},'testers' => {'pass' => 7},'uses' => ['File::Find::Rule','XML::Parser','strict','vars']},'File-Find-Rule-XPath-0.02.tar.gz' => {'author' => 'GRANTM','description' => 'Find files by XPath expression','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 83,'pod' => 40,'pod_errors' => 0,'total' => 123,'with_comments' => 2},'releases' => 1,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Find::Rule' => undef,'Test::Simple' => '0.41'},'requires_recursive' => ['File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3532,'unpacked' => 9262},'testers' => {'pass' => 1},'uses' => ['Carp','File::Find::Rule','File::Spec','strict','vars']},'File-Findgrep-0.01.tar.gz' => {'author' => 'SBURKE','description' => '- example Locale::Maketext-using application','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 424,'pod' => 39,'pod_errors' => 0,'total' => 463,'with_comments' => 51},'releases' => 1,'requires' => ['Locale-Maketext-1.06.tar.gz'],'requires_module' => {'Locale::Maketext' => '1.01'},'requires_recursive' => ['I18N-LangTags-0.28.tar.gz','Locale-Maketext-1.06.tar.gz'],'size' => {'packed' => 6695,'unpacked' => 15886},'testers' => {'pass' => 3},'uses' => ['5.005','Locale::Maketext','strict','vars']},'File-Flat-0.8.tar.gz' => {'author' => 'ADAMK','description' => 'Implements a flat filesystem','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 836,'pod' => 210,'pod_errors' => 0,'total' => 1046,'with_comments' => 192},'releases' => 7,'requires' => ['Class-Autouse-0.7.tar.gz','Class-Inspector-1.tar.gz','File-NCopy0.32.tar.gz','File-Remove0.20.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Class::Autouse' => '0.7','Class::Inspector' => 0,'File::Copy' => 0,'File::NCopy' => '0.32','File::Remove' => '0.2','File::Spec' => '0.82','File::Temp' => '0.12','IO::File' => 0},'requires_recursive' => ['Class-Autouse-0.7.tar.gz','Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','File-NCopy0.32.tar.gz','File-Remove0.20.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 35871,'unpacked' => 122953},'testers' => {'pass' => 3},'uses' => ['File::Copy','File::NCopy','File::Remove','File::Temp','UNIVERSAL','strict','vars']},'File-Flock-101.060501.tar.gz' => {'author' => 'MUIR','description' => 'flock() wrapper.  Auto-create locks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 294,'pod' => 35,'pod_errors' => 0,'total' => 329,'with_comments' => 28},'releases' => 9,'size' => {'packed' => 5191,'unpacked' => 13319},'testers' => {'fail' => 2,'pass' => 11,'tests' => '199'},'uses' => ['Carp','Exporter','Fcntl','strict','vars']},'File-FlockDir-1.04.tar.gz' => {'author' => 'BILLH','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 345,'pod' => 49,'pod_errors' => 0,'total' => 394,'with_comments' => 49},'releases' => 10,'size' => {'packed' => 6360,'unpacked' => 18991},'testers' => {'pass' => 5},'uses' => ['Carp','Cwd','Exporter','Fcntl','File::Basename','File::stat','Sys::Hostname','strict','vars']},'File-Grep-0.01.tar.gz' => {'author' => 'MNEYLON','description' => 'Find matches to a pattern in a series of files and related functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 226,'pod' => 73,'pod_errors' => 0,'total' => 299,'with_comments' => 27},'releases' => 1,'size' => {'packed' => 4649,'unpacked' => 11550},'testers' => {'pass' => 5},'uses' => ['Carp','strict','vars']},'File-HomeDir-0.05.tar.gz' => {'author' => 'SBURKE','description' => '- get home directory for self or other users','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 212,'pod' => 78,'pod_errors' => 0,'total' => 290,'with_comments' => 63},'releases' => 3,'size' => {'packed' => 5941,'unpacked' => 14806},'testers' => {'pass' => 11},'uses' => ['5','Exporter','Mac::Files','Win32::TieRegistry','strict','vars']},'File-Info-1.02.tar.gz' => {'author' => 'FLUFFY','description' => 'Store file information persistently for fast lookup','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1159,'pod' => 666,'pod_errors' => 0,'total' => 1825,'with_comments' => 114},'releases' => 3,'size' => {'packed' => 70416,'unpacked' => 124821},'testers' => {},'uses' => ['','5.005_62','Carp','Config','Env','Exporter','ExtUtils::MakeMaker','Fatal','Fcntl','File::Basename','File::Compare','File::Find','File::Path','File::Spec','File::Spec::Functions','File::Temp','FindBin','IPC::Run','MLDBM','Storable','Test','constant','happy','strict','warnings','warnings::register']},'File-Iterator-0.11.tar.gz' => {'author' => 'SWHITAKER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 88,'pod_errors' => 0,'total' => 207,'with_comments' => 4},'releases' => 9,'size' => {'packed' => 3978,'unpacked' => 8088},'testers' => {'pass' => 10},'uses' => ['5.005','Carp','strict','vars']},'File-LckPwdF-0.01.tar.gz' => {'author' => 'ALLENS','description' => 'Lock and unlock the passwd file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 202,'pod' => 101,'pod_errors' => 0,'total' => 303,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 5008,'unpacked' => 14094},'testers' => {'fail' => 3,'pass' => 9},'uses' => ['5.002','Carp','DynaLoader','Errno','Exporter','POSIX','diagnostics','vars']},'File-LineEdit-1.12.tar.gz' => {'author' => 'MIKO','description' => 'Small utility for editing each line of a file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 196,'pod' => 125,'pod_errors' => 0,'total' => 321,'with_comments' => 38},'releases' => 4,'size' => {'packed' => 4363,'unpacked' => 14552},'testers' => {'pass' => 2},'uses' => ['Carp','Debug::ShowStuff','FileHandle','strict','vars']},'File-List-0.3.1.tar.gz' => {'author' => 'DOPACKI','description' => 'Perl extension for crawling directory trees and compiling lists of files','files' => [],'lines' => {'nonpod' => 146,'pod' => 53,'pod_errors' => 0,'total' => 199,'with_comments' => 6},'releases' => 5,'size' => {'packed' => 2850,'unpacked' => 6829},'testers' => {'pass' => 9},'uses' => ['Exporter','strict','vars']},'File-Lock-0.9.tar.gz' => {'author' => 'KJALB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 0,'pod_errors' => 0,'total' => 138,'with_comments' => 39},'releases' => 1,'size' => {'packed' => 8806,'unpacked' => 35818},'testers' => {'fail' => 2},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter']},'File-Lockf-0.20.tar.gz' => {'author' => 'PHENSON','description' => 'Interface to lockf system call','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 75,'pod_errors' => 0,'total' => 181,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 3062,'unpacked' => 8117},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['DynaLoader','Exporter','strict','vars']},'File-MMagic-1.19.tar.gz' => {'author' => 'KNOK','description' => 'Guess file type','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1668,'pod' => 159,'pod_errors' => 0,'total' => 1827,'with_comments' => 583},'releases' => 21,'size' => {'packed' => 20094,'unpacked' => 69945},'testers' => {'pass' => 3},'uses' => ['FileHandle','strict','vars']},'File-MergeSort-1.08.tar.gz' => {'author' => 'CTBROWN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 161,'pod_errors' => 0,'total' => 399,'with_comments' => 34},'releases' => 10,'requires' => ['IO-1.20.tar.gz','IO-Zlib-1.01.tar.gz'],'requires_module' => {'IO::File' => '0','IO::Zlib' => '0'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','IO-1.20.tar.gz','IO-Zlib-1.01.tar.gz'],'size' => {'packed' => 6402,'unpacked' => 15767},'testers' => {'fail' => 1,'pass' => 4,'tests' => '6'},'uses' => ['5.006','Carp','IO::File','IO::Zlib','strict','warnings']},'File-MimeInfo-0.2.tar.gz' => {'author' => 'PARDUS','description' => 'Determine file type','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 172,'pod' => 107,'pod_errors' => 0,'total' => 279,'with_comments' => 11},'releases' => 2,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Exporter' => 0,'File::Spec' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4805,'unpacked' => 10719},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','File::Spec','strict']},'File-MkTemp-1.0.6.tar.gz' => {'author' => 'TGUMMELS','description' => 'Make temporary filename from template','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 237,'pod' => 97,'pod_errors' => 0,'total' => 334,'with_comments' => 15},'releases' => 7,'size' => {'packed' => 5105,'unpacked' => 17229},'testers' => {'pass' => 12},'uses' => ['Carp','Exporter','File::Spec','FileHandle','strict','vars']},'File-Modified-0.06.tar.gz' => {'author' => 'CORION','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 273,'pod' => 100,'pod_errors' => 0,'total' => 373,'with_comments' => 18},'releases' => 5,'size' => {'packed' => 6271,'unpacked' => 17083},'testers' => {'pass' => 8},'uses' => ['5.006','Exporter','File::Signature','strict','vars','warnings']},'File-Munger-0.01.tar.gz' => {'author' => 'COG','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 240,'pod' => 92,'pod_errors' => 0,'total' => 332,'with_comments' => 33},'releases' => 1,'requires' => ['File-MMagic-1.19.tar.gz'],'requires_module' => {'File::MMagic' => '1.16'},'requires_recursive' => ['File-MMagic-1.19.tar.gz'],'size' => {'packed' => 5137,'unpacked' => 12240},'testers' => {'pass' => 2},'uses' => ['5.006','Exporter','File::MMagic','strict','warnings']},'File-NCopy0.32.tar.gz' => {'author' => 'GABOR','description' => 'Copy file, file Copy file[s] | dir[s], dir','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 536,'pod' => 122,'pod_errors' => 0,'total' => 658,'with_comments' => 41},'releases' => 1,'size' => {'packed' => 6588,'unpacked' => 20186},'testers' => {'pass' => 1,'tests' => '0','unknown' => 189},'uses' => ['5.004','strict','vars']},'File-NFSLock-1.20.tar.gz' => {'author' => 'BBB','description' => 'NFS compatible (safe) locking utility','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 558,'pod' => 198,'pod_errors' => 0,'total' => 756,'with_comments' => 116},'releases' => 11,'size' => {'packed' => 18521,'unpacked' => 64303},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Carp','Fcntl','Sys::Hostname','strict','vars']},'File-PM2File-0.03.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1092,'pod' => 639,'pod_errors' => 2,'total' => 1731,'with_comments' => 76},'releases' => 4,'requires' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'requires_module' => {'File::Package' => '0','File::SmartNL' => '0','File::TestPath' => '0','Test::Tech' => '1.08','Text::Scrub' => '0'},'requires_recursive' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'testers' => {'pass' => 1},'uses' => ['5.001','File::Spec','strict','vars','warnings','warnings::register']},'File-Package-0.02.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 806,'pod' => 385,'pod_errors' => 1,'total' => 1191,'with_comments' => 49},'releases' => 2,'size' => {'packed' => 11538,'unpacked' => 53213},'testers' => {'pass' => 2},'uses' => ['5.001','strict','vars','warnings','warnings::register']},'File-Path-Expand-1.01.tar.gz' => {'author' => 'RCLAMP','description' => 'expand filenames','files' => ['Makefile.PL','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 33,'pod' => 22,'pod_errors' => 0,'total' => 55,'with_comments' => 0},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1878,'unpacked' => 2902},'testers' => {'fail' => 2,'pass' => 2,'tests' => '5'},'uses' => ['Carp','Exporter','User::pwent','strict','vars']},'File-PathConvert-0.9.tar.gz' => {'author' => 'RBS','description' => 'DEPRECATED: USE File::Spec and Cwd::abs_path().','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1067,'pod' => 50,'pod_errors' => 0,'total' => 1117,'with_comments' => 580},'releases' => 9,'size' => {'packed' => 23807,'unpacked' => 90322},'testers' => {'pass' => 8},'uses' => ['5.002','Cwd','strict','vars']},'File-Random-0.07.tar.gz' => {'author' => 'BIGJ','description' => 'Perl module for random selecting of a file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 524,'pod' => 139,'pod_errors' => 0,'total' => 663,'with_comments' => 18},'releases' => 16,'requires' => ['Set-Scalar-1.17.tar.gz','Test-Class-0.03.tar.gz','Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Set::Scalar' => 0,'Test::Class' => '0.03','Test::Exception' => 0,'Test::More' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Attribute-Handlers-0.78.tar.gz','Class-ISA-0.32.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Set-Scalar-1.17.tar.gz','Storable-2.07.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Class-0.03.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz'],'size' => {'packed' => 15124,'unpacked' => 46693},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['','			RandomFilePassesPathsToCheckRoutine','			RandomFileRecursiveOption','5.006','Cwd','Data::Dumper','Exporter','File::Find','File::Random','RandomFileCheckOption','RandomFileMethodAllTests','RandomFileMethodBase','RandomFileSimpleDirOption','Set::Scalar','Test::Class','Test::Exception','Test::More','TestConstants','constant','strict','warnings']},'File-Random-0.10.tar.gz' => {'author' => 'BIGJ','description' => 'Perl module for random selecting of a file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 626,'pod' => 164,'pod_errors' => 0,'total' => 790,'with_comments' => 24},'releases' => 16,'requires' => ['Attribute-Handlers-0.78.tar.gz','Class-ISA-0.32.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','Set-Scalar-1.17.tar.gz','Storable-2.07.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Class-0.03.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.77','Class::ISA' => '0.32','File::Temp' => 0,'IO::File' => '1.08','Set::Scalar' => 0,'Storable' => '2.04','Test::Builder' => '0.15','Test::Builder::Tester' => '0.09','Test::Class' => '0.03','Test::Differences' => '0.43','Test::Exception' => '0.1','Test::More' => '0.44'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Attribute-Handlers-0.78.tar.gz','Class-ISA-0.32.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','Set-Scalar-1.17.tar.gz','Storable-2.07.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Class-0.03.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 16239,'unpacked' => 49218},'testers' => {'pass' => 4},'uses' => ['','			RandomFilePassesPathsToCheckRoutine','			RandomFileRecursiveOption','5.006','Cwd','Data::Dumper','Exporter','File::Find','File::Random','File::Temp','RandomFileMethodAllTests','RandomFileMethodBase','Set::Scalar','Test::Class','Test::Exception','Test::More','TestConstants','constant','strict','warnings']},'File-Random-0.17.tar.gz' => {'author' => 'BIGJ','description' => 'Perl module for random selecting of a file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 824,'pod' => 202,'pod_errors' => 1,'total' => 1026,'with_comments' => 28},'releases' => 16,'requires' => ['Attribute-Handlers-0.78.tar.gz','Class-ISA-0.32.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','Set-Scalar-1.17.tar.gz','Storable-2.07.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Class-0.03.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-ManyParams-0.10.tar.gz','Test-Simple-0.47.tar.gz','Test-Warn-0.07.tar.gz','Want-0.06.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.77','Class::ISA' => '0.32','File::Temp' => 0,'IO::File' => '1.08','Set::Scalar' => 0,'Storable' => '2.04','Test::Builder' => '0.15','Test::Builder::Tester' => '0.09','Test::Class' => '0.03','Test::Differences' => '0.43','Test::Exception' => '0.1','Test::ManyParams' => 0,'Test::More' => '0.44','Test::Warn' => '0.05','Want' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Array-Compare-1.03.tar.gz','Attribute-Handlers-0.78.tar.gz','Class-ISA-0.32.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','Set-CrossProduct-1.4.tar.gz','Set-Scalar-1.17.tar.gz','Storable-2.07.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Class-0.03.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-ManyParams-0.10.tar.gz','Test-Simple-0.47.tar.gz','Test-Warn-0.07.tar.gz','Text-Diff-0.35.tar.gz','Tree-DAG_Node-1.04.tar.gz','Want-0.06.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12834,'unpacked' => 37972},'testers' => {'pass' => 4},'uses' => ['','			RandomFilePassesPathsToCheckRoutine','			RandomFileRecursiveOption','5.006','Carp','Cwd','Data::Dumper','Exporter','File::Find','File::Temp','RandomFileCheckOption','RandomFileSimpleDirOption','Set::Scalar','Test::Class','Test::Exception','Test::ManyParams','Test::More','Test::Warn','Want','constant','strict','warnings']},'File-Rdiff-0.01.tar.gz' => {'author' => 'MLEHMANN','description' => 'interface to librsync (signatures/patches)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 136,'pod_errors' => 0,'total' => 205,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 75939,'unpacked' => 108620},'testers' => {},'uses' => ['DynaLoader','Exporter']},'File-RdistByRsync-0.3.tar.gz' => {'author' => 'MUIR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1009,'pod' => 111,'pod_errors' => 0,'total' => 1120,'with_comments' => 75},'releases' => 3,'requires' => ['File-Slurp-2002.1031.tar.gz','Getopt-Declare-1.09.tar.gz','Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'File::Slurp' => '96.042202','Getopt::Declare' => '1.09','Parse::RecDescent' => '1.8'},'requires_recursive' => ['File-Slurp-2002.1031.tar.gz','Getopt-Declare-1.09.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 10460,'unpacked' => 32217},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Data::Dumper','Exporter','File::Find','File::Slurp','Getopt::Declare','Parse::RecDescent','ParseRdistParser','strict']},'File-ReadBackwards-0.99.tar.gz' => {'author' => 'URI','description' => '- Read a file backwards by lines.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 264,'pod' => 93,'pod_errors' => 0,'total' => 357,'with_comments' => 38},'releases' => 8,'size' => {'packed' => 5957,'unpacked' => 15277},'testers' => {'pass' => 2},'uses' => ['Carp','Fcntl','Symbol','integer','strict','vars']},'File-Remote-1.16.tar.gz' => {'author' => 'NWIGER','description' => 'Read/write/edit remote files transparently','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 989,'pod' => 323,'pod_errors' => 0,'total' => 1312,'with_comments' => 307},'releases' => 5,'size' => {'packed' => 15590,'unpacked' => 56789},'testers' => {'pass' => 7},'uses' => ['5.005','Carp','Exporter','File::Copy','File::Path','Sys::Hostname','strict','vars']},'File-Remove0.20.tar.gz' => {'author' => 'GABOR','description' => 'Remove files and directories','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 110,'pod' => 46,'pod_errors' => 0,'total' => 156,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 2389,'unpacked' => 4781},'testers' => {'pass' => 1,'tests' => '0','unknown' => 201},'uses' => ['5.004','vars']},'File-Repl-1.20.tar.gz' => {'author' => 'DROBERTS','description' => 'file/dir structure replication','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 989,'pod' => 414,'pod_errors' => 5,'total' => 1403,'with_comments' => 253},'releases' => 16,'requires' => ['Win32-API-0.41.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Basename' => '2.6','File::Copy' => '2.03','File::Find' => 0,'Win32::API' => 0},'requires_recursive' => ['Win32-API-0.41.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15921,'unpacked' => 53043},'testers' => {},'uses' => ['5.005_62','Carp','Exporter','File::Basename','File::Copy','File::Find','constant','strict','warnings']},'File-Rotate-Backup-0.06.tar.gz' => {'author' => 'DOWENS','description' => 'Make backups of multiple directories and rotate them on unix.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 787,'pod' => 144,'pod_errors' => 0,'total' => 931,'with_comments' => 37},'releases' => 4,'requires' => ['File-Spec-0.82.tar.gz'],'requires_module' => {'File::Spec' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz'],'size' => {'packed' => 6817,'unpacked' => 29945},'testers' => {'pass' => 2},'uses' => ['File::Spec','strict','vars']},'File-Rsync-0.30.tar.gz' => {'author' => 'LEAKIN','description' => 'Copy efficiently over the net and locally','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 557,'pod' => 170,'pod_errors' => 0,'total' => 727,'with_comments' => 51},'releases' => 16,'size' => {'packed' => 15637,'unpacked' => 45695},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['5.004','Carp','File::Rsync::Config','FileHandle','IO::Select','IPC::Open3','POSIX','strict','vars']},'File-RsyncP-0.44.tar.gz' => {'author' => 'CBARRATT','description' => 'Perl Rsync client','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2406,'pod' => 981,'pod_errors' => 0,'total' => 3387,'with_comments' => 476},'releases' => 7,'size' => {'packed' => 56736,'unpacked' => 202242},'testers' => {'pass' => 1},'uses' => ['5.006','AutoLoader','Data::Dumper','DynaLoader','Exporter','File::Find','File::Path','Getopt::Long','Socket','constant','strict','vars','warnings']},'File-SAUCE-0.02.tar.gz' => {'author' => 'BRICAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 423,'pod' => 183,'pod_errors' => 0,'total' => 606,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 6071,'unpacked' => 20587},'testers' => {'pass' => 3},'uses' => ['Carp','constant','strict']},'File-Same-0.02.tar.gz' => {'author' => 'MSERGEANT','description' => 'Detect which files are the same as a given one','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 48,'pod_errors' => 0,'total' => 133,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2860,'unpacked' => 5595},'testers' => {'pass' => 5},'uses' => ['Digest::MD5','File::Spec','strict','vars']},'File-Scan-0.59.tar.gz' => {'author' => 'HDIAS','description' => 'Perl extension for Scanning files for Viruses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 532,'pod' => 149,'pod_errors' => 6,'total' => 681,'with_comments' => 10},'releases' => 59,'size' => {'packed' => 42040,'unpacked' => 131481},'testers' => {'pass' => 2},'uses' => ['5','Exporter','File::Copy','SelfLoader','strict','vars']},'File-Searcher-0.91.tar.gz' => {'author' => 'ASTUBBS','description' => 'Search filetree do search/replace regexes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 443,'pod' => 222,'pod_errors' => 0,'total' => 665,'with_comments' => 16},'releases' => 2,'size' => {'packed' => 8581,'unpacked' => 28761},'testers' => {'fail' => 6,'pass' => 4},'uses' => ['Archive::Tar','Carp','Class::Generate','Class::Struct','Cwd','File::Copy','File::Find','File::Flock','Time::localtime','strict','vars']},'File-Searcher-Interactive-0.9.tar.gz' => {'author' => 'ASTUBBS','description' => 'Interactive search do search/replace regexes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 148,'pod' => 93,'pod_errors' => 0,'total' => 241,'with_comments' => 0},'releases' => 1,'requires' => ['ANSIColor-1.07.tar.gz','File-Searcher-0.91.tar.gz','Term-Prompt-0.11.tar.gz'],'requires_module' => {'File::Searcher' => 0,'Term::ANSIColor' => 0,'Term::Prompt' => 0},'requires_recursive' => ['ANSIColor-1.07.tar.gz','File-Searcher-0.91.tar.gz','Term-Prompt-0.11.tar.gz','TermReadKey-2.21.tar.gz'],'size' => {'packed' => 3730,'unpacked' => 9725},'testers' => {'fail' => 3,'pass' => 1},'uses' => ['File::Searcher','Term::ANSIColor','Term::Prompt','strict','vars']},'File-Slurp-2002.1031.tar.gz' => {'author' => 'MUIR','description' => 'Read/write/append files quickly','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 104,'pod' => 44,'pod_errors' => 0,'total' => 148,'with_comments' => 1},'releases' => 5,'size' => {'packed' => 2882,'unpacked' => 6377},'testers' => {'pass' => 14},'uses' => ['Carp','Exporter','vars']},'File-SmartNL-0.02.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 999,'pod' => 446,'pod_errors' => 1,'total' => 1445,'with_comments' => 71},'releases' => 3,'requires' => ['File-PM2File-0.04.tar.gz'],'requires_module' => {'File::Package' => 0},'requires_recursive' => ['File-PM2File-0.04.tar.gz'],'size' => {'packed' => 16121,'unpacked' => 68234},'testers' => {'pass' => 1},'uses' => ['5.001','SelfLoader','strict','vars','warnings','warnings::register']},'File-Sort-1.01.tar.gz' => {'author' => 'CNANDOR','description' => 'Sort a file or merge sort multiple files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 754,'pod' => 327,'pod_errors' => 0,'total' => 1081,'with_comments' => 92},'releases' => 6,'size' => {'packed' => 32803,'unpacked' => 129623},'testers' => {'pass' => 11},'uses' => ['Carp','Exporter','Fcntl','IO::File','POSIX','Symbol','locale','strict','vars']},'File-SortedSeek-0.012.tar.gz' => {'author' => 'JFREEMAN','description' => undef,'files' => [],'lines' => {'nonpod' => 437,'pod' => 303,'pod_errors' => 0,'total' => 740,'with_comments' => 26},'releases' => 3,'size' => {'packed' => 20269,'unpacked' => 79080},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars','warnings']},'File-Spec-0.82.tar.gz' => {'author' => 'RBS','description' => 'portably perform operations on file names','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1408,'pod' => 554,'pod_errors' => 0,'total' => 1962,'with_comments' => 112},'releases' => 8,'size' => {'packed' => 16855,'unpacked' => 72115},'testers' => {'pass' => 29},'uses' => ['Cwd','Exporter','File::Basename','File::Spec::$module','File::Spec::Unix','Mac::Files','VMS::Filespec','strict','vars']},'File-Stat-0.01.tar.gz' => {'author' => 'MAKOTO','description' => 'OOP interface for Perl\'s built-in stat() functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 60,'pod' => 63,'pod_errors' => 0,'total' => 123,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2571,'unpacked' => 5369},'testers' => {'pass' => 9},'uses' => ['5.006','Exporter','strict','warnings']},'File-Stat-Bits-0.10.tar.gz' => {'author' => 'FEDOROV','description' => 'stat(2) bit mask constants','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 417,'pod' => 235,'pod_errors' => 0,'total' => 652,'with_comments' => 27},'releases' => 6,'size' => {'packed' => 7915,'unpacked' => 23640},'testers' => {'pass' => 3},'uses' => ['Carp','Config','Exporter','ExtUtils::MakeMaker','File::Basename','strict','sys::stat.ph','sys::sysmacros.ph','vars']},'File-Stat-ModeString-0.22.tar.gz' => {'author' => 'FEDOROV','description' => 'conversion file stat(2) mode to/from string representation.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 425,'pod' => 186,'pod_errors' => 0,'total' => 611,'with_comments' => 22},'releases' => 7,'requires' => ['File-Stat-Bits-0.10.tar.gz'],'requires_module' => {'File::Stat::Bits' => 0},'requires_recursive' => ['File-Stat-Bits-0.10.tar.gz'],'size' => {'packed' => 6586,'unpacked' => 18726},'testers' => {'pass' => 3},'uses' => ['Carp','Config','Exporter','ExtUtils::MakeMaker','File::Stat::Bits','strict','vars']},'File-SubPM-0.02.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1104,'pod' => 571,'pod_errors' => 1,'total' => 1675,'with_comments' => 70},'releases' => 3,'requires' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'requires_module' => {'File::Package' => '0','File::SmartNL' => '0','File::TestPath' => '0','Test::Tech' => '1.08','Text::Scrub' => '0'},'requires_recursive' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'size' => {'packed' => 14522,'unpacked' => 69490},'testers' => {'pass' => 1},'uses' => ['5.001','Cwd','File::Glob','File::Spec','strict','vars','warnings','warnings::register']},'File-Sync-0.09.tar.gz' => {'author' => 'CEVANS','description' => 'POSIX/*nix fsync() and sync()','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 51,'pod' => 42,'pod_errors' => 0,'total' => 93,'with_comments' => 9},'releases' => 6,'size' => {'packed' => 4074,'unpacked' => 9412},'testers' => {'fail' => 1,'pass' => 23,'tests' => '17'},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','Symbol','strict','vars']},'File-Tail-0.98.tar.gz' => {'author' => 'MGRABNAR','description' => 'A more efficient tail -f','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 643,'pod' => 169,'pod_errors' => 0,'total' => 812,'with_comments' => 54},'releases' => 12,'requires' => ['IO-1.20.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::stat' => 0,'FileHandle' => 0,'IO::Seekable' => 0,'Time::HiRes' => '1.12'},'requires_recursive' => ['IO-1.20.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14149,'unpacked' => 63337},'testers' => {'pass' => 15},'uses' => ['Carp','Exporter','File::stat','FileHandle','IO::Seekable','Time::HiRes','strict','vars']},'File-Temp-0.12.tar.gz' => {'author' => 'TJENNESS','description' => 'Create temporary files safely','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1532,'pod' => 331,'pod_errors' => 0,'total' => 1863,'with_comments' => 375},'releases' => 6,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Fcntl' => '1.03','File::Path' => undef,'File::Spec' => '0.8'},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 25898,'unpacked' => 77508},'testers' => {'pass' => 12},'uses' => ['5.005','Carp','Errno','Exporter','Fcntl','File::Path','File::Spec','POSIX','constant','strict']},'File-TestPath-0.01.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 823,'pod' => 436,'pod_errors' => 1,'total' => 1259,'with_comments' => 55},'releases' => 2,'requires' => ['File-PM2File-0.04.tar.gz'],'requires_module' => {'File::Package' => 0},'requires_recursive' => ['File-PM2File-0.04.tar.gz'],'size' => {'packed' => 12148,'unpacked' => 55230},'testers' => {'pass' => 1},'uses' => ['5.001','Cwd','File::Spec','SelfLoader','strict','vars','warnings','warnings::register']},'File-Touch-0.01.tar.gz' => {'author' => 'NWETTERS','description' => 'Update timestamps, create nonexistent files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 118,'pod' => 87,'pod_errors' => 0,'total' => 205,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 2546,'unpacked' => 6563},'testers' => {'pass' => 6},'uses' => ['Carp','Exporter','File::stat','IO::File','strict']},'File-Transaction-1.00.tar.gz' => {'author' => 'NCLEATON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 96,'pod_errors' => 0,'total' => 201,'with_comments' => 1},'releases' => 4,'requires' => ['IO-1.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'IO::File' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3814,'unpacked' => 13039},'testers' => {'pass' => 5},'uses' => ['IO::File','strict','vars']},'File-Transaction-Atomic-1.00.tar.gz' => {'author' => 'NCLEATON','description' => 'atomic change to a group of files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 299,'pod' => 261,'pod_errors' => 0,'total' => 560,'with_comments' => 20},'releases' => 4,'requires' => ['File-Transaction-1.00.tar.gz','IO-1.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Transaction' => 0,'IO::File' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Transaction-1.00.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10352,'unpacked' => 50278},'testers' => {'pass' => 3},'uses' => ['Cwd','DirHandle','File::Transaction','strict','vars']},'File-Util-3.14.tar.gz' => {'author' => 'TOMMY','description' => 'Easy, versatile, portable file handling','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2325,'pod' => 270,'pod_errors' => 0,'total' => 2595,'with_comments' => 249},'releases' => 4,'requires' => ['Class-OOorNO-0.011.tar.gz','Exception-Handler-1.002.2.tar.gz'],'requires_module' => {'Class::OOorNO' => '0.01','Exception::Handler' => 1},'requires_recursive' => ['Class-OOorNO-0.011.tar.gz','Exception-Handler-1.002.2.tar.gz'],'size' => {'packed' => 28209,'unpacked' => 117013},'testers' => {},'uses' => ['5.006','AutoLoader','Class::OOorNO','Config','Exception::Handler','Exporter','Fcntl','strict','vars','warnings']},'File-Version-0.02.tar.gz' => {'author' => 'BROOM','description' => 'Simple File Versioning Class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 239,'pod' => 67,'pod_errors' => 0,'total' => 306,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 4881,'unpacked' => 14809},'testers' => {'pass' => 4},'uses' => ['5.006','Carp','Exporter','integer','strict','warnings']},'File-VirtualPath-1.011.tar.gz' => {'author' => 'DUNCAND','description' => 'Portable abstraction of a file/dir/url path','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 522,'pod' => 223,'pod_errors' => 0,'total' => 745,'with_comments' => 109},'releases' => 4,'size' => {'packed' => 14305,'unpacked' => 61283},'testers' => {'pass' => 10},'uses' => ['5.004','vars','warnings']},'File-Which-0.05.tar.gz' => {'author' => 'PEREINAR','description' => 'Portable implementation of `which\'','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 78,'pod_errors' => 0,'total' => 225,'with_comments' => 24},'releases' => 5,'requires' => ['File-Spec-0.82.tar.gz'],'requires_module' => {'File::Spec' => '0.6'},'requires_recursive' => ['File-Spec-0.82.tar.gz'],'size' => {'packed' => 7264,'unpacked' => 16863},'testers' => {'pass' => 20},'uses' => ['Exporter','File::Spec','strict']},'File-chdir-0.05.tar.gz' => {'author' => 'MSCHWERN','description' => 'a more sensible way to change directories','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1501,'pod' => 1052,'pod_errors' => 0,'total' => 2553,'with_comments' => 55},'releases' => 4,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Cwd' => 0,'File::Spec' => '0.8','File::Spec::Functions' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21583,'unpacked' => 65304},'testers' => {'pass' => 6},'uses' => ['5.004','Cwd','Exporter','File::Spec','strict','vars']},'File-chmod-0.31.tar.gz' => {'author' => 'PINYAN','description' => 'Allows for symbolic chmod notation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 390,'pod' => 238,'pod_errors' => 0,'total' => 628,'with_comments' => 0},'releases' => 8,'size' => {'packed' => 8363,'unpacked' => 27873},'testers' => {'pass' => 9},'uses' => ['Carp','Exporter','strict','vars']},'FileHandle-Deluxe-0.92.tar.gz' => {'author' => 'MIKO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 815,'pod' => 324,'pod_errors' => 1,'total' => 1139,'with_comments' => 194},'releases' => 3,'size' => {'packed' => 16341,'unpacked' => 55808},'testers' => {'pass' => 3},'uses' => ['5.000','Carp','Dev::ShowStuff','Exporter','Fcntl','File::Spec::Functions','FileHandle','IO::Handle','IO::Seekable','Symbol','constant','strict','vars']},'FileHandle-Rollback-1.05.tar.gz' => {'author' => 'MIKO','description' => 'FileHandle with commit, rollback, and journaled crash recovery','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 573,'pod' => 122,'pod_errors' => 0,'total' => 695,'with_comments' => 83},'releases' => 6,'requires' => ['FileHandle-Rollback-1.05.tar.gz'],'requires_module' => {'FileHandle::Rollback' => '0.01'},'requires_recursive' => ['FileHandle-Rollback-1.05.tar.gz'],'size' => {'packed' => 7423,'unpacked' => 25537},'testers' => {'pass' => 1},'uses' => ['5.000','Data::Taxi','FileHandle','IO::Handle','IO::Seekable','Symbol','strict','vars']},'FileKGlob.tar.gz' => {'author' => 'TYEMQ','description' => undef,'files' => [],'lines' => {'nonpod' => 527,'pod' => 0,'pod_errors' => 0,'total' => 527,'with_comments' => 232},'releases' => 1,'size' => {'packed' => 7653,'unpacked' => 19543},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.000','5.001','Exporter','File::Basename']},'FileMetadata-0.2.tar.gz' => {'author' => 'MIDH','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 762,'pod' => 577,'pod_errors' => 0,'total' => 1339,'with_comments' => 52},'releases' => 2,'requires' => ['DBI-1.37.tar.gz','HTML-Parser-3.28.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'DBI' => 0,'HTML::Parser' => 0,'POSIX' => 0,'XML::Simple' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13303,'unpacked' => 46258},'testers' => {'pass' => 3},'uses' => ['DBI','Fcntl','HTML::Parser','POSIX','XML::Simple','strict','utf']},'FileMode-0.05.tar.gz' => {'author' => 'AQUTIV','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 203,'pod' => 72,'pod_errors' => 0,'total' => 275,'with_comments' => 39},'releases' => 1,'size' => {'packed' => 4704,'unpacked' => 13967},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','strict','vars']},'Filesys-CygwinPaths-0.04.tar.gz' => {'author' => 'SOMIAN','description' => 'Perl extension to get various conversions of path specifications in the Cygwin port of Perl. =head2 VERSION 0.04','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 148,'pod_errors' => 0,'total' => 370,'with_comments' => 16},'releases' => 3,'size' => {'packed' => 8947,'unpacked' => 25136},'testers' => {},'uses' => ['5.006','Carp','DynaLoader','Exporter','strict','vars','warnings']},'Filesys-DiskFree-0.06.tar.gz' => {'author' => 'ABARCLAY','description' => 'OS independant parser of the df command','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 270,'pod' => 81,'pod_errors' => 0,'total' => 351,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 5499,'unpacked' => 17053},'testers' => {'pass' => 9},'uses' => ['Carp','strict','vars']},'Filesys-DiskSpace-0.05.tar.gz' => {'author' => 'FTASSIN','description' => 'Perl df (requires h2ph)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 202,'pod' => 74,'pod_errors' => 0,'total' => 276,'with_comments' => 65},'releases' => 4,'size' => {'packed' => 4955,'unpacked' => 16660},'testers' => {'fail' => 2,'pass' => 8,'tests' => '5'},'uses' => ['5.003','Carp','Config','Exporter','strict','sys::syscall.ph','vars']},'Filesys-Ext2-0.20.tgz' => {'author' => 'JPIERCE','description' => 'Interface to e2fs filesystem attributes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 169,'pod' => 153,'pod_errors' => 0,'total' => 322,'with_comments' => 4},'releases' => 8,'size' => {'packed' => 24667,'unpacked' => 79145},'testers' => {},'uses' => ['5','IO::Handle','IO::Select','IPC::Open3','strict','vars']},'Filesys-SamFS-0.035.tar.gz' => {'author' => 'LUPE','description' => 'Interface to SamFS API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 843,'pod' => 229,'pod_errors' => 0,'total' => 1072,'with_comments' => 16},'releases' => 5,'size' => {'packed' => 18025,'unpacked' => 70541},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Filesys-SmbClient-1.4.tar.gz' => {'author' => 'ALIAN','description' => 'Provide Perl API for libsmbclient.so','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 483,'pod' => 355,'pod_errors' => 0,'total' => 838,'with_comments' => 97},'releases' => 11,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 25842,'unpacked' => 94131},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.005_64','AutoLoader','DynaLoader','Exporter','POSIX','Tie::Handle','constant','vars']},'Filesys-SmbClientParser-2.5.tar.gz' => {'author' => 'ALIAN','description' => 'Perl interface to reach Samba ressources','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 844,'pod' => 308,'pod_errors' => 0,'total' => 1152,'with_comments' => 158},'releases' => 12,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 12472,'unpacked' => 44888},'testers' => {'pass' => 6},'uses' => ['Exporter','vars']},'Filesys-Statvfs_Df-0.68.tar.gz' => {'author' => 'IGUTHRIE','description' => 'Interface to the statvfs() system call','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 226,'pod' => 126,'pod_errors' => 0,'total' => 352,'with_comments' => 18},'releases' => 18,'size' => {'packed' => 6306,'unpacked' => 17250},'testers' => {'fail' => 2,'pass' => 6},'uses' => ['5.003','Carp','DynaLoader','Exporter','strict','vars']},'Filter-1.20.tar.gz' => {'author' => 'PMQS','description' => 'sh source filter','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 939,'pod' => 959,'pod_errors' => 0,'total' => 1898,'with_comments' => 25},'releases' => 23,'size' => {'packed' => 32896,'unpacked' => 107534},'testers' => {'pass' => 10},'uses' => ['5.002','Carp','Compress::Zlib','Config','DynaLoader','Exporter','Filter::Util::Call','Filter::Util::Exec','Filter::exec','IO::File','strict','vars']},'Filter-1.29.tar.gz' => {'author' => 'PMQS','description' => 'Interface for creation of Perl Filters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1028,'pod' => 985,'pod_errors' => 0,'total' => 2013,'with_comments' => 31},'releases' => 23,'size' => {'packed' => 39697,'unpacked' => 124340},'testers' => {'pass' => 14},'uses' => ['5.002','Carp','Compress::Zlib','Config','DynaLoader','Exporter','IO::File','strict','vars','warnings']},'Filter-CBC-0.08.tar.gz' => {'author' => 'BEATNIK','description' => 'Source filter for Cipher Block Chaining','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 233,'pod_errors' => 0,'total' => 362,'with_comments' => 6},'releases' => 9,'requires' => ['Crypt-CBC-2.08.tar.gz','Crypt-Rijndael-0.05.tar.gz','Filter-1.29.tar.gz'],'requires_module' => {'Crypt::CBC' => '1.25','Crypt::Rijndael' => '0.04','Filter::Util::Call' => '1.05'},'requires_recursive' => ['Crypt-CBC-2.08.tar.gz','Crypt-Rijndael-0.05.tar.gz','Digest-MD5-2.26.tar.gz','Filter-1.29.tar.gz'],'size' => {'packed' => 8427,'unpacked' => 19340},'testers' => {'pass' => 4},'uses' => ['Crypt::CBC','Filter::Util::Call','strict','vars']},'Filter-CBC-0.09.tar.gz' => {'author' => 'BEATNIK','description' => 'Source filter for Cipher Block Chaining','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 233,'pod_errors' => 0,'total' => 363,'with_comments' => 6},'releases' => 9,'requires' => ['Crypt-CBC-2.08.tar.gz','Crypt-Rijndael-0.05.tar.gz','Filter-1.29.tar.gz'],'requires_module' => {'Crypt::CBC' => '1.25','Crypt::Rijndael' => '0.04','Filter::Util::Call' => '1.05'},'requires_recursive' => ['Crypt-CBC-2.08.tar.gz','Crypt-Rijndael-0.05.tar.gz','Digest-MD5-2.26.tar.gz','Filter-1.29.tar.gz'],'size' => {'packed' => 8485,'unpacked' => 19983},'testers' => {'pass' => 3},'uses' => ['Crypt::CBC','Filter::Util::Call','strict','vars']},'Filter-Handle-0.03.tar.gz' => {'author' => 'BTROTT','description' => 'Apply filters to output filehandles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 107,'pod' => 138,'pod_errors' => 0,'total' => 245,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 4186,'unpacked' => 9353},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['strict','vars']},'Filter-NumberLines-0.02.tar.gz' => {'author' => 'BEATNIK','description' => 'Source filter for line numbering','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 143,'pod_errors' => 0,'total' => 259,'with_comments' => 0},'releases' => 2,'requires' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz'],'requires_module' => {'Filter::Simple' => '0.78','Filter::Util::Call' => '1.05'},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 12762,'unpacked' => 39521},'testers' => {'pass' => 3},'uses' => ['Filter::Simple','Filter::Util::Call','strict','vars']},'Filter-Simple-0.77.tar.gz' => {'author' => 'DCONWAY','description' => 'Simplified source filtering','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 526,'pod' => 384,'pod_errors' => 0,'total' => 910,'with_comments' => 5},'releases' => 8,'requires' => ['Filter-1.29.tar.gz'],'requires_module' => {'Filter::Util::Call' => 0},'requires_recursive' => ['Filter-1.29.tar.gz'],'size' => {'packed' => 11852,'unpacked' => 29668},'testers' => {'fail' => 1,'pass' => 8,'tests' => '26'},'uses' => ['Carp','Data::Dumper','Exporter','Filter::Simple','Filter::Util::Call','Regexp::Common','Text::Balanced','vars']},'Filter-Simple-0.78.tar.gz' => {'author' => 'DCONWAY','description' => 'Simplified source filtering','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 533,'pod' => 386,'pod_errors' => 0,'total' => 919,'with_comments' => 5},'releases' => 8,'requires' => ['Filter-1.29.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Filter::Util::Call' => 0,'Text::Balanced' => 0},'requires_recursive' => ['Filter-1.29.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 12291,'unpacked' => 30874},'testers' => {'fail' => 13,'pass' => 7,'tests' => '5'},'uses' => ['Carp','Data::Dumper','Exporter','Filter::Util::Call','Regexp::Common','Text::Balanced','vars']},'Filter-Trigraph-0.02.tar.gz' => {'author' => 'KASEI','description' => 'Understand ANSI C trigraphs in Perl source.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 24,'pod' => 48,'pod_errors' => 0,'total' => 72,'with_comments' => 1},'releases' => 2,'requires' => ['Filter-Simple-0.78.tar.gz'],'requires_module' => {'Filter::Simple' => '0.50'},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 1817,'unpacked' => 4146},'testers' => {'pass' => 6},'uses' => ['strict']},'Finance-Bank-BNPParibas-0.02.tar.gz' => {'author' => 'BRIAC','description' => 'Check your BNP bank accounts from Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 166,'pod' => 100,'pod_errors' => 0,'total' => 266,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 3827,'unpacked' => 10206},'testers' => {'fail' => 1,'pass' => 1,'tests' => '1'},'uses' => ['Carp','LWP::Debug','WWW::Mechanize','strict','vars']},'Finance-Bank-Barclays-0.05.tar.gz' => {'author' => 'DAVE','description' => 'Check your Barclays bank accounts from Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 56,'pod_errors' => 0,'total' => 153,'with_comments' => 10},'releases' => 5,'requires' => ['WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'WWW::Mechanize' => '0'},'requires_recursive' => ['WWW-Mechanize-0.56.tar.gz'],'size' => {'packed' => 3424,'unpacked' => 7750},'testers' => {'pass' => 10},'uses' => ['Carp','LWP::UserAgent','WWW::Mechanize','strict','warnings']},'Finance-Bank-Commonwealth-1.tar.gz' => {'author' => 'DDICK','description' => 'A web-banking front-end','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 846,'pod' => 182,'pod_errors' => 0,'total' => 1028,'with_comments' => 12},'releases' => 3,'requires' => ['Net_SSLeay.pm-1.23.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.5397','Net::SSLeay' => '1.12'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net_SSLeay.pm-1.23.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11139,'unpacked' => 42926},'testers' => {'fail' => 2,'pass' => 6},'uses' => ['strict','vars']},'Finance-Bank-CreateCard-1.03.tar.gz' => {'author' => 'RMCKAY','description' => 'CreateCard online banking access from perl','files' => ['Makefile.PL','README','Build.PL','MANIFEST'],'lines' => {'nonpod' => 314,'pod' => 104,'pod_errors' => 0,'total' => 418,'with_comments' => 21},'releases' => 5,'size' => {'packed' => 9842,'unpacked' => 30826},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','HTML::TreeBuilder','HTTP::Cookies','LWP::UserAgent','strict','vars']},'Finance-Bank-CreditMut-0.02.tar.gz' => {'author' => 'CBOUVI','description' => 'Check your Crédit Mutuel accounts from Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 207,'pod' => 99,'pod_errors' => 0,'total' => 306,'with_comments' => 32},'releases' => 2,'requires' => ['HTML-TableExtract-1.08.tar.gz','WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'HTML::TableExtract' => '1.08','WWW::Mechanize' => '0.44'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-TableExtract-1.08.tar.gz','HTML-Tagset-3.03.tar.gz','WWW-Mechanize-0.56.tar.gz'],'size' => {'packed' => 4533,'unpacked' => 12359},'testers' => {'pass' => 1},'uses' => ['Carp','HTML::TableExtract','WWW::Mechanize','strict','vars']},'Finance-Bank-DE-NetBank-0.03.tar.gz' => {'author' => 'RMORIZ','description' => 'Check your NetBank Bank Accounts with Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 81,'pod' => 131,'pod_errors' => 0,'total' => 212,'with_comments' => 5},'releases' => 3,'requires' => ['Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','Encode-1.97.tar.gz','Finance-Bank-DE-SpardaBank-0.06.tar.gz','HTML-Tree-3.17.tar.gz','Text-CSV_XS-0.23.tar.gz','WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'Class::Accessor' => 0,'Encode' => 0,'Finance::Bank::DE::SpardaBank' => '0.05','HTML::TreeBuilder' => 0,'Text::CSV_XS' => 0,'WWW::Mechanize' => '0.43','base' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','Crypt-SSLeay-0.51.tar.gz','Encode-1.97.tar.gz','File-Spec-0.82.tar.gz','Finance-Bank-DE-SpardaBank-0.06.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-CSV_XS-0.23.tar.gz','WWW-Mechanize-0.56.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11085,'unpacked' => 29042},'testers' => {'pass' => 2},'uses' => ['Finance::Bank::DE::SpardaBank','strict','vars']},'Finance-Bank-DE-SpardaBank-0.06.tar.gz' => {'author' => 'RMORIZ','description' => 'Check your SpardaBank accounts with Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 303,'pod' => 170,'pod_errors' => 2,'total' => 473,'with_comments' => 20},'releases' => 6,'requires' => ['Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','Crypt-SSLeay-0.51.tar.gz','HTML-Tree-3.17.tar.gz','Text-CSV_XS-0.23.tar.gz','WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'Class::Accessor' => 0,'Crypt::SSLeay' => 0,'HTML::TreeBuilder' => 0,'Text::CSV_XS' => 0,'WWW::Mechanize' => '0.43','base' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','Crypt-SSLeay-0.51.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-CSV_XS-0.23.tar.gz','WWW-Mechanize-0.56.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13522,'unpacked' => 36471},'testers' => {'pass' => 2},'uses' => ['Class::Accessor','Encode','HTML::TreeBuilder','Text::CSV_XS','WWW::Mechanize','strict','vars']},'Finance-Bank-Fubon-TW-0.01.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Check Fubon eBank accounts from Perl','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 61,'pod_errors' => 0,'total' => 155,'with_comments' => 3},'releases' => 1,'requires' => ['Crypt-SSLeay-0.51.tar.gz','WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'Crypt::SSLeay' => 0,'WWW::Mechanize' => '0.39'},'requires_recursive' => ['Crypt-SSLeay-0.51.tar.gz','WWW-Mechanize-0.56.tar.gz'],'size' => {'packed' => 4472,'unpacked' => 9526},'testers' => {'pass' => 2},'uses' => ['Carp','WWW::Mechanize','strict']},'Finance-Bank-HSBC-1.01.tar.gz' => {'author' => 'CHRIS','description' => 'Check your HSBC bank accounts from Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 56,'pod_errors' => 0,'total' => 150,'with_comments' => 9},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz','WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'HTML::TokeParser' => 0,'WWW::Mechanize' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','WWW-Mechanize-0.56.tar.gz'],'size' => {'packed' => 2824,'unpacked' => 6569},'testers' => {'pass' => 2},'uses' => ['Carp','HTML::TokeParser','WWW::Mechanize','strict']},'Finance-Bank-LloydsTSB-1.2.tar.gz' => {'author' => 'SIMON','description' => 'Check your bank accounts from Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 154,'pod' => 50,'pod_errors' => 0,'total' => 204,'with_comments' => 8},'releases' => 3,'requires' => ['WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'WWW::Mechanize' => '0.39'},'requires_recursive' => ['WWW-Mechanize-0.56.tar.gz'],'size' => {'packed' => 3532,'unpacked' => 7953},'testers' => {'pass' => 3},'uses' => ['Carp','HTML::Parser','WWW::Mechanize','strict','vars']},'Finance-Bank-PSK-0.02.tar.gz' => {'author' => 'FLORIAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 140,'pod' => 129,'pod_errors' => 0,'total' => 269,'with_comments' => 10},'releases' => 2,'requires' => ['Class-MethodMaker-1.10.tar.gz','HTML-Parser-3.28.tar.gz','WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'Class::MethodMaker' => '1.06','HTML::TokeParser' => '2.24','WWW::Mechanize' => '0.35'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','WWW-Mechanize-0.56.tar.gz'],'size' => {'packed' => 4091,'unpacked' => 10414},'testers' => {'pass' => 2},'uses' => ['5.005_62','Carp','HTML::TokeParser','WWW::Mechanize','strict','warnings']},'Finance-Bank-Postbank_de-0.07.tar.gz' => {'author' => 'CORION','description' => 'Check your Postbank.de bank account from Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 502,'pod' => 263,'pod_errors' => 0,'total' => 765,'with_comments' => 15},'releases' => 5,'requires' => ['Class-Accessor-0.18.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'Class::Accessor' => 0,'Test::MockObject' => 0,'Test::More' => 0,'WWW::Mechanize' => '0.35'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','WWW-Mechanize-0.56.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21619,'unpacked' => 102846},'testers' => {'fail' => 2,'tests' => '150'},'uses' => ['Carp','Class::Accessor','POSIX','WWW::Mechanize','constant','strict','vars','warnings']},'Finance-Bank-Sporo-0.16.tar.gz' => {'author' => 'KOZO','description' => 'Perl extension for B<SporoPay> of Slovenska Sporitelna.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 189,'pod' => 124,'pod_errors' => 1,'total' => 313,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 3678,'unpacked' => 9242},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','URI::Escape','strict','vars']},'Finance-Bank-TB-0.24.tar.gz' => {'author' => 'KOZO','description' => 'Perl extension for B<TatraPay> and B<CardPay> of Tatrabanka and B<EliotPay> of .eliot.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 285,'pod' => 174,'pod_errors' => 1,'total' => 459,'with_comments' => 26},'releases' => 3,'requires' => ['Crypt-DES-2.03.tar.gz','Digest-SHA1-2.04.tar.gz'],'requires_module' => {'Crypt::DES' => '2.03','Digest::SHA1' => '1.02'},'requires_recursive' => ['Crypt-DES-2.03.tar.gz','Digest-SHA1-2.04.tar.gz'],'size' => {'packed' => 20552,'unpacked' => 98362},'testers' => {'fail' => 1},'uses' => ['Carp','Crypt::DES','Digest::SHA1','Exporter','strict','vars']},'Finance-Bank-easybank-0.02.tar.gz' => {'author' => 'FLORIAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 254,'pod' => 219,'pod_errors' => 0,'total' => 473,'with_comments' => 32},'releases' => 2,'requires' => ['Class-MethodMaker-1.10.tar.gz','HTML-Parser-3.28.tar.gz','WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'Class::MethodMaker' => '1.06','HTML::TokeParser' => '2.24','WWW::Mechanize' => '0.35'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','WWW-Mechanize-0.56.tar.gz'],'size' => {'packed' => 6437,'unpacked' => 19009},'testers' => {'pass' => 8},'uses' => ['5.005_62','Carp','HTML::TokeParser','WWW::Mechanize','strict','warnings']},'Finance-ChartHist-0.02.tar.gz' => {'author' => 'GARTHD','description' => 'Perl module to produce historical stock price graphs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 411,'pod' => 53,'pod_errors' => 0,'total' => 464,'with_comments' => 53},'releases' => 2,'requires' => ['Date-Simple-1.03.tar.gz','Finance-QuoteHist-0.31.tar.gz','GDGraph-1.43.tar.gz'],'requires_module' => {'Date::Simple' => '1.03','Finance::QuoteHist' => '0.29','GD::Graph' => '1.35'},'requires_recursive' => ['Date-Simple-1.03.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','Finance-QuoteHist-0.31.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableExtract-1.08.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5159,'unpacked' => 17074},'testers' => {'fail' => 1,'tests' => '15'},'uses' => ['5.006','AutoLoader','Carp','Date::Simple','Exporter','Finance::QuoteHist','GD::Graph::lines','POSIX','strict','warnings']},'Finance-CompanyNames-1.tar.gz' => {'author' => 'JBAKER','description' => 'Functions for finding company names in English free text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63518,'pod' => 51,'pod_errors' => 0,'total' => 63569,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 334260,'unpacked' => 1148533},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Finance-Currency-Convert-1.03.tgz' => {'author' => 'JANW','description' => 'Convert currencies and fetch their exchange rates (with Finance::Quote)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 201,'pod' => 140,'pod_errors' => 0,'total' => 341,'with_comments' => 17},'releases' => 5,'size' => {'packed' => 4217,'unpacked' => 10758},'testers' => {'pass' => 6},'uses' => ['AutoLoader','Exporter','Finance::Quote','strict','vars']},'Finance-Currency-Convert-Yahoo-0.043.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 48,'pod_errors' => 0,'total' => 253,'with_comments' => 29},'releases' => 7,'size' => {'packed' => 5239,'unpacked' => 11275},'testers' => {'fail' => 8,'pass' => 2},'uses' => ['Carp','HTML::TokeParser','HTTP::Request','LWP::UserAgent','strict','vars','warnings']},'Finance-Edgar-0.01.zip' => {'author' => 'DENNISON','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 130,'pod' => 0,'pod_errors' => 0,'total' => 130,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 1809,'unpacked' => 4133},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['LWP','strict','vars']},'Finance-HSHrates-0.01.tar.gz' => {'author' => 'DJPADZ','description' => 'Get current US Mortgage Rates from HSH','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 55,'pod' => 35,'pod_errors' => 0,'total' => 90,'with_comments' => 18},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::Parser' => '2.2','HTTP::Request' => '1.23','LWP::UserAgent' => '1.62'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8550,'unpacked' => 22464},'testers' => {'pass' => 3,'tests' => '0','unknown' => 15},'uses' => ['5.000','Exporter','HTTP::Request::Common','LWP::UserAgent','strict','vars']},'Finance-Huntington-0.01.tar.gz' => {'author' => 'CNLAVY','description' => 'Perl extension for parsing html bank statements from the Huntington Bank website.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 337,'pod' => 57,'pod_errors' => 0,'total' => 394,'with_comments' => 34},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => '3.11'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 3371,'unpacked' => 12103},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['5.005_62','AutoLoader','Exporter','HTML::Parser','Time::Local','strict','warnings']},'Finance-Loan-0.03.tar.gz' => {'author' => 'ZAKZ','description' => 'Calculates monthly payment, interest paid, and unpaid balance on a loan.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 47,'pod_errors' => 0,'total' => 141,'with_comments' => 17},'releases' => 3,'size' => {'packed' => 2277,'unpacked' => 4705},'testers' => {'pass' => 7},'uses' => ['Exporter','strict','warnings']},'Finance-MoneyNetSymbolLookup-0.02.tar.gz' => {'author' => 'DJPADZ','description' => 'Look up a stock symbol from MoneyNet','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 60,'pod' => 40,'pod_errors' => 0,'total' => 100,'with_comments' => 18},'releases' => 2,'size' => {'packed' => 8561,'unpacked' => 22663},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.000','Exporter','HTTP::Request::Common','LWP::UserAgent','strict','vars']},'Finance-NikkeiQuote-0.5.1.tar.gz' => {'author' => 'DAIBA','description' => 'get stock information from Nikkei','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 113,'pod' => 55,'pod_errors' => 0,'total' => 168,'with_comments' => 0},'releases' => 2,'requires' => ['HTML-TableExtract-1.08.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::TableExtract' => 0,'LWP::UserAgent' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableExtract-1.08.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2240,'unpacked' => 4915},'testers' => {'pass' => 13},'uses' => ['Carp','HTML::TableExtract','LWP::UserAgent','strict','vars']},'Finance-Options-Calc-0.90.tar.gz' => {'author' => 'CCZ','description' => 'Option analysis based on different option pricing models.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 115,'pod' => 42,'pod_errors' => 0,'total' => 157,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 2527,'unpacked' => 7025},'testers' => {'pass' => 8},'uses' => ['Carp','Exporter','strict','vars']},'Finance-QIF-1.00.tar.gz' => {'author' => 'SIMON','description' => 'Parse and create Quicken Interchange Format files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 200,'pod' => 116,'pod_errors' => 0,'total' => 316,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 4012,'unpacked' => 11807},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','strict','warnings']},'Finance-Quote-1.08.tar.gz' => {'author' => 'PJF','description' => 'Get stock and mutual fund quotes from various exchanges','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 3658,'pod' => 908,'pod_errors' => 0,'total' => 4566,'with_comments' => 1124},'releases' => 5,'requires' => ['HTML-TableExtract-1.08.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::TableExtract' => 0,'HTTP::Request::Common' => 0,'LWP::UserAgent' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableExtract-1.08.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 59128,'unpacked' => 212438},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.004','5.005','Carp','Exporter','HTML::TableExtract','HTTP::Headers','HTTP::Request::Common','HTTP::Status','LWP::UserAgent','strict','vars']},'Finance-QuoteHist-0.25.tar.gz' => {'author' => 'MSISK','description' => 'Perl module for fetching historical stock quotes.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2046,'pod' => 700,'pod_errors' => 0,'total' => 2746,'with_comments' => 344},'releases' => 10,'requires' => ['DateManip-5.42a.tar.gz','HTML-TableExtract-1.08.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Date::Manip' => 0,'HTML::TableExtract' => 0,'HTTP::Request' => 0,'LWP::UserAgent' => 0},'requires_recursive' => ['DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableExtract-1.08.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 28196,'unpacked' => 96376},'testers' => {'pass' => 7},'uses' => ['Carp','Date::Manip','Finance::QuoteHist::Generic','HTML::TableExtract','HTTP::Request','LWP::UserAgent','strict','vars']},'Finance-QuoteHist-0.31.tar.gz' => {'author' => 'MSISK','description' => 'Perl module for fetching historical stock quotes.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1970,'pod' => 636,'pod_errors' => 0,'total' => 2606,'with_comments' => 327},'releases' => 10,'requires' => ['DateManip-5.42a.tar.gz','HTML-TableExtract-1.08.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Date::Manip' => 0,'HTML::TableExtract' => 0,'HTTP::Request' => 0,'LWP::UserAgent' => 0},'requires_recursive' => ['DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableExtract-1.08.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 29401,'unpacked' => 95680},'testers' => {'pass' => 2},'uses' => ['Carp','Date::Manip','HTML::TableExtract','HTTP::Request','LWP::UserAgent','strict','vars']},'Finance-Shares-0.91.tar.gz' => {'author' => 'CPWILLMOT','description' => 'Apply tests to series of stock quotes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5295,'pod' => 4084,'pod_errors' => 5,'total' => 9379,'with_comments' => 227},'releases' => 11,'requires' => ['DBIx-Namespace-0.04.tar.gz','Date-Calc-5.3.tar.gz','PodParser-1.23.tar.gz','PostScript-File-1.tar.gz','PostScript-Graph-1.00.tar.gz','Text-CSV_XS-0.23.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'DBIx::Namespace' => '0.03','Date::Calc' => 0,'LWP::UserAgent' => 0,'Pod::Usage' => 0,'PostScript::File' => 1,'PostScript::Graph::Bar' => '0.03','PostScript::Graph::Key' => 1,'PostScript::Graph::Paper' => 1,'PostScript::Graph::Style' => 1,'PostScript::Graph::XY' => '0.04','Text::CSV_XS' => 0},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','DBI-1.37.tar.gz','DBIx-Namespace-0.04.tar.gz','Date-Calc-5.3.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','PostScript-File-1.tar.gz','PostScript-Graph-1.00.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-CSV_XS-0.23.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 127501,'unpacked' => 476898},'testers' => {'pass' => 1},'uses' => ['Carp','DBIx::Namespace','Data::Dumper','Date::Calc','Exporter','LWP::UserAgent','PostScript::File','PostScript::Graph::Bar','PostScript::Graph::Key','PostScript::Graph::Paper','PostScript::Graph::Style','PostScript::Graph::XY','Test::Builder','Text::CSV_XS','strict','warnings']},'Finance-Shares-CGI-0.07.tar.gz' => {'author' => 'CPWILLMOT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 275,'pod' => 180,'pod_errors' => 0,'total' => 455,'with_comments' => 22},'releases' => 5,'requires' => ['CGI.pm-2.77.tar.gz','CGI.pm-2.98.tar.gz','DBIx-Namespace-0.04.tar.gz','Finance-Shares-0.91.tar.gz','PostScript-File-1.tar.gz','PostScript-Graph-1.00.tar.gz'],'requires_module' => {'CGI::Carp' => 0,'CGI::Pretty' => 0,'DBIx::Namespace' => '0.03','Finance::Shares::Averages' => '0.12','Finance::Shares::Bands' => '0.13','Finance::Shares::Model' => '0.11','Finance::Shares::Momentum' => '0.01','Finance::Shares::MySQL' => '1.04','Finance::Shares::Sample' => '0.12','PostScript::File' => 1,'PostScript::Graph::Key' => 1,'PostScript::Graph::Paper' => 1,'PostScript::Graph::Style' => 1},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','CGI.pm-2.77.tar.gz','CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','DBIx-Namespace-0.04.tar.gz','Date-Calc-5.3.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Finance-Shares-0.91.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','PostScript-File-1.tar.gz','PostScript-Graph-1.00.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-CSV_XS-0.23.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 50269,'unpacked' => 165792},'testers' => {'pass' => 2},'uses' => ['CGI::Carp','CGI::Pretty','Finance::Shares::MySQL','strict','warnings']},'Finance-Streamer-1.09.tar.gz' => {'author' => 'JERI','description' => 'interface to Datek Streamer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 616,'pod' => 207,'pod_errors' => 0,'total' => 823,'with_comments' => 75},'releases' => 7,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO::Select' => '1.14','IO::Socket::INET' => '1.25'},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 9148,'unpacked' => 24947},'testers' => {'pass' => 12},'uses' => ['Carp','IO::Select','IO::Socket::INET','constant','strict','warnings']},'Finance-TW-TSEQuote-0.2.tar.gz' => {'author' => 'CLKAO','description' => 'Check stock quotes from Taiwan Security Exchange','files' => ['Makefile.PL','META.yml'],'lines' => {'nonpod' => 79,'pod' => 77,'pod_errors' => 0,'total' => 156,'with_comments' => 1},'releases' => 2,'requires' => ['URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::Simple' => 0,'URI::Escape' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2146,'unpacked' => 4067},'testers' => {'pass' => 2},'uses' => ['Encode','URI::Escape','strict']},'Finance-YahooChart-0.01.tar.gz' => {'author' => 'DJPADZ','description' => 'Get a chart from Yahoo! Finance','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 123,'pod' => 44,'pod_errors' => 0,'total' => 167,'with_comments' => 26},'releases' => 1,'size' => {'packed' => 9522,'unpacked' => 25463},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.000','Exporter','strict','vars']},'Finance-YahooJapan-HistoricalQuotes-0.01.tar.gz' => {'author' => 'HATA','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 260,'pod' => 82,'pod_errors' => 0,'total' => 342,'with_comments' => 40},'releases' => 1,'size' => {'packed' => 3954,'unpacked' => 11038},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','LWP::Simple']},'Finance-YahooProfile-0.12.tar.gz' => {'author' => 'SMALHOTRA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 274,'pod' => 114,'pod_errors' => 1,'total' => 388,'with_comments' => 23},'releases' => 3,'size' => {'packed' => 6021,'unpacked' => 15344},'testers' => {'pass' => 5},'uses' => ['HTTP::Request::Common','LWP::UserAgent','strict','vars']},'FirstGoodURL-1.11.tar.gz' => {'author' => 'PINYAN','description' => 'determines first successful URL in list','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 70,'pod' => 73,'pod_errors' => 0,'total' => 143,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 2719,'unpacked' => 6668},'testers' => {'fail' => 1,'pass' => 7},'uses' => ['Carp','LWP::UserAgent','strict']},'Flash-FLAP-0.03.tar.gz' => {'author' => 'SIMONF','description' => 'Flash Remoting in Perl Translated from PHP Remoting v. 0.5b from the -PHP project.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1733,'pod' => 163,'pod_errors' => 0,'total' => 1896,'with_comments' => 402},'releases' => 4,'size' => {'packed' => 246963,'unpacked' => 620143},'testers' => {'pass' => 2},'uses' => ['5.00000','Exporter','Flash::FLAP','Flash::FLAP::App::Executive','Flash::FLAP::IO::Deserializer','Flash::FLAP::IO::InputStream','Flash::FLAP::IO::OutputStream','Flash::FLAP::IO::Serializer','Flash::FLAP::Util::Object','Flash::FLAP::Util::RemotingService','strict','vars']},'Flash-FLAP-0.06.tar.gz' => {'author' => 'SIMONF','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1863,'pod' => 170,'pod_errors' => 0,'total' => 2033,'with_comments' => 408},'releases' => 4,'size' => {'packed' => 435428,'unpacked' => 1093283},'testers' => {'pass' => 2},'uses' => ['5.00000','Apache','Apache::RequestReq','Apache::RequestUtil','DBI','Exporter','mod_perl','strict','vars','warnings']},'Font-AFM-1.18.tar.gz' => {'author' => 'GAAS','description' => 'Interface to Adobe Font Metrics files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 859,'pod' => 140,'pod_errors' => 0,'total' => 999,'with_comments' => 119},'releases' => 2,'size' => {'packed' => 8815,'unpacked' => 45911},'testers' => {'pass' => 16},'uses' => ['Carp','strict','vars']},'Font-Fret-1.202.tar.gz' => {'author' => 'MHOSKEN','description' => 'Font REporting Tool','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 858,'pod' => 121,'pod_errors' => 1,'total' => 979,'with_comments' => 37},'releases' => 5,'size' => {'packed' => 25888,'unpacked' => 84552},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Exporter','File::Find','File::stat','Font::Metrics::Helvetica','Font::Metrics::HelveticaBold','Font::TTF::Font','Getopt::Std','IO::Scalar','Mac::Memory','Mac::Resources','Text::PDF::File','Text::PDF::Page','Text::PDF::SFont','Text::PDF::TTFont0','Text::PDF::Utils','strict','vars']},'Font-TFM-0.130.tar.gz' => {'author' => 'JANPAZ','description' => 'Read info from TeX font metric files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11,'pod' => 0,'pod_errors' => 0,'total' => 11,'with_comments' => 4},'releases' => 10,'size' => {'packed' => 10490,'unpacked' => 26459},'testers' => {'pass' => 10},'uses' => ['fails']},'Font-TTF-0.31.tar.gz' => {'author' => 'MHOSKEN','description' => 'Truetype Collection class','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 11998,'pod' => 3715,'pod_errors' => 11,'total' => 15713,'with_comments' => 408},'releases' => 20,'size' => {'packed' => 154196,'unpacked' => 599730},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['$t','5.004','Compress::Zlib','Exporter','File::Spec','Font::TTF::AATKern','Font::TTF::AATutils','Font::TTF::Anchor','Font::TTF::Bsln','Font::TTF::Cmap','Font::TTF::Coverage','Font::TTF::Cvt_','Font::TTF::Delta','Font::TTF::Fdsc','Font::TTF::Feat','Font::TTF::Fmtx','Font::TTF::Font','Font::TTF::Fpgm','Font::TTF::GDEF','Font::TTF::GPOS','Font::TTF::GSUB','Font::TTF::Glyf','Font::TTF::Glyph','Font::TTF::Hdmx','Font::TTF::Head','Font::TTF::Hhea','Font::TTF::Hmtx','Font::TTF::Kern','Font::TTF::Kern::ClassArray','Font::TTF::Kern::CompactClassArray','Font::TTF::Kern::OrderedList','Font::TTF::Kern::StateTable','Font::TTF::Kern::Subtable','Font::TTF::LTSH','Font::TTF::Loca','Font::TTF::Maxp','Font::TTF::Mort','Font::TTF::Mort::Chain','Font::TTF::Mort::Contextual','Font::TTF::Mort::Insertion','Font::TTF::Mort::Ligature','Font::TTF::Mort::Noncontextual','Font::TTF::Mort::Rearrangement','Font::TTF::Mort::Subtable','Font::TTF::Name','Font::TTF::OS_2','Font::TTF::PCLT','Font::TTF::Post','Font::TTF::Prep','Font::TTF::Prop','Font::TTF::Segarr','Font::TTF::Table','Font::TTF::Ttopen','Font::TTF::Utils','Font::TTF::Vhea','Font::TTF::Vmtx','IO::File','Win32','Win32::Registry','XML::Parser::Expat','strict','vars']},'Font-TTF-0.34.tar.gz' => {'author' => 'MHOSKEN','description' => 'Truetype Collection class','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 12098,'pod' => 3735,'pod_errors' => 11,'total' => 15833,'with_comments' => 448},'releases' => 20,'size' => {'packed' => 155793,'unpacked' => 605874},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['$t','5.004','Compress::Zlib','Exporter','File::Spec','IO::File','Win32','Win32::Registry','XML::Parser::Expat','strict','vars']},'Font-TTFMetrics-0.1.tar.gz' => {'author' => 'MALAY','description' => 'A parser for the TTF file.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1666,'pod' => 159,'pod_errors' => 0,'total' => 1825,'with_comments' => 534},'releases' => 1,'size' => {'packed' => 14372,'unpacked' => 55540},'testers' => {'pass' => 2},'uses' => ['Carp','IO::File','strict']},'Football-League-Match-0.01.tar.gz' => {'author' => 'STRYTOAST','description' => 'A single footie match','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 124,'pod_errors' => 0,'total' => 188,'with_comments' => 0},'releases' => 1,'requires' => ['Time-Piece-1.08.tar.gz'],'requires_module' => {'Time::Piece' => '1.08'},'requires_recursive' => ['Time-Piece-1.08.tar.gz'],'size' => {'packed' => 2831,'unpacked' => 6058},'testers' => {'pass' => 3},'uses' => ['Time::Piece','strict','warnings']},'FormValidator-0.11.tar.gz' => {'author' => 'FRAJULAC','description' => 'Validates user input (usually from an HTML form) based on input profile.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1185,'pod' => 597,'pod_errors' => 0,'total' => 1782,'with_comments' => 113},'releases' => 1,'size' => {'packed' => 11165,'unpacked' => 42427},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Exporter','strict','vars']},'FormatNroff-0.11.tar.gz' => {'author' => 'FJH','description' => 'Format HTML as nroff man page','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1328,'pod' => 698,'pod_errors' => 0,'total' => 2026,'with_comments' => 23},'releases' => 2,'size' => {'packed' => 12799,'unpacked' => 48627},'testers' => {'fail' => 3,'tests' => '21'},'uses' => ['5.004','Carp','File::Path','HTML::Formatter','HTML::Parse','strict']},'Fortune-0.2.tar.gz' => {'author' => 'GWARD','description' => 'read and write fortune (strfile) databases','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 261,'pod' => 172,'pod_errors' => 0,'total' => 433,'with_comments' => 24},'releases' => 2,'size' => {'packed' => 6568,'unpacked' => 16892},'testers' => {'pass' => 7},'uses' => ['5.004','Carp','IO::File','strict']},'Fraction-v.53b.tar.gz' => {'author' => 'KEVINA','description' => 'Fraction Manipulation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1157,'pod' => 482,'pod_errors' => 0,'total' => 1639,'with_comments' => 97},'releases' => 1,'size' => {'packed' => 15960,'unpacked' => 54693},'testers' => {'fail' => 11,'tests' => '74'},'uses' => ['Carp','Exporter','Math::BigFloat','Math::BigInt','overload','strict','vars']},'FrameMaker-FromHTML-0.03.tar.gz' => {'author' => 'PGMART','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5037,'pod' => 45,'pod_errors' => 0,'total' => 5082,'with_comments' => 472},'releases' => 3,'requires' => ['HTML-Parser-3.28.tar.gz','Image-Size-2.992.tar.gz'],'requires_module' => {'HTML::Parser' => '2.5','Image::Size' => '2.9'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Image-Size-2.992.tar.gz'],'size' => {'packed' => 17600,'unpacked' => 139511},'testers' => {'pass' => 2},'uses' => ['HTML::Parser','Image::Size','vars']},'FramesReady-1.014.tar.gz' => {'author' => 'DERHAAG','description' => 'a frames-capable version of LWP::UserAgent','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 347,'pod' => 148,'pod_errors' => 2,'total' => 495,'with_comments' => 29},'releases' => 2,'requires' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'Digest::MD5' => 0,'HTML::HeadParser' => 0,'MIME::Base64' => '2.1','Net::FTP' => '2.58','URI' => '1.10'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17646,'unpacked' => 52474},'testers' => {'pass' => 3},'uses' => ['HTML::TokeParser','HTTP::Response','LWP::UserAgent','strict','vars']},'FreeWRL-0.14.tar.gz' => {'author' => 'LUKKA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 12175,'pod' => 55,'pod_errors' => 0,'total' => 12230,'with_comments' => 1046},'releases' => 4,'size' => {'packed' => 723426,'unpacked' => 2810060},'testers' => {},'uses' => ['DynaLoader','Exporter','Fcntl','FileHandle','IO::File','IO::Socket','IPC::Open2','LWP::Simple','POSIX','URI::URL','VRML::Config','VRML::Events','VRML::VRMLCU','VRML::VRMLFields','VRML::VRMLNodes','VRMLNodes','VRMLRend','strict','vars']},'FreezeThaw-0.43.tar.gz' => {'author' => 'ILYAZ','description' => 'Convert arbitrary objects to/from strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 678,'pod' => 179,'pod_errors' => 0,'total' => 857,'with_comments' => 130},'releases' => 4,'size' => {'packed' => 10645,'unpacked' => 33435},'testers' => {'pass' => 14},'uses' => ['5.002','Carp','Exporter','strict']},'Freq-0.14.tar.gz' => {'author' => 'IWOODHEAD','description' => 'A purpose-built inverted text index for making term frequency calculations.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 706,'pod' => 74,'pod_errors' => 0,'total' => 780,'with_comments' => 45},'releases' => 1,'requires' => ['CDB_File-0.93.tar.gz','Inline-0.44.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CDB_File' => '0.01','Fcntl' => '1.00','Inline' => '0.30'},'requires_recursive' => ['CDB_File-0.93.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13928,'unpacked' => 37577},'testers' => {'pass' => 2},'uses' => ['5.005_62','CDB_File','Fcntl','FileHandle','Inline','constant','strict','vars','warnings']},'Frontier-RPC-0.06.tar.gz' => {'author' => 'KMACLEOD','description' => 'encode/decode RPC2 format XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 806,'pod' => 238,'pod_errors' => 0,'total' => 1044,'with_comments' => 68},'releases' => 3,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.19'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 13869,'unpacked' => 48288},'testers' => {'pass' => 14},'uses' => ['HTTP::Daemon','HTTP::Request','HTTP::Status','LWP::UserAgent','XML::Parser','strict','vars']},'Function-Override-0.01.tar.gz' => {'author' => 'MSCHWERN','description' => 'Add callbacks to existing functions.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 57,'pod_errors' => 0,'total' => 194,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 3569,'unpacked' => 7455},'testers' => {'pass' => 8},'uses' => ['Carp','Exporter','strict','vars']},'Function_ID-0.02.tar.gz' => {'author' => 'ROODE','description' => 'Variables to let functions know their names.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 58,'pod_errors' => 0,'total' => 140,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2672,'unpacked' => 5693},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'Functional-0.02.tar.gz' => {'author' => 'LBROCARD','description' => 'a module which makes Perl slightly more functional (think Haskell)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1038,'pod' => 526,'pod_errors' => 0,'total' => 1564,'with_comments' => 29},'releases' => 1,'size' => {'packed' => 15368,'unpacked' => 62198},'testers' => {'fail' => 3,'pass' => 3},'uses' => ['Carp','Exporter','Tie::Array','strict','vars']},'Fwctl-0.28.tar.gz' => {'author' => 'FRAJULAC','description' => 'Perl module to configure the Linux kernel packet filtering firewall.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6285,'pod' => 2125,'pod_errors' => 1,'total' => 8410,'with_comments' => 759},'releases' => 9,'requires' => ['IPChains-0.5.tar.gz','Net-IPv4Addr-0.10.tar.gz'],'requires_module' => {'IPChains' => 0,'Net::IPv4Addr' => '0.09'},'requires_recursive' => ['IPChains-0.5.tar.gz','Net-IPv4Addr-0.10.tar.gz'],'size' => {'packed' => 80432,'unpacked' => 632533},'testers' => {},'uses' => ['Carp','Date::Manip','Exporter','Fcntl','Fwctl::Report','Getopt::Long','IPChains','Math::BigInt','Net::IPv4Addr','Symbol','Time::Local','constant','lib','strict','vars']},'GCT-XSP-ActionTaglib-0.02.tar.gz' => {'author' => 'ADZZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 199,'pod' => 146,'pod_errors' => 0,'total' => 345,'with_comments' => 60},'releases' => 2,'size' => {'packed' => 5985,'unpacked' => 15965},'testers' => {},'uses' => ['5.006','Apache::AxKit::Language::XSP','Data::Dumper','strict','warnings']},'GD-2.07.tar.gz' => {'author' => 'LDS','description' => 'Interface to Gd Graphics Library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1358,'pod' => 1237,'pod_errors' => 0,'total' => 2595,'with_comments' => 165},'releases' => 41,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Math::Trig' => 1},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 153759,'unpacked' => 312271},'testers' => {'fail' => 4,'pass' => 1},'uses' => ['5.004','AutoLoader','Carp','DynaLoader','Exporter','FileHandle','Math::Trig','Symbol','strict','vars']},'GD-Barcode-1.14.tar.gz' => {'author' => 'KWITKNR','description' => 'Create barcode image with GD','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1580,'pod' => 927,'pod_errors' => 0,'total' => 2507,'with_comments' => 251},'releases' => 4,'size' => {'packed' => 11375,'unpacked' => 80530},'testers' => {'pass' => 2},'uses' => ['Exporter','GD','GD::Barcode::$sType','strict','vars']},'GD-Convert-2.06.tar.gz' => {'author' => 'SREZIC','description' => 'additional output formats for GD','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 695,'pod' => 116,'pod_errors' => 0,'total' => 811,'with_comments' => 61},'releases' => 9,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => 0},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9630,'unpacked' => 31054},'testers' => {'fail' => 1,'tests' => '25'},'uses' => ['Config','File::Spec','File::Temp','IPC::Open3','IPC::Run','constant','strict','vars']},'GD-Dashboard-0.04.tar.gz' => {'author' => 'FERRANCE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 619,'pod' => 258,'pod_errors' => 4,'total' => 877,'with_comments' => 131},'releases' => 4,'size' => {'packed' => 23851,'unpacked' => 45665},'testers' => {'fail' => 3},'uses' => ['GD','strict','vars']},'GD-Graph-radar-0.06.tar.gz' => {'author' => 'GENE','description' => 'Make radial bar charts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 324,'pod' => 48,'pod_errors' => 0,'total' => 372,'with_comments' => 60},'releases' => 6,'requires' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz'],'requires_module' => {'GD' => 0,'GD::Graph' => 0},'requires_recursive' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15960,'unpacked' => 23155},'testers' => {'fail' => 1,'tests' => '7'},'uses' => ['Carp','GD','GD::Graph','GD::Graph::colour','GD::Graph::utils','GD::Text::Align','strict']},'GD-Graph3d-0.63.tar.gz' => {'author' => 'WADG','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2196,'pod' => 106,'pod_errors' => 0,'total' => 2302,'with_comments' => 615},'releases' => 4,'requires' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz'],'requires_module' => {'GD' => '1.18','GD::Graph' => '1.30','GD::Text::Align' => undef},'requires_recursive' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 97855,'unpacked' => 161486},'testers' => {'pass' => 1},'uses' => ['Carp','Data::Dumper','GD','GD::Graph','GD::Graph::axestype','GD::Graph::bars','GD::Graph::colour','GD::Graph::pie','GD::Graph::utils','strict']},'GD-OrgChart-0.03.tar.gz' => {'author' => 'GALGIER','description' => 'Perl extension for generating personnel organization charts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 552,'pod' => 53,'pod_errors' => 0,'total' => 605,'with_comments' => 44},'releases' => 3,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => '1.41'},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 47423,'unpacked' => 86082},'testers' => {},'uses' => ['5.006','Exporter','GD','strict','warnings']},'GD-Polyline-0.2.tar.gz' => {'author' => 'HARASTY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 532,'pod' => 266,'pod_errors' => 0,'total' => 798,'with_comments' => 134},'releases' => 2,'requires' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '0','GD' => '1','Math::Trig' => '1'},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11301,'unpacked' => 35761},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Carp','GD','Math::Trig','strict','vars']},'GD-SIRDS-0.02.tar.gz' => {'author' => 'COGENT','description' => 'Create a GD image of a Single Image Random Dot Stereogram','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 225,'pod' => 69,'pod_errors' => 0,'total' => 294,'with_comments' => 35},'releases' => 2,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => 0},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4481,'unpacked' => 9629},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','GD','POSIX','constant','strict','warnings']},'GDA-0.2.tar.gz' => {'author' => 'GREGOR','description' => 'GNU Data Access library Perl bindings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 988,'pod' => 147,'pod_errors' => 0,'total' => 1135,'with_comments' => 94},'releases' => 1,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 6005,'unpacked' => 27845},'testers' => {'fail' => 3},'uses' => ['Carp','Inline','strict','vars']},'GDGraph-1.43.tar.gz' => {'author' => 'MVERB','description' => 'Graph Plotting Module for Perl 5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5522,'pod' => 1296,'pod_errors' => 0,'total' => 6818,'with_comments' => 818},'releases' => 19,'requires' => ['GD-2.07.tar.gz','GDTextUtil-0.86.tar.gz'],'requires_module' => {'GD' => '1.18','GD::Text' => '0.80'},'requires_recursive' => ['GD-2.07.tar.gz','GDTextUtil-0.86.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 130020,'unpacked' => 381026},'testers' => {'pass' => 3},'uses' => ['Carp','Data::Dumper','Exporter','GD','GD::Text::Align','Text::ParseWords','constant','strict','vars']},'GDGraph-Map-1.05.tgz' => {'author' => 'RA','description' => 'generate HTML map text for GD::Graph diagramms.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 469,'pod' => 149,'pod_errors' => 1,'total' => 618,'with_comments' => 55},'releases' => 2,'size' => {'packed' => 11028,'unpacked' => 41451},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['Exporter','GD::Graph::axestype','GD::Graph::utils','strict','vars']},'GDGraph-XY-0.92.tar.gz' => {'author' => 'GAFFER','description' => 'XY plotting module for GD::Graph.','files' => ['Makefile.PL'],'lines' => {'nonpod' => 1370,'pod' => 165,'pod_errors' => 0,'total' => 1535,'with_comments' => 198},'releases' => 3,'requires' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz'],'requires_module' => {'GD' => '1.18','GD::Graph' => '1.3'},'requires_recursive' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5959,'unpacked' => 40699},'testers' => {'fail' => 2},'uses' => ['GD','GD::Graph::axestype','GD::Graph::utils','strict']},'GDGraph-boxplot-1.00.tar.gz' => {'author' => 'GAFFER','description' => 'Box and Whisker Graph Module for Perl 5.','files' => ['Makefile.PL'],'lines' => {'nonpod' => 566,'pod' => 166,'pod_errors' => 0,'total' => 732,'with_comments' => 108},'releases' => 1,'requires' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz','Statistics-Descriptive-2.6.tar.gz'],'requires_module' => {'GD' => '1.18','GD::Graph' => '1.3','Statistics::Descriptive' => '2.4'},'requires_recursive' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','Statistics-Descriptive-2.6.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10239,'unpacked' => 38017},'testers' => {},'uses' => ['GD::Graph::axestype','GD::Graph::colour','GD::Graph::utils','Statistics::Descriptive','strict']},'GDS2-1.3.1.tar.gz' => {'author' => 'SCHUMACK','description' => 'manipulate GDS2 stream format files','files' => ['Makefile.PL'],'lines' => {'nonpod' => 3537,'pod' => 880,'pod_errors' => 1,'total' => 4417,'with_comments' => 647},'releases' => 16,'size' => {'packed' => 35190,'unpacked' => 188817},'testers' => {'pass' => 2},'uses' => ['5.006','Attribute::Profiled','Benchmark::Timer','Config','Fcntl','IO::File','constant','strict','warnings']},'GDTextUtil-0.86.tar.gz' => {'author' => 'MVERB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1244,'pod' => 433,'pod_errors' => 1,'total' => 1677,'with_comments' => 108},'releases' => 11,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => 1},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 64698,'unpacked' => 147360},'testers' => {'pass' => 5},'uses' => ['Carp','Config','Cwd','GD','strict','vars']},'GFL-0.14a.tar.gz' => {'author' => 'GGARAND','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2018,'pod' => 459,'pod_errors' => 0,'total' => 2477,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 128158,'unpacked' => 403355},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'GIFgraph-1.10.tar.gz' => {'author' => 'MVERB','description' => 'Graph Plotting Module for Perl 5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3224,'pod' => 516,'pod_errors' => 0,'total' => 3740,'with_comments' => 550},'releases' => 8,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => 0},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 109925,'unpacked' => 233391},'testers' => {'pass' => 1},'uses' => ['5.004','Exporter','GD','GIFgraph','GIFgraph::area','GIFgraph::axestype','GIFgraph::bars','GIFgraph::lines','GIFgraph::linespoints','GIFgraph::points','strict','vars']},'GIFgraph-1.20.tar.gz' => {'author' => 'MVERB','description' => 'Graph Plotting Module (deprecated)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 341,'pod' => 33,'pod_errors' => 0,'total' => 374,'with_comments' => 120},'releases' => 8,'requires' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz'],'requires_module' => {'GD' => '1.14','GD::Graph' => '1.20'},'requires_recursive' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 29434,'unpacked' => 79724},'testers' => {'fail' => 1,'pass' => 2,'tests' => '0','unknown' => 6},'uses' => ['Carp','GD::Graph','GD::Graph::area','GD::Graph::axestype','GD::Graph::bars','GD::Graph::lines','GD::Graph::linespoints','GD::Graph::mixed','GD::Graph::pie','GD::Graph::points','strict']},'GIFgraph-Boxplot-1.00.tar.gz' => {'author' => 'NWRIGHT','description' => 'Box and Whisker Graph Module for Perl 5.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 535,'pod' => 162,'pod_errors' => 0,'total' => 697,'with_comments' => 106},'releases' => 1,'requires' => ['GD-2.07.tar.gz','GIFgraph-1.20.tar.gz','Statistics-Descriptive-2.6.tar.gz'],'requires_module' => {'GD' => '1.14','GIFgraph' => '1.1','Statistics::Descriptive' => '2.4'},'requires_recursive' => ['GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','GIFgraph-1.20.tar.gz','Statistics-Descriptive-2.6.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11874,'unpacked' => 28231},'testers' => {'pass' => 2},'uses' => ['GIFgraph::axestype','GIFgraph::utils','Statistics::Descriptive','strict']},'GIFgraphExtensions-1.0.tar.gz' => {'author' => 'MPOCOCK','description' => 'generates HTML map text while plotting graph','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 231,'pod' => 140,'pod_errors' => 1,'total' => 371,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 4815,'unpacked' => 11155},'testers' => {'fail' => 3},'uses' => ['CGI','Carp','MRP::BaseClass','strict','vars']},'GIFgraph_Map-1.02.tgz' => {'author' => 'RA','description' => 'generate HTML map text.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 409,'pod' => 138,'pod_errors' => 1,'total' => 547,'with_comments' => 55},'releases' => 4,'size' => {'packed' => 9006,'unpacked' => 33421},'testers' => {'pass' => 1,'tests' => '0','unknown' => 12},'uses' => ['Exporter','GIFgraph::axestype','GIFgraph::utils','strict','vars']},'GNOME-GNORBA-0.1.0.tar.gz' => {'author' => 'OTAYLOR','description' => 'Perl extension for using ORBit with GNOME','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 569,'pod' => 21,'pod_errors' => 0,'total' => 590,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 15785,'unpacked' => 45092},'testers' => {'pass' => 1,'tests' => '0','unknown' => 9},'uses' => ['Carp','DynaLoader','Error','Fcntl','POSIX','strict','vars']},'GO-TermFinder-0.2.tar.gz' => {'author' => 'SHERLOCK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4437,'pod' => 1217,'pod_errors' => 0,'total' => 5654,'with_comments' => 1605},'releases' => 2,'requires' => ['Storable-2.07.tar.gz'],'requires_module' => {'Storable' => '1.014'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 729036,'unpacked' => 7486095},'testers' => {'pass' => 3},'uses' => ['Storable','diagnostics','vars','warnings']},'GPG-0.06.tar.gz' => {'author' => 'MILES','description' => 'a Perl2GnuPG interface','files' => ['Makefile.PL'],'lines' => {'nonpod' => 556,'pod' => 219,'pod_errors' => 0,'total' => 775,'with_comments' => 38},'releases' => 3,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'IO::Handle' => 0,'IPC::Open3' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10980,'unpacked' => 50068},'testers' => {'pass' => 4},'uses' => ['IO::Handle','IPC::Open3','strict','vars']},'GPIB_0_30.tgz' => {'author' => 'JEFFMOCK','description' => 'Perl extension for GPIB devices','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1825,'pod' => 656,'pod_errors' => 0,'total' => 2481,'with_comments' => 113},'releases' => 1,'size' => {'packed' => 74788,'unpacked' => 290118},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','IO::Socket','MD5','Storable','constant','strict','vars']},'GPS-Lowrance-Trail-0.13.tar.gz' => {'author' => 'RRWO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 281,'pod' => 123,'pod_errors' => 0,'total' => 404,'with_comments' => 4},'releases' => 3,'size' => {'packed' => 4365,'unpacked' => 12385},'testers' => {'pass' => 2},'uses' => ['5.00500','AutoLoader','Exporter','FileHandle','strict','vars']},'GPS-Magellan-0.6.tar.gz' => {'author' => 'PETERZEN','description' => 'Module for communicating with Magellan receivers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 553,'pod' => 200,'pod_errors' => 5,'total' => 753,'with_comments' => 10},'releases' => 2,'size' => {'packed' => 37691,'unpacked' => 564145},'testers' => {'fail' => 1,'tests' => '20'},'uses' => ['Data::Dumper','XSLoader','strict','vars','warnings']},'GSM-SMS-0.142.tar.gz' => {'author' => 'JOHANVDB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3557,'pod' => 718,'pod_errors' => 1,'total' => 4275,'with_comments' => 669},'releases' => 9,'size' => {'packed' => 43907,'unpacked' => 140202},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Data::Dumper','Device::SerialPort','Exporter','GSM::SMS::Config','GSM::SMS::NBS::Frame','GSM::SMS::NBS::Message','GSM::SMS::NBS::Stack','GSM::SMS::OTA::Bitmap','GSM::SMS::OTA::CLIicon','GSM::SMS::OTA::Config','GSM::SMS::OTA::OTA','GSM::SMS::OTA::Operatorlogo','GSM::SMS::OTA::RTTTL','GSM::SMS::OTA::VCard','GSM::SMS::PDU','GSM::SMS::Spool','GSM::SMS::Transport','GSM::SMS::Transport::Transport','HTTP::Request::Common','Image::Magick','LWP::UserAgent','MIME::Base64','Time::localtime','URI::URL','constant','strict','vars']},'GSM-SMS-0.160.tar.gz' => {'author' => 'JOHANVDB','description' => 'API for sending and receiving EMS messages.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4873,'pod' => 1386,'pod_errors' => 2,'total' => 6259,'with_comments' => 549},'releases' => 9,'requires' => ['Data-Dumper-2.101.tar.gz','File-Temp-0.12.tar.gz','Log-Agent-0.304.tar.gz','MIME-Base64-2.20.tar.gz','PerlMagick-5.56.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'File::Path' => 0,'File::Temp' => 0,'File::stat' => 0,'HTTP::Request' => 0,'Image::Magick' => 0,'LWP::Simple' => 0,'LWP::UserAgent' => 0,'Log::Agent' => 0,'MIME::Base64' => 0,'Test::More' => 0,'URI::Escape' => 0,'URI::URL' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','Log-Agent-0.304.tar.gz','MIME-Base64-2.20.tar.gz','PerlMagick-5.56.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 62793,'unpacked' => 211982},'testers' => {'fail' => 1},'uses' => ['','Carp','Config','Data::Dumper','Exporter','ExtUtils::MakeMaker','File::Path','File::Spec','File::Temp','GSM::SMS::Config::Default','GSM::SMS::NBS::Frame','GSM::SMS::NBS::Message','GSM::SMS::NBS::Stack','GSM::SMS::OTA::Bitmap','GSM::SMS::OTA::CLIicon','GSM::SMS::OTA::Config','GSM::SMS::OTA::OTA','GSM::SMS::OTA::Operatorlogo','GSM::SMS::OTA::PictureMessage','GSM::SMS::OTA::RTTTL','GSM::SMS::OTA::VCard','GSM::SMS::PDU','GSM::SMS::Support::SerialPort','GSM::SMS::Transport','GSM::SMS::TransportRouter::TransportRouter','GSM::SMS::TransportRouterFactory','HTTP::Request::Common','Image::Magick','LWP::UserAgent','Log::Agent','MIME::Base64','URI::Escape','URI::URL','constant','strict','vars']},'GSM-SMS-0.161.tar.gz' => {'author' => 'JOHANVDB','description' => 'API for sending and receiving EMS messages.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4906,'pod' => 1386,'pod_errors' => 2,'total' => 6292,'with_comments' => 549},'releases' => 9,'requires' => ['Data-Dumper-2.101.tar.gz','File-Temp-0.12.tar.gz','Log-Agent-0.304.tar.gz','MIME-Base64-2.20.tar.gz','PerlMagick-5.56.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'File::Path' => 0,'File::Temp' => 0,'File::stat' => 0,'HTTP::Request' => 0,'Image::Magick' => 0,'LWP::Simple' => 0,'LWP::UserAgent' => 0,'Log::Agent' => 0,'MIME::Base64' => 0,'Test::More' => 0,'URI::Escape' => 0,'URI::URL' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','Log-Agent-0.304.tar.gz','MIME-Base64-2.20.tar.gz','PerlMagick-5.56.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 64122,'unpacked' => 216462},'testers' => {},'uses' => ['','Carp','Config','Data::Dumper','Exporter','ExtUtils::MakeMaker','File::Path','File::Spec','File::Temp','GSM::SMS::Config','GSM::SMS::Spool','GSM::SMS::Transport::Transport','HTTP::Request::Common','Image::Magick','LWP::UserAgent','Log::Agent','MIME::Base64','URI::Escape','URI::URL','constant','strict','vars']},'GSSAPI-0.12.tar.gz' => {'author' => 'PGUEN','description' => 'Perl extension providing access to the GSSAPIv2 library','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 406,'pod' => 266,'pod_errors' => 0,'total' => 672,'with_comments' => 13},'releases' => 3,'size' => {'packed' => 17188,'unpacked' => 76817},'testers' => {},'uses' => ['5.005_62','Carp','Exporter','XSLoader','constant','overload','strict','warnings']},'GTop-0.10.tar.gz' => {'author' => 'DOUGM','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 0,'pod_errors' => 0,'total' => 85,'with_comments' => 1},'releases' => 7,'size' => {'packed' => 16924,'unpacked' => 57580},'testers' => {},'uses' => ['strict']},'Gadabout-1.0002.tar.gz' => {'author' => 'JESUS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1977,'pod' => 116,'pod_errors' => 0,'total' => 2093,'with_comments' => 77},'releases' => 3,'requires' => ['Image-Imlib2-0.11.tar.gz'],'requires_module' => {'Image::Imlib2' => '0.03'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Image-Imlib2-0.11.tar.gz','Module-Build-0.19.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 12714,'unpacked' => 55092},'testers' => {},'uses' => ['Apache','Data::Dumper','Image::Imlib2','POSIX','strict','vars']},'Game-Life-0.04.tar.gz' => {'author' => 'MNEYLON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 264,'pod' => 126,'pod_errors' => 0,'total' => 390,'with_comments' => 30},'releases' => 2,'requires' => ['Clone-0.13.tar.gz'],'requires_module' => {'Clone' => 0},'requires_recursive' => ['Clone-0.13.tar.gz'],'size' => {'packed' => 5794,'unpacked' => 17027},'testers' => {'pass' => 2},'uses' => ['Clone','Exporter','strict','vars']},'Games-3D-0.04.tar.gz' => {'author' => 'TELS','description' => 'a package containing 3D points, vectors, areas, objects and links','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 1253,'pod' => 784,'pod_errors' => 0,'total' => 2037,'with_comments' => 166},'releases' => 1,'requires' => ['Games-Object-0.05.tar.gz'],'requires_module' => {'Games::Object' => '0.05'},'requires_recursive' => ['Games-Object-0.05.tar.gz'],'size' => {'packed' => 19417,'unpacked' => 67711},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','Games::Object','strict','vars']},'Games-3D-Model-0.03.tar.gz' => {'author' => 'TELS','description' => 'load/render 3D models','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 624,'pod' => 188,'pod_errors' => 0,'total' => 812,'with_comments' => 128},'releases' => 1,'requires' => ['Games-3D-World-0.05.tar.gz','SDL_perl-1.19.2.tar.gz'],'requires_module' => {'Games::3D::World' => '0.04','SDL' => '1.20.0'},'requires_recursive' => ['Config-Simple-4.55.tar.gz','Games-3D-0.04.tar.gz','Games-3D-World-0.05.tar.gz','Games-Console-0.03.tar.gz','Games-Object-0.05.tar.gz','Games-OpenGL-Font-2D-0.06.tar.gz','SDL-App-FPS-0.20.tar.gz','SDL_perl-1.19.2.tar.gz'],'size' => {'packed' => 10171,'unpacked' => 28223},'testers' => {},'uses' => ['Exporter','SDL::OpenGL','strict','vars']},'Games-3D-World-0.05.tar.gz' => {'author' => 'TELS','description' => '3D level, camera etc, that can be rendered with OpenGL','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 1789,'pod' => 686,'pod_errors' => 0,'total' => 2475,'with_comments' => 216},'releases' => 1,'requires' => ['Games-3D-0.04.tar.gz','Games-Object-0.05.tar.gz','SDL-App-FPS-0.20.tar.gz','SDL_perl-1.19.2.tar.gz'],'requires_module' => {'Games::3D' => '0.02','Games::Object' => '0.05','SDL' => '1.20.3','SDL::App::FPS' => '0.2'},'requires_recursive' => ['Config-Simple-4.55.tar.gz','Games-3D-0.04.tar.gz','Games-Console-0.03.tar.gz','Games-Object-0.05.tar.gz','Games-OpenGL-Font-2D-0.06.tar.gz','SDL-App-FPS-0.20.tar.gz','SDL_perl-1.19.2.tar.gz'],'size' => {'packed' => 29483,'unpacked' => 265755},'testers' => {},'uses' => ['Data::Dumper','Exporter','Games::3D::Area','Games::3D::Point','Games::3D::Thingy','Games::OpenGL::Font::2D','Games::Resource','SDL::App::FPS','SDL::Event','SDL::OpenGL','SDL::OpenGL::Cube','constant','strict','vars']},'Games-AIBots-0.03.tar.gz' => {'author' => 'AUTRIJUS','description' => 'An improved clone of A.I.Wars in Perl','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 1823,'pod' => 87,'pod_errors' => 0,'total' => 1910,'with_comments' => 103},'releases' => 3,'requires' => ['Term-ANSIScreen-1.40.tar.gz','TermReadKey-2.21.tar.gz','Tk-800.024.tar.gz'],'requires_module' => {'Term::ANSIScreen' => '1.2','Term::ReadKey' => '2.14','Tk' => '800.021'},'requires_recursive' => ['Term-ANSIScreen-1.40.tar.gz','TermReadKey-2.21.tar.gz','Tk-800.024.tar.gz'],'size' => {'packed' => 1715285,'unpacked' => 2183937},'testers' => {'pass' => 2},'uses' => ['5.005','File::Glob','Term::ANSIScreen','Term::ReadKey','Win32::Console','Win32::Process','Win32::Sound','fields','integer','strict','vars']},'Games-Alak-0.14.tar.gz' => {'author' => 'SBURKE','description' => 'a simple gomoku-like game','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 406,'pod' => 87,'pod_errors' => 0,'total' => 493,'with_comments' => 57},'releases' => 1,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Term::ReadLine' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 7777,'unpacked' => 22119},'testers' => {'pass' => 8},'uses' => ['5','Term::ReadLine','constant','strict','vars']},'Games-Backgammon-0.13.tar.gz' => {'author' => 'BIGJ','description' => 'Perl extension for modelling backgammon games','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 243,'pod' => 170,'pod_errors' => 0,'total' => 413,'with_comments' => 3},'releases' => 13,'requires' => ['Data-Dumper-2.101.tar.gz','Inline-0.44.tar.gz','Scalar-List-Utils-1.11.tar.gz','Set-Scalar-1.17.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz','Test-Warn-0.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => 0,'Inline' => '0.44','List::Util' => '1.07','Set::Scalar' => 0,'Test::Differences' => '0.45','Test::Exception' => '0.12','Test::More' => 0,'Test::Warn' => '0.05'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Array-Compare-1.03.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Scalar-List-Utils-1.11.tar.gz','Set-Scalar-1.17.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Warn-0.07.tar.gz','Text-Balanced-1.95.tar.gz','Text-Diff-0.35.tar.gz','Tree-DAG_Node-1.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 20950,'unpacked' => 62737},'testers' => {'pass' => 2},'uses' => ['5.006001','Carp','Data::Dumper','Exporter','Inline','List::Util','strict','warnings']},'Games-Bingo-0.05.tar.gz' => {'author' => 'JONASBN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 822,'pod' => 477,'pod_errors' => 0,'total' => 1299,'with_comments' => 13},'releases' => 5,'requires' => ['Data-Dumper-2.101.tar.gz','PDFLib-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'PDFLib' => '0.12','POSIX' => 0,'Test::Harness' => 0,'Test::More' => 0,'Test::Pod' => '0.95'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','PDFLib-0.12.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 16565,'unpacked' => 53112},'testers' => {},'uses' => ['Data::Dumper','PDFLib','POSIX','integer','lib','strict','vars']},'Games-Bingo-Bot-0.01.tar.gz' => {'author' => 'JONASBN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 347,'pod' => 219,'pod_errors' => 0,'total' => 566,'with_comments' => 1},'releases' => 1,'requires' => ['Games-Bingo-0.05.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Games::Bingo' => '0.05','Test::Harness' => 0,'Test::More' => 0,'Test::Pod' => '0.95'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Games-Bingo-0.05.tar.gz','IO-stringy-2.108.tar.gz','PDFLib-0.12.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6255,'unpacked' => 24978},'testers' => {},'uses' => ['Games::Bingo','Games::Bingo::Card','constant','lib','strict','vars','warnings']},'Games-Boggle-1.0.tar.gz' => {'author' => 'TMTM','description' => 'find words on a boggle board','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 50,'pod_errors' => 0,'total' => 125,'with_comments' => 4},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.45'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2684,'unpacked' => 4747},'testers' => {'pass' => 9},'uses' => ['strict','warnings']},'Games-Cards-1.45.tar.gz' => {'author' => 'AKARGER','description' => 'Tools to write card games in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1700,'pod' => 513,'pod_errors' => 0,'total' => 2213,'with_comments' => 364},'releases' => 5,'size' => {'packed' => 91754,'unpacked' => 199285},'testers' => {'pass' => 17},'uses' => ['5.004','Games::Cards::Undo','strict','vars']},'Games-Chess-0.003.tar.gz' => {'author' => 'GDR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1679,'pod' => 3157,'pod_errors' => 140,'total' => 4836,'with_comments' => 62},'releases' => 2,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => 0},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 49507,'unpacked' => 168113},'testers' => {'fail' => 1,'pass' => 1,'tests' => '15'},'uses' => ['Exporter','GD','constant','strict','vars']},'Games-Chess-Referee-0.002.tar.gz' => {'author' => 'GREGOR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 363,'pod' => 45,'pod_errors' => 0,'total' => 408,'with_comments' => 94},'releases' => 1,'size' => {'packed' => 6940,'unpacked' => 20337},'testers' => {'fail' => 3,'tests' => '2'},'uses' => ['Carp','Exporter','Games::Chess','strict','vars']},'Games-Chomp-0.02.tar.gz' => {'author' => 'SZABGAB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 318,'pod' => 168,'pod_errors' => 0,'total' => 486,'with_comments' => 52},'releases' => 2,'size' => {'packed' => 5518,'unpacked' => 14935},'testers' => {'pass' => 3},'uses' => ['5.006','Benchmark','strict','warnings']},'Games-Console-0.03.tar.gz' => {'author' => 'TELS','description' => 'provide a 2D quake style in-game console','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 760,'pod' => 263,'pod_errors' => 0,'total' => 1023,'with_comments' => 66},'releases' => 3,'requires' => ['Games-OpenGL-Font-2D-0.06.tar.gz','SDL_perl-1.19.2.tar.gz'],'requires_module' => {'Games::OpenGL::Font::2D' => '0.05','SDL' => 'v1.20.3'},'requires_recursive' => ['Games-OpenGL-Font-2D-0.06.tar.gz','SDL_perl-1.19.2.tar.gz'],'size' => {'packed' => 20568,'unpacked' => 228773},'testers' => {},'uses' => ['Games::OpenGL::Font::2D','SDL::App::FPS','SDL::Event','SDL::OpenGL','SDL::OpenGL::Cube','strict','vars']},'Games-Crosswords-0.01.tar.gz' => {'author' => 'XERN','description' => 'Crosswords Game','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 72,'pod_errors' => 0,'total' => 233,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 3690,'unpacked' => 9495},'testers' => {'pass' => 2},'uses' => ['5.006','strict','warnings']},'Games-Cryptoquote-1.30.tar.gz' => {'author' => 'BOBO','description' => 'Solves Cryptoquotes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 465,'pod' => 123,'pod_errors' => 0,'total' => 588,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 220670,'unpacked' => 671217},'testers' => {'pass' => 5},'uses' => ['Carp','strict','vars']},'Games-Dice-0.02.tar.gz' => {'author' => 'PNE','description' => 'Simulates rolling dice','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 159,'pod' => 45,'pod_errors' => 0,'total' => 204,'with_comments' => 27},'releases' => 1,'size' => {'packed' => 3884,'unpacked' => 7824},'testers' => {'pass' => 6},'uses' => ['Exporter','strict','vars']},'Games-Die-0.01.tar.gz' => {'author' => 'JMUHLICH','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 67,'pod' => 0,'pod_errors' => 0,'total' => 67,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 1817,'unpacked' => 3579},'testers' => {'pass' => 6},'uses' => ['Games::Die','strict','vars']},'Games-Die-0.03.tar.gz' => {'author' => 'JMUHLICH','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 128,'pod' => 82,'pod_errors' => 0,'total' => 210,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 3171,'unpacked' => 7447},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'Games-Dissociate-0.14.tar.gz' => {'author' => 'SBURKE','description' => 'a Dissociated Press algorithm and filter','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 285,'pod' => 166,'pod_errors' => 0,'total' => 451,'with_comments' => 23},'releases' => 3,'size' => {'packed' => 7952,'unpacked' => 20361},'testers' => {'pass' => 12},'uses' => ['5.000','Carp','Exporter','Getopt::Std','Text::Wrap','locale','strict','vars']},'Games-Euchre-1.00.tar.gz' => {'author' => 'CDOLAN','description' => 'Euchre card game for humans and computers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1753,'pod' => 674,'pod_errors' => 0,'total' => 2427,'with_comments' => 96},'releases' => 1,'requires' => ['Games-Cards-1.45.tar.gz'],'requires_module' => {'Games::Cards' => '1.45'},'requires_recursive' => ['Games-Cards-1.45.tar.gz'],'size' => {'packed' => 21713,'unpacked' => 78871},'testers' => {'fail' => 9},'uses' => ['5.005_62','Games::Cards','WeakRef','strict','warnings']},'Games-Go-GMP-0.01.tar.gz' => {'author' => 'SIMON','description' => 'Low-level interface to the Go Modem Protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 43,'pod_errors' => 0,'total' => 133,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 8985,'unpacked' => 28615},'testers' => {'pass' => 4},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Errno','Exporter','strict','warnings']},'Games-Go-SGF-0.01.tar.gz' => {'author' => 'SIMON','description' => 'Parse and dissect Standard Go Format files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 35,'pod_errors' => 0,'total' => 140,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 3150,'unpacked' => 5987},'testers' => {'pass' => 4},'uses' => ['5.006','Carp','Exporter','Parse::RecDescent','strict','warnings']},'Games-Goban-0.01.tar.gz' => {'author' => 'SIMON','description' => 'Board for playing go, renju, othello, etc.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 224,'pod' => 121,'pod_errors' => 0,'total' => 345,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 4901,'unpacked' => 11646},'testers' => {'pass' => 6},'uses' => ['5.006','Carp','strict','warnings']},'Games-Golf-0.15.tar.gz' => {'author' => 'BOOK','description' => 'Utilities to handle Perl Golf courses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1796,'pod' => 862,'pod_errors' => 0,'total' => 2658,'with_comments' => 224},'releases' => 8,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'File::Basename' => '2.6','IO::File' => '1.08','IO::Select' => '1.14','IPC::Open3' => '1.0103','POSIX' => '1.03'},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 42924,'unpacked' => 131718},'testers' => {'fail' => 2,'pass' => 5,'tests' => '16'},'uses' => ['5.005','Carp','Date::Manip','Exporter','File::Basename','File::Spec','Games::Golf::Entry','Games::Golf::TestSuite','IO::File','IO::Select','IPC::Open3','Mail::Util','POSIX','constant','strict','vars']},'Games-GoogleWhack-1.4.tar.gz' => {'author' => 'FOX','description' => 'Finds, verifies, and/or submits GoogleWhack\'s','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 314,'pod' => 90,'pod_errors' => 0,'total' => 404,'with_comments' => 21},'releases' => 3,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request' => '1.23','LWP::UserAgent' => '1.62'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12571,'unpacked' => 36080},'testers' => {'pass' => 6},'uses' => ['Carp','HTTP::Request','LWP::UserAgent','strict','vars']},'Games-GuessWord-0.15.tar.gz' => {'author' => 'LBROCARD','description' => 'Guess the letters in a word (ie Hangman)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 155,'pod' => 110,'pod_errors' => 0,'total' => 265,'with_comments' => 0},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3874,'unpacked' => 14823},'testers' => {'pass' => 7},'uses' => ['strict','vars']},'Games-Jumble-0.07.tar.gz' => {'author' => 'DSPARLING','description' => 'Create and solve Jumble word puzzles.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 278,'pod' => 107,'pod_errors' => 0,'total' => 385,'with_comments' => 24},'releases' => 7,'size' => {'packed' => 4848,'unpacked' => 14917},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'Games-LMSolve-0.7.8.tar.gz' => {'files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 2353,'pod' => 0,'pod_errors' => 0,'total' => 2353,'with_comments' => 106},'releases' => 3,'testers' => {},'uses' => ['Data::Dumper','English','Exporter','Getopt::Long','strict','vars']},'Games-Literati-0.01.tar.gz' => {'author' => 'CCZ','description' => '- Literati resolver','files' => [],'lines' => {'nonpod' => 644,'pod' => 141,'pod_errors' => 0,'total' => 785,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 5629,'unpacked' => 17749},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','strict']},'Games-LogicPuzzle-0.10.tar.gz' => {'author' => 'AADLER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 231,'pod' => 167,'pod_errors' => 0,'total' => 398,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 4778,'unpacked' => 16222},'testers' => {'pass' => 3},'uses' => ['Carp','strict','warnings']},'Games-Maze-1.02.tar.gz' => {'author' => 'JGAMBLE','description' => 'Create Mazes as Objects.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1654,'pod' => 174,'pod_errors' => 0,'total' => 1828,'with_comments' => 415},'releases' => 3,'size' => {'packed' => 17182,'unpacked' => 84579},'testers' => {'pass' => 6},'uses' => ['5.6.0','Carp','integer','strict','warnings']},'Games-Mines-0.01.10.tar.gz' => {'author' => 'MPECK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 773,'pod' => 223,'pod_errors' => 4,'total' => 996,'with_comments' => 42},'releases' => 1,'size' => {'packed' => 8156,'unpacked' => 27867},'testers' => {'pass' => 1},'uses' => ['5.005_62','Carp','Term::ANSIColor','strict','vars','warnings']},'Games-NIM-0.01.tar.gz' => {'author' => 'SZABGAB','description' => 'mathematical games','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 77,'pod_errors' => 0,'total' => 244,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 2692,'unpacked' => 5576},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','strict','vars']},'Games-Object-0.05.tar.gz' => {'author' => 'PSTEWART','description' => 'Provide a base class for game objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2959,'pod' => 1365,'pod_errors' => 0,'total' => 4324,'with_comments' => 467},'releases' => 5,'size' => {'packed' => 57679,'unpacked' => 201721},'testers' => {'fail' => 1,'pass' => 4,'tests' => '259'},'uses' => ['5.6.0','Carp','Exporter','IO::File','POSIX','constant','strict','vars']},'Games-OpenGL-Font-2D-0.06.tar.gz' => {'author' => 'TELS','description' => 'load/render 2D colored bitmap fonts via OpenGL','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 750,'pod' => 239,'pod_errors' => 0,'total' => 989,'with_comments' => 75},'releases' => 1,'requires' => ['SDL_perl-1.19.2.tar.gz'],'requires_module' => {'SDL' => 'v1.20.3'},'requires_recursive' => ['SDL_perl-1.19.2.tar.gz'],'size' => {'packed' => 21586,'unpacked' => 228804},'testers' => {},'uses' => ['Exporter','SDL::App::FPS','SDL::Event','SDL::OpenGL','SDL::OpenGL::Cube','SDL::Surface','constant','strict','vars']},'Games-QuizTaker-1.24.tar.gz' => {'author' => 'TSTANLEY','description' => 'Create and take your own quizzes and tests','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 292,'pod' => 72,'pod_errors' => 0,'total' => 364,'with_comments' => 5},'releases' => 17,'requires' => ['Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Fcntl' => 0,'Text::Wrap' => 0},'requires_recursive' => ['Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6975,'unpacked' => 17624},'testers' => {'pass' => 15},'uses' => ['Carp','Data::Dumper','Fcntl','Text::Wrap','strict','vars']},'Games-Resource-0.01.tar.gz' => {'author' => 'TELS','description' => 'open game resource files via standard paths','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 234,'pod' => 259,'pod_errors' => 0,'total' => 493,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 6236,'unpacked' => 17744},'testers' => {'fail' => 1,'pass' => 3,'tests' => '19'},'uses' => ['Archive::Zip','Carp','Exporter','File::Spec','strict','vars']},'Games-Rezrov-0.15.tar.gz' => {'author' => 'EDMONSON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9038,'pod' => 0,'pod_errors' => 0,'total' => 9038,'with_comments' => 1784},'releases' => 3,'size' => {'packed' => 125288,'unpacked' => 362331},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['$_[0]','5.004','Carp','Curses','Exporter','FileHandle','Games::Rezrov::GetKey','Games::Rezrov::GetSize','Games::Rezrov::Inliner','Games::Rezrov::MethodMaker','Games::Rezrov::QChunk','Games::Rezrov::Quetzal','Games::Rezrov::StoryFile','Games::Rezrov::ZConst','Games::Rezrov::ZDict','Games::Rezrov::ZHeader','Games::Rezrov::ZIO_Generic','Games::Rezrov::ZIO_Tools','Games::Rezrov::ZObject','Games::Rezrov::ZObjectCache','Games::Rezrov::ZObjectStatus','Games::Rezrov::ZProperty','Games::Rezrov::ZReceiver','Games::Rezrov::ZStatus','Games::Rezrov::ZText','POSIX','SelfLoader','Term::Cap','Term::ReadKey','Term::ReadLine','Tk','Tk::Font','Win32::Console','constant','integer','strict']},'Games-Rezrov-0.17.tar.gz' => {'author' => 'EDMONSON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10477,'pod' => 0,'pod_errors' => 0,'total' => 10477,'with_comments' => 2212},'releases' => 3,'size' => {'packed' => 144603,'unpacked' => 384752},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['5.004','Carp','Curses','Exporter','FileHandle','POSIX','SelfLoader','Term::Cap','Term::ReadKey','Term::ReadLine','Tk','Tk::Font','Win32::Console','constant','integer','strict']},'Games-Scrabble-0.99.tar.gz' => {'author' => 'CCZ','description' => '- please use Games::Literati, for a complete Literati/Scrabble resolver.','files' => [],'lines' => {'nonpod' => 86,'pod' => 54,'pod_errors' => 0,'total' => 140,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2339,'unpacked' => 4315},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','strict']},'Games-WordFind-0.02.tar.gz' => {'author' => 'AJOHNSON','description' => 'Generate word-find type puzzles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 384,'pod' => 54,'pod_errors' => 0,'total' => 438,'with_comments' => 40},'releases' => 1,'size' => {'packed' => 7739,'unpacked' => 21500},'testers' => {'pass' => 7},'uses' => ['AutoLoader','Exporter','strict','vars']},'Games-Worms-0.61.tar.gz' => {'author' => 'SBURKE','description' => '- alife simulator for Conway/Patterson/Beeler worms, etc.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1577,'pod' => 183,'pod_errors' => 0,'total' => 1760,'with_comments' => 242},'releases' => 2,'size' => {'packed' => 20129,'unpacked' => 68598},'testers' => {'pass' => 3},'uses' => ['5','Exporter','Getopt::Std','Tk','strict','vars']},'Gateway-0.42.tar.gz' => {'author' => 'RRA','description' => 'Mail/news gatewaying, moderation support','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 728,'pod' => 874,'pod_errors' => 0,'total' => 1602,'with_comments' => 0},'releases' => 3,'requires' => ['News-Article-1.27.tar.gz'],'requires_module' => {'News::Article' => '1.07'},'requires_recursive' => ['News-Article-1.27.tar.gz'],'size' => {'packed' => 76979,'unpacked' => 243946},'testers' => {'tests' => '0','unknown' => 9},'uses' => []},'GedNav-0.02.tar.gz' => {'author' => 'ROBF','description' => 'Perl extension for quick (& dirty) navigation of GEDCOM files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1176,'pod' => 26,'pod_errors' => 0,'total' => 1202,'with_comments' => 19},'releases' => 2,'requires' => ['CGI.pm-2.98.tar.gz','Data-Dumper-2.101.tar.gz','Roman-1.1.tar.gz','Text-Soundex-3.02.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI' => 0,'Cwd' => 0,'Data::Dumper' => 0,'File::Basename' => 0,'FileHandle' => 0,'GDBM_File' => 0,'POSIX' => 0,'Roman' => 0,'Text::Soundex' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Roman-1.1.tar.gz','Text-Soundex-3.02.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 99101,'unpacked' => 493405},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['Cwd','Date::Manip','Exporter','File::Basename','FileHandle','GDBM_File','POSIX','Text::Soundex','strict','vars']},'Gedcom-1.12.tar.gz' => {'author' => 'PJCJ','description' => 'a module to manipulate Gedcom genealogy files Version 1.12 - 2nd February 2003','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10677,'pod' => 1179,'pod_errors' => 1,'total' => 11856,'with_comments' => 325},'releases' => 13,'size' => {'packed' => 88655,'unpacked' => 412654},'testers' => {'pass' => 10},'uses' => ['5.005','CGI','Carp','Data::Dumper','Engine','Exporter','File::Basename','FileHandle','Symbol','Test','strict','vars']},'Gedcom-Date-0.01.tar.gz' => {'author' => 'PIJLL','description' => 'Perl class for interpreting dates in Gedcom files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 473,'pod' => 247,'pod_errors' => 0,'total' => 720,'with_comments' => 4},'releases' => 1,'requires' => ['DateTime-0.1402.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DateTime' => '0.13','Test::Simple' => '0.44'},'requires_recursive' => ['DateTime-0.1402.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 11795,'unpacked' => 39308},'testers' => {'pass' => 1},'uses' => ['Carp','DateTime','strict','vars']},'Genetics-0.03.tar.gz' => {'author' => 'SLMATH','description' => 'Perl modules for building genetic analysis applications.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10235,'pod' => 3558,'pod_errors' => 0,'total' => 13793,'with_comments' => 849},'releases' => 1,'size' => {'packed' => 125999,'unpacked' => 766722},'testers' => {'fail' => 2,'tests' => '4'},'uses' => ['5.004','5.006','Carp','DBI','Exporter','GD::Graph::Data','GD::Graph::bars','GD::Graph::colour','HTML::Template','Stone','XML::Writer','strict','vars']},'Geo-Coordinates-Convert-0.01.tar.gz' => {'author' => 'JPVIDAL','description' => 'Converts geographics coordinates to Lambert','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 128,'pod' => 51,'pod_errors' => 0,'total' => 179,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 2947,'unpacked' => 6878},'testers' => {},'uses' => ['5.006','strict','vars','warnings']},'Geo-Coordinates-DecimalDegrees-0.04.tar.gz' => {'author' => 'WALTMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 75,'pod_errors' => 0,'total' => 154,'with_comments' => 2},'releases' => 4,'size' => {'packed' => 3311,'unpacked' => 11162},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','strict','warnings']},'Geo-Coordinates-UTM-0.02.tar.gz' => {'author' => 'GRAHAMC','description' => 'Translation between  Lat Lon and UTM Coords','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 220,'pod' => 137,'pod_errors' => 0,'total' => 357,'with_comments' => 13},'releases' => 2,'size' => {'packed' => 6895,'unpacked' => 24142},'testers' => {'pass' => 3},'uses' => ['5.005','AutoLoader','Exporter','Math::Trig','strict','vars']},'Geo-CountryFlags-0.01.tar.gz' => {'author' => 'MIKER','description' => 'Ctry code to flag.gif from pub domain or dir','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 230,'pod' => 144,'pod_errors' => 1,'total' => 374,'with_comments' => 7},'releases' => 1,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::Simple' => '0'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 106819,'unpacked' => 156042},'testers' => {'pass' => 9},'uses' => ['strict','vars']},'Geo-Distance-0.05.tar.gz' => {'author' => 'BLUEFEET','description' => 'Calculate Distances and Closest Locations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 213,'pod' => 251,'pod_errors' => 0,'total' => 464,'with_comments' => 26},'releases' => 4,'size' => {'packed' => 8446,'unpacked' => 21394},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','Math::Trig','strict','warnings']},'Geo-Dymaxion-0.11.tar.gz' => {'author' => 'SDERLE','description' => 'Plot latitude/longitude on a Fuller Dymaxion(tm) map','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 796,'pod' => 112,'pod_errors' => 0,'total' => 908,'with_comments' => 16},'releases' => 2,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.4'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 9556,'unpacked' => 36705},'testers' => {'pass' => 2},'uses' => ['5.006','Exporter','Inline','strict','vars','warnings']},'Geo-E00-0.05.tar.gz' => {'author' => 'ZUMMO','description' => 'Perl extension for reading Esri-E00 formats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 555,'pod' => 390,'pod_errors' => 0,'total' => 945,'with_comments' => 64},'releases' => 3,'requires' => ['Class-Fields-0.16.tar.gz','Data-Dumper-2.101.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => 0,'base' => 0,'strict' => 0,'vars' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8951,'unpacked' => 26555},'testers' => {'pass' => 2},'uses' => ['Carp','IO::File','strict']},'Geo-GNUPlot_0.01.tar.gz' => {'author' => 'CARPENTER','description' => 'Perl extension for plotting position tracks onto a world map.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1329,'pod' => 401,'pod_errors' => 0,'total' => 1730,'with_comments' => 225},'releases' => 1,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO::File' => '1.08'},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 444854,'unpacked' => 1938632},'testers' => {'pass' => 9},'uses' => ['Carp','IO::File','strict','vars']},'Geo-IP-1.15.tar.gz' => {'author' => 'TJMATHER','description' => 'Look up country by IP Address','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 421,'pod' => 200,'pod_errors' => 0,'total' => 621,'with_comments' => 4},'releases' => 15,'size' => {'packed' => 10945,'unpacked' => 29418},'testers' => {},'uses' => ['DynaLoader','Exporter','POSIX','strict','vars']},'Geo-IP-PurePerl-1.10.tar.gz' => {'author' => 'TJMATHER','description' => 'Look up country by IP Address','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 173,'pod' => 90,'pod_errors' => 0,'total' => 263,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 14341,'unpacked' => 35874},'testers' => {'fail' => 3,'tests' => '32'},'uses' => ['Exporter','constant','strict','vars']},'Geo-IPfree-0.2.tar.gz' => {'author' => 'GMPASSOS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 396,'pod' => 122,'pod_errors' => 0,'total' => 518,'with_comments' => 74},'releases' => 2,'size' => {'packed' => 146195,'unpacked' => 245991},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','Memoize','Socket','strict']},'Geo-METAR-1.14.tar.gz' => {'author' => 'JZAWODNY','description' => 'Process Aviation Weather (METAR) Data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 983,'pod' => 246,'pod_errors' => 0,'total' => 1229,'with_comments' => 286},'releases' => 6,'size' => {'packed' => 12375,'unpacked' => 37430},'testers' => {'pass' => 11},'uses' => ['5.005','Carp','strict','vars']},'Geo-PostalCode-0.05.tar.gz' => {'author' => 'TJMATHER','description' => 'Find closest zipcodes, distance, latitude, and longitude.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 225,'pod' => 99,'pod_errors' => 0,'total' => 324,'with_comments' => 8},'releases' => 5,'size' => {'packed' => 5092,'unpacked' => 16063},'testers' => {'fail' => 6,'tests' => '15'},'uses' => ['DB_File','POSIX','constant','strict','vars']},'Geo-ShapeFile-2.40.tar.gz' => {'author' => 'JASONK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1572,'pod' => 316,'pod_errors' => 0,'total' => 1888,'with_comments' => 165},'releases' => 3,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'IO::File' => 0,'Math::Trig' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 282062,'unpacked' => 981618},'testers' => {'pass' => 1},'uses' => ['5.008','AutoLoader','Carp','Exporter','IO::File','Math::Trig','strict','warnings']},'Geo-TAF-1.04.tar.gz' => {'author' => 'DJK','description' => 'Decode METAR and TAF strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 776,'pod' => 227,'pod_errors' => 0,'total' => 1003,'with_comments' => 51},'releases' => 4,'size' => {'packed' => 12779,'unpacked' => 42167},'testers' => {'pass' => 11},'uses' => ['5.005','strict','vars']},'Geo-TigerLine-0.01.tar.gz' => {'author' => 'MSCHWERN','description' => 'TIGER/Line geographic data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5291,'pod' => 4088,'pod_errors' => 0,'total' => 9379,'with_comments' => 75},'releases' => 1,'requires' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Data-Dumper-2.101.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Carp::Assert' => 0,'Class::Accessor' => '0.15','Class::Data::Inheritable' => '0.02','Data::Dumper' => 0,'base' => 0,'strict' => 0,'vars' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 33911,'unpacked' => 336867},'testers' => {'pass' => 4},'uses' => ['','Carp','Carp::Assert','Class::Accessor','Class::Data::Inheritable','strict','vars']},'Geo-Walkabout-0.01.tar.gz' => {'author' => 'MSCHWERN','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 794,'pod' => 428,'pod_errors' => 0,'total' => 1222,'with_comments' => 24},'releases' => 1,'requires' => ['AnyLoader-0.04.tar.gz','Carp-Assert-0.17.tar.gz','Class-DBI-0.93.tar.gz','Class-Fields-0.16.tar.gz','DBD-Pg-1.22.tar.gz'],'requires_module' => {'AnyLoader' => '0.02','Carp::Assert' => '0.10','Class::DBI' => '0.23','DBD::Pg' => 0,'base' => 0},'requires_recursive' => ['AnyLoader-0.04.tar.gz','Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-ISA-0.32.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBD-Pg-1.22.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 41694,'unpacked' => 68224},'testers' => {},'uses' => ['AnyLoader','Carp::Assert','Class::DBI','strict','vars']},'Geo-Weather-1.32.tar.gz' => {'author' => 'MMACHADO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 487,'pod' => 184,'pod_errors' => 2,'total' => 671,'with_comments' => 55},'releases' => 13,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::UserAgent' => '1.73'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6952,'unpacked' => 22630},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','LWP::UserAgent','strict','vars']},'Geo-WeatherNOAA-4.37.tar.gz' => {'author' => 'MSOLOMON','description' => 'Current/forecast weather from NOAA','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 593,'pod' => 135,'pod_errors' => 0,'total' => 728,'with_comments' => 139},'releases' => 19,'requires' => ['Tie-IxHash-1.21.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::Simple' => 0,'LWP::UserAgent' => 0,'Tie::IxHash' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Tie-IxHash-1.21.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11000,'unpacked' => 30449},'testers' => {'pass' => 11},'uses' => ['Exporter','LWP::Simple','LWP::UserAgent','Text::Wrap','Tie::IxHash','strict','vars']},'Geo-WeatherNWS-1.03.tar.gz' => {'author' => 'MSLAGLE','description' => 'A simple way to get current weather data from the NWS.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 869,'pod' => 223,'pod_errors' => 0,'total' => 1092,'with_comments' => 101},'releases' => 10,'requires' => ['libnet-1.16.tar.gz'],'requires_module' => {'Net::FTP' => '2.50'},'requires_recursive' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9545,'unpacked' => 33418},'testers' => {'pass' => 12},'uses' => ['5.005_62','IO::Handle','LWP::UserAgent','Net::FTP','POSIX','strict','warnings']},'Geography-Countries-1.4.tar.gz' => {'author' => 'ABIGAIL','description' => '- 2-letter, 3-letter, and numerical codes for countries.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 507,'pod' => 111,'pod_errors' => 0,'total' => 618,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 9067,'unpacked' => 20159},'testers' => {'pass' => 16},'uses' => ['Exporter','constant','strict','vars']},'Geography-Countries-LatLong-0.9.tar.gz' => {'author' => 'LGODDARD','description' => 'List of mean latidue and longitude','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 360,'pod' => 132,'pod_errors' => 0,'total' => 492,'with_comments' => 8},'releases' => 2,'requires' => ['Geography-Countries-1.4.tar.gz'],'requires_module' => {'Geography::Countries' => '0.1'},'requires_recursive' => ['Geography-Countries-1.4.tar.gz'],'size' => {'packed' => 8231,'unpacked' => 19716},'testers' => {'pass' => 4},'uses' => ['Geography::Countries','strict','vars']},'Geography-Country-Utils-1.06.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Utilities for country-specific information','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 6551,'pod' => 111,'pod_errors' => 0,'total' => 6662,'with_comments' => 435},'releases' => 3,'requires' => ['Logfile-0.300.tar.gz','Time-Local-1.07.tar.gz'],'requires_module' => {'Net::Country' => 0,'Time::Local' => 0},'requires_recursive' => ['Logfile-0.300.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 52213,'unpacked' => 225873},'testers' => {'pass' => 1},'uses' => ['Exporter','Net::Country','Time::Local','strict','vars']},'Geography-NationalGrid-1.6.tar.gz' => {'author' => 'PKENT','description' => 'Base class to create an object for a point and to transform coordinate systems','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 903,'pod' => 317,'pod_errors' => 0,'total' => 1220,'with_comments' => 82},'releases' => 1,'size' => {'packed' => 13029,'unpacked' => 52846},'testers' => {'pass' => 4},'uses' => ['constant','strict','vars']},'Geography-USStates-0.12.tar.gz' => {'author' => 'DIONALM','description' => 'USA State Data','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 197,'pod' => 105,'pod_errors' => 0,'total' => 302,'with_comments' => 68},'releases' => 3,'size' => {'packed' => 4411,'unpacked' => 17995},'testers' => {'pass' => 3},'uses' => ['5.002','Exporter','strict']},'Geography_States-1.6.tgz' => {'author' => 'ABIGAIL','description' => 'Map states and provinces to their codes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 299,'pod' => 87,'pod_errors' => 0,'total' => 386,'with_comments' => 40},'releases' => 4,'size' => {'packed' => 5848,'unpacked' => 13111},'testers' => {'pass' => 9},'uses' => ['vars']},'Gestinanna-POF-0.04.tar.gz' => {'author' => 'JSMITH','description' => 'Gestinanna Persistant Object Framework','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 3809,'pod' => 1078,'pod_errors' => 0,'total' => 4887,'with_comments' => 231},'releases' => 4,'size' => {'packed' => 63535,'unpacked' => 294977},'testers' => {'pass' => 1},'uses' => ['','$class','Carp','Class::Accessor','Class::Container','Class::Fields','Data::Dumper','NEXT','Net::LDAP::Constant','Net::LDAP::Control::Sort','Net::LDAP::Entry','Params::Validate','fields','private','protected','public','strict','vars']},'Gestinanna-POF-Repository-0.01.tar.gz' => {'author' => 'JSMITH','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 2078,'pod' => 477,'pod_errors' => 0,'total' => 2555,'with_comments' => 157},'releases' => 1,'size' => {'packed' => 23973,'unpacked' => 90763},'testers' => {},'uses' => ['','$base_class','$class','$classes{$subclass}','.','Algorithm::Diff','Carp','Class::Container','Data::Dumper','Data::Serializer','Gestinanna::POF::Alzabo','Params::Validate','constant','strict']},'GetRc-0.23.tar.gz' => {'author' => 'KOZO','description' => 'A Module for reading configuration files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 385,'pod' => 195,'pod_errors' => 0,'total' => 580,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 5548,'unpacked' => 18423},'testers' => {'pass' => 4},'uses' => ['5.002','Carp','Exporter','Fcntl','File::Basename','IO::File','UNIVERSAL','strict','vars']},'GetWeb-1.11.tar.gz' => {'author' => 'RHNELSON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6570,'pod' => 0,'pod_errors' => 0,'total' => 6570,'with_comments' => 467},'releases' => 1,'size' => {'packed' => 79118,'unpacked' => 401988},'testers' => {'fail' => 9,'tests' => '99'},'uses' => ['5.002','AnyDBM_File','CGI::Base','CGI::Request','Carp','Cwd','Exporter','HTML::FormatText','HTML::LinkExtor','HTML::Parse','HTTP::Status','LWP::Debug','LWP::Protocol','LWP::UserAgent','MIME::Base64','MIME::Decoder','MIME::Entity','MIME::IO','MIME::Latin1','Mail::Address','Mail::Internet','Mail::Util','MailBot::Internet','Net::Domain','Net::SMTP','POSIX','URI::Escape','URI::URL','URI::URL::file','integer','strict','t::GT','vars']},'Getargs-Long-0.1.3.tar.gz' => {'author' => 'RAM','description' => 'Parses long function args f(-arg => value)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 739,'pod' => 304,'pod_errors' => 0,'total' => 1043,'with_comments' => 184},'releases' => 4,'requires' => ['Log-Agent-0.304.tar.gz'],'requires_module' => {'Log::Agent' => '0.105'},'requires_recursive' => ['Log-Agent-0.304.tar.gz'],'size' => {'packed' => 14277,'unpacked' => 48004},'testers' => {'fail' => 1,'pass' => 17,'tests' => '9'},'uses' => ['Data::Dumper','Exporter','Log::Agent','strict','vars']},'Getopt-ArgvFile-1.06.tgz' => {'author' => 'JSTENZEL','description' => 'Take options from files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 348,'pod' => 261,'pod_errors' => 0,'total' => 609,'with_comments' => 90},'releases' => 7,'requires' => ['Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Test::Harness' => '1.25','Test::More' => '0.11','Text::ParseWords' => '3.1'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11480,'unpacked' => 32721},'testers' => {'pass' => 11},'uses' => ['5.003','Carp','Cwd','Exporter','File::Basename','File::Spec::Functions','Text::ParseWords','strict']},'Getopt-Attribute-1.3.2.tar.gz' => {'author' => 'MARCEL','description' => 'Attribute wrapper for Getopt::Long','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 41,'pod' => 64,'pod_errors' => 0,'total' => 105,'with_comments' => 1},'releases' => 4,'requires' => ['Attribute-Handlers-0.78.tar.gz','Getopt-Long-2.33.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.7','Getopt::Long' => 0,'Test::More' => '0.42'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2601,'unpacked' => 6737},'testers' => {'fail' => 2,'pass' => 9},'uses' => ['5.006001','Attribute::Handlers','Getopt::Long']},'Getopt-Auto-1.00.tar.gz' => {'author' => 'SIMON','description' => 'Framework for command-line applications','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 227,'pod' => 83,'pod_errors' => 0,'total' => 310,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 5562,'unpacked' => 12357},'testers' => {'pass' => 6},'uses' => ['5.006','Carp','FindBin','Pod::Parser','strict','warnings']},'Getopt-AutoConf-1.06.tar.gz' => {'author' => 'DARREN','description' => '- use autoconf(1)-style options','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 146,'pod' => 136,'pod_errors' => 0,'total' => 282,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 6018,'unpacked' => 20660},'testers' => {'fail' => 2,'tests' => '15'},'uses' => ['Exporter','strict','vars']},'Getopt-CallingName-1.10.tar.gz' => {'author' => 'SRSHAH','description' => 'Script duties delegation based upon calling name','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 98,'pod' => 117,'pod_errors' => 0,'total' => 215,'with_comments' => 8},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5366,'unpacked' => 14869},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','English','Exporter','strict','warnings']},'Getopt-Casual-0.13.1.tar.gz' => {'author' => 'PHOTO','description' => 'A casual replacement for other Getopt modules and C<-s>.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 107,'pod' => 94,'pod_errors' => 0,'total' => 201,'with_comments' => 25},'releases' => 5,'size' => {'packed' => 6417,'unpacked' => 14474},'testers' => {'pass' => 8},'uses' => ['strict','vars']},'Getopt-Declare-1.09.tar.gz' => {'author' => 'DCONWAY','description' => 'An easy-to-use WYSIWYG command-line parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1979,'pod' => 1210,'pod_errors' => 0,'total' => 3189,'with_comments' => 84},'releases' => 5,'requires' => ['Text-Balanced-1.95.tar.gz'],'requires_module' => {'Text::Balanced' => 0},'requires_recursive' => ['Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 34724,'unpacked' => 106793},'testers' => {'pass' => 10},'uses' => ['Text::Balanced','Text::Tabs','UNIVERSAL','strict','vars']},'Getopt-ExPar-0.01.tar.gz' => {'author' => 'HLHAMILT','description' => 'Extended Parameters command line parser.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1037,'pod' => 285,'pod_errors' => 0,'total' => 1322,'with_comments' => 203},'releases' => 1,'size' => {'packed' => 18940,'unpacked' => 69960},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.002','English','Exporter','strict']},'Getopt-Function-0.017.tar.gz' => {'author' => 'MIKEDLR','description' => 'provide mixed options with help information','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 262,'pod' => 207,'pod_errors' => 0,'total' => 469,'with_comments' => 22},'releases' => 2,'requires' => ['Getopt-Mixed-1.008.tar.gz'],'requires_module' => {'Getopt::Mixed' => '1.006'},'requires_recursive' => ['Getopt-Mixed-1.008.tar.gz'],'size' => {'packed' => 13709,'unpacked' => 34939},'testers' => {'pass' => 4},'uses' => ['Carp','strict','vars']},'Getopt-GetArgs-1.03.tar.gz' => {'author' => 'BBB','description' => 'Enhanced argument passing to subroutines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 54,'pod_errors' => 0,'total' => 127,'with_comments' => 18},'releases' => 3,'size' => {'packed' => 3573,'unpacked' => 10462},'testers' => {'pass' => 7},'uses' => ['Exporter','strict','vars']},'Getopt-Janus-1.03.tar.gz' => {'author' => 'SBURKE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2178,'pod' => 334,'pod_errors' => 0,'total' => 2512,'with_comments' => 170},'releases' => 3,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 27857,'unpacked' => 91463},'testers' => {'pass' => 1},'uses' => ['5','Carp','Exporter','File::Basename','Tk::BrowseEntry','Tk::Button','Tk::Checkbutton','Tk::DialogBox','Tk::Entry','Tk::Frame','Tk::Menubutton','Tk::Pane','Tk::Text','strict','vars']},'Getopt-Long-2.33.tar.gz' => {'author' => 'JV','description' => 'Advanced handling of command line options','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1573,'pod' => 723,'pod_errors' => 0,'total' => 2296,'with_comments' => 265},'releases' => 12,'requires' => ['PodParser-1.23.tar.gz'],'requires_module' => {'Pod::Usage' => '1.14'},'requires_recursive' => ['File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 32479,'unpacked' => 105461},'testers' => {'pass' => 8},'uses' => ['5.004','Exporter','Pod::Usage','constant','strict','vars']},'Getopt-Mixed-1.008.tar.gz' => {'author' => 'CJM','description' => 'Supports both long and short options','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 540,'pod' => 214,'pod_errors' => 0,'total' => 754,'with_comments' => 180},'releases' => 2,'size' => {'packed' => 9856,'unpacked' => 29364},'testers' => {'pass' => 2,'tests' => '0','unknown' => 18},'uses' => ['5.000','Carp','Exporter']},'Getopt-Plus-0.95.tar.gz' => {'author' => 'FLUFFY','description' => 'Options wrapper with standard options, help system and more','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3335,'pod' => 1292,'pod_errors' => 1,'total' => 4627,'with_comments' => 317},'releases' => 6,'size' => {'packed' => 45120,'unpacked' => 187516},'testers' => {},'uses' => ['','5.00503','5.005_62','Carp','Class::MethodMaker','Config','Cwd','Data::Dumper','Env','Exporter','ExtUtils::MakeMaker','Fatal','Fcntl','File::Basename','File::Compare','File::Find','File::Path','File::Spec','File::Spec::Functions','File::Temp','FindBin','Getopt::Long','IO::File','IO::Pipe','IO::Select','IPC::Run','List::Util','Log::Info','POSIX','Pipeline::DataFlow','Pod::Select','Pod::Text','Pod::Usage','Term::ReadKey','Test','Text::Tabs','Text::Wrap','constant','happy','strict','test','vars','warnings']},'Getopt-Regex-0.03.tar.gz' => {'author' => 'JARW','description' => 'Option handling using regular expressions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 79,'pod_errors' => 0,'total' => 148,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 2994,'unpacked' => 6379},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['Exporter','strict']},'Getopt-Simple-1.46.tgz' => {'author' => 'RSAVAGE','description' => 'A simple-to-use interface to Getopt::Long','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 249,'pod' => 168,'pod_errors' => 0,'total' => 417,'with_comments' => 46},'releases' => 6,'size' => {'packed' => 6896,'unpacked' => 28004},'testers' => {'pass' => 1},'uses' => ['Exporter','Getopt::Long','strict','vars']},'Getopt-Tabular-0.3.tar.gz' => {'author' => 'GWARD','description' => 'Table-driven argument parsing with help text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1350,'pod' => 549,'pod_errors' => 0,'total' => 1899,'with_comments' => 250},'releases' => 3,'size' => {'packed' => 26453,'unpacked' => 80208},'testers' => {'pass' => 9},'uses' => ['Carp','Exporter','strict','vars']},'Getopt-Tiny-1.02.tar.gz' => {'author' => 'MUIR','description' => 'Table of references interface, auto usage()','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 179,'pod' => 90,'pod_errors' => 0,'total' => 269,'with_comments' => 15},'releases' => 2,'size' => {'packed' => 4817,'unpacked' => 14513},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'Getopt-constant-1.02.tar.gz' => {'author' => 'SBURKE','description' => '- set constants from command line options','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 221,'pod' => 214,'pod_errors' => 0,'total' => 435,'with_comments' => 28},'releases' => 2,'size' => {'packed' => 6543,'unpacked' => 17060},'testers' => {'pass' => 7},'uses' => ['5.003_96','constant','strict']},'Gettext-0.01.tar.gz' => {'author' => 'JBRIGGS','description' => 'Perl extension for emulating gettext-related API.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 85,'pod_errors' => 0,'total' => 229,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 2628,'unpacked' => 6822},'testers' => {'pass' => 9},'uses' => ['AutoLoader','Exporter','POSIX','locale','strict','vars']},'Gimp-1.211.tar.gz' => {'author' => 'MLEHMANN','description' => 'Perl extension for writing Gimp Extensions/Plug-ins/Load & Save-Handlers This is mostly a reference manual. For a quick intro, look at L<Gimp::Fu>. For more information, including tutorials, look at the Gimp-Perl pages at http://gimp.pages.de.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4457,'pod' => 1445,'pod_errors' => 4,'total' => 5902,'with_comments' => 222},'releases' => 69,'requires' => ['Data-Dumper-2.101.tar.gz','Gtk-Perl-0.7009.tar.gz','PDL-2.4.0.tar.gz','Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Data::Dumper' => 2,'Gtk' => '0.5','PDL' => '1.99','Parse::RecDescent' => '1.6'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Gtk-Perl-0.7009.tar.gz','PDL-2.4.0.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 272873,'unpacked' => 893584},'testers' => {'pass' => 4},'uses' => ['Carp','Config','DynaLoader','Exporter','Fcntl','File::Basename','Gimp::Config','Gtk','Pod::Html','Pod::Text','Socket','XSLoader','strict','subs','vars']},'Glade-Perl-0.61.tar.gz' => {'author' => 'DMUSGR','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 9808,'pod' => 774,'pod_errors' => 0,'total' => 10582,'with_comments' => 1562},'releases' => 21,'size' => {'packed' => 126148,'unpacked' => 544148},'testers' => {'pass' => 1},'uses' => ['5.000','Carp','Cwd','Data::Dumper','English','ExtUtils::MakeMaker','File::Basename','File::Copy','File::Path','Getopt::Std','Gnome','Gtk','Gtk::GladeXML','Gtk::Keysyms','POSIX','Test','Text::Wrap','Unicode::String','strict','vars']},'Glade-Perl-Two-0.01.tar.gz' => {'author' => 'DMUSGR','description' => 'Utility methods for Glade-Perl (and generated applications).','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 10003,'pod' => 429,'pod_errors' => 0,'total' => 10432,'with_comments' => 1784},'releases' => 1,'size' => {'packed' => 88177,'unpacked' => 415894},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.000','Carp','Cwd','Data::Dumper','ExtUtils::MakeMaker','File::Basename','File::Copy','File::Path','Getopt::Std','Gnome2','Gtk2','Gtk2::Button','Gtk2::Entry','Gtk2::FileSelection','Gtk2::GladeXML','Gtk2::HBox','Gtk2::HButtonBox','Gtk2::Image','Gtk2::Label','Gtk2::VBox','Gtk2::Window','POSIX','Test','Text::Wrap','XML::Parser','strict','subs','vars']},'Glib-0.90.tar.gz' => {'author' => 'MLEHMANN','description' => 'Perl wrappers for the GLib utility and Object libraries','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 241,'pod' => 228,'pod_errors' => 0,'total' => 469,'with_comments' => 56},'releases' => 3,'requires' => ['ExtUtils-Depends-0.101.tar.gz'],'requires_module' => {'ExtUtils::Depends' => '0.1'},'requires_recursive' => ['ExtUtils-Depends-0.101.tar.gz'],'size' => {'packed' => 71850,'unpacked' => 238578},'testers' => {},'uses' => ['5.008','Carp','DynaLoader','strict','warnings']},'GnaData-0.01.tar.gz' => {'author' => 'GNALABS','description' => 'Routines for converting formats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1504,'pod' => 97,'pod_errors' => 9,'total' => 1601,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 11791,'unpacked' => 39715},'testers' => {'fail' => 1,'pass' => 1,'tests' => '11'},'uses' => ['DBI','English','HTML::LinkExtor','HTTP::Cookies','HTTP::Request::Common','IO::File','IO::Handle','LWP::Protocol::https','LWP::UserAgent','Text::Wrapper','URI::URL','strict']},'Gnome-Sound-0.02.tar.gz' => {'author' => 'MSTRAT','description' => 'Perl extension for libgnome/gnome-sound (GNOME 1.x)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 71,'pod' => 55,'pod_errors' => 0,'total' => 126,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 3334,'unpacked' => 6767},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Errno','Exporter','strict','warnings']},'Gnome-StockIcons-1.4.2.tar.gz' => {'author' => 'WVDB','description' => 'Gnome 1.4 stock icons in XPM format','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5414,'pod' => 38,'pod_errors' => 0,'total' => 5452,'with_comments' => 2868},'releases' => 2,'requires' => ['Gtk-Perl-0.7009.tar.gz'],'requires_module' => {'Gtk' => '0'},'requires_recursive' => ['Gtk-Perl-0.7009.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 38213,'unpacked' => 149464},'testers' => {},'uses' => ['strict','vars']},'Gnome-URL-0.02.tar.gz' => {'author' => 'MSTRAT','description' => 'Perl extension for libgnome/gnome-url (GNOME 1.x)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 68,'pod' => 36,'pod_errors' => 0,'total' => 104,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 3080,'unpacked' => 5878},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Errno','Exporter','strict','warnings']},'Gnome2-0.28.tar.gz' => {'author' => 'MLEHMANN','description' => 'Perl interface to the 2.x series of the Gnome libraries','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 50,'pod_errors' => 0,'total' => 107,'with_comments' => 11},'releases' => 3,'requires' => ['Gtk2-0.90.tar.gz'],'requires_module' => {'Gtk2' => '0.24'},'requires_recursive' => ['ExtUtils-Depends-0.101.tar.gz','Glib-0.90.tar.gz','Gtk2-0.90.tar.gz'],'size' => {'packed' => 38248,'unpacked' => 141956},'testers' => {},'uses' => ['5.008','DynaLoader','Exporter','Gtk2','strict','warnings']},'Gnome2-Canvas-0.28.tar.gz' => {'author' => 'MLEHMANN','description' => 'Perl interface to the Gnome Canvas','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 50,'pod_errors' => 0,'total' => 107,'with_comments' => 11},'releases' => 3,'requires' => ['Gtk2-0.90.tar.gz'],'requires_module' => {'Gtk2' => '0.26'},'requires_recursive' => ['ExtUtils-Depends-0.101.tar.gz','Glib-0.90.tar.gz','Gtk2-0.90.tar.gz'],'size' => {'packed' => 51307,'unpacked' => 142540},'testers' => {},'uses' => ['5.008','DynaLoader','Exporter','Gnome2','Gtk2','strict','warnings']},'GnuPG-0.09.tar.gz' => {'author' => 'FRAJULAC','description' => 'Perl module interface to the GNU Privacy Guard.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1393,'pod' => 365,'pod_errors' => 0,'total' => 1758,'with_comments' => 221},'releases' => 7,'size' => {'packed' => 27834,'unpacked' => 91719},'testers' => {'fail' => 8},'uses' => ['Carp','Exporter','Fcntl','POSIX','Symbol','constant','strict','vars']},'GnuPG-Interface-0.33.tar.gz' => {'author' => 'FTOBIN','description' => 'Perl interface to GnuPG','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2058,'pod' => 975,'pod_errors' => 0,'total' => 3033,'with_comments' => 363},'releases' => 12,'requires' => ['Class-MethodMaker-1.10.tar.gz'],'requires_module' => {'Class::MethodMaker' => 1},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz'],'size' => {'packed' => 38494,'unpacked' => 149531},'testers' => {'fail' => 9,'pass' => 7,'tests' => '51'},'uses' => ['','AutoLoader','Carp','Class::Struct','English','Exporter','Fatal','Fcntl','File::Compare','IO::File','IO::Handle','IO::Seekable','POSIX','constant','strict','vars']},'GoXML-XQI-1.1.4.tar.gz' => {'author' => 'MATTMK','description' => 'Perl extension for the XML Query Interface at xqi.goxml.com.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 156,'pod' => 48,'pod_errors' => 0,'total' => 204,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 8787,'unpacked' => 23447},'testers' => {'pass' => 7},'uses' => ['Carp','Exporter','IO::Handle','Socket','strict','vars']},'Grapefruit-0.00105.tar.gz' => {'author' => 'BSMITH','description' => 'Pattern matching and reduction engine for a perl CAS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 605,'pod' => 44,'pod_errors' => 0,'total' => 649,'with_comments' => 67},'releases' => 5,'size' => {'packed' => 7916,'unpacked' => 23138},'testers' => {},'uses' => ['5.006','Carp','Exporter','Scalar::Util','YAML','overload','strict','warnings']},'Graph-0.005.tar.gz' => {'author' => 'JHI','description' => 'graphs and graph algorithms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2708,'pod' => 929,'pod_errors' => 1,'total' => 3637,'with_comments' => 145},'releases' => 8,'size' => {'packed' => 25332,'unpacked' => 105683},'testers' => {'fail' => 1,'pass' => 1,'tests' => '112'},'uses' => ['5.004_04','Carp','Graph','Graph::DFS','Graph::Edge','Graph::Element','strict','vars']},'Graph-0.20101.tar.gz' => {'author' => 'JHI','description' => 'graph operations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2271,'pod' => 979,'pod_errors' => 97,'total' => 3250,'with_comments' => 274},'releases' => 8,'requires' => ['Heap-0.50.tar.gz'],'requires_module' => {'Heap' => '0.01'},'requires_recursive' => ['Heap-0.50.tar.gz'],'size' => {'packed' => 18529,'unpacked' => 83859},'testers' => {'pass' => 33},'uses' => ['Exporter','Heap::Elem','Heap::Fibonacci','strict','vars']},'Graph-Bipartite-0.01.tar.gz' => {'author' => 'DETZOLD','description' => 'Graph algorithms on bipartite graphs.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 29,'pod_errors' => 0,'total' => 206,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 2489,'unpacked' => 5355},'testers' => {'pass' => 2},'uses' => ['5.005_62','Exporter','strict','warnings']},'Graph-Drawing-0.08.tar.gz' => {'author' => 'GENE','description' => 'Graph drawing functionality','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 609,'pod' => 467,'pod_errors' => 0,'total' => 1076,'with_comments' => 96},'releases' => 10,'requires' => ['GD-2.07.tar.gz','Graph-Weighted-0.09.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'GD' => 0,'Graph::Weighted' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','GD-2.07.tar.gz','Graph-0.20101.tar.gz','Graph-Weighted-0.09.tar.gz','Heap-0.50.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10403,'unpacked' => 36255},'testers' => {'pass' => 2},'uses' => ['Carp','GD','Graph::Weighted','constant','strict','vars']},'Graph-Kruskal-2.0.tar.gz' => {'author' => 'STBEY','description' => 'Kruskal Algorithm for Minimal Spanning Trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 296,'pod' => 152,'pod_errors' => 0,'total' => 448,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 4842,'unpacked' => 14006},'testers' => {'pass' => 7},'uses' => ['Carp','Exporter','strict','vars']},'Graph-ReadWrite-1.07.tar.gz' => {'author' => 'NEILB','description' => 'Base class for graph file format reader','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3005,'pod' => 782,'pod_errors' => 0,'total' => 3787,'with_comments' => 646},'releases' => 8,'requires' => ['Graph-0.20101.tar.gz','IO-1.20.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'requires_module' => {'Graph' => 0,'IO::File' => 0,'XML::Parser' => 0,'XML::Writer' => 0},'requires_recursive' => ['Graph-0.20101.tar.gz','Heap-0.50.tar.gz','IO-1.20.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 22335,'unpacked' => 94909},'testers' => {'fail' => 1,'pass' => 5,'tests' => '10'},'uses' => ['5.004','Carp','Graph','IO::File','XML::Parser','XML::Writer','constant','strict','vars']},'Graph-Weighted-0.09.tar.gz' => {'author' => 'GENE','description' => 'A weighted graph implementation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 323,'pod' => 153,'pod_errors' => 0,'total' => 476,'with_comments' => 48},'releases' => 12,'requires' => ['Graph-0.20101.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Graph' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Graph-0.20101.tar.gz','Heap-0.50.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6325,'unpacked' => 22464},'testers' => {'pass' => 1},'uses' => ['Carp','Graph::Directed','constant','strict','vars']},'GraphViz-1.8.tar.gz' => {'author' => 'LBROCARD','description' => 'Interface to the GraphViz graphing tool','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1713,'pod' => 951,'pod_errors' => 0,'total' => 2664,'with_comments' => 105},'releases' => 20,'requires' => ['Graph-0.20101.tar.gz','IPC-Run-0.75.tar.gz','Math-Bezier-0.01.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Graph' => 0,'IPC::Run' => '0.6','Math::Bezier' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Graph-0.20101.tar.gz','Heap-0.50.tar.gz','IPC-Run-0.75.tar.gz','Math-Bezier-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 113418,'unpacked' => 781132},'testers' => {'fail' => 1,'pass' => 7,'tests' => '55'},'uses' => ['5.000','Carp','Config','Graph::Directed','IPC::Run','Math::Bezier','Parse::RecDescent','Time::HiRes','XML::Twig','lib','re','strict','vars']},'GraphViz-DBI-0.02.tar.gz' => {'author' => 'TEEJAY','description' => 'graph database tables and relations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 74,'pod_errors' => 0,'total' => 209,'with_comments' => 5},'releases' => 2,'requires' => ['GraphViz-1.8.tar.gz'],'requires_module' => {'GraphViz' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','Heap-0.50.tar.gz','IPC-Run-0.75.tar.gz','Math-Bezier-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 46310,'unpacked' => 136552},'testers' => {'pass' => 1},'uses' => ['5.005_62','Carp','GraphViz','strict','warnings']},'GraphViz-Data-Structure-0.07.tar.gz' => {'author' => 'MCMAHON','description' => 'Visualise data structures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1067,'pod' => 393,'pod_errors' => 0,'total' => 1460,'with_comments' => 91},'releases' => 3,'requires' => ['Devel-Peek-0.96.tar.gz','GraphViz-1.8.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Devel::Peek' => 0,'GraphViz' => '1.3','Test::More' => 0},'requires_recursive' => ['Devel-Peek-0.96.tar.gz','File-Spec-0.82.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','Heap-0.50.tar.gz','IPC-Run-0.75.tar.gz','Math-Bezier-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 38705,'unpacked' => 197431},'testers' => {'fail' => 2,'tests' => '129'},'uses' => ['Carp','Devel::Peek','GraphViz','lib','strict']},'GraphViz-ISA-0.01.tar.gz' => {'author' => 'MARCEL','description' => 'Graphing @ISA hierarchies at run-time','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 80,'pod' => 62,'pod_errors' => 0,'total' => 142,'with_comments' => 1},'releases' => 1,'requires' => ['GraphViz-1.8.tar.gz'],'requires_module' => {'GraphViz' => '0.11'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','Heap-0.50.tar.gz','IPC-Run-0.75.tar.gz','Math-Bezier-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2988,'unpacked' => 6775},'testers' => {'pass' => 4},'uses' => ['5.005_62','Carp','GraphViz','strict','warnings']},'GraphViz-Makefile-1.11.tar.gz' => {'author' => 'SREZIC','description' => 'Create Makefile graphs using GraphViz','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 252,'pod' => 55,'pod_errors' => 0,'total' => 307,'with_comments' => 23},'releases' => 3,'requires' => ['GraphViz-1.8.tar.gz','Make-1.00.tar.gz'],'requires_module' => {'GraphViz' => 0,'Make' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','Heap-0.50.tar.gz','IPC-Run-0.75.tar.gz','Make-1.00.tar.gz','Math-Bezier-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5709,'unpacked' => 13779},'testers' => {'pass' => 1},'uses' => ['Getopt::Long','GraphViz','Make','strict','vars']},'GraphViz-Zone-0.01.tar.gz' => {'author' => 'CHRIS','description' => 'Perl interface to graphing hosts in BIND zone files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 38,'pod_errors' => 0,'total' => 107,'with_comments' => 8},'releases' => 1,'requires' => ['GraphViz-1.8.tar.gz'],'requires_module' => {'GraphViz' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','Heap-0.50.tar.gz','IPC-Run-0.75.tar.gz','Math-Bezier-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2613,'unpacked' => 4392},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['GraphViz','strict','vars']},'Graphics-ColorDeficiency-0.01.tar.gz' => {'author' => 'IAMCAL','description' => 'Color Deficiency Simulation','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1230,'pod' => 69,'pod_errors' => 0,'total' => 1299,'with_comments' => 0},'releases' => 1,'requires' => ['Graphics-ColorObject-0.3a2.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Graphics::ColorObject' => 0,'Test::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Graphics-ColorObject-0.3a2.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6849,'unpacked' => 40002},'testers' => {},'uses' => ['Graphics::ColorObject']},'Graphics-ColorNames-0.32.tar.gz' => {'author' => 'RRWO','description' => 'provides RGB values for standard color names','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1175,'pod' => 269,'pod_errors' => 0,'total' => 1444,'with_comments' => 16},'releases' => 9,'size' => {'packed' => 13026,'unpacked' => 51344},'testers' => {'pass' => 3},'uses' => ['5.005','Carp','integer','strict','vars','warnings']},'Graphics-ColorNames-Mozilla-0.11.tar.gz' => {'author' => 'XAVIER','description' => 'Mozilla, Netscape 6.0, Galeon (anything using Gecko) color names and equivalent RGB values','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 178,'pod' => 32,'pod_errors' => 0,'total' => 210,'with_comments' => 10},'releases' => 2,'requires' => ['Graphics-ColorNames-0.32.tar.gz'],'requires_module' => {'Graphics::ColorNames' => '0.3'},'requires_recursive' => ['Graphics-ColorNames-0.32.tar.gz'],'size' => {'packed' => 3082,'unpacked' => 8386},'testers' => {'pass' => 6},'uses' => ['5.005','integer','strict','vars','warnings']},'Graphics-ColorObject-0.3a2.tar.gz' => {'author' => 'AREIBENS','description' => 'A OO-Color Module.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1220,'pod' => 151,'pod_errors' => 1,'total' => 1371,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 10061,'unpacked' => 60075},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['POSIX','vars']},'Graphics-ColorPicker-0.09.tar.gz' => {'author' => 'MIKER','description' => 'WYSIWYG web browser HEX color selector','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1053,'pod' => 221,'pod_errors' => 0,'total' => 1274,'with_comments' => 161},'releases' => 4,'size' => {'packed' => 113600,'unpacked' => 202264},'testers' => {'pass' => 5},'uses' => ['Apache','AutoLoader','diagnostics','lib','strict','vars']},'Graphics-MNG-0.04.tar.gz' => {'author' => 'MOTT','description' => 'Perl I/F to the MNG library from Gerard Juyn','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1368,'pod' => 398,'pod_errors' => 0,'total' => 1766,'with_comments' => 121},'releases' => 8,'size' => {'packed' => 594123,'unpacked' => 2211694},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','FileHandle','strict','warnings']},'Graphics-RGBManipulate-0.01.tar.gz' => {'author' => 'SARGIE','description' => 'HSV adjustment tool for RGB colours','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 190,'pod' => 58,'pod_errors' => 0,'total' => 248,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 3259,'unpacked' => 7011},'testers' => {'pass' => 3},'uses' => ['strict']},'Graphics-Simple-0.04.tar.gz' => {'author' => 'LUKKA','description' => '- a simple , device-independent graphics API for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 746,'pod' => 268,'pod_errors' => 0,'total' => 1014,'with_comments' => 33},'releases' => 3,'size' => {'packed' => 13632,'unpacked' => 40787},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['Data::Dumper','Exporter','GSGtk','GSPS','Gnome','Graphics::Simple::Window','Gtk','Tk','Tk::Canvas','strict','vars']},'Graphics-VTK-3.2.001.tar.gz' => {'author' => 'CERNEY','description' => 'A Perl interface to Visualization ToolKit','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 11357,'pod' => 23717,'pod_errors' => 0,'total' => 35074,'with_comments' => 481},'releases' => 2,'size' => {'packed' => 606061,'unpacked' => 4359765},'testers' => {'fail' => 1},'uses' => ['5.004','5.006','AutoLoader','Carp','DynaLoader','Graphics::VTK','Graphics::VTK::Common','Graphics::VTK::Graphics','Graphics::VTK::Imaging','Graphics::VTK::Patented','Graphics::VTK::Tk','Math::Trig','Tk','Tk::Tree','Tk::Widget','strict','vars','warnings']},'Graphics-VTK-4.0.001.tar.gz' => {'author' => 'CERNEY','description' => 'A Perl interface to Visualization ToolKit','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 12263,'pod' => 25581,'pod_errors' => 0,'total' => 37844,'with_comments' => 568},'releases' => 2,'size' => {'packed' => 675226,'unpacked' => 4929719},'testers' => {},'uses' => ['5.004','5.006','AutoLoader','Carp','DynaLoader','Math::Trig','Tk','Tk::Derived','Tk::Frame','Tk::Tree','Tk::Widget','strict','vars','warnings']},'Gsl-0.03.tar.gz' => {'author' => 'LETO','description' => 'Perl Interface to The GNU Scientific Library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 143,'pod' => 73,'pod_errors' => 0,'total' => 216,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 8975,'unpacked' => 49339},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Gtk-0.1.16.tar.gz' => {'author' => 'KJALB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 227,'pod' => 0,'pod_errors' => 0,'total' => 227,'with_comments' => 21},'releases' => 17,'size' => {'packed' => 198834,'unpacked' => 889264},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','Gtk','Tie::Hash','strict','vars']},'Gtk-HandyCList-0.02.tar.gz' => {'author' => 'SIMON','description' => 'A more Perl-friendly Columned List','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 287,'pod' => 96,'pod_errors' => 0,'total' => 383,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 4289,'unpacked' => 11190},'testers' => {'fail' => 3,'pass' => 2},'uses' => ['Carp','Gnome','strict','vars']},'Gtk-Perl-0.7000.tar.gz' => {'author' => 'KJALB','description' => 'Bindings to the Gnome Desktop Toolkit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1889,'pod' => 38,'pod_errors' => 0,'total' => 1927,'with_comments' => 111},'releases' => 10,'size' => {'packed' => 353292,'unpacked' => 1424449},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['AutoLoader','Carp','Data::Dumper','DynaLoader','Exporter','File::Basename','Gnome::Types','Gtk','Gtk::GLArea::Constants','Gtk::GLArea::Types','Gtk::Gdk::ImlibImage','Gtk::GladeXML::Types','Gtk::HTML::Types','Gtk::Types','Gtk::XmHTML::Types','Tie::Hash','strict','vars']},'Gtk-Perl-0.7008.tar.gz' => {'author' => 'LUPUS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3374,'pod' => 5243,'pod_errors' => 0,'total' => 8617,'with_comments' => 185},'releases' => 10,'requires' => ['XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'requires_module' => {'XML::Parser' => 0,'XML::Writer' => 0},'requires_recursive' => ['XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 455977,'unpacked' => 1808519},'testers' => {'fail' => 1,'tests' => '0','unknown' => 3},'uses' => ['AutoLoader','Bonobo::Types','Carp','Cwd','Data::Dumper','DynaLoader','Exporter','File::Basename','Gnome','Gnome::Applet::Types','Gnome::Print::Types','Gnome::Print::TypesLazy','Gnome::Types','Gnome::TypesLazy','Gtk','Gtk::GLArea::Types','Gtk::Gdk::ImlibImage','Gtk::Gdk::Pixbuf','Gtk::Gdk::Pixbuf::Types','Gtk::GladeXML::Types','Gtk::HTML','Gtk::HTML::Types','Gtk::MozEmbed::Types','Gtk::Types','Gtk::TypesLazy','Gtk::XmHTML::Types','IO::File','LWP::Protocol::http','LWP::UserAgent','Tie::Array','Tie::Hash','URI','strict','vars']},'Gtk-Perl-0.7009.tar.gz' => {'author' => 'MLEHMANN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3376,'pod' => 5245,'pod_errors' => 0,'total' => 8621,'with_comments' => 187},'releases' => 10,'requires' => ['XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'requires_module' => {'XML::Parser' => 0,'XML::Writer' => 0},'requires_recursive' => ['XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 447432,'unpacked' => 1814414},'testers' => {},'uses' => ['AutoLoader','Bonobo::Types','Carp','Cwd','Data::Dumper','DynaLoader','Exporter','File::Basename','Gnome','Gnome::Applet::Types','Gnome::Print::Types','Gnome::Print::TypesLazy','Gnome::Types','Gnome::TypesLazy','Gtk::GLArea::Constants','Gtk::GLArea::Types','Gtk::Gdk::Pixbuf::Types','Gtk::GladeXML::Types','Gtk::HTML::Types','Gtk::LWP','Gtk::LWP::http','Gtk::MozEmbed::Types','Gtk::Types','Gtk::TypesLazy','Gtk::XmHTML::Types','Gtk::io','IO::File','LWP::Protocol::http','LWP::UserAgent','Tie::Array','Tie::Hash','URI','strict','vars']},'Gtk2-0.90.tar.gz' => {'author' => 'MLEHMANN','description' => 'Perl interface to the 2.x series of the Gimp Toolkit library','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 716,'pod' => 546,'pod_errors' => 0,'total' => 1262,'with_comments' => 97},'releases' => 3,'requires' => ['ExtUtils-Depends-0.101.tar.gz','Glib-0.90.tar.gz'],'requires_module' => {'ExtUtils::Depends' => '0.1','Glib' => undef},'requires_recursive' => ['ExtUtils-Depends-0.101.tar.gz','Glib-0.90.tar.gz'],'size' => {'packed' => 296845,'unpacked' => 1137552},'testers' => {},'uses' => ['5.008','Carp','DynaLoader','Exporter','Glib','IO::File','constant','strict','warnings']},'Gtk2-GladeXML-0.26.tar.gz' => {'author' => 'MLEHMANN','description' => 'Perl wrappers for the Gtk2::GladeXML utilities.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 68,'pod_errors' => 0,'total' => 212,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 17575,'unpacked' => 62665},'testers' => {},'uses' => ['5.008','DynaLoader','Gtk2','strict','warnings']},'Gtk2-Spell-1.00.tar.gz' => {'author' => 'MLEHMANN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 41,'pod' => 72,'pod_errors' => 0,'total' => 113,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 13558,'unpacked' => 37168},'testers' => {},'uses' => ['5.008','DynaLoader','Gtk2','strict','warnings']},'Guile-0.001.tar.gz' => {'author' => 'SAMTREGAR','description' => 'Perl interface to the Guile interpreter.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 284,'pod' => 1353,'pod_errors' => 2,'total' => 1637,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 28275,'unpacked' => 88165},'testers' => {},'uses' => ['5.6.1','Carp','Data::Dumper','DynaLoader','Exporter','Guile::__scm','Guile::alist','Guile::arbiters','Guile::async','Guile::backtrace','Guile::boolean','Guile::chars','Guile::continuations','Guile::coop_defs','Guile::debug','Guile::dynl','Guile::dynwind','Guile::environments','Guile::eq','Guile::error','Guile::eval','Guile::evalext','Guile::extensions','Guile::feature','Guile::filesys','Guile::fluids','Guile::fports','Guile::gc','Guile::gdb_interface','Guile::gdbint','Guile::gh','Guile::goops','Guile::gsubr','Guile::guardians','Guile::hash','Guile::hashtab','Guile::hooks','Guile::init','Guile::ioext','Guile::iselect','Guile::keywords','Guile::lang','Guile::list','Guile::load','Guile::macros','Guile::mallocs','Guile::modules','Guile::net_db','Guile::numbers','Guile::objects','Guile::objprop','Guile::options','Guile::pairs','Guile::ports','Guile::posix','Guile::print','Guile::procprop','Guile::procs','Guile::properties','Guile::ramap','Guile::random','Guile::rdelim','Guile::read','Guile::root','Guile::rw','Guile::scmconfig','Guile::scmsigs','Guile::script','Guile::simpos','Guile::smob','Guile::snarf','Guile::socket','Guile::sort','Guile::srcprop','Guile::stackchk','Guile::stacks','Guile::stime','Guile::strings','Guile::strop','Guile::strorder','Guile::strports','Guile::struct','Guile::symbols','Guile::tag','Guile::tags','Guile::threads','Guile::throw','Guile::unif','Guile::validate','Guile::values','Guile::variable','Guile::vectors','Guile::version','Guile::vports','Guile::weaks','strict','warnings']},'HH-Unispool-Config-0.2.tar.gz' => {'author' => 'ZOCCAV','description' => 'HollandHouse\' UNISPOOL configuration','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 22354,'pod' => 13619,'pod_errors' => 4,'total' => 35973,'with_comments' => 1952},'releases' => 1,'requires' => ['Error-0.15.tar.gz'],'requires_module' => {'Error' => 0},'requires_recursive' => ['Error-0.15.tar.gz'],'size' => {'packed' => 123851,'unpacked' => 1387551},'testers' => {'pass' => 3},'uses' => ['','5.006','AutoLoader','Error','Exporter','IO::File','POSIX','Sys::Hostname','Time::Local','strict','warnings']},'HPUX-FS_0.05.tar.gz' => {'author' => 'CWHITE','description' => 'Perl function to handle HPUX filesystem stats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 313,'pod' => 128,'pod_errors' => 0,'total' => 441,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 14483,'unpacked' => 69686},'testers' => {'pass' => 5},'uses' => ['5.006','AutoLoader','Carp','Exporter','Storable','strict','warnings']},'HPUX-Ioscan-1.002.tar.gz' => {'author' => 'DDUMONT','description' => 'Perl function to handle HPUX ioscan command','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 107,'pod_errors' => 0,'total' => 212,'with_comments' => 6},'releases' => 5,'size' => {'packed' => 3585,'unpacked' => 9131},'testers' => {'pass' => 8},'uses' => ['Carp','Exporter','FileHandle','strict','vars']},'HPUX-LVM_0.06.tar.gz' => {'author' => 'CWHITE','description' => 'Interface to HPUX\'s LVM volume manager','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1194,'pod' => 224,'pod_errors' => 0,'total' => 1418,'with_comments' => 201},'releases' => 1,'size' => {'packed' => 21117,'unpacked' => 98117},'testers' => {'pass' => 6},'uses' => ['5.006','AutoLoader','Carp','Exporter','Storable','strict','vars','warnings']},'HPUX-Pstat-1.01.tar.gz' => {'author' => 'SCHWENKE','description' => 'Perl wrapper for C<pstat()> functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 57,'pod_errors' => 0,'total' => 100,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 7980,'unpacked' => 30306},'testers' => {},'uses' => ['DynaLoader','strict','vars']},'HPUX-SDUX-0.03.tar.gz' => {'author' => 'ASARIH','description' => 'Helps Perl module management via SD-UX','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 332,'pod' => 53,'pod_errors' => 0,'total' => 385,'with_comments' => 65},'releases' => 3,'size' => {'packed' => 5309,'unpacked' => 12791},'testers' => {},'uses' => ['Carp','Config','Cwd','DirHandle','ExtUtils::MakeMaker','File::Copy','strict','vars']},'HTML-0.6.tar.gz' => {'author' => 'GAND','description' => 'Object-oriented way to build pages of HTML','files' => ['README'],'lines' => {'nonpod' => 2282,'pod' => 622,'pod_errors' => 0,'total' => 2904,'with_comments' => 594},'releases' => 1,'size' => {'packed' => 25761,'unpacked' => 104760},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.001','Carp','strict']},'HTML-ActiveLink-1.02.tar.gz' => {'author' => 'NWIGER','description' => 'Dynamically activate HTML links based on URL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 206,'pod' => 144,'pod_errors' => 0,'total' => 350,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 6179,'unpacked' => 20060},'testers' => {'pass' => 12},'uses' => ['5.004','Carp','strict','vars']},'HTML-Ballot-Trusting-0.2.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 398,'pod' => 309,'pod_errors' => 1,'total' => 707,'with_comments' => 55},'releases' => 4,'requires' => ['CGI.pm-2.98.tar.gz','HTML-EasyTemplate-0.986.tar.gz','HTML-Parser-3.28.tar.gz'],'requires_module' => {'CGI' => 1,'HTML::EasyTemplate' => '0.985','HTML::Entities' => 1},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','HTML-EasyTemplate-0.986.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10038,'unpacked' => 31632},'testers' => {'pass' => 4},'uses' => ['CGI','Carp','HTML::EasyTemplate','strict','warnings']},'HTML-BarChart-0.1.0.tgz' => {'author' => 'TAG','description' => 'Framework for Rendering HTML Bar Charts','files' => ['Makefile.PL'],'lines' => {'nonpod' => 84,'pod' => 40,'pod_errors' => 0,'total' => 124,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 1993,'unpacked' => 4379},'testers' => {'pass' => 3},'uses' => []},'HTML-BarGraph-0.5.tar.gz' => {'author' => 'PODGURSV','description' => 'generate multiset bar graphs with plain HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 729,'pod' => 248,'pod_errors' => 0,'total' => 977,'with_comments' => 43},'releases' => 1,'size' => {'packed' => 12017,'unpacked' => 106736},'testers' => {'pass' => 3},'uses' => ['Data::Dumper','Exporter','strict','vars']},'HTML-Breadcrumbs-0.03.tar.gz' => {'author' => 'GAVINC','description' => 'module to produce HTML \'breadcrumb trails\'.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 371,'pod' => 167,'pod_errors' => 0,'total' => 538,'with_comments' => 60},'releases' => 1,'size' => {'packed' => 8016,'unpacked' => 28105},'testers' => {'pass' => 4},'uses' => ['5.000','Carp','Exporter','File::Basename','strict','vars']},'HTML-Bricks-0.03.tar.gz' => {'author' => 'PETERMCD','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 1540,'pod' => 0,'pod_errors' => 0,'total' => 1540,'with_comments' => 340},'releases' => 1,'size' => {'packed' => 84551,'unpacked' => 339660},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['5.004','Apache::Constants','Apache::Cookie','Apache::File','Apache::Session::File','Carp','Data::Dumper','File::Basename','File::Copy','HTML::Bricks::Config','HTML::Mason','HTML::Mason::Component','HTML::Mason::Parser','HTML::Mason::Request','Image::Magick','strict','vars']},'HTML-CGIChecker-0.90.tar.gz' => {'author' => 'TRIPIE','description' => 'A Perl module to detect dangerous HTML code>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 590,'pod' => 298,'pod_errors' => 0,'total' => 888,'with_comments' => 66},'releases' => 2,'size' => {'packed' => 14389,'unpacked' => 43858},'testers' => {'pass' => 4},'uses' => ['Carp','strict','vars']},'HTML-CMTemplate-0.4.0.tar.gz' => {'author' => 'SHIBLON','description' => 'Generate text-based content from templates.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2363,'pod' => 643,'pod_errors' => 0,'total' => 3006,'with_comments' => 473},'releases' => 6,'size' => {'packed' => 65717,'unpacked' => 245719},'testers' => {'pass' => 4},'uses' => ['Cwd','File::Spec','File::stat','FileHandle','strict','vars']},'HTML-Calendar-Simple-0.04.tar.gz' => {'author' => 'STRYTOAST','description' => 'A simple html calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 269,'pod' => 185,'pod_errors' => 0,'total' => 454,'with_comments' => 14},'releases' => 4,'requires' => ['CGI.pm-2.98.tar.gz','Date-Simple-1.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'CGI' => '2.752','Date::Simple' => '1.03','Test::More' => '0.40'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Date-Simple-1.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6479,'unpacked' => 18768},'testers' => {'pass' => 6},'uses' => ['CGI','Date::Simple','overload','strict']},'HTML-CalendarMonth-1.09.tar.gz' => {'author' => 'MSISK','description' => 'Calendar Months as easy HTML::Element trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1136,'pod' => 280,'pod_errors' => 1,'total' => 1416,'with_comments' => 226},'releases' => 8,'requires' => ['HTML-Element-Extended-1.11.tar.gz'],'requires_module' => {'HTML::ElementTable' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','HTML-Element-Extended-1.11.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz'],'size' => {'packed' => 17690,'unpacked' => 121419},'testers' => {'pass' => 8},'uses' => ['Carp','Date::Calc','Date::Manip','HTML::ElementTable','strict','vars']},'HTML-CalendarMonthDB-1.01.tar.gz' => {'author' => 'MCVELLA','description' => 'Module Generating Persistant HTML Calendars','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 902,'pod' => 281,'pod_errors' => 0,'total' => 1183,'with_comments' => 53},'releases' => 2,'requires' => ['DBI-1.37.tar.gz','Date-Calc-5.3.tar.gz'],'requires_module' => {'DBI' => 0,'Date::Calc' => 0},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','DBI-1.37.tar.gz','Date-Calc-5.3.tar.gz'],'size' => {'packed' => 24322,'unpacked' => 96828},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['DBI','Date::Calc','strict']},'HTML-CalendarMonthSimple-1.23.tar.gz' => {'author' => 'STIGMATA','description' => 'Perl Module for Generating HTML Calendars','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 820,'pod' => 449,'pod_errors' => 0,'total' => 1269,'with_comments' => 38},'releases' => 23,'requires' => ['Date-Calc-5.3.tar.gz'],'requires_module' => {'Date::Calc' => 0},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Date-Calc-5.3.tar.gz'],'size' => {'packed' => 20519,'unpacked' => 75310},'testers' => {'pass' => 2},'uses' => ['Date::Calc','strict']},'HTML-Clean-0.8.tar.gz' => {'author' => 'LINDNER','description' => 'Cleans up HTML code for web browsers, not humans','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 547,'pod' => 143,'pod_errors' => 0,'total' => 690,'with_comments' => 92},'releases' => 3,'size' => {'packed' => 48157,'unpacked' => 181407},'testers' => {'pass' => 22},'uses' => ['5.004','AutoLoader','Carp','Exporter','Fcntl','IO','strict','vars']},'HTML-DOMbo-3.08.tar.gz' => {'author' => 'SBURKE','description' => '- convert between XML::DOM and {XML/HTML}::Element trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 251,'pod' => 50,'pod_errors' => 0,'total' => 301,'with_comments' => 76},'releases' => 1,'size' => {'packed' => 5226,'unpacked' => 12763},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['5','XML::DOM','XML::Element','strict','vars']},'HTML-DWT-2.08.tar.gz' => {'author' => 'WHYTEWOLF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 648,'pod' => 200,'pod_errors' => 0,'total' => 848,'with_comments' => 130},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'File::Basename' => 0,'File::Find' => 0,'Test::More' => '0.18','XML::Simple' => '1.08'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17489,'unpacked' => 60386},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','File::Basename','File::Find','XML::Simple','strict','vars']},'HTML-DWT-Simple-1.02.tar.gz' => {'author' => 'WHYTEWOLF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 272,'pod' => 97,'pod_errors' => 0,'total' => 369,'with_comments' => 77},'releases' => 3,'size' => {'packed' => 13926,'unpacked' => 40474},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'HTML-Defaultify-1.01.tar.gz' => {'author' => 'JSM','description' => 'Pre-fill default values into an existing HTML form','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 833,'pod' => 158,'pod_errors' => 0,'total' => 991,'with_comments' => 324},'releases' => 2,'size' => {'packed' => 14437,'unpacked' => 43753},'testers' => {'pass' => 13},'uses' => ['Carp','Exporter','strict','vars']},'HTML-Diff-0.54.tar.gz' => {'author' => 'EZRAKILTY','description' => 'Calculate savvy diff between two HTML chunks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 35,'pod_errors' => 0,'total' => 195,'with_comments' => 23},'releases' => 2,'size' => {'packed' => 6151,'unpacked' => 17696},'testers' => {'pass' => 3},'uses' => ['Algorithm::Diff','Exporter','strict']},'HTML-DublinCore-0.2.tar.gz' => {'author' => 'ESUMMERS','description' => 'Extract Dublin Core metadata from HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 397,'pod' => 254,'pod_errors' => 0,'total' => 651,'with_comments' => 15},'releases' => 6,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => 3},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 40656,'unpacked' => 164311},'testers' => {'pass' => 2},'uses' => ['','Carp','HTML::Parser','constant','strict','warnings']},'HTML-DynamicTemplate-0.94.tar.gz' => {'author' => 'BRIANNG','description' => 'HTML template class.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 89,'pod_errors' => 0,'total' => 266,'with_comments' => 13},'releases' => 3,'size' => {'packed' => 4147,'unpacked' => 16616},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'HTML-EP-0.1135.tar.gz' => {'author' => 'JWIED','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3898,'pod' => 1410,'pod_errors' => 0,'total' => 5308,'with_comments' => 333},'releases' => 35,'size' => {'packed' => 100677,'unpacked' => 359235},'testers' => {'fail' => 2,'pass' => 5,'tests' => '121'},'uses' => ['$ppm','5.004','Apache','CGI','Compress::Zlib','DBI','Data::Dumper','File::Find','HTML::EP','HTML::EP::Config','HTML::EP::Locale','HTML::EP::Session','HTML::Entities','MD5','MIME::Base64','Mail::Header','Mail::Internet','Net::SMTP','POSIX','Safe','Socket','Storable','Symbol','URI::Escape','strict','vars']},'HTML-EP-0.2011.tar.gz' => {'author' => 'JWIED','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3390,'pod' => 1567,'pod_errors' => 0,'total' => 4957,'with_comments' => 286},'releases' => 35,'size' => {'packed' => 106022,'unpacked' => 356227},'testers' => {'fail' => 9,'pass' => 2,'tests' => '131'},'uses' => ['$ppm','5.004','5.005','CGI::EncryptForm','Compress::Zlib','DBI','Data::Dumper','MD5','MIME::Base64','Mail::Header','Mail::Internet','Net::SMTP','Safe','Socket','Storable','Symbol','strict','vars']},'HTML-EP-Explorer-0.1006.tar.gz' => {'author' => 'JWIED','description' => 'Web driven browsing of a filesystem','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1029,'pod' => 415,'pod_errors' => 0,'total' => 1444,'with_comments' => 29},'releases' => 6,'size' => {'packed' => 23049,'unpacked' => 87468},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['Data::Dumper','Fcntl','HTML::EP::Explorer::Config','strict','vars']},'HTML-EP-Glimpse-0.05.tar.gz' => {'author' => 'JWIED','description' => 'A simple search engine using Glimpse','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 609,'pod' => 160,'pod_errors' => 0,'total' => 769,'with_comments' => 55},'releases' => 4,'size' => {'packed' => 20688,'unpacked' => 52349},'testers' => {'pass' => 1},'uses' => ['5.005','Data::Dumper','File::Find','HTML::EP::Glimpse::Config','POSIX','Safe','Symbol','strict','vars']},'HTML-ERuby-0.02.tar.gz' => {'author' => 'IKEBE','description' => 'ERuby processor for Perl.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 90,'pod_errors' => 0,'total' => 234,'with_comments' => 7},'releases' => 2,'requires' => ['Inline-Ruby-0.02.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Inline::Ruby' => 0,'Test::More' => '0.32'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Inline-Ruby-0.02.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3428,'unpacked' => 9128},'testers' => {},'uses' => ['Data::Dumper','IO::File','Inline::Ruby','strict','vars']},'HTML-EasyTags-1.071.tar.gz' => {'author' => 'DUNCAND','description' => 'Make well-formed XHTML or HTML 4 tags, lists','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 697,'pod' => 274,'pod_errors' => 6,'total' => 971,'with_comments' => 139},'releases' => 8,'size' => {'packed' => 21403,'unpacked' => 74201},'testers' => {'pass' => 5},'uses' => ['5.004','vars','warnings']},'HTML-EasyTemplate-0.986.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 370,'pod' => 283,'pod_errors' => 1,'total' => 653,'with_comments' => 75},'releases' => 14,'requires' => ['HTML-Parser-3.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Fcntl' => '0.1','HTML::TokeParser' => '2.19'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8712,'unpacked' => 25669},'testers' => {'pass' => 5},'uses' => ['Data::Dumper','Fcntl','HTML::TokeParser','strict','warnings']},'HTML-EasyTemplate-DirMenu-0.61.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 209,'pod' => 192,'pod_errors' => 1,'total' => 401,'with_comments' => 26},'releases' => 6,'size' => {'packed' => 5222,'unpacked' => 13351},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['Cwd','Data::Dumper','HTML::EasyTemplate','HTML::TokeParser','strict','warnings']},'HTML-EasyTemplate-PageMenu-0.1.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 112,'pod' => 121,'pod_errors' => 2,'total' => 233,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 3478,'unpacked' => 7500},'testers' => {'pass' => 3},'uses' => ['Cwd','HTML::TokeParser','URI::Escape','strict','warnings']},'HTML-Element-Extended-1.11.tar.gz' => {'author' => 'MSISK','description' => 'Graft HTML strings onto an HTML::Element','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1477,'pod' => 373,'pod_errors' => 0,'total' => 1850,'with_comments' => 331},'releases' => 6,'requires' => ['Data-Dumper-2.101.tar.gz','HTML-Tree-3.17.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'HTML::Element' => '3.01'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz'],'size' => {'packed' => 17919,'unpacked' => 54573},'testers' => {'pass' => 10},'uses' => ['Carp','Data::Dumper','HTML::Element','Tie::Array','strict','vars']},'HTML-Embperl-1.2.1.tar.gz' => {'author' => 'GRICHTER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4645,'pod' => 6701,'pod_errors' => 3,'total' => 11346,'with_comments' => 191},'releases' => 12,'size' => {'packed' => 256739,'unpacked' => 1120490},'testers' => {'fail' => 1,'pass' => 6},'uses' => ['Apache::Session','CGI','Cwd','DynaLoader','Exporter','HTML::Embperl','HTML::Embperl::Session','LWP::UserAgent','Net::SMTP','Safe','constant','strict','vars']},'HTML-Embperl-1.3.6.tar.gz' => {'author' => 'GRICHTER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6585,'pod' => 9023,'pod_errors' => 0,'total' => 15608,'with_comments' => 276},'releases' => 12,'requires' => ['File-Spec-0.82.tar.gz'],'requires_module' => {'File::Spec' => '0.8'},'requires_recursive' => ['File-Spec-0.82.tar.gz'],'size' => {'packed' => 357623,'unpacked' => 1551758},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Apache::Constants','Apache::Session','CGI','Cwd','Devel::Symdump','DynaLoader','Exporter','File::Basename','File::Spec','HTML::Embperl','HTML::Embperl::Module','LWP::UserAgent','Net::SMTP','Safe','Text::ParseWords','constant','strict','vars']},'HTML-Encoding-0.03.tar.gz' => {'author' => 'BJOERN','description' => 'Determine the encoding of (X)HTML documents','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 302,'pod' => 113,'pod_errors' => 0,'total' => 415,'with_comments' => 52},'releases' => 3,'size' => {'packed' => 6297,'unpacked' => 16300},'testers' => {'pass' => 8},'uses' => ['5.006','Exporter','HTML::HeadParser','UNIVERSAL','constant','strict','warnings']},'HTML-Entities-ImodePictogram-0.06.tar.gz' => {'author' => 'MIYAGAWA','description' => 'encode / decode i-mode pictogram','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 155,'pod' => 182,'pod_errors' => 0,'total' => 337,'with_comments' => 3},'releases' => 5,'size' => {'packed' => 5257,'unpacked' => 15216},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'HTML-FillInForm-1.02.tar.gz' => {'author' => 'TJMATHER','description' => 'Fill in HTML forms, separating HTML and code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 330,'pod' => 164,'pod_errors' => 0,'total' => 494,'with_comments' => 37},'releases' => 32,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => '3.26'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 9821,'unpacked' => 35421},'testers' => {'pass' => 2},'uses' => ['Carp','HTML::Parser','integer','strict','vars']},'HTML-FormEngine-0.7.4.tar.gz' => {'author' => 'MORNI','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1852,'pod' => 839,'pod_errors' => 0,'total' => 2691,'with_comments' => 218},'releases' => 4,'requires' => ['Clone-0.13.tar.gz','Date-Pcalc-1.2.tar.gz','Hash-Merge-0.07.tar.gz','gettext-1.01.tar.gz'],'requires_module' => {'Clone' => '0.13','Date::Pcalc' => '1.2','Hash::Merge' => '0.07','Locale::gettext' => '1.01'},'requires_recursive' => ['Clone-0.13.tar.gz','Date-Pcalc-1.2.tar.gz','File-Spec-0.82.tar.gz','Hash-Merge-0.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','gettext-1.01.tar.gz'],'size' => {'packed' => 30865,'unpacked' => 108191},'testers' => {'pass' => 3},'uses' => ['5.004','Clone','Date::Pcalc','Hash::Merge','Locale::gettext','strict','vars']},'HTML-FormEngine-DBSQL-0.2.1.tar.gz' => {'author' => 'MORNI','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1368,'pod' => 718,'pod_errors' => 0,'total' => 2086,'with_comments' => 87},'releases' => 3,'requires' => ['Clone-0.13.tar.gz','Date-Pcalc-1.2.tar.gz','HTML-FormEngine-0.7.4.tar.gz','Hash-Merge-0.07.tar.gz','gettext-1.01.tar.gz'],'requires_module' => {'Clone' => '0.13','Date::Pcalc' => '1.2','HTML::FormEngine' => '','Hash::Merge' => '0.07','Locale::gettext' => '1.01'},'requires_recursive' => ['Clone-0.13.tar.gz','Date-Pcalc-1.2.tar.gz','File-Spec-0.82.tar.gz','HTML-FormEngine-0.7.4.tar.gz','Hash-Merge-0.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','gettext-1.01.tar.gz'],'size' => {'packed' => 27548,'unpacked' => 89343},'testers' => {'pass' => 9},'uses' => ['5.004','Carp','Clone','Digest::MD5','HTML::FormEngine','Hash::Merge','Locale::gettext','strict','vars']},'HTML-FormHighlight-0.03.tar.gz' => {'author' => 'ADEO','description' => 'Highlights fields in an HTML form.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 260,'pod' => 234,'pod_errors' => 2,'total' => 494,'with_comments' => 79},'releases' => 3,'size' => {'packed' => 5140,'unpacked' => 17517},'testers' => {'pass' => 7},'uses' => ['Carp','HTML::Parser','strict']},'HTML-FormParser-0.11.tar.gz' => {'author' => 'SDRABBLE','description' => 'Do things with the contents of HTML forms.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 73,'pod_errors' => 0,'total' => 165,'with_comments' => 4},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 3327,'unpacked' => 7325},'testers' => {'pass' => 31},'uses' => ['HTML::Parser','strict']},'HTML-FormTemplate-2.021.tar.gz' => {'author' => 'DUNCAND','description' => 'Make data-defined persistant forms, reports','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2076,'pod' => 935,'pod_errors' => 30,'total' => 3011,'with_comments' => 344},'releases' => 8,'requires' => ['CGI-MultiValuedHash-1.081.tar.gz','Class-ParamParser-1.041.tar.gz','Data-MultiValuedHash-1.081.tar.gz','HTML-EasyTags-1.071.tar.gz'],'requires_module' => {'CGI::MultiValuedHash' => '1.081','Class::ParamParser' => '1.041','Data::MultiValuedHash' => '1.081','HTML::EasyTags' => '1.071'},'requires_recursive' => ['CGI-MultiValuedHash-1.081.tar.gz','Class-ParamParser-1.041.tar.gz','Data-MultiValuedHash-1.081.tar.gz','HTML-EasyTags-1.071.tar.gz'],'size' => {'packed' => 36551,'unpacked' => 136109},'testers' => {'pass' => 11},'uses' => ['5.004','CGI::MultiValuedHash','Class::ParamParser','Data::MultiValuedHash','HTML::EasyTags','vars','warnings']},'HTML-FormWizard-0.1.09.tar.gz' => {'author' => 'NEVES','description' => 'Forms HTML made simple.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1064,'pod' => 451,'pod_errors' => 0,'total' => 1515,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 11494,'unpacked' => 40294},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'HTML-Format-2.03.tar.gz' => {'author' => 'SBURKE','description' => 'Format HTML as PostScript','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2614,'pod' => 342,'pod_errors' => 0,'total' => 2956,'with_comments' => 269},'releases' => 6,'requires' => ['Font-AFM-1.18.tar.gz','HTML-Tree-3.17.tar.gz'],'requires_module' => {'Font::AFM' => '1.17','HTML::Element' => '3.15'},'requires_recursive' => ['Font-AFM-1.18.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz'],'size' => {'packed' => 23008,'unpacked' => 78839},'testers' => {'pass' => 9},'uses' => ['5','Carp','Data::Dumper','HTML::TreeBuilder','UNIVERSAL','integer','strict','vars']},'HTML-FromANSI-1.00.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Mark up ANSI sequences as HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 84,'pod_errors' => 0,'total' => 245,'with_comments' => 13},'releases' => 3,'requires' => ['HTML-Parser-3.28.tar.gz','Term-VT102-0.78.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTML::Entities' => '0.01','Term::VT102' => '0.01','Test::More' => '0.11'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Term-VT102-0.78.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5270,'unpacked' => 13730},'testers' => {'pass' => 9},'uses' => ['Exporter','HTML::Entities','Term::VT102','strict','vars']},'HTML-FromText-1.005.tar.gz' => {'author' => 'GDR','description' => 'Mark up text as HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 427,'pod' => 309,'pod_errors' => 0,'total' => 736,'with_comments' => 112},'releases' => 2,'size' => {'packed' => 12582,'unpacked' => 39991},'testers' => {'pass' => 22},'uses' => ['5.004','Carp','Exporter','Text::Tabs','strict','vars']},'HTML-GenToc-2.02.tar.gz' => {'author' => 'RUBYKAT','description' => 'generate table of contents for HTML docs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1238,'pod' => 552,'pod_errors' => 9,'total' => 1790,'with_comments' => 174},'releases' => 9,'requires' => ['Data-Dumper-2.101.tar.gz','ExtUtils-configPL-1.1.tar.gz','Getopt-Long-2.33.tar.gz','HTML-SimpleParse-0.12.tar.gz','PodParser-1.23.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'ExtUtils::configPL' => 0,'Getopt::Long' => 0,'HTML::SimpleParse' => '0.1','Pod::Usage' => 0,'Test::Simple' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','ExtUtils-configPL-1.1.tar.gz','File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Getopt-Long-2.33.tar.gz','HTML-SimpleParse-0.12.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 26307,'unpacked' => 101465},'testers' => {'pass' => 10},'uses' => ['5.005_03','Data::Dumper','Exporter','HTML::SimpleParse','strict','vars']},'HTML-HTMLDoc-0.06.tar.gz' => {'author' => 'MFRANKL','description' => 'Perl interface to the htmldoc programm for producing PDF-Files from HTML-Content','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 841,'pod' => 277,'pod_errors' => 0,'total' => 1118,'with_comments' => 227},'releases' => 2,'size' => {'packed' => 7901,'unpacked' => 25408},'testers' => {'pass' => 1},'uses' => ['5.006','IO::File','IPC::Open3','strict','vars','warnings']},'HTML-Hard-Disk-0.2.1.tar.gz' => {'author' => 'SHLOMIF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 302,'pod' => 45,'pod_errors' => 0,'total' => 347,'with_comments' => 7},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 3717,'unpacked' => 9733},'testers' => {'pass' => 2},'uses' => ['File::Copy','File::Find','HTML::TokeParser','strict','vars']},'HTML-HashTable-0.6.tar.gz' => {'author' => 'SKUD','description' => 'Create an HTML table from a Perl hash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 60,'pod_errors' => 1,'total' => 193,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 3031,'unpacked' => 6776},'testers' => {'pass' => 5},'uses' => ['5.005','Exporter','strict']},'HTML-Highlight-0.20.tar.gz' => {'author' => 'TRIPIE','description' => 'A module to highlight words or patterns in HTML documents>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 234,'pod' => 161,'pod_errors' => 1,'total' => 395,'with_comments' => 11},'releases' => 2,'size' => {'packed' => 5353,'unpacked' => 14426},'testers' => {'pass' => 4},'uses' => ['Carp','locale','strict','vars']},'HTML-Index-0.15.tar.gz' => {'author' => 'AWRIGLEY','description' => 'Perl modules for creating and searching an index of HTML files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1066,'pod' => 319,'pod_errors' => 0,'total' => 1385,'with_comments' => 105},'releases' => 10,'requires' => ['BerkeleyDB-0.23.tar.gz','Carp-Assert-0.17.tar.gz','Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tree-3.17.tar.gz','Lingua-Stem-0.60.tar.gz','Text-Soundex-3.02.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'BerkeleyDB' => 0,'Carp' => 0,'Carp::Assert' => 0,'Class::Struct' => 0,'Compress::Zlib' => 0,'Data::Dumper' => 0,'Fcntl' => 0,'File::Path' => 0,'HTML::Entities' => 0,'HTML::TreeBuilder' => 0,'Lingua::Stem' => 0,'Text::Soundex' => 0},'requires_recursive' => ['BerkeleyDB-0.23.tar.gz','Carp-Assert-0.17.tar.gz','Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-German-0.03.tar.gz','Text-Soundex-3.02.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14463,'unpacked' => 53520},'testers' => {'pass' => 1},'uses' => ['BerkeleyDB','Carp','Class::Struct','Compress::Zlib','Data::Dumper','Exporter','Fcntl','File::Path','Getopt::Long','HTML::Entities','HTML::TreeBuilder','Lingua::Stem','Text::Soundex','strict','vars','warnings']},'HTML-KTemplate-1.21.tar.gz' => {'author' => 'KASPER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 771,'pod' => 445,'pod_errors' => 0,'total' => 1216,'with_comments' => 102},'releases' => 7,'size' => {'packed' => 16743,'unpacked' => 60192},'testers' => {'pass' => 2},'uses' => ['Carp','File::Spec','strict','vars']},'HTML-LBI-2.00.tar.gz' => {'author' => 'WHYTEWOLF','description' => 'DreamWeaver HTML Library Module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 202,'pod' => 55,'pod_errors' => 0,'total' => 257,'with_comments' => 68},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'File::Basename' => 0,'File::Find' => 0,'Test::More' => '0.18'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9973,'unpacked' => 28038},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','File::Basename','File::Find','strict','vars']},'HTML-LinkAdd-0.12.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 70,'pod' => 77,'pod_errors' => 1,'total' => 147,'with_comments' => 11},'releases' => 2,'size' => {'packed' => 2675,'unpacked' => 5066},'testers' => {'pass' => 4},'uses' => ['HTML::TokeParser','strict','warnings']},'HTML-LinkExtractor-0.07.tar.gz' => {'author' => 'PODMASTER','description' => 'Extract links from an HTML document','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 327,'pod' => 240,'pod_errors' => 0,'total' => 567,'with_comments' => 36},'releases' => 4,'requires' => ['HTML-TokeParser-Simple-2.1.tar.gz'],'requires_module' => {'HTML::TokeParser::Simple' => '1.3'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-TokeParser-Simple-2.1.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7535,'unpacked' => 21126},'testers' => {'pass' => 4},'uses' => ['Carp','Data::Dumper','HTML::TokeParser::Simple','URI','strict','vars']},'HTML-Links-Localize-0.2.4.tar.gz' => {'author' => 'SHLOMIF','description' => 'Convert HTML Files to be used on a hard disk','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 302,'pod' => 45,'pod_errors' => 0,'total' => 347,'with_comments' => 7},'releases' => 3,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 3829,'unpacked' => 9936},'testers' => {'pass' => 2},'uses' => ['File::Copy','File::Find','HTML::TokeParser','strict','vars']},'HTML-Lint-1.22.tar.gz' => {'author' => 'PETDANCE','description' => 'check for HTML errors in a string or file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 763,'pod' => 428,'pod_errors' => 0,'total' => 1191,'with_comments' => 51},'releases' => 17,'requires' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Find' => 0,'HTML::Parser' => '3.20','HTML::Tagset' => '3.03','Test::Builder' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 58005,'unpacked' => 207305},'testers' => {'pass' => 3},'uses' => ['Exporter','HTML::Entities','HTML::Parser','HTML::Tagset','Test::Builder','constant','strict','vars']},'HTML-Lister-0_5.tar.gz' => {'author' => 'DODGER','description' => 'Multidimensional Structure to HTML List Converter','files' => [],'lines' => {'nonpod' => 179,'pod' => 99,'pod_errors' => 0,'total' => 278,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 6968,'unpacked' => 36752},'testers' => {'pass' => 4},'uses' => []},'HTML-LoL-1.3.tar.gz' => {'author' => 'BOBG','description' => 'Construct HTML from Perl data structures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 264,'pod' => 98,'pod_errors' => 0,'total' => 362,'with_comments' => 7},'releases' => 4,'requires' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'requires_module' => {'HTML::Entities' => '1.18','HTML::Tagset' => '3.02'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 4777,'unpacked' => 14370},'testers' => {'pass' => 9},'uses' => ['Exporter','HTML::Entities','HTML::Tagset','constant','strict','vars']},'HTML-Macro-1.21.tgz' => {'author' => 'SOKOLOV','description' => 'process HTML templates with loops, conditionals, macros and more!','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1238,'pod' => 260,'pod_errors' => 0,'total' => 1498,'with_comments' => 140},'releases' => 2,'size' => {'packed' => 18989,'unpacked' => 59568},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Cwd','Exporter','strict','vars']},'HTML-Mason-1.05.tar.gz' => {'author' => 'JSWARTZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9272,'pod' => 3740,'pod_errors' => 4,'total' => 13012,'with_comments' => 1170},'releases' => 42,'requires' => ['Data-Dumper-2.101.tar.gz','MLDBM-2.01.tar.gz','Params-Validate-0.64.tar.gz'],'requires_module' => {'Data::Dumper' => '2.08','MLDBM' => 2,'Params::Validate' => '0.04'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Data-Dumper-2.101.tar.gz','MLDBM-2.01.tar.gz','Params-Validate-0.64.tar.gz'],'size' => {'packed' => 284995,'unpacked' => 924654},'testers' => {'fail' => 2,'pass' => 12,'tests' => '92'},'uses' => ['5.003','5.004','Apache','Apache::Constants','Apache::Request','Apache::Status','Carp','Cwd','Data::Dumper','Exporter','Fcntl','File::Basename','File::Copy','File::Find','File::Path','Getopt::Long','Getopt::Std','HTML::Mason','HTML::Mason::ApacheHandler','HTML::Mason::Commands','HTML::Mason::Component','HTML::Mason::Component::FileBased','HTML::Mason::Component::Subcomponent','HTML::Mason::Config','HTML::Mason::Interp','HTML::Mason::Request','HTML::Mason::Resolver','HTML::Mason::Resolver::File','HTML::Mason::Tools','HTML::Mason::Utils','POSIX','Params::Validate','mod','strict','vars']},'HTML-Mason-1.22.tar.gz' => {'author' => 'DROLSKY','description' => 'Build sites from modular Perl/HTML blocks','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 11044,'pod' => 5670,'pod_errors' => 7,'total' => 16714,'with_comments' => 1073},'releases' => 42,'size' => {'packed' => 316154,'unpacked' => 1168572},'testers' => {'pass' => 3},'uses' => ['','%s','5.005','Apache','Apache::Constants','Apache::Request','CGI','Class::Container','Config','Cwd','Exporter','File::Basename','File::Path','File::Spec','Getopt::Long','Params::Validate','Scalar::Util','constant','strict','vars']},'HTML-Menu-Hierarchical-0.10.tar.gz' => {'author' => 'DOWENS','description' => 'HTML Hierarchical Menu Generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1099,'pod' => 427,'pod_errors' => 0,'total' => 1526,'with_comments' => 79},'releases' => 9,'size' => {'packed' => 13028,'unpacked' => 60307},'testers' => {'pass' => 4},'uses' => ['Carp','strict','vars']},'HTML-Merge-3.41.tar.gz' => {'author' => 'RAZINF','description' => 'Embedded HTML/SQL/Perl system by Raz Information Systems.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10418,'pod' => 1834,'pod_errors' => 6,'total' => 12252,'with_comments' => 630},'releases' => 10,'requires' => ['DBD-SQLite-0.25.tar.gz','DBI-1.37.tar.gz','Term-ReadLine-Gnu-1.14.tar.gz'],'requires_module' => {'DBD::SQLite' => 0,'DBI' => 0,'Term::ReadLine::Gnu' => 0},'requires_recursive' => ['DBD-SQLite-0.25.tar.gz','DBI-1.37.tar.gz','Term-ReadLine-Gnu-1.14.tar.gz'],'size' => {'packed' => 120415,'unpacked' => 553373},'testers' => {},'uses' => ['CGI','Carp','Config','Cwd','DBI','Date::Format','Exporter','File::Find','HTML::Merge::Ext','HTTP::Date','HTTP::Request::Common','IO::Socket','LWP','POSIX','Symbol','Term::Cap','Tie::Handle','Win32::Console','strict','subs','vars']},'HTML-Munger-0.01.tar.gz' => {'author' => 'DLOWE','description' => 'Module which simplifies the creation of web filters.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 55,'pod_errors' => 0,'total' => 229,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 3349,'unpacked' => 8126},'testers' => {'pass' => 7},'uses' => ['HTML::Parser','integer','strict','vars']},'HTML-Myasp-0.01.tar.gz' => {'author' => 'HANSPOO','description' => 'Generate HTML pages based on Templates. JATP (Just Another Template Parser).','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 156,'pod_errors' => 0,'total' => 272,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 4606,'unpacked' => 9962},'testers' => {'pass' => 8},'uses' => ['5.005_62','Carp','Exporter','IO::File','strict','warnings']},'HTML-Navigation-0.26.tar.gz' => {'author' => 'ASPIERS','description' => 'generic HTML navigation structure class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1085,'pod' => 429,'pod_errors' => 0,'total' => 1514,'with_comments' => 85},'releases' => 2,'requires' => ['URI-1.24.tar.gz'],'requires_module' => {'URI::Escape' => 0},'requires_recursive' => ['URI-1.24.tar.gz'],'size' => {'packed' => 18719,'unpacked' => 112578},'testers' => {'pass' => 6},'uses' => ['5.004','CGI','Carp','Data::Dumper','Exporter','URI::Escape','strict','vars']},'HTML-PageIndex-0.3.tar.gz' => {'author' => 'KMELTZ','description' => 'Class to create HTML page index objects.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 122,'pod' => 81,'pod_errors' => 1,'total' => 203,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 2408,'unpacked' => 6588},'testers' => {'pass' => 7},'uses' => ['Exporter','strict','vars']},'HTML-Pager-0.03.tar.gz' => {'author' => 'SAMTREGAR','description' => 'Perl module to handle CGI HTML paging of arbitary data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 484,'pod' => 242,'pod_errors' => 2,'total' => 726,'with_comments' => 34},'releases' => 3,'size' => {'packed' => 14389,'unpacked' => 43717},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['HTML::Template','integer','strict']},'HTML-Paginator-0_51.tar.gz' => {'author' => 'DODGER','description' => 'Object-Oriented Pagination for Web Applications','files' => [],'lines' => {'nonpod' => 345,'pod' => 266,'pod_errors' => 0,'total' => 611,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 7234,'unpacked' => 20891},'testers' => {'pass' => 6},'uses' => ['strict']},'HTML-Paging-SQL-1.11.tar.gz' => {'author' => 'WAC','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 212,'pod' => 47,'pod_errors' => 0,'total' => 259,'with_comments' => 38},'releases' => 3,'size' => {'packed' => 3566,'unpacked' => 11054},'testers' => {'pass' => 3},'uses' => []},'HTML-ParseBrowser-0_5.tar.gz' => {'author' => 'DODGER','description' => 'OO User Agent string parser','files' => [],'lines' => {'nonpod' => 235,'pod' => 292,'pod_errors' => 0,'total' => 527,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 5139,'unpacked' => 24327},'testers' => {'pass' => 7},'uses' => ['vars']},'HTML-Parser-3.28.tar.gz' => {'author' => 'GAAS','description' => ' Alternative HTML::Parser interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1401,'pod' => 1167,'pod_errors' => 0,'total' => 2568,'with_comments' => 137},'releases' => 38,'requires' => ['HTML-Tagset-3.03.tar.gz'],'requires_module' => {'HTML::Tagset' => 3},'requires_recursive' => ['HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 71185,'unpacked' => 229367},'testers' => {'pass' => 9},'uses' => ['5.004','Carp','DynaLoader','Exporter','HTTP::Headers','IO::File','URI','strict','vars']},'HTML-PhotoAlbum-1.17.tar.gz' => {'author' => 'NWIGER','description' => 'Easily create web based photo albums','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 560,'pod' => 254,'pod_errors' => 0,'total' => 814,'with_comments' => 91},'releases' => 1,'size' => {'packed' => 12399,'unpacked' => 43465},'testers' => {'fail' => 3,'pass' => 1},'uses' => ['5.004','CGI','CGI::FormBuilder','Carp','strict','vars']},'HTML-PopupTreeSelect-1.2.tar.gz' => {'author' => 'SAMTREGAR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 450,'pod' => 186,'pod_errors' => 0,'total' => 636,'with_comments' => 16},'releases' => 3,'requires' => ['HTML-Template-2.6.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'HTML::Template' => '2.6','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8035,'unpacked' => 25964},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','HTML::Template','strict','warnings']},'HTML-PrettyPrinter-0.03.tar.gz' => {'author' => 'CLMS','description' => 'generate nice HTML files from HTML syntax trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 818,'pod' => 489,'pod_errors' => 0,'total' => 1307,'with_comments' => 147},'releases' => 2,'requires' => ['HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz'],'requires_module' => {'HTML::Element' => '3.02','HTML::Tagset' => '3.01'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz'],'size' => {'packed' => 14036,'unpacked' => 41233},'testers' => {'pass' => 7},'uses' => ['5.004','Carp','Exporter','HTML::Element','HTML::Entities','HTML::Tagset','constant','strict','vars']},'HTML-Processor-0.2.1.tar.gz' => {'author' => 'PSCHNELL','description' => 'OO Template Processing Library for HTML,Text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1229,'pod' => 935,'pod_errors' => 3,'total' => 2164,'with_comments' => 270},'releases' => 3,'size' => {'packed' => 28321,'unpacked' => 104754},'testers' => {'pass' => 10},'uses' => ['Cwd','Data::Dumper','Exporter','strict','vars']},'HTML-Puzzle-0.07.tar.gz' => {'author' => 'EBRUNI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 719,'pod' => 219,'pod_errors' => 0,'total' => 938,'with_comments' => 94},'releases' => 5,'size' => {'packed' => 14102,'unpacked' => 43566},'testers' => {'fail' => 3,'tests' => '16'},'uses' => ['5.005','Carp','DBI','Data::Dumper','FileHandle','HTML::Puzzle::DBTable','HTML::Puzzle::Format','HTML::Template','strict','vars','warnings']},'HTML-Puzzle-0.13.tar.gz' => {'author' => 'EBRUNI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 530,'pod' => 317,'pod_errors' => 0,'total' => 847,'with_comments' => 33},'releases' => 5,'size' => {'packed' => 12673,'unpacked' => 39098},'testers' => {},'uses' => ['5.005','Carp','DBI','Data::Dumper','FileHandle','HTML::Template::Extension','strict','vars','warnings']},'HTML-QuickCheck-1.0b1.tar.gz' => {'author' => 'YLU','description' => 'Fast simple validation of HMTL text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 172,'pod' => 49,'pod_errors' => 0,'total' => 221,'with_comments' => 32},'releases' => 1,'size' => {'packed' => 4241,'unpacked' => 9597},'testers' => {'tests' => '0','unknown' => 39},'uses' => []},'HTML-QuickTable-1.10.tar.gz' => {'author' => 'NWIGER','description' => 'Quickly create fairly complex HTML tables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 375,'pod' => 253,'pod_errors' => 0,'total' => 628,'with_comments' => 80},'releases' => 1,'size' => {'packed' => 9882,'unpacked' => 34209},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'HTML-RSSAutodiscovery-1.1.tar.gz' => {'author' => 'ASCOPE','description' => 'methods for retreiving RSS-ish information from an HTML document.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 578,'pod' => 170,'pod_errors' => 0,'total' => 748,'with_comments' => 24},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz','Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::Parser' => 0,'HTTP::Request' => 0,'LWP::UserAgent' => 0,'Test::More' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6008,'unpacked' => 17714},'testers' => {'fail' => 3,'pass' => 1,'tests' => '20'},'uses' => ['Carp','Cwd','Exporter','File::Spec','HTML::Parser','HTTP::Request','LWP::UserAgent','constant','strict']},'HTML-RefMunger-0.01.tar.gz' => {'author' => 'ADESC','description' => 'module to mangle HREF links within HTML files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 388,'pod' => 75,'pod_errors' => 0,'total' => 463,'with_comments' => 72},'releases' => 1,'size' => {'packed' => 12937,'unpacked' => 40633},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','Cwd','Exporter','Getopt::Long','HTML::TokeParser','strict']},'HTML-STable-0.02.tar.gz' => {'author' => 'SEYHAN','description' => 'Perl extension for HTML Tables.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1629,'pod' => 49,'pod_errors' => 0,'total' => 1678,'with_comments' => 117},'releases' => 2,'size' => {'packed' => 12055,'unpacked' => 43622},'testers' => {'pass' => 4},'uses' => ['Exporter','POSIX','Sort::Fields','Time::Local','strict','vars']},'HTML-Sanitizer-0.01.tar.gz' => {'author' => 'NESTING','description' => 'HTML Sanitizer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 296,'pod' => 225,'pod_errors' => 0,'total' => 521,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 5997,'unpacked' => 15740},'testers' => {'fail' => 1,'pass' => 3,'tests' => '7'},'uses' => ['Carp','HTML::TreeBuilder','constant','strict','warnings']},'HTML-Scrubber-0.03.tar.gz' => {'author' => 'PODMASTER','description' => undef,'files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 376,'pod' => 233,'pod_errors' => 1,'total' => 609,'with_comments' => 23},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => 3},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 6473,'unpacked' => 23986},'testers' => {'pass' => 1},'uses' => ['HTML::Entities','strict','vars']},'HTML-Seamstress-1.17.tar.gz' => {'author' => 'TBONE','description' => 'dynamic HTML generation via pure HTML and pure Perl.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 638,'pod' => 391,'pod_errors' => 0,'total' => 1029,'with_comments' => 43},'releases' => 14,'requires' => ['Cache-Cache-1.02.tar.gz','HTML-Stitchery-1.05.tar.gz','HTML-Tree-3.17.tar.gz','Set-Array-0.10.tar.gz'],'requires_module' => {'Cache::Cache' => '0.08','HTML::Stitchery' => 0,'HTML::Tree' => '3.11','Set::Array' => 0},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Stitchery-1.05.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','Set-Array-0.10.tar.gz','Want-0.06.tar.gz'],'size' => {'packed' => 12373,'unpacked' => 33558},'testers' => {'pass' => 4},'uses' => ['5.006','Cache::MemoryCache','Carp','Cwd','Data::Dumper','HTML::Stitchery','HTML::Tree','HTML::TreeBuilder','Set::Array','Symbol','lib','strict','warnings']},'HTML-SimpleLinkExtor-0.72.tar.gz' => {'author' => 'BDFOY','description' => 'a simple way to extract links','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 154,'pod' => 111,'pod_errors' => 0,'total' => 265,'with_comments' => 7},'releases' => 4,'requires' => ['HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'HTML::LinkExtor' => '1.28','URI' => '1.09'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','URI-1.24.tar.gz'],'size' => {'packed' => 3710,'unpacked' => 9371},'testers' => {'pass' => 17},'uses' => ['AutoLoader','HTML::LinkExtor','URI','strict','subs','vars']},'HTML-SimpleParse-0.12.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Bare-bones HTML parser','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 246,'pod' => 207,'pod_errors' => 0,'total' => 453,'with_comments' => 23},'releases' => 11,'size' => {'packed' => 8486,'unpacked' => 21500},'testers' => {'pass' => 5},'uses' => ['strict','vars']},'HTML-StickyForms-0.06.tar.gz' => {'author' => 'PMH','description' => 'HTML form generation for mod_perl/CGI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 411,'pod' => 202,'pod_errors' => 0,'total' => 613,'with_comments' => 110},'releases' => 6,'size' => {'packed' => 5977,'unpacked' => 20779},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['1','strict','vars']},'HTML-StickyQuery-0.11.tar.gz' => {'author' => 'IKEBE','description' => 'add sticky QUERY_STRING','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 200,'pod' => 201,'pod_errors' => 0,'total' => 401,'with_comments' => 5},'releases' => 10,'requires' => ['HTML-Parser-3.28.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'HTML::Parser' => 3,'Test::More' => '0.32','URI' => '1.00'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz'],'size' => {'packed' => 5839,'unpacked' => 18328},'testers' => {'pass' => 2},'uses' => ['Carp','HTML::Parser','URI','strict','vars']},'HTML-Stitchery-1.05.tar.gz' => {'author' => 'TBONE','description' => 'support methods for weaving HTML with HTML::Seamstress','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 186,'pod' => 9,'pod_errors' => 0,'total' => 195,'with_comments' => 14},'releases' => 4,'requires' => ['Set-Array-0.10.tar.gz'],'requires_module' => {'Set::Array' => '0.05'},'requires_recursive' => ['Set-Array-0.10.tar.gz','Want-0.06.tar.gz'],'size' => {'packed' => 2437,'unpacked' => 5279},'testers' => {'pass' => 5},'uses' => ['5.006','Data::Dumper','Set::Array','strict','warnings']},'HTML-Stream-1.54.tar.gz' => {'author' => 'ERYQ','description' => 'HTML output stream','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 876,'pod' => 710,'pod_errors' => 0,'total' => 1586,'with_comments' => 152},'releases' => 15,'size' => {'packed' => 51277,'unpacked' => 157675},'testers' => {'pass' => 1,'tests' => '0','unknown' => 42},'uses' => ['Carp','Exporter','strict','vars']},'HTML-Strip-1.01.tar.gz' => {'author' => 'KILINRAX','description' => 'Perl extension for stripping HTML markup from text.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 111,'pod_errors' => 1,'total' => 203,'with_comments' => 8},'releases' => 5,'size' => {'packed' => 6903,'unpacked' => 18153},'testers' => {'pass' => 3},'uses' => ['5.006','DynaLoader','Exporter','strict','warnings']},'HTML-StripScripts-0.01.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1129,'pod' => 468,'pod_errors' => 1,'total' => 1597,'with_comments' => 15},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'testers' => {'pass' => 3},'uses' => ['strict','vars']},'HTML-StripScripts-Parser-0.02.tar.gz' => {'author' => 'NCLEATON','description' => 'XSS filter using HTML::Parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 48,'pod' => 55,'pod_errors' => 0,'total' => 103,'with_comments' => 1},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz','HTML-StripScripts-0.02.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTML::Parser' => 3,'HTML::StripScripts' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-StripScripts-0.02.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5011,'unpacked' => 17206},'testers' => {'pass' => 3},'uses' => ['HTML::Parser','HTML::StripScripts','strict','vars']},'HTML-StripScripts-Regex-0.01.tar.gz' => {'author' => 'NCLEATON','description' => 'XSS filter using a regular expression','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 91,'pod' => 49,'pod_errors' => 0,'total' => 140,'with_comments' => 14},'releases' => 1,'requires' => ['HTML-StripScripts-0.02.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTML::StripScripts' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-StripScripts-0.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5269,'unpacked' => 17768},'testers' => {'pass' => 2},'uses' => ['HTML::StripScripts','strict','vars']},'HTML-Subtext-1.03.tar.gz' => {'author' => 'KAELIN','description' => 'Text substitutions on an HTML template','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 86,'pod' => 56,'pod_errors' => 0,'total' => 142,'with_comments' => 0},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'HTML::Parser' => 2,'URI::Escape' => 3},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','URI-1.24.tar.gz'],'size' => {'packed' => 4131,'unpacked' => 10139},'testers' => {'pass' => 8},'uses' => ['HTML::Filter','URI::Escape','strict','vars']},'HTML-Summary-0.017.tar.gz' => {'author' => 'AWRIGLEY','description' => 'module for generating a summary from a web page.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1498,'pod' => 168,'pod_errors' => 0,'total' => 1666,'with_comments' => 577},'releases' => 7,'requires' => ['HTML-Tree-3.17.tar.gz'],'requires_module' => {'HTML::TreeBuilder' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz'],'size' => {'packed' => 21087,'unpacked' => 70518},'testers' => {'fail' => 1,'pass' => 21,'tests' => '25'},'uses' => ['5.004','Exporter','constant','of','strict','these','vars']},'HTML-SummaryBasic-0.1.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 125,'pod_errors' => 1,'total' => 274,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 3888,'unpacked' => 11268},'testers' => {'pass' => 3},'uses' => ['Carp','HTML::HeadParser','HTML::TokeParser','strict','warnings']},'HTML-SyntaxHighlighter-0.03.tar.gz' => {'author' => 'KILINRAX','description' => 'a module for converting raw HTML into html-escaped, highlighted code; suitable for inclusion within a web page.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 526,'pod' => 175,'pod_errors' => 0,'total' => 701,'with_comments' => 29},'releases' => 3,'size' => {'packed' => 6939,'unpacked' => 19602},'testers' => {'pass' => 3},'uses' => ['Exporter','HTML::Entities','HTML::Parser','strict','vars']},'HTML-Table-1.18a.tar.gz' => {'author' => 'AJPEACOCK','description' => 'Write HTML tables via spreadsheet metaphor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1802,'pod' => 397,'pod_errors' => 0,'total' => 2199,'with_comments' => 553},'releases' => 4,'size' => {'packed' => 16241,'unpacked' => 76246},'testers' => {'pass' => 5},'uses' => ['5.002','strict','vars']},'HTML-TableBracket-0.11.tar.gz' => {'author' => 'JEEK','description' => 'Tournament Table Bracket Generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 353,'pod' => 63,'pod_errors' => 0,'total' => 416,'with_comments' => 41},'releases' => 1,'size' => {'packed' => 4175,'unpacked' => 13385},'testers' => {'pass' => 4},'uses' => ['GraphViz','POSIX','strict']},'HTML-TableContentParser-0.13.tar.gz' => {'author' => 'SDRABBLE','description' => 'Do interesting things with the contents of tables.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 190,'pod' => 86,'pod_errors' => 0,'total' => 276,'with_comments' => 13},'releases' => 4,'size' => {'packed' => 4664,'unpacked' => 13300},'testers' => {'pass' => 22},'uses' => ['HTML::Parser','strict']},'HTML-TableExtract-1.08.tar.gz' => {'author' => 'MSISK','description' => 'Flexible HTML table extraction','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1580,'pod' => 322,'pod_errors' => 1,'total' => 1902,'with_comments' => 294},'releases' => 14,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 23943,'unpacked' => 94864},'testers' => {'pass' => 22},'uses' => ['Carp','HTML::Entities','HTML::Parser','strict','vars']},'HTML-TableExtractor-0.11.tar.gz' => {'author' => 'SDRABBLE','description' => 'Do stuff with the layout of HTML tables.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 74,'pod_errors' => 0,'total' => 163,'with_comments' => 2},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 3097,'unpacked' => 6705},'testers' => {'pass' => 29},'uses' => ['HTML::Parser','strict']},'HTML-TableLayout-1.001008.tar.gz' => {'author' => 'SFARRELL','description' => 'Layout Manager for cgi-based web applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2538,'pod' => 213,'pod_errors' => 0,'total' => 2751,'with_comments' => 608},'releases' => 4,'size' => {'packed' => 23400,'unpacked' => 81170},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','Data::Dumper','Exporter','strict']},'HTML-TableParser-0.34.tar.gz' => {'author' => 'DJERIUS','description' => 'Extract data from an HTML table','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1124,'pod' => 359,'pod_errors' => 0,'total' => 1483,'with_comments' => 144},'releases' => 8,'requires' => ['HTML-Parser-3.28.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTML::Entities' => 0,'HTML::Parser' => '3.26','Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 47156,'unpacked' => 267826},'testers' => {'pass' => 14},'uses' => ['5.006','Carp','HTML::Entities','HTML::Parser','strict','warnings']},'HTML-TableTiler-1.05.tar.gz' => {'author' => 'DOMIZIO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 532,'pod' => 212,'pod_errors' => 0,'total' => 744,'with_comments' => 9},'releases' => 5,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::PullParser' => 1},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 8142,'unpacked' => 40075},'testers' => {'pass' => 5},'uses' => ['5.005','Carp','HTML::PullParser','strict']},'HTML-TagFilter-0.073.tar.gz' => {'author' => 'WROSS','description' => 'An HTML::Parser-based selective tag remover','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 349,'pod' => 315,'pod_errors' => 0,'total' => 664,'with_comments' => 15},'releases' => 5,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => 1},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 10092,'unpacked' => 29755},'testers' => {'pass' => 7},'uses' => ['HTML::Parser','strict','vars']},'HTML-TagReader-1.03.tar.gz' => {'author' => 'GUS','description' => 'Perl extension module for reading html/sgml/xml files by tags.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 62,'pod' => 125,'pod_errors' => 0,'total' => 187,'with_comments' => 1},'releases' => 15,'size' => {'packed' => 44784,'unpacked' => 161663},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['DynaLoader','strict','vars']},'HTML-Tagset-3.03.tar.gz' => {'author' => 'SBURKE','description' => 'data tables useful in parsing HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 323,'pod' => 137,'pod_errors' => 0,'total' => 460,'with_comments' => 67},'releases' => 3,'size' => {'packed' => 6642,'unpacked' => 16022},'testers' => {'pass' => 32},'uses' => ['5','strict','vars']},'HTML-Tempi-0.01.tar.gz' => {'author' => 'RFAUST','description' => 'Perl extension for HTML templates','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 173,'pod_errors' => 0,'total' => 249,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 16005,'unpacked' => 54412},'testers' => {'pass' => 4},'uses' => ['5.005_62','DynaLoader','Exporter','Tempi','strict','warnings']},'HTML-Template-2.6.tar.gz' => {'author' => 'SAMTREGAR','description' => 'a simple HTML templating system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2336,'pod' => 929,'pod_errors' => 1,'total' => 3265,'with_comments' => 384},'releases' => 25,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'File::Spec' => '0.82'},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 60820,'unpacked' => 221485},'testers' => {'fail' => 1,'pass' => 24},'uses' => ['Carp','Data::Dumper','Digest::MD5','File::Spec','GTop','IPC::SharedCache','Storable','integer','strict','vars']},'HTML-Template-Expr-0.04.tar.gz' => {'author' => 'SAMTREGAR','description' => 'HTML::Template extension adding expression support','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 378,'pod' => 310,'pod_errors' => 6,'total' => 688,'with_comments' => 40},'releases' => 4,'requires' => ['HTML-Template-2.6.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'HTML::Template' => '2.4','Parse::RecDescent' => 0,'Test::More' => 0,'Text::Balanced' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18783,'unpacked' => 56026},'testers' => {'pass' => 4},'uses' => ['Carp','HTML::Template','Parse::RecDescent','constant','strict','vars']},'HTML-Template-Extension-0.21.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1027,'pod' => 784,'pod_errors' => 0,'total' => 1811,'with_comments' => 195},'releases' => 9,'requires' => ['HTML-Parser-3.28.tar.gz','HTML-Template-2.6.tar.gz'],'requires_module' => {'HTML::Parser' => 0,'HTML::Template' => '2.1'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Template-2.6.tar.gz','perl-5.8.0.tar.gz'],'testers' => {'pass' => 2},'uses' => ['Carp','Data::Dumper','FileHandle','HTML::Template','HTML::TokeParser','strict','vars']},'HTML-Template-Filter-Dreamweaver.tar.gz' => {'author' => 'BPAULSEN','description' => 'a module that provides a filter function to translate Dreamweaver MX Template pages (.dwt) to HTML::Template pages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 357,'pod' => 52,'pod_errors' => 0,'total' => 409,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 12240,'unpacked' => 44355},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Exporter','strict','warnings']},'HTML-Template-JIT-0.04.tar.gz' => {'author' => 'SAMTREGAR','description' => 'a just-in-time compiler for HTML::Template','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 863,'pod' => 192,'pod_errors' => 0,'total' => 1055,'with_comments' => 102},'releases' => 4,'requires' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','Inline-0.44.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Digest::MD5' => 0,'File::Path' => 0,'File::Spec' => 0,'HTML::Template' => '2.5','Inline' => '0.43','Inline::C' => 0,'Test::More' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 28874,'unpacked' => 121075},'testers' => {'pass' => 4},'uses' => ['5.006','Carp','Digest::MD5','File::Path','File::Spec','HTML::Template','strict','vars','warnings']},'HTML-Template-XPath-0.10.tar.gz' => {'author' => 'TJMATHER','description' => 'Easy access to XML files from HTML::Template using XPath','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 340,'pod' => 135,'pod_errors' => 0,'total' => 475,'with_comments' => 29},'releases' => 3,'requires' => ['HTML-Template-2.6.tar.gz','IO-1.20.tar.gz','XML-LibXML-1.54.tar.gz'],'requires_module' => {'HTML::Template' => '1.8','IO::File' => 0,'XML::LibXML' => '1.31'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Template-2.6.tar.gz','IO-1.20.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7734,'unpacked' => 23535},'testers' => {'fail' => 1,'pass' => 1,'tests' => '1'},'uses' => ['Carp','HTML::Template','IO::File','IO::Handle','XML::LibXML','strict','vars']},'HTML-Toc-0.91.tar.gz' => {'author' => 'FVULTO','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 4130,'pod' => 1682,'pod_errors' => 0,'total' => 5812,'with_comments' => 1775},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 42570,'unpacked' => 264364},'testers' => {'pass' => 4},'uses' => ['FileHandle','HTML::Parser','Roman','constant','existing','strict','vars']},'HTML-TokeParser-Simple-2.1.tar.gz' => {'author' => 'OVID','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 359,'pod' => 285,'pod_errors' => 0,'total' => 644,'with_comments' => 20},'releases' => 6,'requires' => ['HTML-Parser-3.28.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTML::Parser' => '3.25','HTML::TokeParser' => '2.24','Test::More' => ''},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 9921,'unpacked' => 34668},'testers' => {'pass' => 3},'uses' => ['Carp','HTML::TokeParser','constant','strict','vars']},'HTML-Tree-3.17.tar.gz' => {'author' => 'SBURKE','description' => 'overview of HTML::TreeBuilder et al','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6159,'pod' => 3207,'pod_errors' => 0,'total' => 9366,'with_comments' => 1060},'releases' => 28,'requires' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'requires_module' => {'HTML::Parser' => '2.19','HTML::Tagset' => '3.02'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 118038,'unpacked' => 359411},'testers' => {'pass' => 25},'uses' => ['5','Exporter','HTML::FormatText','integer','strict','vars']},'HTML-Validator-0.13.tar.gz' => {'author' => 'SAIT','description' => 'HTML validator utilizing nsgmls and libwww','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => -3,'pod' => 10,'pod_errors' => 1,'total' => 7,'with_comments' => 0},'releases' => 10,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.36'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18652,'unpacked' => 54217},'testers' => {},'uses' => []},'HTML-WWWTheme-1.06.tar.gz' => {'author' => 'CHOGAN','description' => 'Standard theme generation, including sidebars and navigation bars','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 630,'pod' => 311,'pod_errors' => 0,'total' => 941,'with_comments' => 80},'releases' => 5,'size' => {'packed' => 21854,'unpacked' => 72352},'testers' => {'pass' => 7},'uses' => ['Carp','strict','vars']},'HTML-WebMake-2.2.tar.gz' => {'author' => 'JMASON','description' => 'a simple web site management system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10840,'pod' => 462,'pod_errors' => 2,'total' => 11302,'with_comments' => 1116},'releases' => 4,'requires' => ['File-Spec-0.82.tar.gz','Text-EtText-2.2.tar.gz'],'requires_module' => {'File::Spec' => 0,'Text::EtText' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Text-EtText-2.2.tar.gz'],'size' => {'packed' => 559459,'unpacked' => 2846066},'testers' => {'fail' => 4,'pass' => 3,'tests' => '419'},'uses' => ['.$mod.','AnyDBM_File','CGI','Carp','Cwd','Exporter','Fcntl','File::Basename','File::Copy','File::Find','File::Path','File::Spec','HTML::Entities','HTML::Parser','HTML::WebMake::CGI::CVS','HTML::WebMake::PerlCodeLibrary','IO::String','Image::Size','POSIX','Pod::Html','Text::EtText::EtText2HTML','Text::EtText::LinkGlossary','goto','locale','strict','vars']},'HTML-Widgets-Menu-0.12.tar.gz' => {'author' => 'FRANKIE','description' => 'Builds an HTML menu','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 585,'pod' => 285,'pod_errors' => 0,'total' => 870,'with_comments' => 20},'releases' => 6,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.14'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 11299,'unpacked' => 39280},'testers' => {'pass' => 6},'uses' => ['AutoLoader','CGI','CGI::Carp','DBI','Exporter','strict','vars']},'HTML-Widgets-Search-0.05.tar.gz' => {'author' => 'FRANKIE','description' => 'Perl module for building searches returning','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 369,'pod' => 121,'pod_errors' => 0,'total' => 490,'with_comments' => 11},'releases' => 3,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '0.7'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 5108,'unpacked' => 14554},'testers' => {'pass' => 4},'uses' => ['AutoLoader','Carp','DBI','Exporter','URI','strict','vars']},'HTML-Widgets-SelectLayers-0.02.tar.gz' => {'author' => 'IVAN','description' => 'Perl extension for selectable HTML layers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 235,'pod' => 106,'pod_errors' => 1,'total' => 341,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 5402,'unpacked' => 18392},'testers' => {'pass' => 5},'uses' => ['strict','vars']},'HTML-XSSLint-0.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'audit XSS vulnerability of web pages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 131,'pod' => 64,'pod_errors' => 0,'total' => 195,'with_comments' => 1},'releases' => 1,'requires' => ['Digest-MD5-2.26.tar.gz','IO-String-1.02.tar.gz','Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Digest::MD5' => 0,'HTML::Form' => 0,'IO::String' => 0,'LWP' => 0,'Test::More' => '0.32'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4157,'unpacked' => 10631},'testers' => {'fail' => 1,'tests' => '13'},'uses' => ['Carp','Digest::MD5','HTML::Form','HTTP::Request','LWP::UserAgent','URI','strict','vars']},'HTMLTMPL-1.34.tar.gz' => {'author' => 'ISTEEL','description' => 'Merges runtime data with static HTML template file.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 509,'pod' => 341,'pod_errors' => 0,'total' => 850,'with_comments' => 99},'releases' => 5,'size' => {'packed' => 7724,'unpacked' => 21650},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'HTTP-Browscap-0.01.tar.gz' => {'author' => 'JAMESPO','description' => 'Provides info on web browser capabilities','files' => ['README'],'lines' => {'nonpod' => 120,'pod' => 17,'pod_errors' => 0,'total' => 137,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 2387,'unpacked' => 6292},'testers' => {'fail' => 1,'tests' => '0','unknown' => 9},'uses' => ['strict','vars']},'HTTP-BrowserDetect-0.97.tar.gz' => {'author' => 'LHS','description' => 'Detect browser, version, OS from UserAgent','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 424,'pod' => 186,'pod_errors' => 1,'total' => 610,'with_comments' => 34},'releases' => 6,'size' => {'packed' => 9331,'unpacked' => 34493},'testers' => {'pass' => 21},'uses' => ['Exporter','strict','vars']},'HTTP-Cookies-Mozilla-1.03.tar.gz' => {'author' => 'BDFOY','description' => 'work with the Mozilla cookies.txt file','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 39,'pod_errors' => 0,'total' => 159,'with_comments' => 9},'releases' => 1,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','HTTP::Cookies' => '1.25','Test::Manifest' => '0.9','Test::More' => '0','Test::Pod' => '0.72','Test::Prereq' => '0.18','Text::Diff' => '0'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Digest-MD5-2.26.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3430,'unpacked' => 7140},'testers' => {},'uses' => ['','Carp','HTTP::Cookies','constant','strict','vars']},'HTTP-Cookies-Omniweb-1.03.tar.gz' => {'author' => 'BDFOY','description' => 'work with the OmniWeb cookies.xml file','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 121,'pod' => 43,'pod_errors' => 0,'total' => 164,'with_comments' => 4},'releases' => 1,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','HTTP::Cookies' => '1.25','Test::Manifest' => '0.9','Test::More' => '0','Test::Pod' => '0.72','Test::Prereq' => '0.18','Text::Diff' => '0'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Digest-MD5-2.26.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3600,'unpacked' => 7663},'testers' => {},'uses' => ['','HTTP::Cookies','constant','strict','vars']},'HTTP-Cookies-Safari-1.02.tar.gz' => {'author' => 'BDFOY','description' => 'work with Apple Safari cookie files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 37,'pod_errors' => 0,'total' => 174,'with_comments' => 18},'releases' => 2,'requires' => ['DateManip-5.42a.tar.gz','File-Find-Rule-0.10.tar.gz','Mac-PropertyList-0.1.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Date::Manip' => '0','File::Find::Rule' => '0','HTTP::Cookies' => '1.25','Mac::PropertyList' => '0','Test::Manifest' => '0.9','Test::More' => '0','Test::Pod' => '0.72','Test::Prereq' => '0.18','Text::Diff' => '0'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','Mac-PropertyList-0.1.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3820,'unpacked' => 8666},'testers' => {},'uses' => ['','Date::Manip','HTTP::Cookies','Mac::PropertyList','constant','strict','vars']},'HTTP-DAV-0.31.tar.gz' => {'author' => 'PCOLLINS','description' => 'A WebDAV client library for Perl5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4299,'pod' => 1651,'pod_errors' => 1,'total' => 5950,'with_comments' => 901},'releases' => 6,'requires' => ['XML-DOM-1.42.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.48','XML::DOM' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 76555,'unpacked' => 272149},'testers' => {'fail' => 2,'pass' => 4},'uses' => ['Carp','Cwd','Data::Dumper','Exporter','File::Glob','FileHandle','HTML::FormatText','HTML::TreeBuilder','HTTP::Date','HTTP::Headers','HTTP::Response','LWP','LWP::UserAgent','Test','Time::Local','URI','URI::Escape','URI::file','XML::DOM','strict','vars']},'HTTP-DAVServer-0.2.tar.gz' => {'author' => 'JLAWRENC','description' => 'allows you to write server-side functions to accept, process and respond to WebDAV client requests. WebDAV - RFC 2518 - is a protocol which allows clients to manipulate files on a remote server using HTTP.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1196,'pod' => 573,'pod_errors' => 0,'total' => 1769,'with_comments' => 21},'releases' => 2,'requires' => ['DateTime-0.1402.tar.gz','XML-SAX-0.12.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'DateTime' => '0.08','XML::SAX' => '0.12','XML::Simple' => '2.03'},'requires_recursive' => ['DateTime-0.1402.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17881,'unpacked' => 69852},'testers' => {'pass' => 2},'uses' => ['CGI','Data::Dumper','DateTime','Digest::MD5','File::Copy','File::stat','XML::Simple','strict','warnings']},'HTTP-Daemon-SSL-1.00.tar.gz' => {'author' => 'BEHROOZI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 58,'pod_errors' => 0,'total' => 150,'with_comments' => 5},'releases' => 1,'requires' => ['IO-Socket-SSL-0.94.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Daemon' => 1,'IO::Socket::SSL' => '0.93'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-Socket-SSL-0.94.tar.gz','MIME-Base64-2.20.tar.gz','Net_SSLeay.pm-1.23.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6434,'unpacked' => 12433},'testers' => {'pass' => 1},'uses' => ['HTTP::Daemon','IO::Socket::SSL','vars']},'HTTP-File-3.6.tar.gz' => {'author' => 'TBONE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 114,'pod' => 79,'pod_errors' => 0,'total' => 193,'with_comments' => 5},'releases' => 12,'requires' => ['http-headers-useragent-1.00.tar.gz'],'requires_module' => {'HTTP::Headers::UserAgent' => '1.00'},'requires_recursive' => ['http-headers-useragent-1.00.tar.gz'],'size' => {'packed' => 4244,'unpacked' => 13213},'testers' => {'pass' => 2},'uses' => ['File::Basename','HTTP::Headers::UserAgent','strict']},'HTTP-GHTTP-1.07.tar.gz' => {'author' => 'MSERGEANT','description' => 'Perl interface to the gnome ghttp library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 187,'pod_errors' => 0,'total' => 317,'with_comments' => 1},'releases' => 8,'size' => {'packed' => 8205,'unpacked' => 23656},'testers' => {'pass' => 2},'uses' => ['DynaLoader','Exporter','IO::Handle','strict','vars']},'HTTP-GetImages-0.343.tar.gz' => {'author' => 'LGODDARD','description' => 'Spider collects images from HTML pages','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 424,'pod' => 187,'pod_errors' => 0,'total' => 611,'with_comments' => 66},'releases' => 7,'requires' => ['HTML-Parser-3.28.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::TokeParser' => '0.1','HTTP::Request' => '0.1','LWP::UserAgent' => '0.1'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6964,'unpacked' => 19289},'testers' => {'pass' => 3},'uses' => ['Carp','HTML::TokeParser','HTTP::Request','LWP::UserAgent','strict','vars','warnings']},'HTTP-Lite-2.1.4.tar.gz' => {'author' => 'RHOOPER','description' => 'Lightweight HTTP implementation','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 762,'pod' => 249,'pod_errors' => 0,'total' => 1011,'with_comments' => 41},'releases' => 12,'size' => {'packed' => 276478,'unpacked' => 305361},'testers' => {'pass' => 3},'uses' => ['Errno','Fcntl','Socket','strict','vars']},'HTTP-MHTTP-0.13.tar.gz' => {'author' => 'PIERS','description' => 'this library provides reasonably low level access to the HTTP protocol, for perl. This does not replace LWP (what possibly could :-) but is a cut for speed. It also supports all of HTTP 1.0, so you have GET, POST, PUT, HEAD, and DELETE. Some support of HTTP 1.1 is available - sepcifically Transfer-Encoding = chunked and the Keep-Alive extensions. Additionally - rudimentary SSL support can be compiled in. This effectively enables negotiation of TLS, but does not validate the certificates.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 136,'pod' => 118,'pod_errors' => 0,'total' => 254,'with_comments' => 2},'releases' => 12,'size' => {'packed' => 15572,'unpacked' => 52986},'testers' => {'pass' => 1},'uses' => ['5.005','Carp','DynaLoader','Exporter','MIME::Base64','strict','vars']},'HTTP-MobileAgent-0.16.tar.gz' => {'author' => 'MIYAGAWA','description' => 'HTTP mobile user agent string parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1084,'pod' => 605,'pod_errors' => 0,'total' => 1689,'with_comments' => 19},'releases' => 16,'requires' => ['Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Headers' => '1.43','Test::More' => '0.32'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17083,'unpacked' => 74706},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','strict','vars']},'HTTP-Proxy-0.08.tar.gz' => {'author' => 'BOOK','description' => 'HTTP proxy','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 816,'pod' => 239,'pod_errors' => 0,'total' => 1055,'with_comments' => 125},'releases' => 8,'requires' => ['Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Daemon' => '1.25','LWP::UserAgent' => 2,'Test::More' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15013,'unpacked' => 46038},'testers' => {'fail' => 1,'pass' => 1,'tests' => '78'},'uses' => ['Carp','Exporter','Fcntl','HTTP::Daemon','IO::Select','LWP::ConnCache','LWP::UserAgent','POSIX','Sys::Hostname','constant','strict','vars']},'HTTP-ProxyAutoConfig-0.1.tar.gz' => {'author' => 'REATMON','description' => 'provides a unifed way to get the proxy information','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 647,'pod' => 57,'pod_errors' => 0,'total' => 704,'with_comments' => 121},'releases' => 1,'size' => {'packed' => 14667,'unpacked' => 47585},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','IO::Socket','POSIX','Sys::Hostname','strict','vars']},'HTTP-ProxyCheck-1.0.tar.gz' => {'author' => 'THOM','description' => 'Checks HTTP proxy servers.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 89,'pod_errors' => 0,'total' => 327,'with_comments' => 31},'releases' => 3,'requires' => ['Class-Default-0.2.tar.gz','IO-1.20.tar.gz','Validate-Net-0.4.tar.gz'],'requires_module' => {'Class::Default' => '0.2','IO::Socket' => 0,'Validate::Net' => '0.3'},'requires_recursive' => ['Class-Default-0.2.tar.gz','Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Validate-Net-0.4.tar.gz'],'size' => {'packed' => 3829,'unpacked' => 11467},'testers' => {'pass' => 6},'uses' => ['Class::Default','IO::Socket','Validate::Net','strict','vars']},'HTTP-ProxySelector-0.02.tar.gz' => {'author' => 'UDASSIN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 100,'pod' => 103,'pod_errors' => 0,'total' => 203,'with_comments' => 10},'releases' => 2,'size' => {'packed' => 3167,'unpacked' => 7004},'testers' => {'pass' => 3},'uses' => ['5.006','LWP::UserAgent','integer','strict','warnings']},'HTTP-QuickBase-1.45.tar.gz' => {'author' => 'CVONROES','description' => 'Wraps the QuickBase HTTP API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1279,'pod' => 310,'pod_errors' => 0,'total' => 1589,'with_comments' => 36},'releases' => 12,'requires' => ['Crypt-SSLeay-0.51.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Crypt::SSLeay' => '0.14','LWP::UserAgent' => '1.64'},'requires_recursive' => ['Crypt-SSLeay-0.51.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11615,'unpacked' => 43525},'testers' => {'pass' => 2},'uses' => ['LWP::UserAgent','MIME::Base64','strict']},'HTTP-RecordedSession-0.05.tar.gz' => {'author' => 'CBROOKS','description' => 'Class to interface with serialized clicks from Apache::Recorder','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 141,'pod' => 103,'pod_errors' => 0,'total' => 244,'with_comments' => 1},'releases' => 3,'requires' => ['Storable-2.07.tar.gz'],'requires_module' => {'Storable' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4064,'unpacked' => 11777},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['Data::Dumper','Storable','strict','vars']},'HTTP-Request-Form-0.952.tar.gz' => {'author' => 'GBAUER','description' => 'Generates HTTP::Request objects out of forms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 673,'pod' => 216,'pod_errors' => 0,'total' => 889,'with_comments' => 22},'releases' => 8,'requires' => ['HTML-Tree-3.17.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::TreeBuilder' => 0,'HTTP::Request::Common' => 0,'LWP::UserAgent' => 0,'URI::URL' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10575,'unpacked' => 43514},'testers' => {'pass' => 10},'uses' => ['HTTP::Request::Common','URI::URL','strict','vars']},'HTTP-Rollup-0.4.tar.gz' => {'author' => 'JMAY','description' => 'translate an HTTP query string to a hierarchical structure','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 266,'pod' => 82,'pod_errors' => 0,'total' => 348,'with_comments' => 25},'releases' => 3,'requires' => ['CGI.pm-2.98.tar.gz'],'requires_module' => {'CGI::Util' => '1.3'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 4141,'unpacked' => 10859},'testers' => {'pass' => 4},'uses' => ['5.005','CGI::Util','Exporter','strict','vars']},'HTTP-SimpleLinkChecker-1.04.tar.gz' => {'author' => 'BDFOY','description' => 'get the HTTP status of a URL','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 26,'pod_errors' => 0,'total' => 90,'with_comments' => 1},'releases' => 4,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request' => undef},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 1619,'unpacked' => 2790},'testers' => {'pass' => 10},'uses' => ['HTTP::Request','LWP::UserAgent','strict','vars']},'HTTP-Size-0.4.tar.gz' => {'author' => 'BDFOY','description' => 'get the download size for web resources','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 103,'pod_errors' => 0,'total' => 264,'with_comments' => 1},'releases' => 4,'requires' => ['HTML-SimpleLinkExtor-0.72.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::SimpleLinkExtor' => '0','HTTP::Request' => '0','URI' => '0'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-SimpleLinkExtor-0.72.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 24118,'unpacked' => 31759},'testers' => {'fail' => 2,'pass' => 4,'tests' => '6'},'uses' => ['HTML::SimpleLinkExtor','HTTP::Request','LWP::UserAgent','URI','subs','vars']},'HTTP-WebTest-2.03.tar.gz' => {'author' => 'ILYAM','description' => 'Testing static and dynamic web content','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3885,'pod' => 4029,'pod_errors' => 0,'total' => 7914,'with_comments' => 262},'releases' => 16,'requires' => ['Algorithm-Diff-1.15.tar.gz','CGI.pm-2.98.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','podlators-1.27.tar.gz'],'requires_module' => {'Algorithm::Diff' => 0,'CGI::Cookie' => 0,'LWP' => '5.6','MIME::Base64' => 0,'Net::SMTP' => 0,'Pod::Man' => '1.14','Pod::Usage' => 0,'Test::Builder::Tester' => 0,'Test::MockObject' => '0.07','Test::More' => 0,'Text::Balanced' => 0,'Time::HiRes' => 0,'URI' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'size' => {'packed' => 90135,'unpacked' => 371366},'testers' => {'pass' => 1},'uses' => ['5.005','Algorithm::Diff','Cwd','Exporter','File::Copy','File::Find','File::Path','File::Spec::Functions','HTML::TokeParser','HTTP::Cookies','HTTP::Daemon','HTTP::Request','HTTP::Request::Common','HTTP::Status','HTTP::WebTest::API','HTTP::WebTest::Cookies','IO::File','LWP::UserAgent','MIME::Base64','Net::SMTP','Test::Builder','Text::Balanced','Time::HiRes','URI','constant','strict','vars']},'HTTP-WebTest-Plugin-Apache-1.01.tar.gz' => {'author' => 'ILYAM','description' => 'Plugin for local web file tests','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 475,'pod' => 226,'pod_errors' => 0,'total' => 701,'with_comments' => 57},'releases' => 2,'requires' => ['File-Temp-0.12.tar.gz','HTTP-WebTest-2.03.tar.gz'],'requires_module' => {'File::Temp' => 0,'HTTP::WebTest' => 2},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTTP-WebTest-2.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'size' => {'packed' => 26256,'unpacked' => 64021},'testers' => {'pass' => 2},'uses' => ['Config','File::Basename','File::Copy','File::Path','File::Spec::Functions','File::Temp','HTTP::Request::Common','HTTP::WebTest::Plugin','HTTP::WebTest::Utils','IO::File','POSIX','Time::HiRes','URI','constant','strict']},'HTTP-WebTest-Plugin-DateTest-1.01.tar.gz' => {'author' => 'JLAPOUTRE','description' => 'Evaluate the "age" of embedded date strings in response body','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 243,'pod' => 93,'pod_errors' => 0,'total' => 336,'with_comments' => 27},'releases' => 2,'requires' => ['HTTP-WebTest-2.03.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz'],'requires_module' => {'Date::Parse' => '2.23','HTTP::WebTest' => 2,'Test::More' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTTP-WebTest-2.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Time-HiRes-1.49.tar.gz','TimeDate-1.16.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'size' => {'packed' => 8888,'unpacked' => 23824},'testers' => {'pass' => 2},'uses' => ['Date::Language::English','Date::Parse','HTTP::WebTest::Plugin','strict','vars']},'HTTP-WebTest-Plugin-TagAttTest-1.00.tar.gz' => {'author' => 'EFANCHE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 223,'pod' => 93,'pod_errors' => 0,'total' => 316,'with_comments' => 39},'releases' => 1,'requires' => ['HTTP-WebTest-2.03.tar.gz'],'requires_module' => {'HTTP::WebTest' => 2},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTTP-WebTest-2.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'size' => {'packed' => 5312,'unpacked' => 13617},'testers' => {},'uses' => ['HTML::TokeParser','HTTP::Status','HTTP::WebTest::Plugin','strict','vars']},'HTTP-WebTest-Plugin-XMLReport-1.01.tar.gz' => {'author' => 'JLAPOUTRE','description' => 'Report plugin for HTTP::WebTest, generates output in XML format =head2 VERSION version 1.00 - $Revision: 1.4 $ Compatible with L<HTTP::WebTest|HTTP::WebTest> version 2.x API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 210,'pod' => 150,'pod_errors' => 0,'total' => 360,'with_comments' => 21},'releases' => 2,'requires' => ['HTTP-WebTest-2.03.tar.gz','IO-stringy-2.108.tar.gz','Test-Simple-0.47.tar.gz','XML-Writer-0.4.tar.gz'],'requires_module' => {'HTTP::WebTest' => 2,'IO::Scalar' => 2,'Test::More' => 0,'XML::Writer' => '0.4'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTTP-WebTest-2.03.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','XML-Writer-0.4.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'size' => {'packed' => 13917,'unpacked' => 46266},'testers' => {'pass' => 1},'uses' => ['HTTP::WebTest::ReportPlugin','IO::Scalar','POSIX','XML::Writer','strict','vars']},'HTTP-Webdav-0.1.18-0.17.1.tar.gz' => {'author' => 'GRICHTER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3018,'pod' => 4479,'pod_errors' => 2,'total' => 7497,'with_comments' => 16},'releases' => 1,'size' => {'packed' => 33078,'unpacked' => 216693},'testers' => {'fail' => 1},'uses' => ['DynaLoader','Exporter','constant','strict','vars']},'HTTPD-Log-Filter-1.07.tar.gz' => {'author' => 'AWRIGLEY','description' => 'module to filter entries out of an httpd log','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 490,'pod' => 162,'pod_errors' => 0,'total' => 652,'with_comments' => 30},'releases' => 4,'requires' => ['IO-1.20.tar.gz','IO-Zlib-1.01.tar.gz'],'requires_module' => {'IO::File' => undef,'IO::Zlib' => undef},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','IO-1.20.tar.gz','IO-Zlib-1.01.tar.gz'],'size' => {'packed' => 10273,'unpacked' => 48842},'testers' => {'pass' => 7},'uses' => ['IO::File','IO::Zlib','strict','vars','warnings']},'HTTPD-Log-Merge-1.tar.gz' => {'author' => 'AWRIGLEY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 136,'pod' => 48,'pod_errors' => 0,'total' => 184,'with_comments' => 16},'releases' => 1,'requires' => ['HTTPD-Log-Filter-1.07.tar.gz','IO-1.20.tar.gz','TimeDate-1.16.tar.gz'],'requires_module' => {'Date::Parse' => undef,'HTTPD::Log::Filter' => '1.03','IO::File' => undef},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','HTTPD-Log-Filter-1.07.tar.gz','IO-1.20.tar.gz','IO-Zlib-1.01.tar.gz','TimeDate-1.16.tar.gz'],'size' => {'packed' => 5244,'unpacked' => 23378},'testers' => {'pass' => 3},'uses' => ['Date::Parse','HTTPD::Log::Filter','IO::File','strict','v5.6.0','vars','warnings']},'HTTPD-User-Manage-1.59.tar.gz' => {'author' => 'LDS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2792,'pod' => 1246,'pod_errors' => 1,'total' => 4038,'with_comments' => 187},'releases' => 7,'size' => {'packed' => 112121,'unpacked' => 252758},'testers' => {'fail' => 3,'pass' => 7,'tests' => '52'},'uses' => ['$module','Carp','DBI','Exporter','Fcntl','File::Basename','HTTPD::GroupAdmin','HTTPD::Realm','HTTPD::RealmManager','HTTPD::UserAdmin','MD5','MIME::Base64','Msql','NDBM_File','Symbol','strict','vars']},'HTTPD-User-Manage-1.61.tar.gz' => {'author' => 'LDS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2844,'pod' => 1246,'pod_errors' => 1,'total' => 4090,'with_comments' => 193},'releases' => 7,'size' => {'packed' => 113915,'unpacked' => 258688},'testers' => {'fail' => 3,'pass' => 9,'tests' => '66'},'uses' => ['$module','Carp','DBI','Digest::SHA1','Exporter','Fcntl','File::Basename','MD5','MIME::Base64','Msql','NDBM_File','Symbol','strict','vars']},'HTTPD-WatchLog-0.02.tar.gz' => {'author' => 'RYOCHIN','description' => 'watching Apache AccessLog simply in realtime','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 125,'pod_errors' => 0,'total' => 260,'with_comments' => 8},'releases' => 2,'requires' => ['Class-Accessor-0.18.tar.gz','File-Tail-0.98.tar.gz'],'requires_module' => {'Class::Accessor' => '0.1','File::Tail' => '0.5'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','File-Tail-0.98.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3956,'unpacked' => 10295},'testers' => {'pass' => 2},'uses' => ['','5.00502','Class::Accessor','File::Tail','Socket','strict','vars']},'Hardware-Verilog-Parser-0.13.tar.gz' => {'author' => 'GSLONDON','description' => 'A complete grammar for parsing Verilog code using perl','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2173,'pod' => 52,'pod_errors' => 0,'total' => 2225,'with_comments' => 341},'releases' => 12,'size' => {'packed' => 23854,'unpacked' => 115656},'testers' => {'fail' => 3,'pass' => 3},'uses' => ['5','Benchmark','Data::Dumper','Parse::RecDescent','PrecompiledParser','strict','vars']},'Hardware-Vhdl-Parser-0.12.tar.gz' => {'author' => 'GSLONDON','description' => 'A complete grammar for parsing VHDL code using perl','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2355,'pod' => 52,'pod_errors' => 0,'total' => 2407,'with_comments' => 167},'releases' => 7,'size' => {'packed' => 13033,'unpacked' => 56477},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['Parse::RecDescent','strict','vars']},'Hardware-iButton-0.03.tar.gz' => {'author' => 'SCOTT','description' => 'object to represent iButtons','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1136,'pod' => 137,'pod_errors' => 0,'total' => 1273,'with_comments' => 286},'releases' => 1,'size' => {'packed' => 21741,'unpacked' => 64262},'testers' => {'pass' => 4},'uses' => ['AutoLoader','Exporter','IO::File','IO::Stty','POSIX','Time::HiRes','constant','strict','vars']},'Harvey-1.02.1.tar.gz' => {'author' => 'MEYERCJM','description' => 'Simple dialog module for testing parsings.','files' => ['README'],'lines' => {'nonpod' => 8874,'pod' => 782,'pod_errors' => 0,'total' => 9656,'with_comments' => 2886},'releases' => 2,'size' => {'packed' => 4358848,'unpacked' => 93673151},'testers' => {'fail' => 2},'uses' => ['5.006','Fcntl','Harvey::Verb','Harvey::Word','MLDBM','strict','warnings']},'Hash-Case-1.002.tar.gz' => {'author' => 'MARKOV','description' => 'base class for hashes with key-casing requirements','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 256,'pod' => 215,'pod_errors' => 0,'total' => 471,'with_comments' => 14},'releases' => 2,'size' => {'packed' => 4060,'unpacked' => 15623},'testers' => {'pass' => 7},'uses' => ['Carp','Tie::Hash','strict']},'Hash-Filler-1.40.tar.gz' => {'author' => 'LUISMUNOZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 371,'pod' => 154,'pod_errors' => 0,'total' => 525,'with_comments' => 59},'releases' => 5,'requires' => ['Time-HiRes-1.49.tar.gz'],'requires_module' => {'Time::HiRes' => 0},'requires_recursive' => ['Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 8649,'unpacked' => 32933},'testers' => {'pass' => 7},'uses' => ['Carp','Time::HiRes','constant','strict','vars']},'Hash-Merge-0.07.tar.gz' => {'author' => 'MNEYLON','description' => 'Merges arbitrarily deep hashes into a single hash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 365,'pod' => 190,'pod_errors' => 0,'total' => 555,'with_comments' => 74},'releases' => 5,'requires' => ['Clone-0.13.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Clone' => 0,'Test::More' => '0.33'},'requires_recursive' => ['Clone-0.13.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7319,'unpacked' => 25670},'testers' => {'pass' => 17},'uses' => ['Clone','strict','vars']},'Hash-MultiKey-0.05.tar.gz' => {'author' => 'FXN','description' => 'hashes whose keys can be multiple','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 235,'pod_errors' => 0,'total' => 387,'with_comments' => 31},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6954,'unpacked' => 28544},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','strict','vars','warnings']},'Hash-NoVivify-0.01.tar.gz' => {'author' => 'BPOWERS','description' => 'Provide non-autovivifying hash functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 48,'pod_errors' => 0,'total' => 80,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 2632,'unpacked' => 6570},'testers' => {'pass' => 11},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Hash-WithDefaults-0.04.tar.gz' => {'author' => 'JENDA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 562,'pod' => 86,'pod_errors' => 0,'total' => 648,'with_comments' => 31},'releases' => 1,'size' => {'packed' => 4033,'unpacked' => 16263},'testers' => {'pass' => 6},'uses' => ['Carp','Tie::Hash','strict','vars']},'HashBang-0.10.tar.gz' => {'author' => 'INGY','description' => 'Write your own language interpreters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11,'pod' => 39,'pod_errors' => 0,'total' => 50,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1915,'unpacked' => 3077},'testers' => {'pass' => 5},'uses' => []},'Heap-0.50.tar.gz' => {'author' => 'JMM','description' => 'Implement Binary Heap','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1675,'pod' => 483,'pod_errors' => 0,'total' => 2158,'with_comments' => 239},'releases' => 3,'size' => {'packed' => 28966,'unpacked' => 204663},'testers' => {'pass' => 34},'uses' => ['AutoLoader','Exporter','strict','vars']},'Heap-Priority-0.01.tar.gz' => {'author' => 'JFREEMAN','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 165,'pod' => 156,'pod_errors' => 0,'total' => 321,'with_comments' => 8},'releases' => 3,'size' => {'packed' => 7233,'unpacked' => 30780},'testers' => {'pass' => 9},'uses' => ['Carp','strict','vars']},'Heap-Simple-0.05.tar.gz' => {'author' => 'THOSPEL','description' => 'Fast and easy to use classic heaps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 747,'pod' => 546,'pod_errors' => 0,'total' => 1293,'with_comments' => 19},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.11'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 15186,'unpacked' => 57935},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','Heap::Simple::$name','constant','strict','vars']},'Hook-Heckle-0.01.01.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 103,'pod' => 88,'pod_errors' => 0,'total' => 191,'with_comments' => 0},'releases' => 1,'requires' => ['Class-Maker-0.5.14.tar.gz'],'requires_module' => {'Class::Maker' => 0},'requires_recursive' => ['Class-Maker-0.5.14.tar.gz','Data-Dumper-2.101.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz'],'size' => {'packed' => 2631,'unpacked' => 5807},'testers' => {'pass' => 8},'uses' => ['5.006','Class::Maker','strict','warnings']},'Hook-LexWrap-0.20.tar.gz' => {'author' => 'DCONWAY','description' => 'Lexically scoped subroutine wrappers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 153,'pod' => 172,'pod_errors' => 0,'total' => 325,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 6369,'unpacked' => 17854},'testers' => {'fail' => 2,'pass' => 12},'uses' => ['5.006','Carp']},'Hook-Scope-0.04.tar.gz' => {'author' => 'ABERGMAN','description' => 'Register code to run on scope leaves.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 141,'pod' => 66,'pod_errors' => 2,'total' => 207,'with_comments' => 10},'releases' => 4,'requires' => ['B-Generate-1.06.tar.gz','optimizer-0.05.tar.gz'],'requires_module' => {'B::Generate' => '1.06','optimizer' => '0.05'},'requires_recursive' => ['B-Generate-1.06.tar.gz','optimizer-0.05.tar.gz'],'size' => {'packed' => 9712,'unpacked' => 24880},'testers' => {'fail' => 1},'uses' => ['5.008','B::Generate','DynaLoader','Exporter','strict','vars']},'Hook-WrapSub-0.03.tar.gz' => {'author' => 'JDPORTER','description' => 'wrap subs with pre- and post-call hooks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 168,'pod' => 137,'pod_errors' => 0,'total' => 305,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 4953,'unpacked' => 14653},'testers' => {'pass' => 11},'uses' => ['Exporter','Symbol','strict','vars']},'HookPrePostCall-1.2.tar.gz' => {'author' => 'PVERD','description' => 'Add actions before and after a routine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 128,'pod' => 60,'pod_errors' => 0,'total' => 188,'with_comments' => 10},'releases' => 2,'size' => {'packed' => 2502,'unpacked' => 6438},'testers' => {'pass' => 7},'uses' => ['5.000','strict']},'HtDig-Config-1.01.tar.gz' => {'author' => 'JTILLMAN','description' => 'Perl extension for managing ht://Dig configuration files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 847,'pod' => 201,'pod_errors' => 0,'total' => 1048,'with_comments' => 180},'releases' => 1,'requires' => ['DateManip-5.42a.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'Date::Manip' => 0,'Net::SMTP' => 0},'requires_recursive' => ['DateManip-5.42a.tar.gz','IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 20023,'unpacked' => 72440},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['AutoLoader','Data::Dumper','Date::Manip','Exporter','File::Copy','File::Spec','File::stat','Net::SMTP','strict','vars']},'HtDig-Database-0.52.tar.gz' => {'author' => 'GHUTCHIS','description' => 'Perl interface Ht://Dig docdb and config files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 259,'pod' => 92,'pod_errors' => 0,'total' => 351,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 6373,'unpacked' => 15544},'testers' => {'pass' => 6},'uses' => ['5.000','Carp','Exporter','constant','strict','vars']},'HyperWave-CSP-0.03.1.tar.gz' => {'author' => 'GOSSAMER','description' => 'Communicate with a HyperWave server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1552,'pod' => 159,'pod_errors' => 1,'total' => 1711,'with_comments' => 143},'releases' => 3,'size' => {'packed' => 17124,'unpacked' => 71992},'testers' => {'fail' => 5},'uses' => ['Carp','Exporter','Fcntl','Locale::Language','Socket','Symbol','strict','succeeds','vars']},'I18N-AcceptLanguage-1.00.tar.gz' => {'author' => 'CGILMORE','description' => 'Matches language preference to available languages','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 466,'pod' => 105,'pod_errors' => 0,'total' => 571,'with_comments' => 306},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.45'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8370,'unpacked' => 26852},'testers' => {'pass' => 6},'uses' => ['5.006001','strict','vars','warnings']},'I18N-Charset-1.24.tar.gz' => {'author' => 'MTHURN','description' => 'Character set names and aliases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2855,'pod' => 237,'pod_errors' => 1,'total' => 3092,'with_comments' => 260},'releases' => 19,'requires' => ['App-Info-0.23.tar.gz','IO-String-1.02.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'App::Info::Lib::Iconv' => 0,'IO::String' => 0,'Test::More' => 0,'Test::Simple' => 0},'requires_recursive' => ['App-Info-0.23.tar.gz','File-Spec-0.82.tar.gz','IO-String-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 25186,'unpacked' => 116514},'testers' => {'pass' => 4},'uses' => ['5.002','Carp','Exporter','IO::String','Unicode::MapUTF8','strict','vars']},'I18N-LangTags-0.28.tar.gz' => {'author' => 'SBURKE','description' => 'compare & extract language tags (RFC3066)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 780,'pod' => 1758,'pod_errors' => 0,'total' => 2538,'with_comments' => 112},'releases' => 15,'size' => {'packed' => 22128,'unpacked' => 61436},'testers' => {'pass' => 2},'uses' => ['5','5.000','Exporter','HTML::TreeBuilder','LWP::Simple','strict','vars']},'IBM-LoadLeveler-0.07.tar.gz' => {'author' => 'HAWKINSM','description' => 'Interface to IBM LoadLeveler Job Scheduler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 730,'pod' => 783,'pod_errors' => 8,'total' => 1513,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 33302,'unpacked' => 156484},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','llapi.ph','strict','warnings']},'IChing-Hexagram-Illuminatus-0.01.tar.gz' => {'author' => 'STRYTOAST','description' => 'An IChing hexagram','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 142,'pod' => 163,'pod_errors' => 0,'total' => 305,'with_comments' => 6},'releases' => 1,'requires' => ['HTML-Summary-0.017.tar.gz','HTML-Tree-3.17.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::Summary' => '0.01','HTML::TreeBuilder' => '2.03','HTTP::Request' => '1.3','LWP::UserAgent' => '2.00'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Summary-0.017.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4207,'unpacked' => 10125},'testers' => {'pass' => 3},'uses' => ['HTML::Summary','HTML::TreeBuilder','HTTP::Request','LWP::UserAgent','strict','warnings']},'IDNA-Punycode-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'encodes Unicode string in Punycode','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 154,'pod' => 49,'pod_errors' => 0,'total' => 203,'with_comments' => 1},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2570,'unpacked' => 5247},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','constant','integer','strict']},'IETF-ACE-0.02.tar.gz' => {'author' => 'JBRIGGS','description' => 'Perl extension for IETF IDN WG ACE character conversions','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 564,'pod' => 76,'pod_errors' => 0,'total' => 640,'with_comments' => 108},'releases' => 2,'size' => {'packed' => 6740,'unpacked' => 21400},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['AutoLoader','Exporter','MIME::Base64','Unicode::String','diagnostics','strict','vars']},'ILL-GS-0.04.tar.gz' => {'author' => 'DCHRIS','description' => 'Interlibrary Loan Generic Script (GS)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 110,'pod' => 88,'pod_errors' => 0,'total' => 198,'with_comments' => 24},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4330,'unpacked' => 10439},'testers' => {'pass' => 3},'uses' => ['Carp','strict','warnings']},'IMAP-Admin-1.6.1.tar.gz' => {'author' => 'EESTABROO','description' => 'IMAP Administration','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 659,'pod' => 139,'pod_errors' => 0,'total' => 798,'with_comments' => 30},'releases' => 20,'size' => {'packed' => 13587,'unpacked' => 40487},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['Carp','Cwd','Digest::HMAC','Digest::MD5','IO::Select','IO::Socket','IO::Socket::INET','MIME::Base64','strict','vars']},'IMAPGet-0.1.tar.gz' => {'author' => 'UGEN','description' => undef,'files' => [],'lines' => {'nonpod' => 454,'pod' => 0,'pod_errors' => 0,'total' => 454,'with_comments' => 29},'releases' => 1,'size' => {'packed' => 3344,'unpacked' => 11562},'testers' => {},'uses' => ['5.002','Fcntl','FileHandle','Socket','strict']},'INET6-1.27.tar.gz' => {'author' => 'MONDEJAR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 335,'pod' => 130,'pod_errors' => 0,'total' => 465,'with_comments' => 21},'releases' => 2,'size' => {'packed' => 5317,'unpacked' => 15733},'testers' => {'fail' => 2,'tests' => '6'},'uses' => ['Carp','Errno','Exporter','IO::Socket','Socket6','strict']},'INSPEC-0.01.tar.gz' => {'author' => 'VPLA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 692,'pod' => 62,'pod_errors' => 0,'total' => 754,'with_comments' => 202},'releases' => 1,'size' => {'packed' => 8454,'unpacked' => 24342},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.000','Exporter','LWP::Simple','Text::ParseWords','strict','vars']},'IO-1.20.tar.gz' => {'author' => 'GBARR','description' => 'Object interface to system select call','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2020,'pod' => 876,'pod_errors' => 0,'total' => 2896,'with_comments' => 104},'releases' => 18,'size' => {'packed' => 31587,'unpacked' => 108912},'testers' => {'fail' => 6,'pass' => 1},'uses' => ['5.000','5.003_26','Carp','DynaLoader','Exporter','Fcntl','File::stat','IO::','SelectSaver','Socket','Symbol','Tie::Hash','happy','strict','vars']},'IO-BLOB-Pg-0.91.tar.gz' => {'author' => 'MAHEX','description' => 'Emulate IO::File interface for PostgreSQL Large Objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 458,'pod' => 109,'pod_errors' => 0,'total' => 567,'with_comments' => 24},'releases' => 2,'requires' => ['DBD-Pg-1.22.tar.gz','DBI-1.37.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DBD::Pg' => 0,'DBI' => 0,'Test::More' => 0},'requires_recursive' => ['DBD-Pg-1.22.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7455,'unpacked' => 20984},'testers' => {'fail' => 2,'pass' => 1,'tests' => '3'},'uses' => ['5.005_03','Carp','Data::Dumper','IO::Handle','strict','vars']},'IO-Capture-0.01.tar.gz' => {'author' => 'REYNOLDS','description' => 'Abstract Base Class to build modules to capture output.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 553,'pod' => 687,'pod_errors' => 0,'total' => 1240,'with_comments' => 6},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10652,'unpacked' => 51205},'testers' => {'pass' => 3},'uses' => ['Carp','strict']},'IO-Cat-1.01.tar.gz' => {'author' => 'FIMM','description' => 'Object-oriented Perl implementation of cat(1)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 111,'pod' => 45,'pod_errors' => 0,'total' => 156,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 2293,'unpacked' => 4426},'testers' => {'pass' => 6},'uses' => ['Carp','IO::File','strict','vars']},'IO-Default-1.03.tar.gz' => {'author' => 'NWIGER','description' => 'Replace select() with $DEFOUT, $DEFERR, $DEF','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 182,'pod' => 86,'pod_errors' => 0,'total' => 268,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 4483,'unpacked' => 13179},'testers' => {'pass' => 9},'uses' => ['5.005','Carp','Exporter','strict','vars']},'IO-Dir-Dirfd-0.01.tar.gz' => {'author' => 'GRUBER','description' => 'Perl extension to extract the file descriptor from a dirhandle','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 37,'pod_errors' => 0,'total' => 90,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 2790,'unpacked' => 10561},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['DynaLoader','Exporter','strict','vars']},'IO-Dirent-0.02.tar.gz' => {'author' => 'SCOTTW','description' => 'Access to dirent structs returned by readdir','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 60,'pod' => 85,'pod_errors' => 0,'total' => 145,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 4412,'unpacked' => 11871},'testers' => {'pass' => 2},'uses' => ['DynaLoader','Exporter','constant','strict','vars']},'IO-Event-0.2.tar.gz' => {'author' => 'MUIR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 899,'pod' => 232,'pod_errors' => 0,'total' => 1131,'with_comments' => 80},'releases' => 2,'size' => {'packed' => 12071,'unpacked' => 47283},'testers' => {'fail' => 1,'tests' => '23'},'uses' => ['Carp','Event','Event::Watcher','IO::Handle','IO::Socket::INET','IO::Socket::UNIX','POSIX','Socket','Symbol','UNIVERSAL','strict']},'IO-Extended-0.06.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 244,'pod' => 115,'pod_errors' => 0,'total' => 359,'with_comments' => 8},'releases' => 5,'size' => {'packed' => 3684,'unpacked' => 9145},'testers' => {'pass' => 1},'uses' => ['5.005_62','Exporter','strict','subs','warnings']},'IO-File-Log-1.01.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'IO::File abstraction on logging files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 234,'pod' => 78,'pod_errors' => 0,'total' => 312,'with_comments' => 26},'releases' => 2,'requires' => ['IO-1.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'IO::Select' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5099,'unpacked' => 13481},'testers' => {'pass' => 5},'uses' => ['5.005_62','Carp','IO::File','IO::Select','strict','vars','warnings']},'IO-File-Multi-1.02.tar.gz' => {'author' => 'NEMWS','description' => 'Print to multiple filehandles with one output call','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 104,'pod' => 54,'pod_errors' => 0,'total' => 158,'with_comments' => 36},'releases' => 2,'size' => {'packed' => 3227,'unpacked' => 7838},'testers' => {'pass' => 3},'uses' => ['Carp','IO::File','strict','vars']},'IO-File-flock-0.07.tar.gz' => {'author' => 'MAKOTO','description' => 'extension of IO::File for flock','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 71,'pod' => 75,'pod_errors' => 0,'total' => 146,'with_comments' => 3},'releases' => 5,'size' => {'packed' => 2417,'unpacked' => 4888},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','Fcntl','IO::File','strict','warnings']},'IO-Filter-0.01.tar.gz' => {'author' => 'RWMJ','description' => 'Generic filters for IO handles.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 991,'pod' => 523,'pod_errors' => 9,'total' => 1514,'with_comments' => 221},'releases' => 1,'size' => {'packed' => 7847,'unpacked' => 42933},'testers' => {'fail' => 1,'pass' => 10,'tests' => '38'},'uses' => ['Carp','IO::Pipe','constant','strict','succeeds','vars']},'IO-Interface-0.97.tar.gz' => {'author' => 'LDS','description' => 'Perl extension for access to network card configuration information','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 109,'pod' => 143,'pod_errors' => 0,'total' => 252,'with_comments' => 8},'releases' => 3,'size' => {'packed' => 6895,'unpacked' => 23341},'testers' => {'pass' => 7},'uses' => ['5.005','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'IO-Language-0.01.tar.gz' => {'author' => 'CWEST','description' => 'Perl module for I18N output.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 35,'pod_errors' => 0,'total' => 99,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1802,'unpacked' => 3360},'testers' => {'pass' => 3},'uses' => ['Carp','IO::Handle','Lingua::Translate','strict','vars','warnings']},'IO-LockedFile-0.23.tar.gz' => {'author' => 'RANI','description' => 'supply object methods for locking files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 456,'pod' => 194,'pod_errors' => 0,'total' => 650,'with_comments' => 105},'releases' => 5,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Fcntl' => undef,'IO::File' => undef},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7599,'unpacked' => 26109},'testers' => {'fail' => 1,'pass' => 9},'uses' => ['Carp','Fcntl','IO::File','strict','vars']},'IO-Multiplex-1.04.tar.gz' => {'author' => 'BBB','description' => 'Manage Input Output on many file handles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 615,'pod' => 399,'pod_errors' => 0,'total' => 1014,'with_comments' => 61},'releases' => 11,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO::Socket' => 0},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 13178,'unpacked' => 43470},'testers' => {'pass' => 9},'uses' => ['Carp','Fcntl','FileHandle','IO::Handle','POSIX','Socket','Tie::Handle','strict','vars']},'IO-NonBlocking-1.035.tar.gz' => {'author' => 'ROMERUN','description' => 'Object-oriented interface to non-blocking IO server implementation.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 390,'pod' => 331,'pod_errors' => 1,'total' => 721,'with_comments' => 27},'releases' => 7,'size' => {'packed' => 7271,'unpacked' => 19863},'testers' => {'pass' => 4},'uses' => ['Fcntl','IO::Select','IO::Socket','POSIX','Socket','Tie::RefHash','strict','vars','warnings']},'IO-Null-0.02.tar.gz' => {'author' => 'SBURKE','description' => '- class for null filehandles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 117,'pod_errors' => 0,'total' => 181,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 3894,'unpacked' => 9694},'testers' => {'pass' => 10},'uses' => ['5','strict','vars']},'IO-Pager-0.05.tgz' => {'author' => 'JPIERCE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 273,'pod' => 348,'pod_errors' => 0,'total' => 621,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 6034,'unpacked' => 18992},'testers' => {'pass' => 1},'uses' => ['5','File::Spec','Tie::Handle','strict','vars']},'IO-React-1.03.tar.gz' => {'author' => 'GARROW','description' => 'Object oriented expect-like communication','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 92,'pod_errors' => 0,'total' => 239,'with_comments' => 18},'releases' => 2,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'IO::File' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3424,'unpacked' => 8206},'testers' => {'pass' => 6},'uses' => ['5.6.0','Carp','IO::File','strict']},'IO-Select-Trap-0.03.tar.gz' => {'author' => 'SCOTTS','description' => 'IO::Select() functionality on Scalar-based Filehandles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 186,'pod' => 56,'pod_errors' => 0,'total' => 242,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 3181,'unpacked' => 7966},'testers' => {'pass' => 2,'tests' => '0','unknown' => 3},'uses' => ['IO::Select','strict','vars']},'IO-SendFile-0.01.tar.gz' => {'author' => 'ADDI','description' => 'Perl extension that implements the sendfile() interface.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 30,'pod_errors' => 0,'total' => 61,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 2138,'unpacked' => 3907},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'IO-Shaper-0.2.tar.gz' => {'author' => 'BHOLZMAN','description' => 'Simple TCP Traffic Shaper','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 27,'pod_errors' => 0,'total' => 121,'with_comments' => 1},'releases' => 2,'requires' => ['IO-1.20.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'IO::Select' => 0,'Time::HiRes' => 0},'requires_recursive' => ['IO-1.20.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 2833,'unpacked' => 5840},'testers' => {'pass' => 2},'uses' => ['5.006','IO::Select','IO::Socket','Time::HiRes','strict','warnings']},'IO-Sockatmark-1.00.tar.gz' => {'author' => 'LDS','description' => 'Perl extension for TCP urgent data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 47,'pod_errors' => 0,'total' => 83,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2315,'unpacked' => 4733},'testers' => {'pass' => 6},'uses' => ['5.005','DynaLoader','Exporter','strict','vars']},'IO-Socket-Multicast-0.25.tar.gz' => {'author' => 'LDS','description' => 'Send and receive multicast messages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 185,'pod_errors' => 0,'total' => 390,'with_comments' => 1},'releases' => 7,'requires' => ['IO-Interface-0.97.tar.gz'],'requires_module' => {'IO::Interface' => '0.94'},'requires_recursive' => ['IO-Interface-0.97.tar.gz'],'size' => {'packed' => 8477,'unpacked' => 31353},'testers' => {'fail' => 3,'pass' => 6},'uses' => ['5.005','Carp','DynaLoader','Exporter','IO::Interface','IO::Socket','strict','vars']},'IO-Socket-SSL-0.94.tar.gz' => {'author' => 'BEHROOZI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 766,'pod' => 264,'pod_errors' => 0,'total' => 1030,'with_comments' => 37},'releases' => 17,'requires' => ['Net_SSLeay.pm-1.23.tar.gz'],'requires_module' => {'Net::SSLeay' => '1.08'},'requires_recursive' => ['Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 24677,'unpacked' => 69803},'testers' => {'pass' => 2},'uses' => ['Carp','IO::Socket','Net::SSLeay','strict','vars']},'IO-Socket-Socks-0.1.tar.gz' => {'author' => 'REATMON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2784,'pod' => 1279,'pod_errors' => 0,'total' => 4063,'with_comments' => 277},'releases' => 1,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO::Socket::INET' => 0},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 38161,'unpacked' => 132756},'testers' => {'pass' => 1},'uses' => ['','Carp','Exporter','IO::Socket','IO::Socket::INET','constant','strict','vars']},'IO-String-1.02.tar.gz' => {'author' => 'GAAS','description' => 'IO::File interface for in-core strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 81,'pod_errors' => 0,'total' => 518,'with_comments' => 25},'releases' => 6,'size' => {'packed' => 6314,'unpacked' => 17510},'testers' => {'pass' => 8},'uses' => ['5.005_03','Data::Dumper','IO::Handle','strict','vars']},'IO-Stty-.02.tar.gz' => {'author' => 'AUSCHUTZ','description' => 'POSIX compliant stty interface','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 319,'pod' => 0,'pod_errors' => 0,'total' => 319,'with_comments' => 50},'releases' => 2,'size' => {'packed' => 7019,'unpacked' => 23224},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['5','POSIX']},'IO-Tee-0.64.tar.gz' => {'author' => 'KENSHAN','description' => 'Multiplex output to multiple handles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 250,'pod' => 129,'pod_errors' => 0,'total' => 379,'with_comments' => 7},'releases' => 6,'size' => {'packed' => 5039,'unpacked' => 15387},'testers' => {'pass' => 19},'uses' => ['5.004','Carp','IO::File','IO::Handle','Symbol','strict','vars']},'IO-Tty-1.02.tar.gz' => {'author' => 'RGIERSIG','description' => 'Low-level allocate a pseudo-Tty, import constants.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 353,'pod' => 243,'pod_errors' => 0,'total' => 596,'with_comments' => 12},'releases' => 8,'size' => {'packed' => 23105,'unpacked' => 67395},'testers' => {'fail' => 1,'pass' => 28},'uses' => ['Carp','DynaLoader','IO::File','IO::Handle','IO::Tty::Constant','POSIX','strict','vars']},'IO-Zlib-1.01.tar.gz' => {'author' => 'TOMHUGHES','description' => 'IO:: style interface to Compress::Zlib','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 201,'pod' => 119,'pod_errors' => 0,'total' => 320,'with_comments' => 5},'releases' => 4,'requires' => ['Compress-Zlib-1.22.tar.gz'],'requires_module' => {'Compress::Zlib' => 0},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz'],'size' => {'packed' => 4250,'unpacked' => 11334},'testers' => {'fail' => 2,'pass' => 30,'tests' => '61'},'uses' => ['5.004','Carp','Compress::Zlib','Symbol','Tie::Handle','strict','vars']},'IO-stringy-2.108.tar.gz' => {'author' => 'ERYQ','description' => 'I/O handle to read/write to array of lines','files' => [],'lines' => {'nonpod' => 0,'pod' => 0,'pod_errors' => 0,'total' => 0,'with_comments' => 0},'releases' => 22,'size' => {'packed' => 67531,'unpacked' => 108857},'testers' => {'pass' => 51},'uses' => []},'IO_CSVHeaderFile_0.02.tgz' => {'author' => 'VASEK','description' => 'Perl extension for CSV Files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 51,'pod_errors' => 0,'total' => 146,'with_comments' => 3},'releases' => 1,'requires' => ['Text-CSV_XS-0.23.tar.gz'],'requires_module' => {'Text::CSV_XS' => '0.2'},'requires_recursive' => ['Text-CSV_XS-0.23.tar.gz'],'size' => {'packed' => 2504,'unpacked' => 4783},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','IO::File','Text::CSV_XS','strict','vars']},'IP-Country-2.14.tar.gz' => {'author' => 'NWETTERS','description' => 'fast lookup of country codes from IP addresses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 612,'pod' => 287,'pod_errors' => 0,'total' => 899,'with_comments' => 59},'releases' => 19,'requires' => ['Geography-Countries-1.4.tar.gz'],'requires_module' => {'Geography::Countries' => '1.3'},'requires_recursive' => ['Geography-Countries-1.4.tar.gz'],'size' => {'packed' => 149999,'unpacked' => 371773},'testers' => {'pass' => 2},'uses' => ['Carp','Socket','strict','vars']},'IP-Registry-9999.9999.tar.gz' => {'author' => 'NWETTERS','description' => 'deprecated, use IP::Country::Fast','files' => ['Makefile.PL'],'lines' => {'nonpod' => 14,'pod' => 5,'pod_errors' => 0,'total' => 19,'with_comments' => 0},'releases' => 10,'requires' => ['IP-Country-2.14.tar.gz'],'requires_module' => {'IP::Country::Fast' => '212.005'},'requires_recursive' => ['Geography-Countries-1.4.tar.gz','IP-Country-2.14.tar.gz'],'size' => {'packed' => 1699,'unpacked' => 3186},'testers' => {'pass' => 1,'tests' => '0','unknown' => 6},'uses' => ['IP::Country::Fast','vars']},'IPA-1.01.tar.gz' => {'author' => 'KARASIK','description' => 'Image Processing Algorithms','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 858,'pod' => 652,'pod_errors' => 1,'total' => 1510,'with_comments' => 33},'releases' => 2,'size' => {'packed' => 62282,'unpacked' => 266672},'testers' => {'fail' => 1},'uses' => ['Carp','DynaLoader','Exporter','Prima::Classes','constant','strict','vars']},'IPC-Cache-0.02.tar.gz' => {'author' => 'DCLINTON','description' => 'Shared-memory object cache','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 494,'pod' => 157,'pod_errors' => 0,'total' => 651,'with_comments' => 38},'releases' => 2,'requires' => ['IPC-ShareLite-0.09.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'IPC::ShareLite' => '0.06','Storable' => '0.607'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IPC-ShareLite-0.09.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10667,'unpacked' => 33483},'testers' => {'pass' => 9},'uses' => ['Carp','Fcntl','IPC::ShareLite','Storable','strict','vars']},'IPC-ChildSafe-3.15.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 599,'pod' => 271,'pod_errors' => 0,'total' => 870,'with_comments' => 107},'releases' => 16,'testers' => {'fail' => 1,'pass' => 8},'uses' => ['5.004','Carp','Config','DynaLoader','Exporter','Win32::OLE','constant','strict','vars']},'IPC-Cmd-0.03.tar.gz' => {'author' => 'KANE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 296,'pod' => 125,'pod_errors' => 0,'total' => 421,'with_comments' => 25},'releases' => 2,'requires' => ['Locale-Maketext-Simple-0.02.tar.gz','Module-Load-Conditional-0.03.tar.gz','Params-Check-0.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Locale::Maketext::Simple' => 0,'Module::Load::Conditional' => 0,'Params::Check' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Locale-Maketext-Simple-0.02.tar.gz','Module-Load-0.05.tar.gz','Module-Load-Conditional-0.03.tar.gz','Params-Check-0.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5774,'unpacked' => 15083},'testers' => {'pass' => 2},'uses' => ['Config','Locale::Maketext::Simple','Module::Load::Conditional','Params::Check','strict','vars']},'IPC-LDT-2.03.tgz' => {'author' => 'JSTENZEL','description' => 'Implements a length based IPC protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 926,'pod' => 424,'pod_errors' => 0,'total' => 1350,'with_comments' => 236},'releases' => 2,'requires' => ['Filter-1.29.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'Filter::Util::Call' => 1,'Storable' => '0.6'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 13688,'unpacked' => 51433},'testers' => {'pass' => 10},'uses' => ['5.00503','Carp','Filter::Util::Call','IO::Select','POSIX','Storable','constant','fields','strict']},'IPC-Locker-1.410.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1087,'pod' => 279,'pod_errors' => 0,'total' => 1366,'with_comments' => 230},'releases' => 10,'testers' => {'pass' => 11},'uses' => ['5.004','Carp','Exporter','IO::Select','IO::Socket','POSIX','Socket','Sys::Hostname','strict','vars']},'IPC-MM-0.03.tar.gz' => {'author' => 'ACHOUNG','description' => 'Perl interface to Ralf Engelschall\'s mm library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 270,'pod' => 221,'pod_errors' => 0,'total' => 491,'with_comments' => 11},'releases' => 3,'size' => {'packed' => 11262,'unpacked' => 40437},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'IPC-Run-0.75.tar.gz' => {'author' => 'RBS','description' => 'system() and background procs w/ piping, redirs, ptys (Unix, Win32)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 5386,'pod' => 1920,'pod_errors' => 1,'total' => 7306,'with_comments' => 704},'releases' => 27,'size' => {'packed' => 87938,'unpacked' => 298371},'testers' => {'fail' => 3,'pass' => 13,'tests' => '264'},'uses' => ['','Carp','Data::Dumper','Exporter','Fcntl','File::Basename','File::Spec','IO::Handle','IO::Pty','POSIX','Socket','Symbol','Test','Text::ParseWords','UNIVERSAL','Win32::Process','Win32API::File','strict','vars']},'IPC-Run3-0.007.tar.gz' => {'author' => 'RBS','description' => 'Run a subprocess in batch mode (a la system) on Unix, Win32, etc.','files' => ['Makefile.PL'],'lines' => {'nonpod' => 389,'pod' => 146,'pod_errors' => 0,'total' => 535,'with_comments' => 26},'releases' => 3,'size' => {'packed' => 6187,'unpacked' => 18270},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','File::Spec','File::Temp','POSIX','UNIVERSAL','strict']},'IPC-Session-0.05.tar.gz' => {'author' => 'STEVEGT','description' => 'remote shell session mgr; wraps open3()','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 291,'pod' => 107,'pod_errors' => 0,'total' => 398,'with_comments' => 25},'releases' => 3,'size' => {'packed' => 5338,'unpacked' => 14803},'testers' => {'pass' => 12},'uses' => ['FileHandle','IPC::Open3','strict','vars']},'IPC-ShareLite-0.09.tar.gz' => {'author' => 'MAURICE','description' => 'Light-weight interface to shared memory','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 260,'pod' => 197,'pod_errors' => 0,'total' => 457,'with_comments' => 5},'releases' => 7,'size' => {'packed' => 36779,'unpacked' => 111216},'testers' => {'pass' => 3},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','subs','vars']},'IPC-Shareable-0.53.tar.gz' => {'author' => 'BSUGARS','description' => 'share Perl variables between processes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 939,'pod' => 324,'pod_errors' => 0,'total' => 1263,'with_comments' => 18},'releases' => 6,'requires' => ['Storable-2.07.tar.gz'],'requires_module' => {'Storable' => '0.607'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 26200,'unpacked' => 92249},'testers' => {},'uses' => ['5.00503','Carp','Data::Dumper','IPC::Semaphore','IPC::SysV','Storable','constant','strict','vars']},'IPC-Shareable-0.60.tar.gz' => {'author' => 'BSUGARS','description' => 'Tie a variable to shared memory','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1103,'pod' => 354,'pod_errors' => 0,'total' => 1457,'with_comments' => 33},'releases' => 6,'requires' => ['Storable-2.07.tar.gz'],'requires_module' => {'Storable' => '0.607'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 29239,'unpacked' => 102114},'testers' => {'fail' => 2,'pass' => 11,'tests' => '93'},'uses' => ['5.00503','Carp','Data::Dumper','Exporter','IPC::Semaphore','IPC::Shareable::SharedMem','IPC::SysV','Storable','constant','strict','vars']},'IPC-SharedCache-1.3.tar.gz' => {'author' => 'SAMTREGAR','description' => 'Manage a cache in SysV IPC shared memory','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 837,'pod' => 284,'pod_errors' => 0,'total' => 1121,'with_comments' => 116},'releases' => 3,'requires' => ['IPC-ShareLite-0.09.tar.gz','IPC-SysV-1.03.tar.gz','Storable-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '0','IPC::ShareLite' => '0.06','IPC::SysV' => '0','Storable' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IPC-ShareLite-0.09.tar.gz','IPC-SysV-1.03.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19717,'unpacked' => 67598},'testers' => {'pass' => 11},'uses' => ['Carp','Data::Dumper','IPC::ShareLite','Storable','integer','strict','vars']},'IPC-Signal-1.00.tar.gz' => {'author' => 'ROSCH','description' => 'Translate signal names to/from numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 56,'pod_errors' => 0,'total' => 132,'with_comments' => 11},'releases' => 2,'size' => {'packed' => 2649,'unpacked' => 5577},'testers' => {'pass' => 12},'uses' => ['5.003_94','Carp','Config','Exporter','strict','vars']},'IPC-SysV-1.03.tar.gz' => {'author' => 'GBARR','description' => 'shared memory, semaphores, messages etc','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 358,'pod' => 260,'pod_errors' => 1,'total' => 618,'with_comments' => 17},'releases' => 4,'size' => {'packed' => 7351,'unpacked' => 25302},'testers' => {'fail' => 5},'uses' => ['Carp','Class::Struct','Config','DynaLoader','Exporter','strict','vars']},'IPC-XPA-0.05.tar.gz' => {'author' => 'DJERIUS','description' => 'Interface to SAO XPA messaging system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 268,'pod' => 233,'pod_errors' => 0,'total' => 501,'with_comments' => 20},'releases' => 2,'size' => {'packed' => 9030,'unpacked' => 29300},'testers' => {},'uses' => ['Carp','Data::Dumper','DynaLoader','Exporter','strict','vars']},'IPC_SysV.tar.gz' => {'author' => 'JACKS','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 363,'pod' => 458,'pod_errors' => 15,'total' => 821,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 10378,'unpacked' => 40462},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','IPC::SysV']},'IPChains-0.5.tar.gz' => {'author' => 'JESSICAQ','description' => 'Create and Manipulate ipchains','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 334,'pod' => 234,'pod_errors' => 0,'total' => 568,'with_comments' => 29},'releases' => 2,'size' => {'packed' => 50881,'unpacked' => 198014},'testers' => {'fail' => 2},'uses' => ['DynaLoader','Exporter']},'IPTables-0.05.tar.gz' => {'author' => 'ZOZO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 228,'pod' => 0,'pod_errors' => 0,'total' => 228,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 22238,'unpacked' => 85338},'testers' => {'fail' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'IPTables-IPv4-0.97b.tar.gz' => {'author' => 'DPATES','description' => 'Perl module for manipulating iptables rules for the IPv4 protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 857,'pod' => 670,'pod_errors' => 0,'total' => 1527,'with_comments' => 31},'releases' => 1,'size' => {'packed' => 169821,'unpacked' => 490978},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','FileHandle','strict','vars']},'IRC-Bot-0.04.tar.gz' => {'author' => 'BWSMITH','description' => 'Channel Maintenance IRC bot.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1244,'pod' => 389,'pod_errors' => 0,'total' => 1633,'with_comments' => 84},'releases' => 4,'requires' => ['Cache-Cache-1.02.tar.gz','POE-Component-IRC-2.9.tar.gz'],'requires_module' => {'Cache::Cache' => '1.02','POE::Component::IRC' => '2.7'},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','POE-0.26.tar.gz','POE-Component-IRC-2.9.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9764,'unpacked' => 41098},'testers' => {'pass' => 1},'uses' => ['Cache::FileCache','Carp','Exporter','POE','POE::Component::IRC','POSIX','constant','diagnostics','strict','vars','warnings']},'IRR-1.00.tar.gz' => {'author' => 'TCAINE','description' => 'Perl interface to the Internet Route Registry Daemon','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 173,'pod' => 138,'pod_errors' => 0,'total' => 311,'with_comments' => 4},'releases' => 1,'requires' => ['Net-ext-1.011.tar.gz'],'requires_module' => {'Net::TCP' => 0},'requires_recursive' => ['Net-ext-1.011.tar.gz'],'size' => {'packed' => 4544,'unpacked' => 11700},'testers' => {'pass' => 4},'uses' => ['Exporter','Net::TCP','constant','strict','vars','warnings']},'IS-Conf-0.01.tar.gz' => {'author' => 'STEVEGT','description' => 'Infrastructure Configuration Management','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 60,'pod' => 56,'pod_errors' => 0,'total' => 116,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 9170,'unpacked' => 23663},'testers' => {'pass' => 5},'uses' => ['strict','vars']},'IS-Init-0.93.tar.gz' => {'author' => 'STEVEGT','description' => 'Clusterwide "init", spawn cluster applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 480,'pod' => 75,'pod_errors' => 0,'total' => 555,'with_comments' => 38},'releases' => 2,'size' => {'packed' => 15667,'unpacked' => 49849},'testers' => {'fail' => 9,'tests' => '99'},'uses' => ['Data::Dump','IO::Select','IO::Socket','POSIX','strict','vars']},'Ima-DBI-0.29.tar.gz' => {'author' => 'TMTM','description' => 'Database connection caching and organization','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 455,'pod' => 479,'pod_errors' => 0,'total' => 934,'with_comments' => 19},'releases' => 19,'requires' => ['Class-Data-Inheritable-0.02.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Data::Inheritable' => '0.02','Class::WhiteHole' => '0.03','DBI' => '1.2','Test::More' => '0.18'},'requires_recursive' => ['Class-Data-Inheritable-0.02.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 13902,'unpacked' => 43229},'testers' => {'pass' => 3},'uses' => ['Carp','Class::Data::Inheritable','Class::WhiteHole','DBI','DBI::db','DBI::st','strict','vars']},'Image-Base-1.07.tar.gz' => {'author' => 'SUMMER','description' => 'base class for loading, manipulating and saving images.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 253,'pod' => 152,'pod_errors' => 0,'total' => 405,'with_comments' => 35},'releases' => 5,'size' => {'packed' => 4509,'unpacked' => 17577},'testers' => {'pass' => 9},'uses' => ['Carp','strict','vars']},'Image-Button-0.53.tar.gz' => {'author' => 'JOANMG','description' => 'Base class for building PNG buttons using GD.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 648,'pod' => 426,'pod_errors' => 0,'total' => 1074,'with_comments' => 82},'releases' => 1,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => '2.05'},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8699,'unpacked' => 35460},'testers' => {'pass' => 1},'uses' => ['Cwd','GD','strict','vars']},'Image-Caption-0.01.tar.gz' => {'author' => 'IWADE','description' => 'Perl module for captioning RGB data','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 43,'pod_errors' => 0,'total' => 118,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 246946,'unpacked' => 3194315},'testers' => {'pass' => 4},'uses' => ['5.005_62','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Image-DS9-0.13.tar.gz' => {'author' => 'DJERIUS','description' => 'Interface to SAO DS9 image & analysis prog','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1920,'pod' => 968,'pod_errors' => 0,'total' => 2888,'with_comments' => 91},'releases' => 3,'requires' => ['IPC-XPA-0.05.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'IPC::XPA' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IPC-XPA-0.05.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 27832,'unpacked' => 95506},'testers' => {},'uses' => ['Carp','Data::Dumper','Exporter','IPC::XPA','PDL::Types','constant','strict','vars','warnings']},'Image-DeAnim-0.02.tar.gz' => {'author' => 'KENMACF','description' => 'Create static GIF file from animated GIF','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 157,'pod' => 46,'pod_errors' => 0,'total' => 203,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 3233,'unpacked' => 6970},'testers' => {'pass' => 9},'uses' => ['Exporter','strict','vars']},'Image-Density-0.1.tar.gz' => {'author' => 'GREGOR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 280,'pod' => 36,'pod_errors' => 0,'total' => 316,'with_comments' => 19},'releases' => 1,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline::C' => '0.44'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 341542,'unpacked' => 375819},'testers' => {'pass' => 2},'uses' => ['Exporter','Inline','strict','vars','warnings']},'Image-Dot-1.1.tar.gz' => {'author' => 'RGIERSIG','description' => 'create 1x1 pixel image files (pure-perl)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 178,'pod' => 30,'pod_errors' => 0,'total' => 208,'with_comments' => 32},'releases' => 2,'size' => {'packed' => 4383,'unpacked' => 8888},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars','warnings']},'Image-Filter-0.07.tar.gz' => {'author' => 'BEATNIK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 412,'pod' => 946,'pod_errors' => 0,'total' => 1358,'with_comments' => 18},'releases' => 7,'size' => {'packed' => 54216,'unpacked' => 142893},'testers' => {'fail' => 2},'uses' => ['DynaLoader','Exporter','vars']},'Image-GD-Thumbnail-0.02.tar.gz' => {'author' => 'LGODDARD','description' => 'Produce thumbnail images with the GD library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 26,'pod' => 53,'pod_errors' => 0,'total' => 79,'with_comments' => 1},'releases' => 4,'size' => {'packed' => 1921,'unpacked' => 3168},'testers' => {'pass' => 3},'uses' => ['strict','warnings']},'Image-Grab-1.4.tar.gz' => {'author' => 'MAHEX','description' => 'Grabbing images off the Internet','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 443,'pod' => 270,'pod_errors' => 0,'total' => 713,'with_comments' => 29},'releases' => 9,'requires' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tree-3.17.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Digest::MD5' => '2.07','HTML::HeadParser' => 0,'HTML::TreeBuilder' => '0.51','HTTP::Cookies' => 0,'LWP::UserAgent' => 0,'URI::URL' => 1},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12445,'unpacked' => 35176},'testers' => {'pass' => 8},'uses' => ['Carp','Config','Exporter','HTML::TreeBuilder','HTTP::Cookies','HTTP::Request','Image::Magick','LWP::UserAgent','MD5','POSIX','URI::URL','strict','vars']},'Image-IPTCInfo-1.6.tar.gz' => {'author' => 'JCARTER','description' => 'Extracts IPTC meta-info from images','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1242,'pod' => 147,'pod_errors' => 0,'total' => 1389,'with_comments' => 350},'releases' => 3,'size' => {'packed' => 34112,'unpacked' => 62503},'testers' => {'pass' => 6},'uses' => ['vars']},'Image-IPTCInfo-RasterCaption-0.1.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 188,'pod' => 90,'pod_errors' => 0,'total' => 278,'with_comments' => 17},'releases' => 1,'requires' => ['Image-IPTCInfo-1.6.tar.gz','PerlMagick-5.56.tar.gz'],'requires_module' => {'Image::IPTCInfo' => '1.6','Image::Magick' => '0.1'},'requires_recursive' => ['Image-IPTCInfo-1.6.tar.gz','PerlMagick-5.56.tar.gz'],'size' => {'packed' => 23459,'unpacked' => 57892},'testers' => {},'uses' => ['Carp','Image::IPTCInfo','Image::Magick','strict','vars']},'Image-IPTCInfo-TemplateFile-0.2.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 62,'pod_errors' => 0,'total' => 229,'with_comments' => 21},'releases' => 1,'requires' => ['Image-IPTCInfo-1.6.tar.gz'],'requires_module' => {'Image::IPTCInfo' => '1.6'},'requires_recursive' => ['Image-IPTCInfo-1.6.tar.gz'],'size' => {'packed' => 4046,'unpacked' => 11641},'testers' => {'pass' => 1},'uses' => ['Carp','Image::IPTCInfo','strict','vars']},'Image-Imlib2-0.11.tar.gz' => {'author' => 'LBROCARD','description' => 'Interface to the Imlib2 image library','files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 260,'pod_errors' => 0,'total' => 366,'with_comments' => 9},'releases' => 5,'requires' => ['Module-Build-0.19.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Module::Build' => '0.01','Test::More' => '0.01'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Module-Build-0.19.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 14047,'unpacked' => 46980},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Image-Info-1.12.tar.gz' => {'author' => 'GAAS','description' => 'Extract meta information from image files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2301,'pod' => 498,'pod_errors' => 3,'total' => 2799,'with_comments' => 149},'releases' => 19,'size' => {'packed' => 304144,'unpacked' => 437471},'testers' => {'fail' => 1,'pass' => 4,'tests' => '13'},'uses' => ['Compress::Zlib','Config','Exporter','IO::String','Image::Xbm','Image::Xpm','Symbol','XML::Simple','strict','vars']},'Image-Magick-Thumbnail-0.01.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 30,'pod' => 46,'pod_errors' => 0,'total' => 76,'with_comments' => 0},'releases' => 1,'requires' => ['PerlMagick-5.56.tar.gz'],'requires_module' => {'Image::Magick' => '0.1'},'requires_recursive' => ['PerlMagick-5.56.tar.gz'],'size' => {'packed' => 61769,'unpacked' => 64211},'testers' => {'pass' => 3},'uses' => ['Image::Magick','strict','warnings']},'Image-Maps-Plot-FromLatLong-0.1.tar.gz' => {'author' => 'LGODDARD','description' => 'Plot latitude/longitude points on JPEG maps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 731,'pod' => 350,'pod_errors' => 0,'total' => 1081,'with_comments' => 117},'releases' => 1,'requires' => ['Data-Dumper-2.101.tar.gz','PerlMagick-5.56.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => '0.01','File::Basename' => '0.01','Image::Magick' => '0.01'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','PerlMagick-5.56.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 1005645,'unpacked' => 1085599},'testers' => {'fail' => 1},'uses' => ['5.006','Config','Data::Dumper','File::Basename','Image::Magick','WWW::MapBlast','strict','warnings']},'Image-Maps-Plot-FromPostcode-2.tar.gz' => {'author' => 'LGODDARD','description' => 'Plot various maps from postal codes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 149,'pod_errors' => 6,'total' => 202,'with_comments' => 3},'releases' => 9,'requires' => ['Data-Dumper-2.101.tar.gz','PerlMagick-5.56.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => '0.01','File::Basename' => '0.01','Image::Magick' => '0.01'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','PerlMagick-5.56.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 595053,'unpacked' => 659619},'testers' => {'pass' => 1},'uses' => ['5.006','Image::Maps::Plot::FromLatLong','WWW::MapBlast','strict','warnings']},'Image-OrgChart-0.20.tar.gz' => {'author' => 'MZSANFORD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 413,'pod' => 177,'pod_errors' => 0,'total' => 590,'with_comments' => 26},'releases' => 7,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => '1.16'},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6474,'unpacked' => 25124},'testers' => {'fail' => 1,'pass' => 3,'tests' => '12'},'uses' => ['Exporter','GD','strict','vars']},'Image-PBMlib-1.05.tar.gz' => {'author' => 'ELIJAH','description' => 'Helper functions for PBM/PGM/PPM image file formats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 474,'pod' => 145,'pod_errors' => 0,'total' => 619,'with_comments' => 56},'releases' => 2,'size' => {'packed' => 6541,'unpacked' => 22941},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Image-ParseGIF-0.2.tar.gz' => {'author' => 'BENL','description' => 'Parse GIF images into component parts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 802,'pod' => 240,'pod_errors' => 0,'total' => 1042,'with_comments' => 161},'releases' => 5,'size' => {'packed' => 18866,'unpacked' => 42903},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['Fcntl','IO::File','IO::Handle','diagnostics','strict','vars']},'Image-Processor-0.6.tar.gz' => {'author' => 'AARONJJ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 704,'pod' => 312,'pod_errors' => 1,'total' => 1016,'with_comments' => 43},'releases' => 1,'requires' => ['Image-Size-2.992.tar.gz','Mail-MboxParser-0.38.tar.gz','PerlMagick-5.56.tar.gz','Text-Template-1.44.tar.gz'],'requires_module' => {'Image::Magick' => '5.4','Image::Size' => 0,'Mail::MboxParser' => '0.31','Text::Template' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Image-Size-2.992.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','Mail-MboxParser-0.38.tar.gz','MailTools-1.58.tar.gz','PerlMagick-5.56.tar.gz','Text-Template-1.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9024,'unpacked' => 28954},'testers' => {},'uses' => ['File::Copy','File::Path','Image::Magick','Mail::MboxParser','Text::Template','strict','vars']},'Image-Shoehorn-1.42.tar.gz' => {'author' => 'ASCOPE','description' => 'massage the dimensions and filetype of an image','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1051,'pod' => 339,'pod_errors' => 0,'total' => 1390,'with_comments' => 109},'releases' => 7,'requires' => ['Error-0.15.tar.gz','File-MMagic-1.19.tar.gz','PerlMagick-5.56.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '0','Cwd' => '0','Error' => '0','File::Basename' => '0','File::MMagic' => '1.16','Image::Magick' => '5.44','Test::More' => '0'},'requires_recursive' => ['Error-0.15.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','PerlMagick-5.56.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 33088,'unpacked' => 55212},'testers' => {'fail' => 1},'uses' => ['Apache','Apache::Constants','Apache::File','Apache::Log','Carp','Data::Dumper','Error','File::Basename','File::MMagic','Image::Magick','strict']},'Image-Shoehorn-Gallery-0.22.tar.gz' => {'author' => 'ASCOPE','description' => 'generate "smart" HTML slideshows from a directory of image files.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2225,'pod' => 672,'pod_errors' => 0,'total' => 2897,'with_comments' => 102},'releases' => 4,'requires' => ['Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz','Image-IPTCInfo-1.6.tar.gz','Image-Info-1.12.tar.gz','Image-Shoehorn-1.42.tar.gz','Image-Size-2.992.tar.gz','XML-Filter-XML_Directory_2XHTML-1.3.1.tar.gz','XML-Filter-XSLT-0.03.tar.gz','XML-SAX-Machines-0.4.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Cwd' => 0,'Digest::MD5' => 0,'DirHandle' => 0,'File::Basename' => 0,'File::Copy' => 0,'File::Path' => 0,'IO::File' => 0,'Image::IPTCInfo' => '1.6','Image::Info' => '1.11','Image::Shoehorn' => '1.41','Image::Size' => '2.99','XML::Filter::XML_Directory_2XHTML' => '1.3.1','XML::Filter::XSLT' => '0.03','XML::SAX::Machines' => '0.34'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','Image-IPTCInfo-1.6.tar.gz','Image-Info-1.12.tar.gz','Image-Shoehorn-1.42.tar.gz','Image-Size-2.992.tar.gz','MIME-Types-1.06.tar.gz','PerlMagick-5.56.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Directory-0.99.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-Filter-XML_Directory_2-Base-1.4.4.tar.gz','XML-Filter-XML_Directory_2XHTML-1.3.1.tar.gz','XML-Filter-XML_Directory_Pruner-1.3.tar.gz','XML-Filter-XSLT-0.03.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Machines-0.4.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 99905,'unpacked' => 152578},'testers' => {},'uses' => ['Carp','Carp::Heavy','Data::Dumper','Digest::MD5','DirHandle','File::Basename','File::Copy','File::Path','IO::File','Image::IPTCInfo','Image::Info','Image::Shoehorn','Image::Size','XML::Directory::SAX','XML::Filter::XML_Directory_2XHTML','XML::Filter::XSLT::LibXSLT','XML::SAX::Base','XML::SAX::Machines','XML::SAX::Writer','constant','strict']},'Image-Size-2.992.tar.gz' => {'author' => 'RJRAY','description' => 'Measure size of images in common formats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 855,'pod' => 182,'pod_errors' => 0,'total' => 1037,'with_comments' => 179},'releases' => 29,'requires' => ['File-Spec-0.82.tar.gz'],'requires_module' => {'File::Spec' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz'],'size' => {'packed' => 123479,'unpacked' => 181655},'testers' => {'pass' => 20},'uses' => ['5.002','AutoLoader','Compress::Zlib','Exporter','strict','vars']},'Image-Temperature-0.01.tar.gz' => {'author' => 'XERN','description' => 'Taking temperature of images','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 48,'pod' => 55,'pod_errors' => 0,'total' => 103,'with_comments' => 1},'releases' => 1,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => '1'},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2386,'unpacked' => 4409},'testers' => {},'uses' => ['Exporter','GD','strict']},'Image-Thumbnail-0.41.tar.gz' => {'author' => 'LGODDARD','description' => 'Thumbnail images from GD or ImageMagick','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 400,'pod' => 195,'pod_errors' => 0,'total' => 595,'with_comments' => 58},'releases' => 5,'requires' => ['Test-Harness-2.29.tar.gz'],'requires_module' => {'Test::Harness' => '0.1'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 143754,'unpacked' => 167326},'testers' => {'fail' => 1},'uses' => ['Carp','GD','strict','warnings']},'Image-Timeline-0.08.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Create GIF or PNG timelines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 269,'pod' => 112,'pod_errors' => 0,'total' => 381,'with_comments' => 23},'releases' => 8,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => 0},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14375,'unpacked' => 26258},'testers' => {'fail' => 1,'tests' => '11'},'uses' => ['Date::Format','GD','strict']},'Image-WMF-1.01.tar.gz' => {'author' => 'TCOX','description' => 'Perl extension for creating Windows Metafile images on UNIX.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1997,'pod' => 39,'pod_errors' => 0,'total' => 2036,'with_comments' => 63},'releases' => 1,'size' => {'packed' => 11556,'unpacked' => 65169},'testers' => {'pass' => 2},'uses' => ['5.00323','Exporter','strict','vars']},'Image-WorldMap-0.14.tar.gz' => {'author' => 'LBROCARD','description' => 'Create graphical world maps of data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 567,'pod' => 70,'pod_errors' => 0,'total' => 637,'with_comments' => 44},'releases' => 5,'requires' => ['Image-Imlib2-0.11.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Image::Imlib2' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Image-Imlib2-0.11.tar.gz','Module-Build-0.19.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 84782,'unpacked' => 119405},'testers' => {},'uses' => ['Carp','Exporter','Image::Imlib2','strict','vars']},'Image-XFace-0.1.tar.gz' => {'author' => 'CWRL','description' => 'encode and decode `X-Face\' 48x48x1 face bitmaps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 87,'pod' => 67,'pod_errors' => 0,'total' => 154,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 8915,'unpacked' => 23940},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','GD','integer']},'Image-Xbm-1.08.tar.gz' => {'author' => 'SUMMER','description' => 'Load, create, manipulate and save xbm image files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 543,'pod' => 276,'pod_errors' => 0,'total' => 819,'with_comments' => 54},'releases' => 9,'requires' => ['Image-Base-1.07.tar.gz'],'requires_module' => {'Image::Base' => '1.06'},'requires_recursive' => ['Image-Base-1.07.tar.gz'],'size' => {'packed' => 7512,'unpacked' => 33488},'testers' => {'pass' => 7},'uses' => ['Carp','IO::String','Image::Base','strict','vars']},'Image-Xpm-1.09.tar.gz' => {'author' => 'SUMMER','description' => 'Load, create, manipulate and save xpm image files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 582,'pod' => 224,'pod_errors' => 0,'total' => 806,'with_comments' => 85},'releases' => 7,'requires' => ['Image-Base-1.07.tar.gz'],'requires_module' => {'Image::Base' => '1.06'},'requires_recursive' => ['Image-Base-1.07.tar.gz'],'size' => {'packed' => 9593,'unpacked' => 38779},'testers' => {'pass' => 6},'uses' => ['Carp','IO::String','Image::Base','strict','vars']},'Imager-0.38.tar.gz' => {'author' => 'ADDI','description' => 'Perl extension for Generating 24 bit Images','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3763,'pod' => 1327,'pod_errors' => 0,'total' => 5090,'with_comments' => 197},'releases' => 13,'size' => {'packed' => 340984,'unpacked' => 1136583},'testers' => {'pass' => 3},'uses' => ['Affix::Infix2Postfix','Data::Dumper','DynaLoader','Exporter','IO::File','Imager','Imager::Color','Imager::Font','Imager::Regops','Parse::RecDescent','constant','strict','vars']},'Imager-0.39.tar.gz' => {'author' => 'ADDI','description' => 'Perl extension for Generating 24 bit Images','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6195,'pod' => 2955,'pod_errors' => 0,'total' => 9150,'with_comments' => 304},'releases' => 13,'size' => {'packed' => 484560,'unpacked' => 1681747},'testers' => {'fail' => 2,'pass' => 3,'tests' => '635'},'uses' => ['Affix::Infix2Postfix','Data::Dumper','DynaLoader','Exporter','IO::File','Imager','Imager::Color','Imager::Color::Float','Imager::Expr','Imager::Expr::Assem','Imager::Fill','Imager::Font','Imager::Regops','Parse::RecDescent','constant','strict','vars']},'Imager-0.41.tar.gz' => {'author' => 'ADDI','description' => 'Perl extension for Generating 24 bit Images','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6825,'pod' => 3728,'pod_errors' => 0,'total' => 10553,'with_comments' => 317},'releases' => 13,'size' => {'packed' => 523140,'unpacked' => 1850059},'testers' => {'fail' => 3,'pass' => 12,'tests' => '957','unknown' => 3},'uses' => ['Affix::Infix2Postfix','Data::Dumper','DynaLoader','Exporter','IO::File','Imager::Color','Imager::Expr','Imager::Expr::Assem','Imager::Font','Parse::RecDescent','constant','strict','vars']},'Imager-Album-0.06.tar.gz' => {'author' => 'ADDI','description' => 'Perl extension for processing Images for output to web.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 973,'pod' => 28,'pod_errors' => 0,'total' => 1001,'with_comments' => 36},'releases' => 1,'requires' => ['Imager-0.41.tar.gz'],'requires_module' => {'Imager' => '0.41'},'requires_recursive' => ['Imager-0.41.tar.gz'],'size' => {'packed' => 11798,'unpacked' => 35417},'testers' => {'fail' => 2},'uses' => ['File::Basename','File::Spec','Gtk','Gtk::Gdk','Imager','strict','vars']},'Imager-Chart-Radial-0.1.tar.gz' => {'author' => 'TEEJAY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 291,'pod' => 134,'pod_errors' => 1,'total' => 425,'with_comments' => 33},'releases' => 1,'requires' => ['Imager-0.41.tar.gz'],'requires_module' => {'Imager' => 0},'requires_recursive' => ['Imager-0.41.tar.gz'],'size' => {'packed' => 4719,'unpacked' => 16401},'testers' => {'pass' => 1},'uses' => ['Imager','strict','vars']},'Imager-Graph-0.02.tar.gz' => {'author' => 'TONYC','description' => 'Perl extension for producing Graphs using the Imager library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1478,'pod' => 712,'pod_errors' => 0,'total' => 2190,'with_comments' => 37},'releases' => 3,'requires' => ['Imager-0.41.tar.gz'],'requires_module' => {'Imager' => '0.38'},'requires_recursive' => ['Imager-0.41.tar.gz'],'size' => {'packed' => 131035,'unpacked' => 204914},'testers' => {'fail' => 3,'tests' => '12'},'uses' => ['Carp','Data::Dumper','Exporter','Imager','Imager::Fountain','Imager::Graph','POSIX','constant','strict','vars']},'Imager-Graph-0.03.tar.gz' => {'author' => 'TONYC','description' => 'Perl extension for producing Graphs using the Imager library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1478,'pod' => 712,'pod_errors' => 0,'total' => 2190,'with_comments' => 37},'releases' => 3,'requires' => ['Imager-0.41.tar.gz'],'requires_module' => {'Imager' => '0.38'},'requires_recursive' => ['Imager-0.41.tar.gz'],'size' => {'packed' => 130898,'unpacked' => 205037},'testers' => {'fail' => 3,'pass' => 1,'tests' => '12'},'uses' => ['Carp','Data::Dumper','Exporter','Imager','Imager::Fountain','Imager::Graph::Util','POSIX','constant','strict','vars']},'Imager-Plot-0.07.tar.gz' => {'author' => 'ADDI','description' => 'Perl extension for generating fancy graphic plots in color.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1088,'pod' => 112,'pod_errors' => 0,'total' => 1200,'with_comments' => 90},'releases' => 6,'requires' => ['Imager-0.41.tar.gz'],'requires_module' => {'Imager' => '0.39'},'requires_recursive' => ['Imager-0.41.tar.gz'],'size' => {'packed' => 67220,'unpacked' => 158406},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Exporter','Imager','Imager::Plot::Axis','Imager::Plot::DataSet','strict','vars']},'Imager-Plot-0.09.tar.gz' => {'author' => 'ADDI','description' => 'Perl extension for generating fancy graphic plots in color.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1118,'pod' => 112,'pod_errors' => 0,'total' => 1230,'with_comments' => 92},'releases' => 6,'requires' => ['Imager-0.41.tar.gz'],'requires_module' => {'Imager' => '0.41'},'requires_recursive' => ['Imager-0.41.tar.gz'],'size' => {'packed' => 149426,'unpacked' => 288572},'testers' => {'fail' => 2},'uses' => ['Exporter','Imager','Imager::Plot::Util','strict','vars']},'Include-1.02a.tar.gz' => {'author' => 'GBARR','description' => 'Parse C header files for use in XS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 353,'pod' => 70,'pod_errors' => 0,'total' => 423,'with_comments' => 19},'releases' => 2,'size' => {'packed' => 5824,'unpacked' => 14655},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['Carp','Config','Exporter','File::Path']},'InfoBrief-0.14.tar.gz' => {'author' => 'ULPFR','description' => 'Perl extension for printing envelopes for Infobrief mailings according to the standards of the Deutsche Bundespost','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 601,'pod' => 64,'pod_errors' => 0,'total' => 665,'with_comments' => 31},'releases' => 5,'size' => {'packed' => 12471,'unpacked' => 49565},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'IniConf-1.03.tar.gz' => {'author' => 'RBOW','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 0,'pod_errors' => 0,'total' => 20,'with_comments' => 0},'releases' => 8,'requires' => ['Config-IniFiles-2.38.tar.gz'],'requires_module' => {'Config::IniFiles' => 0},'requires_recursive' => ['Config-IniFiles-2.38.tar.gz'],'size' => {'packed' => 1707,'unpacked' => 2615},'testers' => {'pass' => 2},'uses' => ['Config::IniFiles','strict','vars']},'InitializeServer-1.0.tar.gz' => {'author' => 'JACKS','description' => undef,'files' => [],'lines' => {'nonpod' => 518,'pod' => 0,'pod_errors' => 0,'total' => 518,'with_comments' => 195},'releases' => 1,'size' => {'packed' => 5163,'unpacked' => 17203},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['AutoLoader','Carp','Exporter','Ioctl','Usage','Wait']},'Inline-0.43.tar.gz' => {'author' => 'INGY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3517,'pod' => 2746,'pod_errors' => 1,'total' => 6263,'with_comments' => 245},'releases' => 15,'requires' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Data::Dumper' => '2.09','Digest::MD5' => '2.09','Parse::RecDescent' => '1.78'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 81356,'unpacked' => 263489},'testers' => {'fail' => 1,'pass' => 37},'uses' => ['5.005','AutoLoader','Carp','Config','Cwd','Data::Dumper','Digest::MD5','DynaLoader','Exporter','ExtUtils::MakeMaker','FindBin','Inline','Inline::MakeMaker','Inline::denter','Parse::RecDescent','Socket','strict']},'Inline-0.44.tar.gz' => {'author' => 'INGY','description' => 'Write Perl subroutines in other languages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4616,'pod' => 2804,'pod_errors' => 1,'total' => 7420,'with_comments' => 287},'releases' => 15,'requires' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Data::Dumper' => '2.09','Digest::MD5' => '2.09','File::Spec' => '0.8','Parse::RecDescent' => '1.8'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 91450,'unpacked' => 290971},'testers' => {'pass' => 17},'uses' => ['5.005','AutoLoader','Carp','Config','Cwd','Data::Dumper','Digest::MD5','DynaLoader','Exporter','ExtUtils::MakeMaker','File::Spec','File::Spec::Unix','FindBin','Socket','strict']},'Inline-ASM-0.03.tar.gz' => {'author' => 'NEILW','description' => 'Write Perl subroutines in Assembler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 401,'pod' => 221,'pod_errors' => 0,'total' => 622,'with_comments' => 38},'releases' => 3,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.42'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 9144,'unpacked' => 26855},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','Config','Cwd','Data::Dumper','ExtUtils::MakeMaker','FindBin','Inline::C','strict']},'Inline-Awk-0.03.tar.gz' => {'author' => 'JMCNAMARA','description' => 'Add awk code to your Perl programs.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 302,'pod' => 279,'pod_errors' => 0,'total' => 581,'with_comments' => 97},'releases' => 1,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 8368,'unpacked' => 23350},'testers' => {'pass' => 6},'uses' => ['Carp','Inline','strict','vars']},'Inline-BC-0.06.tar.gz' => {'author' => 'PIERS','description' => 'Inline ILSM for bc the arbitrary precision math Language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 301,'pod' => 57,'pod_errors' => 0,'total' => 358,'with_comments' => 41},'releases' => 6,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.43'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 219758,'unpacked' => 902572},'testers' => {'pass' => 2},'uses' => ['Carp','Cwd','Data::Dumper','DynaLoader','Exporter','Inline','Inline::denter','strict','vars']},'Inline-Basic-0.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Write Perl subroutines in Basic','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 33,'pod_errors' => 0,'total' => 108,'with_comments' => 3},'releases' => 1,'requires' => ['IO-stringy-2.108.tar.gz','Inline-0.44.tar.gz','Language-Basic-1.44.tar.gz'],'requires_module' => {'IO::Scalar' => '2.104','Inline' => '0.43','Language::Basic' => '1.44'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Inline-0.44.tar.gz','Language-Basic-1.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 1734,'unpacked' => 2849},'testers' => {'fail' => 4,'pass' => 2},'uses' => ['Carp','IO::Scalar','Inline','Language::Basic','strict','vars']},'Inline-Befunge-0.04.tar.gz' => {'author' => 'JQUELIN','description' => 'write Perl subs in Befunge','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 201,'pod' => 178,'pod_errors' => 0,'total' => 379,'with_comments' => 32},'releases' => 4,'requires' => ['Inline-0.44.tar.gz','Language-Befunge-0.38.tar.gz'],'requires_module' => {'Inline' => '0.43','Language::Befunge' => '0.36'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Language-Befunge-0.38.tar.gz','Parse-RecDescent-1.94.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 5631,'unpacked' => 13266},'testers' => {'fail' => 3,'tests' => '1'},'uses' => ['','Carp','Inline','strict','warnings']},'Inline-CPP-0.14.tar.gz' => {'author' => 'NEILW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 929,'pod' => 199,'pod_errors' => 0,'total' => 1128,'with_comments' => 101},'releases' => 10,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.31'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 12044,'unpacked' => 36579},'testers' => {'fail' => 2,'pass' => 2,'tests' => '4'},'uses' => ['Carp','Config','Cwd','Data::Dumper','ExtUtils::MakeMaker','FindBin','Inline','Parse::RecDescent','strict','vars']},'Inline-CPP-0.24.tar.gz' => {'author' => 'NEILW','description' => 'Easy implementation of C++ extensions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1164,'pod' => 618,'pod_errors' => 0,'total' => 1782,'with_comments' => 150},'releases' => 10,'size' => {'packed' => 24308,'unpacked' => 71386},'testers' => {'fail' => 2,'pass' => 9,'tests' => '14'},'uses' => ['Carp','Config','Data::Dumper','Inline::C','Parse::RecDescent','strict','vars']},'Inline-CPR-0.12.tar.gz' => {'author' => 'INGY','description' => 'C Perl Run - Embed Perl in C, ala Inline','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 333,'pod' => 134,'pod_errors' => 0,'total' => 467,'with_comments' => 49},'releases' => 3,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.41'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 7382,'unpacked' => 18708},'testers' => {'pass' => 7},'uses' => ['Carp','Config','Cwd','Data::Dumper','ExtUtils::MakeMaker','FindBin','Inline','strict']},'Inline-Files-0.62.tar.gz' => {'author' => 'DCONWAY','description' => 'Multiple virtual files after __END__','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 678,'pod' => 445,'pod_errors' => 0,'total' => 1123,'with_comments' => 29},'releases' => 2,'requires' => ['Filter-1.29.tar.gz'],'requires_module' => {'Filter::Util::Call' => 0},'requires_recursive' => ['Filter-1.29.tar.gz'],'size' => {'packed' => 13603,'unpacked' => 45845},'testers' => {'fail' => 1,'pass' => 3,'tests' => '67'},'uses' => ['Carp','Cwd','Data::Dumper','Filter::Util::Call','strict','vars']},'Inline-Filters-0.12.tar.gz' => {'author' => 'NEILW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 189,'pod' => 123,'pod_errors' => 0,'total' => 312,'with_comments' => 19},'releases' => 2,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.42'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 4897,'unpacked' => 12105},'testers' => {'fail' => 5,'tests' => '5'},'uses' => ['Config','strict']},'Inline-Guile-0.001.tar.gz' => {'author' => 'SAMTREGAR','description' => 'Inline module for Guile Scheme interpreter','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 123,'pod' => 69,'pod_errors' => 0,'total' => 192,'with_comments' => 13},'releases' => 1,'requires' => ['Guile-0.001.tar.gz','Inline-0.44.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Guile' => '0.001','Inline' => '0.43'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Guile-0.001.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3538,'unpacked' => 8248},'testers' => {'fail' => 1,'pass' => 1,'tests' => '4'},'uses' => ['Carp','Guile','Inline','strict','warnings']},'Inline-Interp-0.04.tar.gz' => {'author' => 'IAMCAL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 185,'pod' => 153,'pod_errors' => 0,'total' => 338,'with_comments' => 0},'releases' => 3,'requires' => ['Inline-0.44.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Inline' => '0.43','Test::Simple' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3335,'unpacked' => 7648},'testers' => {'pass' => 2},'uses' => ['Carp','Inline','strict']},'Inline-Java-0.33.tar.gz' => {'author' => 'PATL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6060,'pod' => 764,'pod_errors' => 1,'total' => 6824,'with_comments' => 229},'releases' => 11,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.43'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 57591,'unpacked' => 213900},'testers' => {'fail' => 1,'pass' => 5,'tests' => '298'},'uses' => ['Carp','Config','Cwd','Data::Dumper','DynaLoader','Exporter','File::Basename','File::Copy','File::Find','File::Spec','IO::File','IO::Pipe','IO::Socket','IPC::Open3','Inline','Inline::Java::JNI','POSIX','Tie::Array','Tie::Hash','Tie::Scalar','strict','vars']},'Inline-Java-0.41.tar.gz' => {'author' => 'PATL','description' => 'Easy implementation of Java extensions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4148,'pod' => 722,'pod_errors' => 1,'total' => 4870,'with_comments' => 248},'releases' => 11,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.44'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 61394,'unpacked' => 230105},'testers' => {'pass' => 1},'uses' => ['Carp','Config','Cwd','Data::Dumper','DynaLoader','Exporter','File::Basename','File::Copy','File::Find','File::Spec','IO::File','IO::Socket','IPC::Open3','Inline','Inline::Java::Array','Inline::Java::Callback','Inline::Java::Class','Inline::Java::JVM','Inline::Java::Object','Inline::Java::Portable','Inline::Java::Protocol','Our::Module','POSIX','Tie::Array','Tie::Hash','Tie::Scalar','strict','vars']},'Inline-Octave-0.18.tar.gz' => {'author' => 'AADLER','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 1020,'pod' => 349,'pod_errors' => 0,'total' => 1369,'with_comments' => 122},'releases' => 6,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.4'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 14517,'unpacked' => 49161},'testers' => {},'uses' => ['Carp','Data::Dumper','IPC::Open2','Inline','Math::Complex','vars']},'Inline-Python-0.20.tar.gz' => {'author' => 'NEILW','description' => 'Easy implementation of Python extensions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 464,'pod' => 500,'pod_errors' => 3,'total' => 964,'with_comments' => 48},'releases' => 7,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.42'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 32651,'unpacked' => 105515},'testers' => {'pass' => 3},'uses' => ['Carp','DynaLoader','Exporter','Inline','Inline::denter','strict','vars']},'Inline-Ruby-0.02.tar.gz' => {'author' => 'NEILW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 628,'pod' => 617,'pod_errors' => 0,'total' => 1245,'with_comments' => 62},'releases' => 2,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.42'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 25729,'unpacked' => 80673},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','Inline','Inline::denter','strict','vars']},'Inline-SLang-0.20.tar.gz' => {'author' => 'DJBURKE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2540,'pod' => 1702,'pod_errors' => 0,'total' => 4242,'with_comments' => 691},'releases' => 8,'requires' => ['Inline-0.44.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Inline' => '0.42','Test::More' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 109356,'unpacked' => 403644},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','IO::File','Inline','Inline::denter','Math::Complex','strict','vars']},'Inline-SMITH-0.03.tar.gz' => {'author' => 'IAMCAL','description' => 'write Perl subs in SMITH','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 274,'pod' => 114,'pod_errors' => 0,'total' => 388,'with_comments' => 33},'releases' => 2,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.43'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 4742,'unpacked' => 11388},'testers' => {'pass' => 3},'uses' => ['Carp','Inline','strict']},'Inline-Struct-0.06.tar.gz' => {'author' => 'NEILW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 579,'pod' => 149,'pod_errors' => 0,'total' => 728,'with_comments' => 43},'releases' => 2,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.42'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 8229,'unpacked' => 24388},'testers' => {'pass' => 7,'tests' => '0','unknown' => 3},'uses' => ['Carp','Data::Dumper','Inline','Parse::RecDescent','strict','vars']},'Inline-TT-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'use TT BLOCK as your Perl sub','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 45,'pod_errors' => 0,'total' => 174,'with_comments' => 10},'releases' => 2,'requires' => ['Inline-0.44.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Inline' => '0.43','Template' => '2.07','Test::More' => '0.32'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 2581,'unpacked' => 5832},'testers' => {'pass' => 1},'uses' => ['Carp','IO::File','Inline','Template::Context','Template::Document','Template::Parser','strict','vars']},'Inline-Tcl-0.09.tar.gz' => {'author' => 'RRS','description' => 'Write Perl subroutines in Tcl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 262,'pod' => 86,'pod_errors' => 0,'total' => 348,'with_comments' => 32},'releases' => 7,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.4'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 7476,'unpacked' => 20811},'testers' => {'fail' => 2,'pass' => 1,'tests' => '3'},'uses' => ['Carp','Data::Dumper','DynaLoader','Exporter','Inline','strict','vars']},'Inline-WebChat-0.62.tar.gz' => {'author' => 'SIMONW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 117,'pod' => 131,'pod_errors' => 0,'total' => 248,'with_comments' => 12},'releases' => 1,'requires' => ['Inline-0.44.tar.gz','webchat-0.64.tar.gz'],'requires_module' => {'Inline' => '0.1','WWW::Chat::Processor' => '0.62'},'requires_recursive' => ['Data-Dump-0.04.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','Inline-0.44.tar.gz','MIME-Base64-2.20.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz','webchat-0.64.tar.gz'],'size' => {'packed' => 3945,'unpacked' => 8934},'testers' => {'fail' => 3,'pass' => 1,'tests' => '3'},'uses' => ['Carp','Inline','WWW::Chat::Processor','strict']},'Inline-YAML-0.10.tar.gz' => {'author' => 'INGY','description' => 'Specify YAML content directly in your Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 155,'pod' => 81,'pod_errors' => 0,'total' => 236,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 3376,'unpacked' => 7780},'testers' => {'pass' => 5},'uses' => ['Cwd','Exporter','File::Spec','Filter::Simple','YAML','strict','vars']},'Interface-Polymorphism-0.2.tar.gz' => {'author' => 'PDCAWLEY','description' => 'Another study in polymorphism','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 0,'pod_errors' => 0,'total' => 94,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 2923,'unpacked' => 6061},'testers' => {'pass' => 7},'uses' => ['5.6.0','Carp','strict']},'Internals-1.1.tar.gz' => {'author' => 'STBEY','description' => 'Write-protect variables, manipulate refcounts','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 46,'pod' => 105,'pod_errors' => 0,'total' => 151,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 11167,'unpacked' => 32924},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['DynaLoader','Exporter','strict','vars']},'Interpolation-0.69.tar.gz' => {'author' => 'JENDA','description' => 'Arbitrary string interpolation semantics (using tie()) Version 0.69 Originaly by Mark-Jason Dominus (mjd-perl-interpolation@plover.com) Since version 0.66 maintained by Jenda@Krynicky.cz','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 243,'pod_errors' => 2,'total' => 680,'with_comments' => 36},'releases' => 5,'size' => {'packed' => 10722,'unpacked' => 32592},'testers' => {'pass' => 14},'uses' => ['Carp','HTML::Entities','POSIX','Tie::Scalar','strict','vars','warnings']},'Interval.0.01.tar.gz' => {'author' => 'KTORP','description' => 'handling of temporal intervals based on Date::Manip','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 953,'pod' => 163,'pod_errors' => 0,'total' => 1116,'with_comments' => 247},'releases' => 1,'size' => {'packed' => 8654,'unpacked' => 61887},'testers' => {'fail' => 3,'pass' => 1},'uses' => ['Carp','Date::Manip','Exporter','strict','vars']},'Interval.0.03.tar.gz' => {'author' => 'KTORP','description' => 'Lightweight normalised interval data type','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1258,'pod' => 627,'pod_errors' => 0,'total' => 1885,'with_comments' => 98},'releases' => 1,'size' => {'packed' => 14414,'unpacked' => 99480},'testers' => {'fail' => 13,'pass' => 2},'uses' => ['Carp','Date::Manip','Exporter','strict','vars']},'Introspector-0.04.tar.gz' => {'author' => 'MDUPONT','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 17080,'pod' => 1069,'pod_errors' => 0,'total' => 18149,'with_comments' => 4969},'releases' => 1,'size' => {'packed' => 836581,'unpacked' => 3726806},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['5.006','5.61','::development::projects::sourceforge::introspector_root::ParseGCCXML','AutoLoader','B','BaseTypes','CGI','Carp','Carp::Assert','Class::Contract','CrossReference','Data::Dumper','DynaLoader','Errno','Eval','Exporter','File::Copy','File::Path','FileHandle','GeneratedPackage','HTML::Template','Introspector::Breaker','Introspector::CreateClassesTest','Introspector::Eval','Introspector::FileHandle','Introspector::GCC','Introspector::gcc','Introspector::gcc::noderef','LoadMetaInfo','MetaFeature','MetaInfo','MetaPackage','NodeVisitors','PACKAGE_NAME','Pg','ProgramKnowledge','RDF::Redland','SOAP::Lite','TestGroups','XML::Parser::PerlSAX','XML::Simple','XMLRPC::Lite','constant','db','introspector::node_base','introspector::node_call_expr','introspector::node_function_decl','introspector::node_function_type','introspector::node_string_cst','introspector::node_tree_list','strict','vars','warnings','warnings::register']},'Isam-0.2.tar.gz' => {'author' => 'CYK','description' => 'Perl extension for ISAM files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 914,'pod' => 239,'pod_errors' => 1,'total' => 1153,'with_comments' => 128},'releases' => 1,'size' => {'packed' => 9765,'unpacked' => 42654},'testers' => {},'uses' => ['AutoLoader','Carp','Class::Struct','DynaLoader','Exporter','strict','vars']},'Ivrs-0.10.tar.gz' => {'author' => 'MUKUND','description' => 'Perl extension for Interactive Voice Response System.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1131,'pod' => 137,'pod_errors' => 0,'total' => 1268,'with_comments' => 97},'releases' => 6,'size' => {'packed' => 541486,'unpacked' => 864679},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','IO::Handle','POSIX','asm::termios.ph','strict','vars']},'JBrowseEntry.4.22.tar.gz' => {'author' => 'TURNERJW','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 1199,'pod' => 132,'pod_errors' => 0,'total' => 1331,'with_comments' => 150},'releases' => 1,'size' => {'packed' => 10067,'unpacked' => 39567},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['Carp','Tk','Tk::Frame','Tk::LabEntry','strict','vars']},'JFIF-0.10.0.tar.gz' => {'author' => 'KRZAK','description' => 'JFIF/JPEG tags operations.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 158,'pod' => 45,'pod_errors' => 0,'total' => 203,'with_comments' => 9},'releases' => 7,'size' => {'packed' => 2483,'unpacked' => 5391},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['strict']},'JOAP-0.01.tar.gz' => {'author' => 'EVAN','description' => 'Perl extension for the Jabber Object Access Protocol (JOAP)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5745,'pod' => 3349,'pod_errors' => 0,'total' => 9094,'with_comments' => 631},'releases' => 1,'requires' => ['Class-Data-Inheritable-0.02.tar.gz','Error-0.15.tar.gz','Net-Jabber-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Class::Data::Inheritable' => '0.02','Error' => '0.15','Net::Jabber' => '1.28','Symbol' => '1.04'},'requires_recursive' => ['Class-Data-Inheritable-0.02.tar.gz','Digest-SHA1-2.04.tar.gz','Error-0.15.tar.gz','Net-Jabber-1.28.tar.gz','XML-Stream-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 125382,'unpacked' => 752843},'testers' => {'pass' => 2},'uses' => ['5.008','Class::Data::Inheritable','Error','Error::Simple','Exporter','Net::Jabber','Net::Jabber::Protocol','Symbol','strict','warnings']},'JOT-0.1.tar.gz' => {'author' => 'JOHANVDB','description' => 'Parses the JOT specification for Ink Storage and Interchange Format','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 138,'pod_errors' => 0,'total' => 575,'with_comments' => 26},'releases' => 1,'size' => {'packed' => 5703,'unpacked' => 17014},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['GD','constant','strict']},'JPEG-Comment-02.tar.gz' => {'author' => 'IFROL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 19,'pod_errors' => 0,'total' => 61,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 2193,'unpacked' => 3815},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Exporter','strict','vars']},'JaM-1.0.10.tar.gz' => {'author' => 'JRED','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 10589,'pod' => 0,'pod_errors' => 0,'total' => 10589,'with_comments' => 286},'releases' => 22,'size' => {'packed' => 75040,'unpacked' => 301206},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','Cwd','DBI','Data::Dumper','Date::Manip','File::Basename','File::Find','FileHandle','Gtk','Gtk::HTML','Gtk::Keysyms','MIME::Entity','MIME::Parser','MIME::Types','MIME::WordDecoder','MIME::Words','Net::POP3','Net::SMTP','POSIX','Storable','Time::Local','Unicode::String','strict','vars']},'Jabber-Component-Proxy-0.02.tar.gz' => {'author' => 'QMACRO','description' => 'A simple proxy for Jabber Components','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 43,'pod_errors' => 0,'total' => 281,'with_comments' => 18},'releases' => 2,'requires' => ['Jabber-Connection-0.03.tar.gz','XML-XPath-1.13.tar.gz'],'requires_module' => {'Jabber::Connection' => '0.02','XML::XPath' => '1.02'},'requires_recursive' => ['Digest-SHA1-2.04.tar.gz','Jabber-Connection-0.03.tar.gz','XML-Parser-2.31.tar.gz','XML-XPath-1.13.tar.gz'],'size' => {'packed' => 3574,'unpacked' => 7944},'testers' => {'pass' => 3},'uses' => ['Jabber::Connection','Jabber::NodeFactory','XML::XPath','XML::XPath::XMLParser','strict','vars','warnings']},'Jabber-Connection-0.03.tar.gz' => {'author' => 'QMACRO','description' => 'handle client and component connections','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1017,'pod' => 505,'pod_errors' => 0,'total' => 1522,'with_comments' => 35},'releases' => 2,'requires' => ['Digest-SHA1-2.04.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Digest::SHA1' => '1.03','XML::Parser' => '2.29'},'requires_recursive' => ['Digest-SHA1-2.04.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 12265,'unpacked' => 37149},'testers' => {'pass' => 9},'uses' => ['Carp','Digest::SHA1','Exporter','IO::Select','IO::Socket::INET','XML::Parser','constant','strict','vars']},'Jabber-RPC-0.01.tar.gz' => {'author' => 'QMACRO','description' => 'Jabber-RPC Implementation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 308,'pod' => 141,'pod_errors' => 0,'total' => 449,'with_comments' => 43},'releases' => 1,'requires' => ['Frontier-RPC-0.06.tar.gz','Jabber-Connection-0.03.tar.gz'],'requires_module' => {'Frontier::RPC2' => undef,'Jabber::Connection' => '0.02'},'requires_recursive' => ['Digest-SHA1-2.04.tar.gz','Frontier-RPC-0.06.tar.gz','Jabber-Connection-0.03.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 5212,'unpacked' => 14566},'testers' => {'pass' => 6},'uses' => ['Frontier::RPC2','Jabber::Connection','Jabber::NS','Jabber::NodeFactory','constant','strict','vars']},'Jabber-RPC-HTTPgate-0.01.tar.gz' => {'author' => 'QMACRO','description' => 'gateway between XML-RPC and Jabber-RPC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 385,'pod' => 198,'pod_errors' => 0,'total' => 583,'with_comments' => 75},'releases' => 1,'requires' => ['Jabber-RPC-0.01.tar.gz'],'requires_module' => {'Jabber::RPC' => '0.01'},'requires_recursive' => ['Digest-SHA1-2.04.tar.gz','Frontier-RPC-0.06.tar.gz','Jabber-Connection-0.03.tar.gz','Jabber-RPC-0.01.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 8929,'unpacked' => 29786},'testers' => {'pass' => 8},'uses' => ['Jabber::Connection','Jabber::NS','URI','strict','vars']},'Jabber-SimpleSend-0.01.tar.gz' => {'author' => 'GMCCAR','description' => 'Send a Jabber message simply.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 64,'pod_errors' => 0,'total' => 143,'with_comments' => 1},'releases' => 1,'requires' => ['Net-Jabber-1.28.tar.gz','Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => 0,'Net::Jabber' => 0,'Test::More' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-Jabber-1.28.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-Stream-1.16.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2722,'unpacked' => 6466},'testers' => {'fail' => 1,'tests' => '3'},'uses' => ['Carp','Exporter','Net::Jabber','strict','warnings']},'Jabber-mod_perl-0.05.tar.gz' => {'author' => 'PIERS','description' => 'Perl handlers for jabberd','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 503,'pod' => 426,'pod_errors' => 0,'total' => 929,'with_comments' => 18},'releases' => 3,'size' => {'packed' => 30506,'unpacked' => 130263},'testers' => {},'uses' => ['$file','Cwd','Data::Dumper','constant','strict','vars']},'Jail-0.8.tar.gz' => {'author' => 'BPANNIER','description' => 'SGIPerl extension for grabbing video, modifying images and display images','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 202,'pod' => 506,'pod_errors' => 2,'total' => 708,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 153755,'unpacked' => 263579},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Jar-Signer-0.1.tar.gz' => {'author' => 'MSOUTHERN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 175,'pod' => 122,'pod_errors' => 0,'total' => 297,'with_comments' => 1},'releases' => 1,'requires' => ['File-chdir-0.05.tar.gz'],'requires_module' => {'File::chdir' => undef},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-chdir-0.05.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3116,'unpacked' => 8093},'testers' => {'pass' => 2},'uses' => ['File::Basename','File::chdir']},'Java-4.5.tar.gz' => {'author' => 'METZZO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1022,'pod' => 655,'pod_errors' => 0,'total' => 1677,'with_comments' => 285},'releases' => 18,'size' => {'packed' => 64435,'unpacked' => 149291},'testers' => {'fail' => 2},'uses' => ['5','Carp','Exporter','Symbol','constant','overload','vars']},'Java-JVM-Classfile-0.19.tar.gz' => {'author' => 'LBROCARD','description' => 'Parse JVM Classfiles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2696,'pod' => 216,'pod_errors' => 0,'total' => 2912,'with_comments' => 71},'releases' => 7,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Class::Struct' => 0,'Test::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19735,'unpacked' => 117833},'testers' => {'pass' => 6},'uses' => ['Carp','Class::Struct','Exporter','IO::File','constant','strict','vars']},'Java-SJ-0.01.tar.gz' => {'author' => 'WIGGLY','description' => 'Highly configurable Java program startup system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1583,'pod' => 603,'pod_errors' => 0,'total' => 2186,'with_comments' => 384},'releases' => 2,'requires' => ['File-Slurp-2002.1031.tar.gz','XML-XPath-1.13.tar.gz'],'requires_module' => {'File::Slurp' => 0,'XML::XPath' => 0},'requires_recursive' => ['File-Slurp-2002.1031.tar.gz','XML-Parser-2.31.tar.gz','XML-XPath-1.13.tar.gz'],'size' => {'packed' => 18231,'unpacked' => 76511},'testers' => {'pass' => 1},'uses' => ['Carp','Cwd','Data::Dumper','English','File::Glob','File::Path','File::Slurp','File::Spec','File::Spec::Functions','File::Temp','IO::File','IO::Handle','XML::XPath','strict']},'JavaScript-0.52.tar.gz' => {'author' => 'CLAESJAC','description' => 'Allowes JavaScript execution withing Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 256,'pod' => 298,'pod_errors' => 0,'total' => 554,'with_comments' => 11},'releases' => 3,'size' => {'packed' => 15072,'unpacked' => 51713},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','constant','strict','vars','warnings']},'JavaScript-Toolbox-0.01.tar.gz' => {'author' => 'PEIRY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 490,'pod' => 188,'pod_errors' => 0,'total' => 678,'with_comments' => 0},'releases' => 1,'requires' => ['HTTP-BrowserDetect-0.97.tar.gz'],'requires_module' => {'HTTP::BrowserDetect' => '0.97'},'requires_recursive' => ['HTTP-BrowserDetect-0.97.tar.gz'],'size' => {'packed' => 3547,'unpacked' => 15921},'testers' => {'pass' => 3},'uses' => ['HTTP::BrowserDetect','strict','v5.6','warnings']},'Jcode-0.83.tar.gz' => {'author' => 'DANKOGAI','description' => 'Japanese Charset Handler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14204,'pod' => 388,'pod_errors' => 0,'total' => 14592,'with_comments' => 192},'releases' => 34,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::Base64' => '2.1'},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 188328,'unpacked' => 751786},'testers' => {'pass' => 3},'uses' => ['5.004','Carp','DynaLoader','Exporter','MIME::Base64','strict','vars']},'Joystick-1.01.zip' => {'author' => 'BDLILLEY','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 126,'pod' => 94,'pod_errors' => 0,'total' => 220,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 9559,'unpacked' => 19974},'testers' => {},'uses' => ['Carp','Exporter','Win32::API','strict','vars']},'Jvm-0.9.2.tar.gz' => {'author' => 'YEWEI','description' => 'Perl extension for Java VM invocation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 434,'pod' => 138,'pod_errors' => 0,'total' => 572,'with_comments' => 41},'releases' => 4,'size' => {'packed' => 14190,'unpacked' => 51665},'testers' => {'pass' => 1},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'KeyState-0.01.tar.gz' => {'author' => 'MMUSGROVE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 69,'pod_errors' => 0,'total' => 126,'with_comments' => 9},'releases' => 3,'requires' => ['Win32-API-0.41.tar.gz'],'requires_module' => {'Win32::API' => '0.41'},'requires_recursive' => ['Win32-API-0.41.tar.gz'],'size' => {'packed' => 5256,'unpacked' => 12872},'testers' => {},'uses' => ['5.006','Exporter','Win32::API','strict','warnings']},'Kite-0.4.tar.gz' => {'author' => 'ABW','description' => 'collection of modules useful in Kite design and construction.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2639,'pod' => 1338,'pod_errors' => 0,'total' => 3977,'with_comments' => 569},'releases' => 2,'size' => {'packed' => 36041,'unpacked' => 137813},'testers' => {'fail' => 3,'pass' => 1,'tests' => '95'},'uses' => ['','5.004','Exporter','Template','XML::Parser','strict','vars']},'Kohonen-SOM-0.133.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 752,'pod' => 497,'pod_errors' => 2,'total' => 1249,'with_comments' => 65},'releases' => 5,'size' => {'packed' => 102266,'unpacked' => 233820},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars','warnings']},'Kolab-Config-0.01.tar.gz' => {'author' => 'STEPHANB','description' => 'A Perl Module that acts as a standard interface to the configuration settings of a Kolab server.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 51,'pod_errors' => 0,'total' => 110,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 2324,'unpacked' => 4545},'testers' => {},'uses' => ['5.008','Exporter','IO::File','strict','vars','warnings']},'Kolab-DirServ-0.03.tar.gz' => {'author' => 'STEPHANB','description' => 'A Perl Module that handles Address book synchronisation between Kolab servers.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 311,'pod' => 74,'pod_errors' => 0,'total' => 385,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 4369,'unpacked' => 12870},'testers' => {},'uses' => ['5.008','Exporter','IO::File','Kolab::Config','Kolab::DirServ::Config','Kolab::Util','MIME::Body','MIME::Entity','MIME::Parser','Mail::IMAPClient','Net::LDAP','Net::LDAP::Entry','Net::LDAP::LDIF','POSIX','URI','strict','warnings']},'Kolab-DirServ-Config-0.01.tar.gz' => {'author' => 'STEPHANB','description' => 'A Perl Module that acts as a standard interface to the configuration settings of a Kolab server.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 57,'pod_errors' => 0,'total' => 126,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 2466,'unpacked' => 5023},'testers' => {},'uses' => ['5.008','Exporter','IO::File','Kolab::Config','strict','vars','warnings']},'Kolab-Util-0.01.tar.gz' => {'author' => 'STEPHANB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 0,'pod_errors' => 0,'total' => 73,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 1875,'unpacked' => 2998},'testers' => {'pass' => 1},'uses' => ['5.008','Exporter','strict','warnings']},'Krb4-0.93.tar.gz' => {'author' => 'JHORWITZ','description' => 'Perl extension for Kerberos 4','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 215,'pod_errors' => 0,'total' => 297,'with_comments' => 9},'releases' => 6,'size' => {'packed' => 7274,'unpacked' => 22858},'testers' => {},'uses' => ['5.002','DynaLoader','Exporter','strict','vars']},'Krb4-1.1.tar.gz' => {'author' => 'JHORWITZ','description' => 'Interface to Kerberos 4 API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 81,'pod' => 215,'pod_errors' => 0,'total' => 296,'with_comments' => 9},'releases' => 6,'size' => {'packed' => 7313,'unpacked' => 23737},'testers' => {},'uses' => ['5.002','DynaLoader','Exporter','strict','vars']},'Krb5-0.9.tar.gz' => {'author' => 'JHORWITZ','description' => 'Perl extension for Kerberos 5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 159,'pod' => 228,'pod_errors' => 1,'total' => 387,'with_comments' => 8},'releases' => 4,'size' => {'packed' => 18162,'unpacked' => 99554},'testers' => {},'uses' => ['5.004','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Krb5-1.2.tar.gz' => {'author' => 'JHORWITZ','description' => 'Interface to Kerberos 5 API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 162,'pod' => 228,'pod_errors' => 1,'total' => 390,'with_comments' => 8},'releases' => 4,'size' => {'packed' => 18389,'unpacked' => 101786},'testers' => {'fail' => 2},'uses' => ['5.004','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'LCC-0.01.tar.gz' => {'author' => 'ELIZABETH','description' => 'Content Provider Modules for the Local Content Cache system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2337,'pod' => 956,'pod_errors' => 0,'total' => 3293,'with_comments' => 872},'releases' => 1,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO::File' => 0,'IO::Socket' => 0},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 20640,'unpacked' => 97766},'testers' => {'pass' => 5},'uses' => ['1','strict']},'LEGO-RCX-1.01.tar.gz' => {'author' => 'JQUILLAN','description' => 'Control you Lego Mindstorm RCX computer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1048,'pod' => 335,'pod_errors' => 0,'total' => 1383,'with_comments' => 59},'releases' => 3,'size' => {'packed' => 17539,'unpacked' => 60619},'testers' => {'pass' => 1,'tests' => '0','unknown' => 9},'uses' => ['FileHandle','POSIX','strict','vars']},'LISP-0.01.tar.gz' => {'author' => 'DOUGW','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 332,'pod' => 246,'pod_errors' => 0,'total' => 578,'with_comments' => 32},'releases' => 1,'size' => {'packed' => 5353,'unpacked' => 14351},'testers' => {'pass' => 7},'uses' => ['Carp','Exporter','LIST','constant','strict','warnings']},'LJ-Simple-0.06.tar.gz' => {'author' => 'SIMES','description' => 'Simple Perl to access LiveJournal','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2253,'pod' => 1433,'pod_errors' => 1,'total' => 3686,'with_comments' => 138},'releases' => 4,'size' => {'packed' => 28575,'unpacked' => 118298},'testers' => {'pass' => 3},'uses' => ['5.006','Exporter','POSIX','Socket','strict','use','warnings']},'LSF-0.21.tar.gz' => {'author' => 'MSOUTHERN','description' => 'load various LSF modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 599,'pod' => 441,'pod_errors' => 0,'total' => 1040,'with_comments' => 27},'releases' => 9,'requires' => ['DateManip-5.42a.tar.gz','System2-0.82.tar.gz'],'requires_module' => {'Date::Manip' => '5.4','System2' => '0.82'},'requires_recursive' => ['DateManip-5.42a.tar.gz','System2-0.82.tar.gz'],'size' => {'packed' => 8585,'unpacked' => 28692},'testers' => {'pass' => 2},'uses' => ['Carp','Date::Manip','LSF','LSF::Job','LSF::JobInfo','System2']},'LSF-0.4.tar.gz' => {'author' => 'MSOUTHERN','description' => 'load various LSF modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 675,'pod' => 499,'pod_errors' => 0,'total' => 1174,'with_comments' => 23},'releases' => 9,'requires' => ['DateManip-5.42a.tar.gz','IPC-Run-0.75.tar.gz'],'requires_module' => {'Date::Manip' => '5.4','IPC::Run' => '0.66'},'requires_recursive' => ['DateManip-5.42a.tar.gz','IPC-Run-0.75.tar.gz'],'size' => {'packed' => 9401,'unpacked' => 34768},'testers' => {'fail' => 2},'uses' => ['','Date::Manip','IPC::Run','LSF','LSF::Job','strict','warnings']},'LSF-0.9.tar.gz' => {'author' => 'MSOUTHERN','description' => 'A perl API built on top of the LSF command line tools','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 789,'pod' => 535,'pod_errors' => 0,'total' => 1324,'with_comments' => 30},'releases' => 9,'requires' => ['DateManip-5.42a.tar.gz','IPC-Run-0.75.tar.gz'],'requires_module' => {'Date::Manip' => '5.4','IPC::Run' => '0.66'},'requires_recursive' => ['DateManip-5.42a.tar.gz','IPC-Run-0.75.tar.gz'],'size' => {'packed' => 12010,'unpacked' => 41177},'testers' => {},'uses' => ['','Date::Manip','IPC::Run','LSF','strict','warnings']},'LSF-Base-0.05.tar.gz' => {'author' => 'PFRANCEUS','description' => 'Object oriented Perl extension for use with the Platform Computing Corporation\'s Load Sharing Facility (LSF) Base product.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 223,'pod' => 246,'pod_errors' => 0,'total' => 469,'with_comments' => 34},'releases' => 4,'size' => {'packed' => 18500,'unpacked' => 66503},'testers' => {},'uses' => ['DynaLoader','Exporter','strict','vars']},'LSF-Batch-0.04.tar.gz' => {'author' => 'PFRANCEUS','description' => 'Perl extension for use with the Platform Computing Corporation\'s Load Sharing Facility (LSF) Batch product.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 848,'pod' => 1002,'pod_errors' => 0,'total' => 1850,'with_comments' => 22},'releases' => 4,'size' => {'packed' => 45770,'unpacked' => 265732},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'LWP-attic-1.00.tar.gz' => {'author' => 'GAAS','description' => 'Low level I/O capability','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 853,'pod' => 206,'pod_errors' => 0,'total' => 1059,'with_comments' => 48},'releases' => 1,'size' => {'packed' => 6058,'unpacked' => 23935},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['LWP::Debug','Net::SSLeay','Socket','Symbol','Tk']},'LWPng-alpha-0.24.tar.gz' => {'author' => 'GAAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5165,'pod' => 358,'pod_errors' => 0,'total' => 5523,'with_comments' => 345},'releases' => 22,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.40'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 84522,'unpacked' => 267673},'testers' => {'fail' => 9,'tests' => '38'},'uses' => ['Compress::Zlib','Data::Dumper','Fcntl','HTML::HeadParser','HTTP::Date','HTTP::Headers::Auth','HTTP::Headers::Util','HTTP::Message','HTTP::Request','HTTP::Response','IO::Handle','IO::Socket','IO::Socket::INET','LWP::Conn::FTP::Data::Listen','LWP::Conn::FTP::Ready','LWP::Conn::FTP::Trans','LWP::Conn::FTP::User','LWP::Conn::HTTP::Active','LWP::MediaTypes','MD5','MIME::Base64','MIME::QuotedPrint','POSIX','Socket','Time::HiRes','URI','strict','vars']},'LaBrea-Tarpit-1.11.tar.gz' => {'author' => 'MIKER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3786,'pod' => 1653,'pod_errors' => 1,'total' => 5439,'with_comments' => 821},'releases' => 6,'size' => {'packed' => 128886,'unpacked' => 431683},'testers' => {'pass' => 1},'uses' => ['5.005_62','AutoLoader','Exporter','Fcntl','POSIX','Socket','Time::Local','diagnostics','strict','vars','warnings']},'LaTeX-Parser-0.01.tar.gz' => {'author' => 'SVENH','description' => 'Perl extension to parse LaTeX files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 134,'pod' => 47,'pod_errors' => 0,'total' => 181,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 2928,'unpacked' => 5699},'testers' => {'pass' => 8},'uses' => ['integer','strict']},'Language-Basic-1.44.tar.gz' => {'author' => 'AKARGER','description' => 'Perl Module to interpret BASIC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4037,'pod' => 857,'pod_errors' => 0,'total' => 4894,'with_comments' => 927},'releases' => 6,'size' => {'packed' => 52891,'unpacked' => 189374},'testers' => {'pass' => 17},'uses' => ['5.004','Exporter','constant','strict','vars']},'Language-Befunge-0.38.tar.gz' => {'author' => 'JQUELIN','description' => 'a Befunge-98 interpreter','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2321,'pod' => 982,'pod_errors' => 0,'total' => 3303,'with_comments' => 282},'releases' => 22,'requires' => ['Storable-2.07.tar.gz'],'requires_module' => {'Storable' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 56913,'unpacked' => 220609},'testers' => {'pass' => 4},'uses' => ['Carp','Config','Storable','strict','v5.6','warnings']},'Language-DATR-DATR2XML-0.901.tar.gz' => {'author' => 'LGODDARD','description' => 'Convert DATR to XML and back, wth XSLT & DTD','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1087,'pod' => 370,'pod_errors' => 3,'total' => 1457,'with_comments' => 340},'releases' => 4,'size' => {'packed' => 28503,'unpacked' => 100509},'testers' => {'pass' => 7},'uses' => ['5.005_62','HTTP::Request','LWP::UserAgent','strict','warnings']},'Language-FP-0.03.tgz' => {'author' => 'SEANO','description' => '- think like Jonh Backus wants you to','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 780,'pod' => 118,'pod_errors' => 0,'total' => 898,'with_comments' => 87},'releases' => 3,'requires' => ['Parse-RecDescent-1.94.tar.gz','Regexp-Common-2.113.tar.gz'],'requires_module' => {'Parse::RecDescent' => '0.01','Regexp::Common' => '0.01'},'requires_recursive' => ['Parse-RecDescent-1.94.tar.gz','Regexp-Common-2.113.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 9699,'unpacked' => 25493},'testers' => {'pass' => 8},'uses' => ['Carp','Data::Dumper','Exporter','Parse::RecDescent','Regexp::Common']},'Language-Functional-0.03.tar.gz' => {'author' => 'LBROCARD','description' => 'a module which makes Perl slightly more functional','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 980,'pod' => 733,'pod_errors' => 0,'total' => 1713,'with_comments' => 27},'releases' => 1,'size' => {'packed' => 16456,'unpacked' => 62873},'testers' => {'pass' => 10},'uses' => ['Carp','Exporter','Tie::Array','strict','vars']},'Language-Homespring-0.04.tar.gz' => {'author' => 'IAMCAL','description' => 'Perl interpreter for "Homespring"','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 759,'pod' => 158,'pod_errors' => 0,'total' => 917,'with_comments' => 49},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7608,'unpacked' => 25029},'testers' => {'pass' => 2},'uses' => ['strict','warnings']},'Language-Homespring-Visualise-GraphViz-0.03.tar.gz' => {'author' => 'IAMCAL','description' => 'A visual op-tree viewer for "Homespring"','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 86,'pod' => 72,'pod_errors' => 0,'total' => 158,'with_comments' => 1},'releases' => 3,'requires' => ['GraphViz-1.8.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'GraphViz' => '1.8','Test::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','Heap-0.50.tar.gz','IPC-Run-0.75.tar.gz','Math-Bezier-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 40831,'unpacked' => 102247},'testers' => {'pass' => 1},'uses' => ['GraphViz','strict','warnings']},'Language-Mumps-1.07.tar.gz' => {'author' => 'SMUELLER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2693,'pod' => 45,'pod_errors' => 0,'total' => 2738,'with_comments' => 729},'releases' => 2,'size' => {'packed' => 23132,'unpacked' => 75833},'testers' => {'pass' => 11},'uses' => ['Curses','DBI','Data::DumpXML','Data::DumpXML::Parser','Fcntl','Time::Local','XML::Dumper','XML::Parser','strict','vars']},'Language-Ook-0.03.tar.gz' => {'author' => 'JQUELIN','description' => 'an Ook! interpreter','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 61,'pod_errors' => 0,'total' => 167,'with_comments' => 14},'releases' => 3,'size' => {'packed' => 3090,'unpacked' => 9278},'testers' => {'pass' => 6},'uses' => ['5.006','Carp','strict','warnings']},'Language-Prolog-Interpreter-0.021.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 216,'pod' => 160,'pod_errors' => 1,'total' => 376,'with_comments' => 25},'releases' => 2,'size' => {'packed' => 4368,'unpacked' => 11376},'testers' => {'pass' => 4},'uses' => ['Carp']},'Language-Prolog-SWI-0.01.tar.gz' => {'author' => 'DRRHO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1010,'pod' => 70,'pod_errors' => 0,'total' => 1080,'with_comments' => 32},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.46'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 12094,'unpacked' => 69912},'testers' => {},'uses' => ['5.006','AutoLoader','DynaLoader','Exporter','strict','vars','warnings']},'Language-Prolog-Sugar-0.03.tar.gz' => {'author' => 'SALVA','description' => 'Syntactic sugar for Prolog term constructors','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 121,'pod_errors' => 0,'total' => 251,'with_comments' => 1},'releases' => 2,'requires' => ['Language-Prolog-Types-0.08.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Language::Prolog::Types' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Language-Prolog-Types-0.08.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3052,'unpacked' => 7510},'testers' => {'pass' => 4},'uses' => ['Carp','Language::Prolog::Types','strict','warnings']},'Language-Prolog-Types-0.08.tar.gz' => {'author' => 'SALVA','description' => 'Prolog types in Perl.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 962,'pod' => 799,'pod_errors' => 1,'total' => 1761,'with_comments' => 20},'releases' => 5,'size' => {'packed' => 10713,'unpacked' => 39756},'testers' => {'pass' => 8},'uses' => ['Carp','Exporter','strict','warnings']},'Language-Prolog-Yaswi-0.04.tar.gz' => {'author' => 'SALVA','description' => 'Yet another interface to SWI-Prolog','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 311,'pod' => 288,'pod_errors' => 0,'total' => 599,'with_comments' => 4},'releases' => 3,'requires' => ['Language-Prolog-Sugar-0.03.tar.gz','Language-Prolog-Types-0.08.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Language::Prolog::Sugar' => '0.03','Language::Prolog::Types' => '0.08','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Language-Prolog-Sugar-0.03.tar.gz','Language-Prolog-Types-0.08.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 23082,'unpacked' => 72311},'testers' => {},'uses' => ['Carp','Exporter','Language::Prolog::Types','Language::Prolog::Types::Converter','XSLoader','strict','warnings']},'Language-XS-0.01.tar.gz' => {'author' => 'MLEHMANN','description' => 'Write XS code on the fly and load it dynamically.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 308,'pod' => 105,'pod_errors' => 0,'total' => 413,'with_comments' => 25},'releases' => 1,'size' => {'packed' => 8057,'unpacked' => 21960},'testers' => {'fail' => 2,'pass' => 4,'tests' => '8'},'uses' => ['Carp','Config','DirHandle','DynaLoader','ExtUtils::Liblist','ExtUtils::MakeMaker','File::Spec','strict']},'Language-XSB-0.12.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 463,'pod' => 295,'pod_errors' => 0,'total' => 758,'with_comments' => 13},'releases' => 5,'requires' => ['Inline-0.44.tar.gz','Language-Prolog-Types-0.08.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Inline::C' => 0,'Language::Prolog::Types' => 0,'Test::More' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Language-Prolog-Types-0.08.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'testers' => {},'uses' => ['Carp','Exporter','Language::Prolog::Types','Language::Prolog::Types::Converter','Language::XSB::Config','Tie::Array','Tie::Scalar','strict','warnings']},'Lexical-Alias-0.04.tar.gz' => {'author' => 'PINYAN','description' => 'makes a lexical an alias for another variable','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 126,'pod_errors' => 0,'total' => 176,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 4111,'unpacked' => 12104},'testers' => {'pass' => 3},'uses' => ['DynaLoader','Exporter']},'Lexical-Typeglob-0.02.tar.gz' => {'author' => 'JJORE','description' => 'Like Symbol without a symbol table.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 25,'pod' => 41,'pod_errors' => 0,'total' => 66,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2788,'unpacked' => 5643},'testers' => {'pass' => 3},'uses' => ['DynaLoader','Exporter','strict','warnings']},'Lib-Module-0.67.tar.gz' => {'author' => 'RKIES','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 602,'pod' => 78,'pod_errors' => 0,'total' => 680,'with_comments' => 54},'releases' => 3,'size' => {'packed' => 13764,'unpacked' => 42854},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','DB','Exporter','File::Basename','vars']},'LibA2-0.003.tar.gz' => {'author' => 'CJM','description' => 'Read/write Apple II disk image files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2146,'pod' => 311,'pod_errors' => 0,'total' => 2457,'with_comments' => 851},'releases' => 2,'size' => {'packed' => 26715,'unpacked' => 101302},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['5.000','Carp','Exporter','FileHandle','POSIX','integer','strict','vars']},'LibTerm-GetKey-1.02.tar.gz' => {'author' => 'BARRYP','description' => 'A perl module for quick easy simple key control','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 337,'pod' => 111,'pod_errors' => 0,'total' => 448,'with_comments' => 37},'releases' => 1,'size' => {'packed' => 6603,'unpacked' => 20750},'testers' => {'pass' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','warnings']},'LibWeb-0.01.tar.gz' => {'author' => 'CKONG','description' => 'CGI HANDLING FOR LIBWEB APPLICATIONS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4658,'pod' => 2002,'pod_errors' => 0,'total' => 6660,'with_comments' => 1316},'releases' => 2,'size' => {'packed' => 59849,'unpacked' => 282011},'testers' => {'pass' => 6},'uses' => ['5.004','CGI','Carp','Crypt::CBC','DBI','Digest::HMAC','Digest::MD5','Digest::SHA1','FileHandle','LibWeb::CGI','LibWeb::Class','LibWeb::Core','LibWeb::Crypt','LibWeb::Database','LibWeb::HTML::Default','LibWeb::HTML::Error','LibWeb::Session','SelfLoader','strict','vars']},'LibWeb-0.02.tar.gz' => {'author' => 'CKONG','description' => 'Extra cgi supports for libweb applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5807,'pod' => 2238,'pod_errors' => 0,'total' => 8045,'with_comments' => 1695},'releases' => 2,'size' => {'packed' => 78102,'unpacked' => 355300},'testers' => {'fail' => 1,'pass' => 6,'tests' => '41'},'uses' => ['5.004','CGI','Carp','Crypt::Blowfish','DBI','Digest::HMAC','Digest::MD5','Digest::SHA1','FileHandle','Mail::Sendmail','SelfLoader','strict','vars']},'Library-Catalog-0.12.tar.gz' => {'author' => 'AMBS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 940,'pod' => 210,'pod_errors' => 0,'total' => 1150,'with_comments' => 89},'releases' => 2,'requires' => ['DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','XML-DT-0.24.1.tar.gz','XML-XPath-1.13.tar.gz'],'requires_module' => {'DB_File' => '1.804','Data::Dumper' => '2.10','XML::DT' => '0.19','XML::XPath' => '1.12'},'requires_recursive' => ['DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','XML-DT-0.24.1.tar.gz','XML-Parser-2.31.tar.gz','XML-XPath-1.13.tar.gz'],'size' => {'packed' => 12688,'unpacked' => 39027},'testers' => {'fail' => 2,'tests' => '61'},'uses' => ['CGI','DB_File','Data::Dumper','Exporter','Text::BibTeX','XML::DT','XML::XPath','strict','v5.6.0','warnings']},'Library-Simple-0.02.tar.gz' => {'author' => 'AMBS','description' => 'Perl extension for Digital Library support','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 468,'pod' => 106,'pod_errors' => 0,'total' => 574,'with_comments' => 16},'releases' => 2,'size' => {'packed' => 6426,'unpacked' => 15931},'testers' => {'fail' => 2,'pass' => 5},'uses' => ['5.005_62','CGI','DB_File','Data::Dumper','Exporter','Fcntl','Library::Thesaurus','XML::DT','strict','warnings']},'LineByLine-1.0.tar.gz' => {'author' => 'BCROWELL','description' => 'Line-by-line message authentication for a plain text file.','files' => [],'lines' => {'nonpod' => 429,'pod' => 124,'pod_errors' => 0,'total' => 553,'with_comments' => 32},'releases' => 1,'size' => {'packed' => 5685,'unpacked' => 18676},'testers' => {},'uses' => ['Digest::SHA1','strict']},'LinePrinter-0.10.tar.gz' => {'author' => 'CFUHRMAN','description' => 'Perl extension for direct-to-lpd printing.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 902,'pod' => 82,'pod_errors' => 0,'total' => 984,'with_comments' => 391},'releases' => 1,'size' => {'packed' => 15994,'unpacked' => 49732},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['AutoLoader','Carp','Exporter','FileHandle','Socket','strict','vars']},'Lingua-31337-0.02.tar.gz' => {'author' => 'CWEST','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 132,'pod' => 37,'pod_errors' => 0,'total' => 169,'with_comments' => 14},'releases' => 1,'size' => {'packed' => 2321,'unpacked' => 5392},'testers' => {'pass' => 8},'uses' => ['strict','vars']},'Lingua-AF-Numbers-1.1.tar.gz' => {'author' => 'ALIZTA','description' => 'Perl module for converting numeric values into their Afrikaans equivalents =head1 DESCRIPTION Initial release, documentation and updates will follow.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 225,'pod' => 28,'pod_errors' => 0,'total' => 253,'with_comments' => 9},'releases' => 4,'size' => {'packed' => 2565,'unpacked' => 6354},'testers' => {'pass' => 3},'uses' => ['strict']},'Lingua-AM-Abbreviate-0.01.tar.gz' => {'author' => 'DYACOB','description' => 'Expand or Contract Amharic Abbreviations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 113,'pod' => 29,'pod_errors' => 0,'total' => 142,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 2905,'unpacked' => 5809},'testers' => {'pass' => 3},'uses' => ['5.000','Exporter']},'Lingua-AR-MacArabic-0.03.tar.gz' => {'author' => 'SADAHIRO','description' => 'transcode between Mac OS Arabic encoding and Unicode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 119,'pod_errors' => 0,'total' => 161,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 9415,'unpacked' => 35911},'testers' => {'pass' => 10},'uses' => ['5.006001','AutoLoader','DynaLoader','Exporter','strict','vars']},'Lingua-Atinlay-Igpay-0.03.tar.gz' => {'author' => 'CWEST','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 46,'pod' => 27,'pod_errors' => 0,'total' => 73,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 1768,'unpacked' => 2986},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Lingua-Bork-0.03.tar.gz' => {'author' => 'MCHING','description' => 'Perl extension for Bork Bork Bork','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 34,'pod_errors' => 0,'total' => 91,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 8249,'unpacked' => 22710},'testers' => {'pass' => 10},'uses' => ['Exporter','strict','vars','warnings']},'Lingua-CS-Num2Word-0.01.tar.gz' => {'author' => 'RVASICEK','description' => 'number to text convertor for czech. Output text is in iso-8859-2 encoding.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 39,'pod_errors' => 0,'total' => 172,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 2149,'unpacked' => 5273},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'Lingua-Conjunction-1.99.tar.gz' => {'author' => 'RRWO','description' => 'Convert lists into conjunctions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 124,'pod' => 66,'pod_errors' => 0,'total' => 190,'with_comments' => 26},'releases' => 1,'size' => {'packed' => 2951,'unpacked' => 8486},'testers' => {'tests' => '0','unknown' => 30},'uses' => ['Carp','Exporter','strict','vars']},'Lingua-DE-ASCII-0.09.tar.gz' => {'author' => 'BIGJ','description' => 'Perl extension to convert german umlauts to and from ascii','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 999,'pod' => 72,'pod_errors' => 0,'total' => 1071,'with_comments' => 182},'releases' => 9,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 751119,'unpacked' => 3825550},'testers' => {'pass' => 1},'uses' => ['5.006','Exporter','strict','warnings']},'Lingua-DE-Num2Word-0.01.tar.gz' => {'author' => 'RVASICEK','description' => 'positive number to text convertor for german. Output text is in iso-8859-1 encoding.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 43,'pod_errors' => 0,'total' => 125,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 1954,'unpacked' => 3982},'testers' => {'pass' => 4},'uses' => ['strict','vars']},'Lingua-DE-Sentence-0.07.tar.gz' => {'author' => 'HOLSTEN','description' => 'Perl extension for tokenizing german texts into their sentences.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 645,'pod' => 151,'pod_errors' => 0,'total' => 796,'with_comments' => 41},'releases' => 5,'size' => {'packed' => 23478,'unpacked' => 56999},'testers' => {'pass' => 3},'uses' => ['5.005_62','Exporter','POSIX','locale','strict','warnings']},'Lingua-DetectCyrillic-0.02.tar.gz' => {'author' => 'RUDENKO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2907,'pod' => 488,'pod_errors' => 7,'total' => 3395,'with_comments' => 187},'releases' => 2,'requires' => ['Unicode-Map8-0.12.tar.gz','Unicode-String-2.07.tar.gz'],'requires_module' => {'Unicode::Map8' => 0,'Unicode::String' => 0},'requires_recursive' => ['MIME-Base64-2.20.tar.gz','Unicode-Map8-0.12.tar.gz','Unicode-String-2.07.tar.gz'],'size' => {'packed' => 55393,'unpacked' => 169120},'testers' => {'pass' => 2},'uses' => ['Lingua::DetectCyrillic::DictRus','Lingua::DetectCyrillic::DictUkr','Lingua::DetectCyrillic::WordHash2Rus','Lingua::DetectCyrillic::WordHash2Ukr','Unicode::Map8','Unicode::String']},'Lingua-EN-AddressParse-1.11.tar.gz' => {'author' => 'KIMRYAN','description' => 'manipulate geographical addresses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 993,'pod' => 246,'pod_errors' => 0,'total' => 1239,'with_comments' => 104},'releases' => 11,'requires' => ['Lingua-EN-NameParse-1.18.tar.gz','Locale-SubCountry-1.23.tar.gz','Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Lingua::EN::NameParse' => 0,'Locale::SubCountry' => 0,'Parse::RecDescent' => 0},'requires_recursive' => ['Lingua-EN-NameParse-1.18.tar.gz','Locale-SubCountry-1.23.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 13565,'unpacked' => 46296},'testers' => {'pass' => 8},'uses' => ['5.004','Exporter','Lingua::EN::NameParse','Locale::SubCountry','Parse::RecDescent','strict','vars']},'Lingua-EN-Dict-0.20.zip' => {'author' => 'JBRYAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 600,'pod' => 297,'pod_errors' => 2,'total' => 897,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 88914,'unpacked' => 557932},'testers' => {'fail' => 3},'uses' => ['Data::Dumper','IO::Handle','Socket','XML::Parser','strict']},'Lingua-EN-Fathom-1.07.tar.gz' => {'author' => 'KIMRYAN','description' => 'Readability measurements for English text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 440,'pod' => 196,'pod_errors' => 0,'total' => 636,'with_comments' => 59},'releases' => 8,'requires' => ['Lingua-EN-Syllable-0.251.tar.gz'],'requires_module' => {'Lingua::EN::Syllable' => 0},'requires_recursive' => ['Lingua-EN-Syllable-0.251.tar.gz'],'size' => {'packed' => 7302,'unpacked' => 24778},'testers' => {'pass' => 8},'uses' => ['Exporter','Lingua::EN::Syllable','strict','vars']},'Lingua-EN-Gender-0.02.tar.gz' => {'author' => 'GOSSAMER','description' => 'Inflect pronouns for gender','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 60,'pod_errors' => 3,'total' => 149,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 2336,'unpacked' => 4792},'testers' => {'tests' => '0','unknown' => 24},'uses' => ['Exporter','strict','vars']},'Lingua-EN-Infinitive-1.07.tgz' => {'author' => 'RSAVAGE','description' => 'Find infinitive of a conjugated word','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1230,'pod' => 90,'pod_errors' => 0,'total' => 1320,'with_comments' => 128},'releases' => 6,'size' => {'packed' => 10944,'unpacked' => 45563},'testers' => {'pass' => 1},'uses' => ['Exporter','strict','vars']},'Lingua-EN-Inflect-1.88.tar.gz' => {'author' => 'DCONWAY','description' => 'English sing->plur, a/an, nums, participles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1720,'pod' => 762,'pod_errors' => 0,'total' => 2482,'with_comments' => 97},'releases' => 10,'size' => {'packed' => 37566,'unpacked' => 126944},'testers' => {'pass' => 8},'uses' => ['Env','Exporter','strict','vars']},'Lingua-EN-Keywords-2.0.tar.gz' => {'author' => 'SIMON','description' => 'Automatically extracts keywords from text','files' => ['Makefile.PL','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 51,'pod' => 29,'pod_errors' => 0,'total' => 80,'with_comments' => 5},'releases' => 6,'requires' => ['Lingua-EN-Tagger-0.02.tar.gz'],'requires_module' => {'Lingua::EN::Tagger' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','Lingua-EN-Tagger-0.02.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','MIME-Base64-2.20.tar.gz','PerlIO-gzip-0.15.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-German-0.03.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4639,'unpacked' => 8746},'testers' => {'pass' => 2},'uses' => ['5.005_62','Exporter','Lingua::EN::Tagger','strict','warnings']},'Lingua-EN-MatchNames-1.12.tar.gz' => {'author' => 'BRIANL','description' => 'Smart matching for human names','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 150,'pod' => 82,'pod_errors' => 0,'total' => 232,'with_comments' => 20},'releases' => 4,'requires' => ['Lingua-EN-NameParse-1.18.tar.gz','Lingua-EN-Nickname-1.13.tar.gz','String-Approx-3.20.tar.gz','Text-Metaphone-1.96.tar.gz','Text-Soundex-3.02.tar.gz'],'requires_module' => {'Lingua::EN::NameParse' => 0,'Lingua::EN::Nickname' => 0,'String::Approx' => 0,'Text::Metaphone' => 0,'Text::Soundex' => 0},'requires_recursive' => ['Lingua-EN-NameParse-1.18.tar.gz','Lingua-EN-Nickname-1.13.tar.gz','Parse-RecDescent-1.94.tar.gz','String-Approx-3.20.tar.gz','Text-Balanced-1.95.tar.gz','Text-Metaphone-1.96.tar.gz','Text-Soundex-3.02.tar.gz'],'size' => {'packed' => 4131,'unpacked' => 9695},'testers' => {'pass' => 11},'uses' => ['Carp','Exporter','Lingua::EN::NameParse','Lingua::EN::Nickname','String::Approx','Text::Metaphone','Text::Soundex','strict','vars']},'Lingua-EN-NameCase-1.13.tar.gz' => {'author' => 'SUMMER','description' => 'Convert NAMES and names to Correct Case','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 114,'pod_errors' => 0,'total' => 258,'with_comments' => 34},'releases' => 5,'size' => {'packed' => 5331,'unpacked' => 21334},'testers' => {'pass' => 8},'uses' => ['5.004','Carp','locale','strict','vars']},'Lingua-EN-NameLookup-0.01.tar.gz' => {'author' => 'PBARLOW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 90,'pod_errors' => 1,'total' => 234,'with_comments' => 4},'releases' => 1,'requires' => ['Text-Soundex-3.02.tar.gz'],'requires_module' => {'Text::Soundex' => 2},'requires_recursive' => ['Text-Soundex-3.02.tar.gz'],'size' => {'packed' => 80211,'unpacked' => 201453},'testers' => {'pass' => 4},'uses' => ['Carp','Text::Soundex','strict','vars','warnings']},'Lingua-EN-NameParse-1.18.tar.gz' => {'author' => 'KIMRYAN','description' => 'routines for manipulating a person\'s name','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1413,'pod' => 402,'pod_errors' => 0,'total' => 1815,'with_comments' => 202},'releases' => 19,'requires' => ['Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Parse::RecDescent' => 0},'requires_recursive' => ['Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 18774,'unpacked' => 68329},'testers' => {'pass' => 15},'uses' => ['5.001','Exporter','Parse::RecDescent','strict','vars']},'Lingua-EN-Namegame-0.05.tar.gz' => {'author' => 'YUMPY','description' => 'Converts name to verse as in  Name Game song','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 161,'pod_errors' => 0,'total' => 338,'with_comments' => 55},'releases' => 4,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 7018,'unpacked' => 16863},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','strict','warnings']},'Lingua-EN-Nickname-1.13.tar.gz' => {'author' => 'BRIANL','description' => 'Genealogical nickname matching(Peggy=Midge)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2124,'pod' => 51,'pod_errors' => 0,'total' => 2175,'with_comments' => 564},'releases' => 5,'size' => {'packed' => 34246,'unpacked' => 103392},'testers' => {'fail' => 1,'pass' => 8},'uses' => ['Exporter','strict','vars']},'Lingua-EN-Numbers-0.01.tar.gz' => {'author' => 'PANDICH','description' => 'Converts numeric values into their English string equivalents.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 473,'pod' => 136,'pod_errors' => 0,'total' => 609,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 4801,'unpacked' => 15050},'testers' => {'pass' => 9},'uses' => ['5.004','Carp','Exporter','strict','vars']},'Lingua-EN-Numbers-Ordinate-0.01.tar.gz' => {'author' => 'SBURKE','description' => 'go from cardinal (53) to ordinal (53rd)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 61,'pod' => 114,'pod_errors' => 0,'total' => 175,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 4224,'unpacked' => 11317},'testers' => {'pass' => 9},'uses' => ['5','Exporter','strict','vars']},'Lingua-EN-Numericalize-1.52.tar.gz' => {'author' => 'ECALDER','description' => 'Replaces English descriptions of numbers with numerals','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 226,'pod' => 87,'pod_errors' => 0,'total' => 313,'with_comments' => 18},'releases' => 3,'size' => {'packed' => 12989,'unpacked' => 32563},'testers' => {'fail' => 2,'pass' => 13,'tests' => '101'},'uses' => ['Exporter']},'Lingua-EN-Segmenter-0.08.tar.gz' => {'author' => 'SPLICE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1208,'pod' => 456,'pod_errors' => 0,'total' => 1664,'with_comments' => 78},'releases' => 8,'size' => {'packed' => 144836,'unpacked' => 375429},'testers' => {'pass' => 3},'uses' => ['Carp','Class::Exporter','Exporter','Lingua::Stem','Math::HashSum','Math::VecStat','Math::Vector::SortIndexes','strict']},'Lingua-EN-Sentence-0.25.tar.gz' => {'author' => 'SHLOMOY','description' => 'Module for splitting text into sentences.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 278,'pod' => 100,'pod_errors' => 1,'total' => 378,'with_comments' => 117},'releases' => 25,'size' => {'packed' => 6994,'unpacked' => 31212},'testers' => {'pass' => 3},'uses' => ['5.005_03','Carp','Exporter','POSIX','locale','strict','vars']},'Lingua-EN-Squeeze-1998.1204.tar.gz' => {'author' => 'JARIAALTO','description' => 'Shorten english text for Pagers/GSM phones','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 989,'pod' => 334,'pod_errors' => 5,'total' => 1323,'with_comments' => 209},'releases' => 4,'size' => {'packed' => 12559,'unpacked' => 37089},'testers' => {'pass' => 7},'uses' => ['Carp','English','SelfLoader','autouse','strict','vars']},'Lingua-EN-Summarize-0.2.tar.gz' => {'author' => 'FIMM','description' => 'A simple tool for summarizing bodies of English text.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 173,'pod' => 68,'pod_errors' => 0,'total' => 241,'with_comments' => 12},'releases' => 2,'requires' => ['HTML-Summary-0.017.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Text::Sentence' => 0,'Text::Wrap' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Summary-0.017.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14021,'unpacked' => 35645},'testers' => {'pass' => 17},'uses' => ['Carp','Exporter','HTML::Parser','Text::Sentence','Text::Wrap','strict','vars']},'Lingua-EN-Syllable-0.251.tar.gz' => {'author' => 'GREGFAST','description' => 'Estimate syllable count in words','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 107,'pod' => 37,'pod_errors' => 0,'total' => 144,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 3293,'unpacked' => 5896},'testers' => {'pass' => 9},'uses' => ['strict','vars']},'Lingua-EN-Tagger-0.02.tar.gz' => {'author' => 'MCEGLOWS','description' => 'Part of speech tagger for English natural language processing.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 806,'pod' => 175,'pod_errors' => 0,'total' => 981,'with_comments' => 84},'releases' => 2,'requires' => ['File-Spec-0.82.tar.gz','Lingua-Stem-0.60.tar.gz','PerlIO-gzip-0.15.tar.gz','Storable-2.07.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '0.01','File::Spec' => '0.01','FileHandle' => '0.01','LWP::UserAgent' => '0.01','Lingua::Stem::En' => '0.01','PerlIO::gzip' => '0.01','Storable' => '0.01'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','MIME-Base64-2.20.tar.gz','PerlIO-gzip-0.15.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-German-0.03.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8667,'unpacked' => 23197},'testers' => {'pass' => 3},'uses' => ['Carp','File::Spec','FileHandle','LWP::UserAgent','Lingua::Stem::En','PerlIO::gzip','Storable','strict','warnings']},'Lingua-EN-VerbTense-3.00.zip' => {'author' => 'JBRYAN','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1293,'pod' => 126,'pod_errors' => 2,'total' => 1419,'with_comments' => 61},'releases' => 1,'size' => {'packed' => 14479,'unpacked' => 56289},'testers' => {'pass' => 3},'uses' => ['Exporter','strict']},'Lingua-EN-Words2Nums-0.11.tar.gz' => {'author' => 'JOEY','description' => 'convert English text to numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 232,'pod' => 48,'pod_errors' => 0,'total' => 280,'with_comments' => 33},'releases' => 9,'size' => {'packed' => 7137,'unpacked' => 17634},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','warnings']},'Lingua-EO-Supersignoj-0.02.tar.gz' => {'author' => 'JUERD','description' => 'Convert Esperanto characters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 68,'pod' => 132,'pod_errors' => 0,'total' => 200,'with_comments' => 0},'releases' => 2,'requires' => ['Attribute-Property-1.04.tar.gz'],'requires_module' => {'Attribute::Property' => '1.03'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Attribute-Property-1.04.tar.gz'],'size' => {'packed' => 3447,'unpacked' => 9725},'testers' => {'pass' => 3},'uses' => ['Attribute::Property','strict','utf']},'Lingua-ES-Numeros-0.01.tar.gz' => {'author' => 'JREY','description' => 'Convierte números a texto en Español (Castellano)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 543,'pod' => 229,'pod_errors' => 0,'total' => 772,'with_comments' => 56},'releases' => 1,'size' => {'packed' => 7844,'unpacked' => 20967},'testers' => {'pass' => 4},'uses' => ['5.004','Carp','Exporter','strict','vars']},'Lingua-ES-Silabas-0.01.tar.gz' => {'author' => 'MARCOS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 37,'pod_errors' => 0,'total' => 109,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 2534,'unpacked' => 4849},'testers' => {'pass' => 5},'uses' => ['Exporter','strict','warnings']},'Lingua-EU-Numbers-0.03.tar.gz' => {'author' => 'ISABELLE','description' => 'Converts numbers into Bask (Euskara).','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 280,'pod' => 73,'pod_errors' => 0,'total' => 353,'with_comments' => 33},'releases' => 3,'size' => {'packed' => 6850,'unpacked' => 26291},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','strict','vars']},'Lingua-FA-MacFarsi-0.03.tar.gz' => {'author' => 'SADAHIRO','description' => 'transcode between Mac OS Farsi encoding and Unicode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 119,'pod_errors' => 0,'total' => 161,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 9089,'unpacked' => 35621},'testers' => {'pass' => 10},'uses' => ['5.006001','AutoLoader','DynaLoader','Exporter','strict','vars']},'Lingua-FI-Hyphenate-0.04.tar.gz' => {'author' => 'JHI','description' => 'Finnish hyphenation (suomen tavutus)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 84,'pod' => 100,'pod_errors' => 0,'total' => 184,'with_comments' => 7},'releases' => 4,'size' => {'packed' => 2815,'unpacked' => 5655},'testers' => {'pass' => 10},'uses' => ['Exporter','strict','vars']},'Lingua-FI-Kontti-0.02.tar.gz' => {'author' => 'JHI','description' => 'Finnish Pig Latin (kontinkieli)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 98,'pod_errors' => 0,'total' => 272,'with_comments' => 68},'releases' => 2,'requires' => ['Lingua-FI-Hyphenate-0.04.tar.gz'],'requires_module' => {'Lingua::FI::Hyphenate' => 0},'requires_recursive' => ['Lingua-FI-Hyphenate-0.04.tar.gz'],'size' => {'packed' => 3645,'unpacked' => 9016},'testers' => {'pass' => 5},'uses' => ['Exporter','Lingua::FI::Hyphenate','strict','vars']},'Lingua-FI-Transcribe-0.03.tar.gz' => {'author' => 'JHI','description' => 'Finnish transcription','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 70,'pod_errors' => 0,'total' => 175,'with_comments' => 1},'releases' => 3,'requires' => ['Lingua-FI-Hyphenate-0.04.tar.gz'],'requires_module' => {'Lingua::FI::Hyphenate' => 0},'requires_recursive' => ['Lingua-FI-Hyphenate-0.04.tar.gz'],'size' => {'packed' => 3060,'unpacked' => 6365},'testers' => {'pass' => 7},'uses' => ['Lingua::FI::Hyphenate','strict','vars']},'Lingua-FR-Numbers-0.04.tar.gz' => {'author' => 'BRIAC','description' => 'Converts numeric values into French strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 329,'pod' => 128,'pod_errors' => 0,'total' => 457,'with_comments' => 52},'releases' => 4,'size' => {'packed' => 7768,'unpacked' => 26705},'testers' => {'fail' => 1,'pass' => 2,'tests' => '262'},'uses' => ['Carp','Exporter','strict','vars']},'Lingua-FeatureMatrix-0.05.tar.gz' => {'author' => 'KAHN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1314,'pod' => 789,'pod_errors' => 6,'total' => 2103,'with_comments' => 224},'releases' => 4,'requires' => ['Class-MethodMaker-1.10.tar.gz','Graph-0.20101.tar.gz'],'requires_module' => {'Class::MethodMaker' => '1.06','Graph' => '0.201'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','Graph-0.20101.tar.gz','Heap-0.50.tar.gz'],'size' => {'packed' => 21628,'unpacked' => 68833},'testers' => {'fail' => 1},'uses' => ['5.006','Carp','Class::MethodMaker','Graph::Directed','IO::File','Text::Wrap','strict','warnings']},'Lingua-HE-MacHebrew-0.03.tar.gz' => {'author' => 'SADAHIRO','description' => 'transcode between Mac OS Hebrew encoding and Unicode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 41,'pod' => 119,'pod_errors' => 0,'total' => 160,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 10050,'unpacked' => 41200},'testers' => {'pass' => 10},'uses' => ['5.006001','AutoLoader','DynaLoader','Exporter','strict','vars']},'Lingua-HE-Sentence-0.02.tar.gz' => {'author' => 'SHLOMOY','description' => 'Module for splitting Hebrew text into sentences.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 107,'pod_errors' => 1,'total' => 242,'with_comments' => 59},'releases' => 2,'size' => {'packed' => 4015,'unpacked' => 10298},'testers' => {'pass' => 3},'uses' => ['5.005_03','Carp','Exporter','POSIX','locale','strict','vars']},'Lingua-ID-Nums2Words-0.01.tar.gz' => {'author' => 'SHARYANTO','description' => 'convert number to Indonesian verbage.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 203,'pod' => 24,'pod_errors' => 0,'total' => 227,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 2700,'unpacked' => 6369},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'Lingua-ID-Words2Nums-0.01.tar.gz' => {'author' => 'SHARYANTO','description' => 'convert Indonesian verbage to number.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 233,'pod' => 28,'pod_errors' => 0,'total' => 261,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 3028,'unpacked' => 7719},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'Lingua-IT-Conjugate-0.50.tar.gz' => {'author' => 'ACALPINI','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 913,'pod' => 49,'pod_errors' => 0,'total' => 962,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 7541,'unpacked' => 29505},'testers' => {'pass' => 5},'uses' => ['FindBin','Tie::RegexpHash','strict','vars','warnings']},'Lingua-IT-Hyphenate-0.14.tar.gz' => {'author' => 'ACALPINI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 27,'pod_errors' => 0,'total' => 77,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 2069,'unpacked' => 3715},'testers' => {'pass' => 4},'uses' => ['Exporter','vars']},'Lingua-IW-Logical-0.5.tar.gz' => {'author' => 'SMALYSHEV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 294,'pod' => 63,'pod_errors' => 0,'total' => 357,'with_comments' => 61},'releases' => 5,'size' => {'packed' => 4137,'unpacked' => 10831},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['Exporter','integer','strict']},'Lingua-Ident-1.0.tar.gz' => {'author' => 'MPIOTR','description' => 'Statistical language identification','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 118,'pod' => 37,'pod_errors' => 0,'total' => 155,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 7944,'unpacked' => 14818},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['Carp','locale','strict']},'Lingua-Ispell-0.07.tar.gz' => {'author' => 'JDPORTER','description' => 'Interface to the Ispell spellchecker','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 396,'pod' => 191,'pod_errors' => 0,'total' => 587,'with_comments' => 24},'releases' => 3,'size' => {'packed' => 8806,'unpacked' => 30367},'testers' => {'pass' => 9},'uses' => ['Carp','Exporter','FileHandle','IPC::Open2','strict','vars']},'Lingua-JA-Fold-0.04.tar.gz' => {'author' => 'HATA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 254,'pod' => 102,'pod_errors' => 0,'total' => 356,'with_comments' => 15},'releases' => 4,'requires' => ['Encode-1.97.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Encode' => '1.92','Exporter' => '5.566'},'requires_recursive' => ['Encode-1.97.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6370,'unpacked' => 23477},'testers' => {'pass' => 2},'uses' => ['5.008','Carp','Encode','Exporter','strict','utf','warnings']},'Lingua-JA-Mail-0.02.tar.gz' => {'author' => 'HATA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 450,'pod' => 253,'pod_errors' => 0,'total' => 703,'with_comments' => 45},'releases' => 2,'requires' => ['Encode-1.97.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'Encode' => '1.92','MIME::Base64' => '2.12'},'requires_recursive' => ['Encode-1.97.tar.gz','MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 8140,'unpacked' => 40337},'testers' => {'pass' => 2},'uses' => ['5.008','Carp','Encode','MIME::Base64','strict','warnings']},'Lingua-JA-Number-0.01.tar.gz' => {'author' => 'MSCHILLI','description' => 'Translate numbers into Japanese','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 74,'pod_errors' => 0,'total' => 203,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 11677,'unpacked' => 30410},'testers' => {'pass' => 9},'uses' => ['strict','warnings']},'Lingua-JA-Regular-0.06.tar.gz' => {'author' => 'TAKEFUMI','description' => 'Regularize of the Japanese character.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 757,'pod' => 231,'pod_errors' => 0,'total' => 988,'with_comments' => 387},'releases' => 6,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10864,'unpacked' => 46402},'testers' => {'pass' => 1},'uses' => ['5.005','Exporter','Jcode','strict','vars']},'Lingua-JA-Romaji-0.03.tar.gz' => {'author' => 'KESINGER','description' => 'Perl extension for romaji and kana conversion','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1570,'pod' => 52,'pod_errors' => 0,'total' => 1622,'with_comments' => 19},'releases' => 3,'size' => {'packed' => 9067,'unpacked' => 50554},'testers' => {'pass' => 6},'uses' => ['5.006','Exporter','strict','warnings']},'Lingua-JA-Sort-JIS-0.04.tar.gz' => {'author' => 'SADAHIRO','description' => 'compare and sort Japanese character strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 975,'pod' => 430,'pod_errors' => 0,'total' => 1405,'with_comments' => 25},'releases' => 3,'size' => {'packed' => 31976,'unpacked' => 64326},'testers' => {'pass' => 9},'uses' => ['Carp','Exporter','strict','vars']},'Lingua-KO-Hangul-Util-0.11.tar.gz' => {'author' => 'SADAHIRO','description' => 'utility functions for Hangul Syllables in Unicode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 172,'pod' => 131,'pod_errors' => 0,'total' => 303,'with_comments' => 24},'releases' => 10,'size' => {'packed' => 8525,'unpacked' => 33752},'testers' => {'pass' => 5},'uses' => ['5.006','Exporter','constant','strict','warnings']},'Lingua-Lexicon-IDP-1.0.tar.gz' => {'author' => 'ASCOPE','description' => 'OOP methods for Internet Dictionary Project','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 550,'pod' => 108,'pod_errors' => 0,'total' => 658,'with_comments' => 69},'releases' => 1,'requires' => ['IO-1.20.tar.gz','Memoize-1.01.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '0','File::Spec::Functions' => '1.1','IO::File' => '0','Memoize' => '0','Test::More' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Memoize-1.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 338177,'unpacked' => 950148},'testers' => {'pass' => 10},'uses' => ['Carp','Cwd','Exporter','File::Spec','File::Spec::Functions','IO::File','Memoize','constant','strict']},'Lingua-LinkParser1.01.tar.gz' => {'author' => 'DBRIAN','description' => 'Perl module implementing the Link Grammar Parser by Sleator, Temperley and Lafferty at CMU.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 846,'pod' => 357,'pod_errors' => 0,'total' => 1203,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 146715,'unpacked' => 529849},'testers' => {},'uses' => ['5.005','AutoLoader','Carp','DynaLoader','Exporter','Lingua::LinkParser::Dictionary','Lingua::LinkParser::Linkage','Lingua::LinkParser::Linkage::Sublinkage','Lingua::LinkParser::Linkage::Sublinkage::Link','Lingua::LinkParser::Linkage::Word','Lingua::LinkParser::Sentence','overload','strict']},'Lingua-LinkParser1.08.tar.gz' => {'author' => 'DBRIAN','description' => 'Perl module implementing the Link Grammar Parser by Sleator, Temperley and Lafferty at CMU.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 950,'pod' => 393,'pod_errors' => 1,'total' => 1343,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 151028,'unpacked' => 540311},'testers' => {},'uses' => ['5.005','5.006','AutoLoader','Carp','DynaLoader','Exporter','overload','strict','vars']},'Lingua-NL-Numbers-1.2.tar.gz' => {'author' => 'ALIZTA','description' => 'Perl module for converting numeric values into their Dutch equivalents =head1 DESCRIPTION Initial release, documentation and updates will follow.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 233,'pod' => 28,'pod_errors' => 0,'total' => 261,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 2547,'unpacked' => 6504},'testers' => {'pass' => 3},'uses' => ['strict']},'Lingua-Num2Word-0.03.tar.gz' => {'author' => 'RVASICEK','description' => 'wrapper for number to text conversion modules of various languages in the Lingua:: hierarchy.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 246,'pod' => 240,'pod_errors' => 0,'total' => 486,'with_comments' => 31},'releases' => 3,'size' => {'packed' => 4575,'unpacked' => 11009},'testers' => {'pass' => 6},'uses' => ['strict','vars']},'Lingua-PL-Numbers-1.0.tar.gz' => {'author' => 'HENRIKS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 325,'pod' => 35,'pod_errors' => 0,'total' => 360,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2989,'unpacked' => 8361},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars']},'Lingua-PT-Conjugate-1.09.tar.gz' => {'author' => 'EGROSS','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 10571,'pod' => 508,'pod_errors' => 0,'total' => 11079,'with_comments' => 475},'releases' => 18,'size' => {'packed' => 110946,'unpacked' => 376119},'testers' => {'pass' => 1},'uses' => ['Exporter']},'Lingua-PT-Nums2Words-0.2.tar.gz' => {'author' => 'SYP','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 159,'pod' => 66,'pod_errors' => 0,'total' => 225,'with_comments' => 27},'releases' => 2,'size' => {'packed' => 2872,'unpacked' => 6211},'testers' => {'pass' => 5},'uses' => ['5.000','Exporter','strict','vars']},'Lingua-PT-PLN-0.05.tar.gz' => {'author' => 'AMBS','description' => 'Perl extension for simple natural language processing, portuguese language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 631,'pod' => 113,'pod_errors' => 0,'total' => 744,'with_comments' => 62},'releases' => 1,'size' => {'packed' => 37609,'unpacked' => 89613},'testers' => {'fail' => 1,'pass' => 1,'tests' => '11'},'uses' => ['Exporter','locale','strict','vars']},'Lingua-PT-Stemmer-0.01.tar.gz' => {'author' => 'XERN','description' => 'Galician language stemming','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 778,'pod' => 82,'pod_errors' => 0,'total' => 860,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 4864,'unpacked' => 22654},'testers' => {'pass' => 12},'uses' => ['5.006','strict','warnings']},'Lingua-Pangram-0.02.tar.gz' => {'author' => 'IDORU','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 53,'pod_errors' => 0,'total' => 106,'with_comments' => 8},'releases' => 2,'requires' => ['Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Harness' => '1.02','Test::More' => '0.1'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 9726,'unpacked' => 24338},'testers' => {'pass' => 6},'uses' => ['Exporter','locale','strict','vars']},'Lingua-Phoneme-0.011.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 252,'pod' => 209,'pod_errors' => 0,'total' => 461,'with_comments' => 23},'releases' => 2,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'DBD::mysql' => '0.1','DBI' => '0.1'},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz'],'size' => {'packed' => 1614792,'unpacked' => 5519499},'testers' => {'fail' => 1,'pass' => 7},'uses' => ['Carp','DBD::mysql','strict','warnings']},'Lingua-Phonology-0.11.tar.gz' => {'author' => 'JASPAX','description' => 'a module providing a unified way to deal with linguistic representations of phonology.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2868,'pod' => 1565,'pod_errors' => 0,'total' => 4433,'with_comments' => 408},'releases' => 4,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Basename' => '2.6','File::Spec' => '0.82'},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 47197,'unpacked' => 166256},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','File::Basename','File::Spec::Functions','Lingua::Phonology','Lingua::Phonology::Features','Lingua::Phonology::Functions','Lingua::Phonology::PseudoSegment','Lingua::Phonology::Rules','Lingua::Phonology::Segment','Lingua::Phonology::Syllable','Lingua::Phonology::Symbols','strict','warnings','warnings::register']},'Lingua-Phonology-0.25.tar.gz' => {'author' => 'JASPAX','description' => 'a module providing a unified way to deal with linguistic representations of phonology.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3349,'pod' => 1694,'pod_errors' => 0,'total' => 5043,'with_comments' => 448},'releases' => 4,'size' => {'packed' => 53683,'unpacked' => 184983},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','Graph','Whatif','strict','warnings','warnings::register']},'Lingua-Preferred-0.2.2.tar.gz' => {'author' => 'EDAVIS','description' => 'Pick a language based on user\'s preferences','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 180,'pod' => 66,'pod_errors' => 0,'total' => 246,'with_comments' => 2},'releases' => 5,'requires' => ['Log-TraceMessages-1.3.tar.gz'],'requires_module' => {'Log::TraceMessages' => '1.0'},'requires_recursive' => ['HTML-FromText-1.005.tar.gz','Log-TraceMessages-1.3.tar.gz'],'size' => {'packed' => 5761,'unpacked' => 17338},'testers' => {'pass' => 6},'uses' => ['AutoLoader','Exporter','Log::TraceMessages','strict','vars']},'Lingua-RU-Antimat-1.00.tar.gz' => {'author' => 'ILYAS','description' => 'Removes foul language from a Russian string','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 93,'pod_errors' => 0,'total' => 209,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 10302,'unpacked' => 35896},'testers' => {'pass' => 7},'uses' => ['5.004','FileHandle','locale','strict']},'Lingua-RU-Charset-0.02.tar.gz' => {'author' => 'FARBER','description' => 'Detect/Convert russian character sets.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 416,'pod' => 28,'pod_errors' => 0,'total' => 444,'with_comments' => 130},'releases' => 2,'size' => {'packed' => 4078,'unpacked' => 19383},'testers' => {'pass' => 12},'uses' => ['Exporter','vars']},'Lingua-RU-Number-0.02.tar.gz' => {'author' => 'SAFRONOV','description' => 'Converts numbers to money sum in words (in Russian roubles)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 153,'pod' => 23,'pod_errors' => 0,'total' => 176,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 2839,'unpacked' => 6833},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Lingua-RU-PhTranslit-0.4.tar.gz' => {'author' => 'MBASOV','description' => 'Phonetic correct translit (for Cyrillic)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 141,'pod' => 54,'pod_errors' => 0,'total' => 195,'with_comments' => 10},'releases' => 3,'size' => {'packed' => 3281,'unpacked' => 6195},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Lingua-RU-Translit-0.02.tar.gz' => {'author' => 'SERG','description' => 'Perl extension for decoding cyrillic translit/volapyuk','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 27,'pod' => 22,'pod_errors' => 0,'total' => 49,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 13838,'unpacked' => 39188},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Lingua-Rhyme-0.092.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 352,'pod' => 205,'pod_errors' => 1,'total' => 557,'with_comments' => 35},'releases' => 6,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '0.01'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 1368883,'unpacked' => 3886423},'testers' => {'pass' => 8},'uses' => ['strict','warnings']},'Lingua-Rhyme-FindScheme-0.02.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 80,'pod' => 73,'pod_errors' => 0,'total' => 153,'with_comments' => 5},'releases' => 2,'requires' => ['Lingua-Rhyme-0.092.tar.gz'],'requires_module' => {'Lingua::Rhyme' => '0.07'},'requires_recursive' => ['DBI-1.37.tar.gz','Lingua-Rhyme-0.092.tar.gz'],'size' => {'packed' => 2383,'unpacked' => 4694},'testers' => {'pass' => 4},'uses' => ['Lingua::Rhyme','strict','warnings']},'Lingua-Romana-Perligata-0.50.tar.gz' => {'author' => 'DCONWAY','description' => 'Perl in Latin','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1766,'pod' => 941,'pod_errors' => 0,'total' => 2707,'with_comments' => 49},'releases' => 2,'requires' => ['Filter-1.29.tar.gz'],'requires_module' => {'Filter::Util::Call' => 0},'requires_recursive' => ['Filter-1.29.tar.gz'],'size' => {'packed' => 30330,'unpacked' => 100203},'testers' => {'pass' => 10},'uses' => ['Carp','Data::Dumper','Filter::Util::Call','IO::Handle','vars']},'Lingua-Sinica-PerlYuYan-0.03.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Use Chinese to write Perl','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 183,'pod' => 50,'pod_errors' => 0,'total' => 233,'with_comments' => 4},'releases' => 3,'requires' => ['Filter-Simple-0.78.tar.gz'],'requires_module' => {'Filter::Simple' => '0.70'},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 5958,'unpacked' => 12585},'testers' => {'pass' => 5},'uses' => ['Filter::Simple','strict']},'Lingua-SoundChange-0.05.tar.gz' => {'author' => 'PNE','description' => 'Create regular sound changes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 499,'pod' => 505,'pod_errors' => 0,'total' => 1004,'with_comments' => 58},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.19'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 16152,'unpacked' => 48013},'testers' => {'pass' => 8},'uses' => ['5.005_03','Carp','constant','strict','vars','warnings']},'Lingua-Spelling-Alternative-0.01.tar.gz' => {'author' => 'DPAVLIN','description' => 'alternative spelling of a given word in a given language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 189,'pod' => 56,'pod_errors' => 0,'total' => 245,'with_comments' => 28},'releases' => 1,'size' => {'packed' => 3547,'unpacked' => 9579},'testers' => {'pass' => 5},'uses' => ['5.001','Exporter','strict','vars']},'Lingua-Stem-0.60.tar.gz' => {'author' => 'SNOWHARE','description' => 'Stemming of words','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1949,'pod' => 1044,'pod_errors' => 0,'total' => 2993,'with_comments' => 304},'releases' => 4,'requires' => ['Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Text-German-0.03.tar.gz'],'requires_module' => {'Lingua::GL::Stemmer' => 0,'Lingua::PT::Stemmer' => 0,'Lingua::Stem::It' => 0,'Lingua::Stem::Snowball::Da' => '1.01','Lingua::Stem::Snowball::No' => '1.00','Lingua::Stem::Snowball::Se' => '1.01','Text::German' => 0},'requires_recursive' => ['Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Text-German-0.03.tar.gz'],'size' => {'packed' => 15706,'unpacked' => 98838},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','Lingua::GL::Stemmer','Lingua::PT::Stemmer','Lingua::Stem::Snowball::Da','Lingua::Stem::Snowball::No','Lingua::Stem::Snowball::Se','Text::German','strict','vars']},'Lingua-Stem-It-0.01.tar.gz' => {'author' => 'ACALPINI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 363,'pod' => 90,'pod_errors' => 0,'total' => 453,'with_comments' => 62},'releases' => 1,'size' => {'packed' => 4949,'unpacked' => 14985},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','strict','vars']},'Lingua-Stem-Snowball-Da-1.01.tar.gz' => {'author' => 'CINE','description' => 'Stemming algorithm for Danish','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 35,'pod_errors' => 0,'total' => 273,'with_comments' => 43},'releases' => 1,'size' => {'packed' => 103930,'unpacked' => 387540},'testers' => {'pass' => 8},'uses' => ['bytes','constant','strict','vars']},'Lingua-Strfname-0.02.tar.gz' => {'author' => 'DWHEELER','description' => 'Formats people\'s names.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 46,'pod' => 84,'pod_errors' => 0,'total' => 130,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 2942,'unpacked' => 6621},'testers' => {'pass' => 7},'uses' => ['Exporter','strict','vars']},'Lingua-Syllable-0.03.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 36,'pod_errors' => 0,'total' => 72,'with_comments' => 0},'releases' => 3,'requires' => ['Lingua-EN-Syllable-0.251.tar.gz','Lingua-Rhyme-0.092.tar.gz'],'requires_module' => {'Lingua::EN::Syllable' => '0.01','Lingua::Rhyme' => '0.071'},'requires_recursive' => ['DBI-1.37.tar.gz','Lingua-EN-Syllable-0.251.tar.gz','Lingua-Rhyme-0.092.tar.gz'],'size' => {'packed' => 1582,'unpacked' => 2670},'testers' => {'pass' => 4},'uses' => ['Exporter','Lingua::EN::Syllable','Lingua::Rhyme']},'Lingua-TH-Segmentation-0.08.tar.gz' => {'author' => 'ROMERUN','description' => 'an XS interface to Thai word segment. Lib','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 67,'pod' => 46,'pod_errors' => 0,'total' => 113,'with_comments' => 6},'releases' => 6,'size' => {'packed' => 8199,'unpacked' => 20681},'testers' => {},'uses' => ['5.00503','DynaLoader','Exporter','strict','vars']},'Lingua-TR-Hyphenate-0.01.tar.gz' => {'author' => 'ENGIN','description' => 'A hyphenator for Turkish.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 384,'pod' => 63,'pod_errors' => 0,'total' => 447,'with_comments' => 29},'releases' => 1,'size' => {'packed' => 3300,'unpacked' => 13665},'testers' => {'pass' => 3},'uses' => ['5.006','Exporter','strict','warnings']},'Lingua-TT-Yanalif-0.08.tar.gz' => {'author' => 'AMICHAUER','description' => 'Converts tatar texts (to new latin orfography)','files' => ['Makefile.PL'],'lines' => {'nonpod' => 244,'pod' => 33,'pod_errors' => 1,'total' => 277,'with_comments' => 20},'releases' => 5,'requires' => ['Unicode-Lite-0.12.tar.gz'],'requires_module' => {'Unicode::Lite' => '0.12'},'requires_recursive' => ['MIME-Base64-2.20.tar.gz','Unicode-Lite-0.12.tar.gz','Unicode-Map-0.112.tar.gz','Unicode-String-2.07.tar.gz','enum-1.016.tar.gz'],'size' => {'packed' => 10477,'unpacked' => 36817},'testers' => {'pass' => 8},'uses' => ['5.005_62','Exporter','locale','strict','utf','warnings']},'Lingua-Translate-0.06.tar.gz' => {'author' => 'SAMV','description' => 'Translate text from one language to another','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 866,'pod' => 354,'pod_errors' => 0,'total' => 1220,'with_comments' => 100},'releases' => 5,'size' => {'packed' => 14492,'unpacked' => 42941},'testers' => {'pass' => 8},'uses' => ['Carp','HTML::TokeParser','HTTP::Request::Common','I18N::LangTags','IO::Socket','LWP::UserAgent','Unicode::MapUTF8','strict','vars']},'Lingua-Wordnet0.73.tar.gz' => {'author' => 'DBRIAN','description' => 'Perl extension for accessing and manipulating Wordnet databases.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1415,'pod' => 407,'pod_errors' => 2,'total' => 1822,'with_comments' => 122},'releases' => 1,'size' => {'packed' => 33225,'unpacked' => 129606},'testers' => {'fail' => 3,'pass' => 1},'uses' => ['5.005','Apache::Constants','DB_File','Exporter','strict','vars']},'Lingua-ZH-CCDICT-0.02.tar.gz' => {'author' => 'DROLSKY','description' => 'Perl interface to CCDICT Chinese dictionary','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1234,'pod' => 428,'pod_errors' => 0,'total' => 1662,'with_comments' => 27},'releases' => 2,'requires' => ['BerkeleyDB-0.23.tar.gz','Params-Validate-0.64.tar.gz','Storable-2.07.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'BerkeleyDB' => '0.19','Params::Validate' => '0.24','Storable' => 0,'Test::More' => '0.46'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','BerkeleyDB-0.23.tar.gz','File-Spec-0.82.tar.gz','Params-Validate-0.64.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2704573,'unpacked' => 12508332},'testers' => {'pass' => 3},'uses' => ['','5.006001','BerkeleyDB','File::Spec','Lingua::ZH::CCDICT::Romanization','Lingua::ZH::CCDICT::Romanization::Pinyin','Params::Validate','Test::More','strict','vars']},'Lingua-ZH-CEDICT-0.02.tar.gz' => {'author' => 'CRENZ','description' => 'Interface for CEDICT, a Chinese-English dictionary','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1207,'pod' => 326,'pod_errors' => 0,'total' => 1533,'with_comments' => 50},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 434372,'unpacked' => 1055670},'testers' => {'pass' => 6},'uses' => ['$file','5.006','Exporter','Net::MySQL','Storable','Text::Iconv','bytes','strict','utf','vars','warnings']},'Lingua-ZH-ChineseNaming-0.02.tar.gz' => {'author' => 'XERN','description' => 'Analyzing Chinese Names','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 162,'pod' => 120,'pod_errors' => 0,'total' => 282,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 14250,'unpacked' => 22739},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','strict']},'Lingua-ZH-HanConvert-0.12.tgz' => {'author' => 'DIVEC','description' => 'Convert traditional <-> simplified Chinese','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 865,'pod' => 65,'pod_errors' => 0,'total' => 930,'with_comments' => 6},'releases' => 4,'size' => {'packed' => 31220,'unpacked' => 67181},'testers' => {'pass' => 6},'uses' => ['Exporter','strict','utf','warnings']},'Lingua-ZH-HanDetect-0.04.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Guess Chinese text\'s variant and encoding','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 41,'pod_errors' => 0,'total' => 131,'with_comments' => 4},'releases' => 3,'size' => {'packed' => 4874,'unpacked' => 9715},'testers' => {'pass' => 2},'uses' => ['Exporter','bytes','strict','vars']},'Lingua-ZH-Keywords-0.04.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Extract keywords from Chinese text','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 41,'pod_errors' => 0,'total' => 118,'with_comments' => 3},'releases' => 4,'requires' => ['Lingua-ZH-TaBE-0.03.tar.gz'],'requires_module' => {'Lingua::ZH::TaBE' => '0'},'requires_recursive' => ['Lingua-ZH-TaBE-0.03.tar.gz'],'size' => {'packed' => 20141,'unpacked' => 39062},'testers' => {},'uses' => ['Encode','Exporter','strict','vars']},'Lingua-ZH-Numbers-0.03.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Converts numeric values into Chinese','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 243,'pod' => 108,'pod_errors' => 0,'total' => 351,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 5887,'unpacked' => 17224},'testers' => {'pass' => 4},'uses' => ['5.001','Exporter','strict','vars']},'Lingua-ZH-PinyinConvert-0.05.tar.gz' => {'author' => 'XERN','description' => 'Translation among various Chinese Pinyin Systems','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 536,'pod' => 76,'pod_errors' => 0,'total' => 612,'with_comments' => 3},'releases' => 5,'size' => {'packed' => 10918,'unpacked' => 36507},'testers' => {'fail' => 1,'pass' => 10,'tests' => '7'},'uses' => ['5.006','Carp','Exporter','strict']},'Lingua-ZH-Summarize-0.01.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Summarizing bodies of Chinese text','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 51,'pod_errors' => 0,'total' => 167,'with_comments' => 8},'releases' => 1,'requires' => ['Lingua-ZH-Toke-0.01.tar.gz','Lingua-ZH-Wrap-0.02.tar.gz'],'requires_module' => {'Lingua::ZH::Toke' => '0','Lingua::ZH::Wrap' => '0'},'requires_recursive' => ['Lingua-ZH-TaBE-0.03.tar.gz','Lingua-ZH-Toke-0.01.tar.gz','Lingua-ZH-Wrap-0.02.tar.gz'],'size' => {'packed' => 11714,'unpacked' => 20978},'testers' => {},'uses' => ['Encode','Exporter','Lingua::ZH::Toke','Lingua::ZH::Wrap','strict','vars']},'Lingua-ZH-TaBE-0.03.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Chinese processing via libtabe','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 367,'pod' => 168,'pod_errors' => 0,'total' => 535,'with_comments' => 3},'releases' => 3,'size' => {'packed' => 15534,'unpacked' => 50119},'testers' => {},'uses' => ['DynaLoader','Exporter','_h2ph_pre.ph','strict','vars']},'Lingua-ZH-Toke-0.01.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Chinese Tokenizer','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 80,'pod_errors' => 0,'total' => 199,'with_comments' => 4},'releases' => 1,'requires' => ['Lingua-ZH-TaBE-0.03.tar.gz'],'requires_module' => {'Lingua::ZH::TaBE' => '0'},'requires_recursive' => ['Lingua-ZH-TaBE-0.03.tar.gz'],'size' => {'packed' => 5503,'unpacked' => 15091},'testers' => {},'uses' => ['Encode','Encode::compat','strict','vars']},'Lingua-ZH-Wrap-0.02.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Wrap Chinese text','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 59,'pod_errors' => 0,'total' => 128,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 3858,'unpacked' => 8711},'testers' => {'pass' => 9},'uses' => ['Exporter','strict','vars']},'Lingua-ZH-ZhuYinWen-0.01.tar.gz' => {'author' => 'XERN','description' => 'ZhuYinWen Bastardizer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13212,'pod' => 36,'pod_errors' => 0,'total' => 13248,'with_comments' => 1},'releases' => 1,'requires' => ['String-Multibyte-1.05.tar.gz'],'requires_module' => {'String::Multibyte' => '1.03'},'requires_recursive' => ['String-Multibyte-1.05.tar.gz'],'size' => {'packed' => 44054,'unpacked' => 82423},'testers' => {'pass' => 9},'uses' => ['5.006','Exporter','String::Multibyte','strict']},'Lingua-Zompist-Barakhinei-0.02.tar.gz' => {'author' => 'PNE','description' => 'Inflect Barakhinei nouns, verbs, adjectives','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1168,'pod' => 309,'pod_errors' => 0,'total' => 1477,'with_comments' => 56},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.19'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 24113,'unpacked' => 89935},'testers' => {'pass' => 7},'uses' => ['5.005','Exporter','re','strict','vars']},'Lingua-Zompist-Cadhinor-0.92.tar.gz' => {'author' => 'PNE','description' => 'Inflect Cadhinor nouns, verbs, adjectives','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 951,'pod' => 235,'pod_errors' => 0,'total' => 1186,'with_comments' => 46},'releases' => 7,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.19'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 25613,'unpacked' => 119397},'testers' => {'pass' => 7},'uses' => ['5.005','Exporter','strict','vars']},'Lingua-Zompist-Kebreni-0.90.tar.gz' => {'author' => 'PNE','description' => 'Conjugate Kebreni verbs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 772,'pod' => 230,'pod_errors' => 0,'total' => 1002,'with_comments' => 118},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.19'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 14886,'unpacked' => 60856},'testers' => {'pass' => 7},'uses' => ['5.005','Carp','Exporter','constant','strict','vars','warnings']},'Lingua-Zompist-Verdurian-0.91.tar.gz' => {'author' => 'PNE','description' => 'Inflect Verdurian nouns, verbs, adjectives','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 821,'pod' => 187,'pod_errors' => 0,'total' => 1008,'with_comments' => 69},'releases' => 8,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.19'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 21605,'unpacked' => 99600},'testers' => {'pass' => 7},'uses' => ['5.005','Exporter','strict','vars']},'Lingua_EN_Numbers_Easy-1.2.tgz' => {'author' => 'ABIGAIL','description' => '- Hash access to Lingua::EN::Numbers objects.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 53,'pod_errors' => 0,'total' => 132,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 2766,'unpacked' => 5878},'testers' => {'pass' => 4},'uses' => ['Lingua::EN::Numbers','strict','vars']},'Link_Controller-0.037.tar.gz' => {'author' => 'MIKEDLR','description' => 'perl module with LinkController constants','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2207,'pod' => 1119,'pod_errors' => 5,'total' => 3326,'with_comments' => 335},'releases' => 6,'requires' => ['CDB_File-BiIndex-0.030.tar.gz','CGI-Response-0.03.tar.gz','CGI.pm-2.98.tar.gz','DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','Getopt-Function-0.017.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Stream-1.54.tar.gz','HTML-Tagset-3.03.tar.gz','MLDBM-2.01.tar.gz','Schedule-SoftTime-0.030.tar.gz','Search-Binary-0.95.tar.gz','URI-1.24.tar.gz','WWW-Link-0.036.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CDB_File::BiIndex' => '0.03','CDB_File::BiIndex::Generator' => '0.3','CGI::Carp' => '1.09','CGI::Response' => 0,'Carp' => 0,'Cwd' => 0,'DB_File' => 0,'Data::Dumper' => 0,'English' => 0,'Exporter' => 0,'Fcntl' => 0,'File::Copy' => 0,'File::Find' => 0,'File::Path' => 0,'Getopt::Function' => '0.017','HTML::LinkExtor' => 0,'HTML::Stream' => 0,'HTML::Tagset' => 0,'HTTP::Date' => 0,'HTTP::Status' => 0,'LWP::Debug' => 0,'LWP::MediaTypes' => 0,'LWP::RobotUA' => 0,'LWP::UserAgent' => 0,'MLDBM' => 0,'Schedule::SoftTime' => '0.03','Search::Binary' => 0,'Sys::Hostname' => 0,'URI' => 0,'WWW::Link' => '0.034','WWW::Link::Repair' => 0,'WWW::Link::Repair::Substitutor' => 0,'WWW::Link::Reporter::Compile' => 0,'WWW::Link::Reporter::HTML' => 0,'WWW::Link::Reporter::LongList' => 0,'WWW::Link::Reporter::RepairForm' => 0,'WWW::Link::Reporter::Text' => 0,'WWW::Link::Selector' => 0,'WWW::Link::Tester::Adaptive' => 0,'WWW::RobotRules::AnyDBM_File' => 0},'requires_recursive' => ['CDB_File-0.93.tar.gz','CDB_File-BiIndex-0.030.tar.gz','CDB_File-Generator-0.030.tar.gz','CGI-Response-0.03.tar.gz','CGI.pm-2.98.tar.gz','DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Function-0.017.tar.gz','Getopt-Mixed-1.008.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Stream-1.54.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MLDBM-2.01.tar.gz','Net-Telnet-3.03.tar.gz','Schedule-SoftTime-0.030.tar.gz','Search-Binary-0.95.tar.gz','URI-1.24.tar.gz','WWW-Link-0.036.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 418575,'unpacked' => 1283424},'testers' => {},'uses' => ['Carp','Cwd','English','Exporter','HTML::Parser','HTTP::Date','HTTP::Request','HTTP::Response','LWP::RobotUA','LWP::UserAgent','Search::Binary','Sys::Hostname','URI','WWW::RobotRules','strict','vars','warnings']},'Linux-AIO-0.111.tar.gz' => {'author' => 'MLEHMANN','description' => 'asynchronous I/O using linux/clone','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 75,'pod_errors' => 0,'total' => 118,'with_comments' => 0},'releases' => 5,'size' => {'packed' => 6426,'unpacked' => 19794},'testers' => {'fail' => 3,'tests' => '13'},'uses' => ['Exporter','XSLoader']},'Linux-Cpuinfo-1.5.tar.gz' => {'author' => 'JSTOWE','description' => 'Object Oriented Interface to /proc/cpuinfo','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 316,'pod' => 179,'pod_errors' => 0,'total' => 495,'with_comments' => 43},'releases' => 5,'size' => {'packed' => 6983,'unpacked' => 17231},'testers' => {'pass' => 6},'uses' => ['5.00503','Carp','strict','vars']},'Linux-Fuser-1.2.tar.gz' => {'author' => 'JSTOWE','description' => 'Determine which processes have a file open','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 70,'pod_errors' => 0,'total' => 246,'with_comments' => 27},'releases' => 2,'size' => {'packed' => 3493,'unpacked' => 8459},'testers' => {'pass' => 5},'uses' => ['Carp','strict','vars']},'Linux-LVM-0.13.tar.gz' => {'author' => 'CKERNER','description' => 'Linux Logical Volume Manager(LVM) Interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 508,'pod' => 276,'pod_errors' => 0,'total' => 784,'with_comments' => 148},'releases' => 4,'size' => {'packed' => 6221,'unpacked' => 30014},'testers' => {'pass' => 3},'uses' => ['5.006','AutoLoader','Exporter','strict','warnings']},'Linux-MemInfo-0.03.tar.gz' => {'author' => 'CKERNER','description' => 'Easy interface into /proc/meminfo','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 70,'pod' => 109,'pod_errors' => 0,'total' => 179,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 3332,'unpacked' => 7390},'testers' => {'pass' => 3},'uses' => ['5.006','AutoLoader','Exporter','strict','warnings']},'Linux-NBD-0.21.tar.gz' => {'author' => 'MLEHMANN','description' => 'interface to the linux network block device.','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 290,'pod' => 187,'pod_errors' => 1,'total' => 477,'with_comments' => 8},'releases' => 3,'size' => {'packed' => 7734,'unpacked' => 19659},'testers' => {'fail' => 2},'uses' => ['Carp','Socket','XSLoader']},'Linux-Pid-0.02.tar.gz' => {'author' => 'RGARCIA','description' => 'Interface to Linux getpp?id functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 23,'pod_errors' => 0,'total' => 65,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 1920,'unpacked' => 3593},'testers' => {'pass' => 3},'uses' => []},'Linux-Svgalib-1.2.tar.gz' => {'author' => 'JSTOWE','description' => 'Object Oriented Perl interface to svgalib','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 754,'pod' => 441,'pod_errors' => 0,'total' => 1195,'with_comments' => 26},'releases' => 1,'size' => {'packed' => 19775,'unpacked' => 125324},'testers' => {'pass' => 1},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Linux-net-dev-1.00.tar.gz' => {'author' => 'VSEGO','description' => 'Perl extension for parsing /proc/net/dev','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 83,'pod' => 54,'pod_errors' => 0,'total' => 137,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 5523,'unpacked' => 14345},'testers' => {'pass' => 5},'uses' => ['5.000','AutoLoader','Carp','Exporter','strict','warnings']},'Linux-stat-1.00.tar.gz' => {'author' => 'VSEGO','description' => 'parse /proc/stat','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 156,'pod' => 122,'pod_errors' => 0,'total' => 278,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 7223,'unpacked' => 23569},'testers' => {'pass' => 4},'uses' => ['5.000','strict']},'Linux-usermod-0.3.tar.gz' => {'author' => 'VIDUL','description' => 'modify user accounts','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 253,'pod' => 84,'pod_errors' => 0,'total' => 337,'with_comments' => 0},'releases' => 2,'requires' => ['Test-1.24.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Test' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3879,'unpacked' => 12986},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'Lip-Pod-0.001.tar.gz' => {'author' => 'GREGOR','description' => 'Literate Perl filter =for none ############################################################################### ###############################################################################','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 235,'pod' => 111,'pod_errors' => 0,'total' => 346,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 3641,'unpacked' => 11121},'testers' => {'fail' => 2,'pass' => 4,'tests' => '2'},'uses' => ['Pod::Parser','Text::Tabs','strict','vars']},'Lirc-Client-1.09.tar.gz' => {'author' => 'MGRIMES','description' => 'A client library for the Linux Infrared Remote Control','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 216,'pod' => 70,'pod_errors' => 0,'total' => 286,'with_comments' => 39},'releases' => 1,'size' => {'packed' => 5484,'unpacked' => 18065},'testers' => {'fail' => 1,'tests' => '3'},'uses' => ['IO::Socket','strict','vars']},'List-Compare-0.2.tar.gz' => {'author' => 'JKEENAN','description' => 'Compare elements of two or more lists','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2408,'pod' => 1050,'pod_errors' => 0,'total' => 3458,'with_comments' => 133},'releases' => 8,'size' => {'packed' => 40240,'unpacked' => 284300},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Dumper','strict','warnings']},'List-Comprehensions-0.13.tar.gz' => {'author' => 'OPHIUCI','description' => 'allows for list comprehensions in Perl','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 203,'pod' => 70,'pod_errors' => 0,'total' => 273,'with_comments' => 6},'releases' => 4,'requires' => ['Alias-2.32.tar.gz','Array-RefElem-0.02.tar.gz','PadWalker-0.09.tar.gz'],'requires_module' => {'Alias' => 0,'Array::RefElem' => 0,'PadWalker' => 0},'requires_recursive' => ['Alias-2.32.tar.gz','Array-RefElem-0.02.tar.gz','PadWalker-0.09.tar.gz'],'size' => {'packed' => 2340,'unpacked' => 5538},'testers' => {'pass' => 1,'tests' => '0','unknown' => 4},'uses' => ['Alias','Array::RefElem','Carp','Exporter','PadWalker','warnings']},'List-Indexed-1.0.tar.gz' => {'author' => 'ARPADF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 376,'pod' => 152,'pod_errors' => 0,'total' => 528,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 4222,'unpacked' => 16250},'testers' => {'pass' => 1},'uses' => ['Exporter']},'List-Intersperse-1.00.tar.gz' => {'author' => 'TAYERS','description' => 'Intersperse / unsort / disperse a list','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 84,'pod' => 44,'pod_errors' => 0,'total' => 128,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 2301,'unpacked' => 4791},'testers' => {'pass' => 9},'uses' => ['Exporter','strict','vars']},'List-Member-0.02.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 27,'pod' => 39,'pod_errors' => 0,'total' => 66,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 1590,'unpacked' => 2423},'testers' => {'pass' => 4},'uses' => ['5.005_62','Carp','Exporter','strict','warnings']},'List-Permutor-0.022.tar.gz' => {'author' => 'PHOENIX','description' => 'Process all possible permutations of a list','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 71,'pod' => 41,'pod_errors' => 0,'total' => 112,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 2695,'unpacked' => 6395},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'List-Priority-0.02.tar.gz' => {'author' => 'UDASSIN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 145,'pod' => 120,'pod_errors' => 0,'total' => 265,'with_comments' => 23},'releases' => 2,'size' => {'packed' => 3503,'unpacked' => 9142},'testers' => {'fail' => 1,'pass' => 11},'uses' => ['5.006','strict','vars','warnings']},'List-Sliding-Changes-0.02.tar.gz' => {'author' => 'CORION','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 66,'pod' => 61,'pod_errors' => 0,'total' => 127,'with_comments' => 1},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 12588,'unpacked' => 34157},'testers' => {'pass' => 11},'uses' => ['Carp','Exporter','strict','vars']},'List-Utils-0.01.tar.gz' => {'author' => 'TBONE','description' => 'Additional list utilities','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 45,'pod_errors' => 0,'total' => 102,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 1691,'unpacked' => 2878},'testers' => {'pass' => 7},'uses' => ['5.005_62','Exporter','strict','warnings']},'LoadHtml.5_0.tar.gz' => {'author' => 'TURNERJW','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 1010,'pod' => 0,'pod_errors' => 0,'total' => 1010,'with_comments' => 245},'releases' => 1,'size' => {'packed' => 25556,'unpacked' => 74002},'testers' => {},'uses' => ['Exporter','LWP::Simple','Socket','lib']},'LoadWorm-1.02.tar.gz' => {'author' => 'GLENNWOOD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 464,'pod' => 372,'pod_errors' => 1,'total' => 836,'with_comments' => 26},'releases' => 5,'requires' => ['ParallelUserAgent-2.56.tar.gz','Tk-800.024.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.2','LWP::Parallel' => '2.3','LWP::Parallel::RobotUA' => 0,'Tk' => '4.02'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','ParallelUserAgent-2.56.tar.gz','Tk-800.024.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 27760,'unpacked' => 84522},'testers' => {'fail' => 1},'uses' => ['English','LWP::Parallel::RobotUA','Time::HiRes','Win32']},'Locale-Codes-2.06.tar.gz' => {'author' => 'NEILB','description' => 'ISO 639 two letter language codes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1833,'pod' => 692,'pod_errors' => 0,'total' => 2525,'with_comments' => 228},'releases' => 12,'size' => {'packed' => 24931,'unpacked' => 101012},'testers' => {'pass' => 13},'uses' => ['5.002','Carp','Exporter','constant','strict','vars']},'Locale-Hebrew-1.02.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Bidirectional Hebrew support','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 38,'pod_errors' => 0,'total' => 72,'with_comments' => 8},'releases' => 3,'size' => {'packed' => 14177,'unpacked' => 50269},'testers' => {'fail' => 3,'pass' => 4,'tests' => '2'},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Locale-Hebrew-Calendar-0.03.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Jewish Calendar','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 42,'pod_errors' => 0,'total' => 87,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 5958,'unpacked' => 13404},'testers' => {'pass' => 5},'uses' => ['DynaLoader','Exporter','strict','vars']},'Locale-Maketext-1.06.tar.gz' => {'author' => 'SBURKE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1870,'pod' => 1053,'pod_errors' => 0,'total' => 2923,'with_comments' => 232},'releases' => 8,'requires' => ['I18N-LangTags-0.28.tar.gz'],'requires_module' => {'I18N::LangTags' => '0.21'},'requires_recursive' => ['I18N-LangTags-0.28.tar.gz'],'size' => {'packed' => 44661,'unpacked' => 122761},'testers' => {'pass' => 4},'uses' => ['5','integer','strict','utf','vars']},'Locale-Maketext-Fuzzy-0.02.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Maketext from already interpolated strings','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 181,'pod' => 140,'pod_errors' => 0,'total' => 321,'with_comments' => 26},'releases' => 2,'requires' => ['Locale-Maketext-1.06.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Locale::Maketext' => '0.01','Test::More' => '0.01'},'requires_recursive' => ['File-Spec-0.82.tar.gz','I18N-LangTags-0.28.tar.gz','Locale-Maketext-1.06.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6344,'unpacked' => 15263},'testers' => {'pass' => 4},'uses' => ['Locale::Maketext','strict']},'Locale-Maketext-Gettext-1.10.tar.gz' => {'author' => 'IMACAT','description' => 'Joins the gettext and Maketext frameworks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1137,'pod' => 304,'pod_errors' => 0,'total' => 1441,'with_comments' => 224},'releases' => 17,'size' => {'packed' => 26373,'unpacked' => 122347},'testers' => {'pass' => 2},'uses' => ['5.008','Encode','Exporter','File::Spec::Functions','Locale::Maketext','strict','vars','warnings']},'Locale-Maketext-Lexicon-0.27.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Use other catalog formats in Maketext','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 612,'pod' => 323,'pod_errors' => 0,'total' => 935,'with_comments' => 59},'releases' => 22,'requires' => ['Locale-Maketext-1.06.tar.gz','PodParser-1.23.tar.gz','Regexp-Common-2.113.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Locale::Maketext' => '0.01','Pod::Usage' => '0.01','Regexp::Common' => '0.01','Test::More' => '0.01'},'requires_recursive' => ['File-Spec-0.82.tar.gz','I18N-LangTags-0.28.tar.gz','Locale-Maketext-1.06.tar.gz','PodParser-1.23.tar.gz','Regexp-Common-2.113.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 21915,'unpacked' => 80714},'testers' => {'fail' => 1,'pass' => 3,'tests' => '73'},'uses' => ['Encode','File::Glob','File::Spec','FileHandle','FindBin','Locale::Maketext','T_L10N','strict']},'Locale-Maketext-Simple-0.02.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Simple interface to Locale::Maketext::Lexicon','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 600,'pod' => 87,'pod_errors' => 0,'total' => 687,'with_comments' => 42},'releases' => 2,'size' => {'packed' => 7875,'unpacked' => 21165},'testers' => {'pass' => 2},'uses' => ['$self->{path}::$self->{dispatch}','ExtUtils::MM_Unix','File::Find','File::Path','File::Spec','Locale::Maketext::Lexicon','Module::Install','Module::Install::Base','inc::Module::Install','strict','vars']},'Locale-PGetText-0.16.tar.gz' => {'author' => 'MSHOYHER','description' => 'What GNU gettext does, written in pure perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 32,'pod_errors' => 0,'total' => 105,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 2744,'unpacked' => 5938},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['Exporter','Fcntl','strict','vars']},'Locale-PO-0.11.tar.gz' => {'author' => 'ALANSZ','description' => 'Manipulate .po entries from gettext','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 282,'pod' => 111,'pod_errors' => 0,'total' => 393,'with_comments' => 24},'releases' => 2,'size' => {'packed' => 12782,'unpacked' => 50488},'testers' => {'pass' => 11},'uses' => ['AutoLoader','Carp','Exporter','locale','strict','vars']},'Locale-SubCountry-1.23.tar.gz' => {'author' => 'KIMRYAN','description' => 'ISO 3166-2 two letter subcountry codes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5001,'pod' => 391,'pod_errors' => 0,'total' => 5392,'with_comments' => 82},'releases' => 15,'size' => {'packed' => 46782,'unpacked' => 104085},'testers' => {'pass' => 1},'uses' => ['Exporter','locale','strict','vars']},'Locales-0.04.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4838,'pod' => 1572,'pod_errors' => 0,'total' => 6410,'with_comments' => 91},'releases' => 4,'size' => {'packed' => 46415,'unpacked' => 168382},'testers' => {'pass' => 2},'uses' => ['','Carp','Exporter','Locale::Constants','strict','utf','vars']},'LockFile-NetLock-0.29.tar.gz' => {'author' => 'RONALDWS','description' => 'FTP based locking using the FTP mkdir command.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 331,'pod' => 129,'pod_errors' => 0,'total' => 460,'with_comments' => 62},'releases' => 1,'size' => {'packed' => 11170,'unpacked' => 39899},'testers' => {},'uses' => ['Carp','Config','Exporter','FileHandle','POSIX','strict','warnings']},'LockFile-Simple-0.2.5.tar.gz' => {'author' => 'RAM','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 899,'pod' => 199,'pod_errors' => 0,'total' => 1098,'with_comments' => 362},'releases' => 5,'size' => {'packed' => 12350,'unpacked' => 37619},'testers' => {'pass' => 22},'uses' => ['Carp','Exporter','Sys::Hostname','strict','vars']},'Log-Agent-0.303.tar.gz' => {'author' => 'MROGASKI','description' => 'logging agent','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4945,'pod' => 1736,'pod_errors' => 0,'total' => 6681,'with_comments' => 2116},'releases' => 20,'size' => {'packed' => 52852,'unpacked' => 208011},'testers' => {'pass' => 7},'uses' => ['AutoLoader','Carp','Carp::Datum','Exporter','Fcntl','Log::Agent::Channel','Log::Agent::Channel::File','Log::Agent::Channel::Handle','Log::Agent::Channel::Syslog','Log::Agent::Driver','Log::Agent::Driver::Datum','Log::Agent::Driver::Default','Log::Agent::File::Native','Log::Agent::File::Rotate','Log::Agent::File_Pool','Log::Agent::Formatting','Log::Agent::Message','Log::Agent::Prefixer','Log::Agent::Priorities','Log::Agent::Stamping','Log::Agent::Tag','Log::Agent::Tag::Caller','Log::Agent::Tag::Priority','Log::Agent::Tag::String','Log::Agent::Tag_List','Mail::Mailer','Symbol','Sys::Syslog','Tie::Array','overload','strict','vars']},'Log-Agent-0.304.tar.gz' => {'author' => 'MROGASKI','description' => 'logging agent','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4962,'pod' => 1736,'pod_errors' => 0,'total' => 6698,'with_comments' => 2128},'releases' => 20,'size' => {'packed' => 53853,'unpacked' => 211529},'testers' => {'pass' => 6},'uses' => ['AutoLoader','Carp','Carp::Datum','Exporter','Fcntl','Log::Agent::File::Rotate','Mail::Mailer','Symbol','Sys::Syslog','Tie::Array','overload','strict','vars']},'Log-Agent-Logger-0.1.1.tar.gz' => {'author' => 'RAM','description' => 'Application-level logging interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 391,'pod' => 195,'pod_errors' => 0,'total' => 586,'with_comments' => 117},'releases' => 2,'requires' => ['Getargs-Long-0.1.3.tar.gz','Log-Agent-0.304.tar.gz'],'requires_module' => {'Getargs::Long' => '0.103','Log::Agent' => '0.208'},'requires_recursive' => ['Getargs-Long-0.1.3.tar.gz','Log-Agent-0.304.tar.gz'],'size' => {'packed' => 8514,'unpacked' => 27842},'testers' => {'fail' => 1,'pass' => 7},'uses' => ['Carp','Getargs::Long','Log::Agent','Log::Agent::Formatting','Log::Agent::Priorities','Log::Agent::Tag::Caller','Log::Agent::Tag::Priority','Log::Agent::Tag_List','vars']},'Log-Agent-Rotate-0.1.3.tar.gz' => {'author' => 'RAM','description' => 'parameters for logfile rotation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 714,'pod' => 167,'pod_errors' => 0,'total' => 881,'with_comments' => 273},'releases' => 5,'requires' => ['Compress-Zlib-1.22.tar.gz','Getargs-Long-0.1.3.tar.gz','LockFile-Simple-0.2.5.tar.gz','Log-Agent-0.304.tar.gz'],'requires_module' => {'Compress::Zlib' => '0.4','Getargs::Long' => '0.103','LockFile::Simple' => '0.202','Log::Agent' => '0.201'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Getargs-Long-0.1.3.tar.gz','LockFile-Simple-0.2.5.tar.gz','Log-Agent-0.304.tar.gz'],'size' => {'packed' => 11704,'unpacked' => 41244},'testers' => {'fail' => 1,'pass' => 9},'uses' => ['Compress::Zlib','Fcntl','File::stat','Getargs::Long','LockFile::Simple','Log::Agent','Symbol','strict','vars']},'Log-Agent-Rotate-0.104.tar.gz' => {'author' => 'MROGASKI','description' => 'Logfile rotation config and support','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 762,'pod' => 176,'pod_errors' => 0,'total' => 938,'with_comments' => 305},'releases' => 5,'requires' => ['Compress-Zlib-1.22.tar.gz','Getargs-Long-0.1.3.tar.gz','LockFile-Simple-0.2.5.tar.gz','Log-Agent-0.304.tar.gz'],'requires_module' => {'Compress::Zlib' => '0.4','Getargs::Long' => '0.103','LockFile::Simple' => '0.202','Log::Agent' => '0.201'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Getargs-Long-0.1.3.tar.gz','LockFile-Simple-0.2.5.tar.gz','Log-Agent-0.304.tar.gz'],'size' => {'packed' => 13100,'unpacked' => 48045},'testers' => {'pass' => 5},'uses' => ['Compress::Zlib','Fcntl','File::stat','Getargs::Long','LockFile::Simple','Log::Agent','Symbol','strict','vars']},'Log-AndError-0.99.tar.gz' => {'author' => 'TBOLIOLI','description' => 'Logging module for ISA inclusion in other modules or as a standalone module.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 336,'pod' => 288,'pod_errors' => 0,'total' => 624,'with_comments' => 48},'releases' => 1,'size' => {'packed' => 5366,'unpacked' => 20433},'testers' => {'pass' => 7},'uses' => ['5.005','5.6.0','Exporter','constant','strict','vars','warnings']},'Log-Channel-0.6.tar.gz' => {'author' => 'JMAY','description' => 'yet another logging package','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 517,'pod' => 225,'pod_errors' => 1,'total' => 742,'with_comments' => 24},'releases' => 4,'requires' => ['Log-Dispatch-2.06.tar.gz'],'requires_module' => {'Log::Dispatch' => '1.8'},'requires_recursive' => ['Log-Dispatch-2.06.tar.gz'],'size' => {'packed' => 9006,'unpacked' => 38050},'testers' => {'fail' => 7,'pass' => 1,'tests' => '99'},'uses' => ['Carp','Log::Dispatch','Log::Dispatch::Config','POSIX','XML::Simple','strict','vars']},'Log-Common-1.00.tar.gz' => {'author' => 'MHAMILTON','description' => 'log messages in the httpd access and error log styles','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 180,'pod' => 179,'pod_errors' => 0,'total' => 359,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 4556,'unpacked' => 11229},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['Carp','strict','vars']},'Log-Delimited-0.90.tar.gz' => {'author' => 'EARL','description' => 'simple module to help log results','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 209,'pod' => 85,'pod_errors' => 0,'total' => 294,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 3591,'unpacked' => 9364},'testers' => {'pass' => 8},'uses' => ['Exporter','File::Path','Storable','Sys::Hostname','strict','vars']},'Log-Detect-1.412.tar.gz' => {'author' => 'WSNYDER','description' => 'Detect and show error regexps in logfiles','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 484,'pod' => 178,'pod_errors' => 0,'total' => 662,'with_comments' => 111},'releases' => 4,'size' => {'packed' => 11940,'unpacked' => 37165},'testers' => {'pass' => 4},'uses' => ['Carp','Class::Struct','Data::Dumper','Exporter','IO::File','Text::Wrap','strict','vars']},'Log-Dispatch-2.06.tar.gz' => {'author' => 'DROLSKY','description' => 'Dispatches messages to multiple Log::Dispatch::* objects','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 947,'pod' => 1408,'pod_errors' => 78,'total' => 2355,'with_comments' => 14},'releases' => 22,'size' => {'packed' => 26195,'unpacked' => 103640},'testers' => {'pass' => 3},'uses' => ['','5.005','Apache::Log','MIME::Lite','Mail::Send','Params::Validate','fields','strict','vars']},'Log-Dispatch-Config-1.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Log4j for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 362,'pod' => 348,'pod_errors' => 0,'total' => 710,'with_comments' => 10},'releases' => 14,'requires' => ['AppConfig-1.55.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Log-Dispatch-2.06.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'AppConfig' => '1.52','File::Temp' => '0.12','IO::Scalar' => 0,'Log::Dispatch' => 2,'Test::More' => '0.32'},'requires_recursive' => ['AppConfig-1.55.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Log-Dispatch-2.06.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11284,'unpacked' => 41234},'testers' => {'pass' => 4},'uses' => ['AppConfig','Carp','Log::Dispatch','POSIX','Time::Piece','strict','vars']},'Log-Dispatch-DBI-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Class for logging to database via DBI interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 92,'pod_errors' => 0,'total' => 165,'with_comments' => 1},'releases' => 2,'requires' => ['DBD-CSV-0.2002.tar.gz','DBI-1.37.tar.gz','File-Temp-0.12.tar.gz','Log-Dispatch-2.06.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DBD::CSV' => 0,'DBI' => 0,'File::Temp' => '0.12','Log::Dispatch' => 2,'Test::More' => '0.32'},'requires_recursive' => ['DBD-CSV-0.2002.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Log-Dispatch-2.06.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2882,'unpacked' => 8105},'testers' => {'pass' => 3},'uses' => ['DBI','Log::Dispatch','Log::Dispatch::Output','strict','vars']},'Log-Dispatch-File-Alerts-1.00.tar.gz' => {'author' => 'JACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 166,'pod' => 76,'pod_errors' => 0,'total' => 242,'with_comments' => 19},'releases' => 1,'requires' => ['Log-Dispatch-2.06.tar.gz','Log-Log4perl-0.35.tar.gz'],'requires_module' => {'Log::Dispatch' => '2.06','Log::Log4perl' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Log-Dispatch-2.06.tar.gz','Log-Log4perl-0.35.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4998,'unpacked' => 16856},'testers' => {'pass' => 2},'uses' => ['5.006001','Fcntl','Log::Dispatch::File','Log::Log4perl::DateFormat','Time::HiRes','strict','warnings']},'Log-Dispatch-File-Rolling-1.03.tar.gz' => {'author' => 'JACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 173,'pod' => 96,'pod_errors' => 0,'total' => 269,'with_comments' => 21},'releases' => 4,'requires' => ['Log-Dispatch-2.06.tar.gz','Log-Log4perl-0.35.tar.gz'],'requires_module' => {'Log::Dispatch' => '2.06','Log::Log4perl' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Log-Dispatch-2.06.tar.gz','Log-Log4perl-0.35.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5011,'unpacked' => 15653},'testers' => {'pass' => 2},'uses' => ['5.006001','Fcntl','Log::Dispatch::File','Log::Log4perl::DateFormat','Time::HiRes','strict','warnings']},'Log-Dispatch-File-Stamped-0.01.tar.gz' => {'author' => 'CHOLET','description' => 'Logging to date/time stamped files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 101,'pod_errors' => 3,'total' => 170,'with_comments' => 12},'releases' => 1,'requires' => ['Log-Dispatch-2.06.tar.gz'],'requires_module' => {'Log::Dispatch' => 0,'Log::Dispatch::File' => 0},'requires_recursive' => ['Log-Dispatch-2.06.tar.gz'],'size' => {'packed' => 3203,'unpacked' => 7398},'testers' => {'pass' => 1},'uses' => ['File::Basename','File::Spec::Functions','Log::Dispatch::File','POSIX','strict','vars']},'Log-Dispatch-FileRotate-1.10.tar.gz' => {'author' => 'MARKPF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 542,'pod' => 320,'pod_errors' => 12,'total' => 862,'with_comments' => 148},'releases' => 8,'size' => {'packed' => 11962,'unpacked' => 40900},'testers' => {'pass' => 3},'uses' => ['','5.005','Date::Manip','Fcntl','Log::Dispatch::File','Log::Dispatch::Output','Params::Validate','strict','vars']},'Log-Dispatch-Jabber-0.3.tar.gz' => {'author' => 'ASCOPE','description' => 'Log messages via Jabber','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 398,'pod' => 268,'pod_errors' => 0,'total' => 666,'with_comments' => 14},'releases' => 5,'requires' => ['Log-Dispatch-2.06.tar.gz','Net-Jabber-1.28.tar.gz'],'requires_module' => {'Log::Dispatch' => '2.01','Net::Jabber::Client' => '1.26'},'requires_recursive' => ['Digest-SHA1-2.04.tar.gz','Log-Dispatch-2.06.tar.gz','Net-Jabber-1.28.tar.gz','XML-Stream-1.16.tar.gz'],'size' => {'packed' => 6606,'unpacked' => 17651},'testers' => {'pass' => 2},'uses' => ['Cwd','Exporter','File::Spec','Log::Dispatch::Output','Log::Dispatch::Screen','Net::Jabber','strict']},'Log-Dispatch-Tk-1.6.tar.gz' => {'author' => 'DDUMONT','description' => 'Interface class between Log::Dispatch and Tk','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 184,'pod' => 150,'pod_errors' => 0,'total' => 334,'with_comments' => 9},'releases' => 6,'requires' => ['Log-Dispatch-2.06.tar.gz','Tk-800.024.tar.gz'],'requires_module' => {'Log::Dispatch' => '2.00','Log::Dispatch::Output' => '1.011','Tk' => 0},'requires_recursive' => ['Log-Dispatch-2.06.tar.gz','Tk-800.024.tar.gz'],'size' => {'packed' => 4403,'unpacked' => 12844},'testers' => {'fail' => 1,'pass' => 3,'tests' => '4'},'uses' => ['Log::Dispatch::Output','Tk','Tk::Derived','Tk::ROText','fields','strict','vars']},'Log-Dispatch-Win32EventLog-0.02.tar.gz' => {'author' => 'ABERGMAN','description' => 'Log::Dispatch to the Win32 Eventlog','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 56,'pod' => 55,'pod_errors' => 0,'total' => 111,'with_comments' => 0},'releases' => 1,'requires' => ['Log-Dispatch-2.06.tar.gz','libwin32-0.191.zip'],'requires_module' => {'Log::Dispatch' => '2.01','Win32::EventLog' => 0},'requires_recursive' => ['Log-Dispatch-2.06.tar.gz','libwin32-0.191.zip'],'size' => {'packed' => 2506,'unpacked' => 5344},'testers' => {'pass' => 1},'uses' => ['Log::Dispatch','Log::Dispatch::Output','Params::Validate','Win32::EventLog','strict','vars']},'Log-ErrLogger-1.5.tar.gz' => {'author' => 'WORENKD','description' => 'Log errors and error-like events','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 533,'pod' => 217,'pod_errors' => 0,'total' => 750,'with_comments' => 52},'releases' => 2,'requires' => ['MailTools-1.58.tar.gz'],'requires_module' => {'Mail::Mailer' => 0},'requires_recursive' => ['MailTools-1.58.tar.gz'],'size' => {'packed' => 7585,'unpacked' => 28387},'testers' => {'pass' => 3},'uses' => ['Exporter','IO::File','IO::Handle','Mail::Mailer','strict','vars']},'Log-FileSimple-0.01.tar.gz' => {'author' => 'EBRUNI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 132,'pod_errors' => 0,'total' => 238,'with_comments' => 6},'releases' => 1,'requires' => ['Data-Dumper-2.101.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'FileHandle' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4075,'unpacked' => 9829},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','Data::Dumper','FileHandle','strict','warnings']},'Log-Info-1.19.tar.gz' => {'author' => 'FLUFFY','description' => 'Single interface for log output','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3232,'pod' => 1483,'pod_errors' => 2,'total' => 4715,'with_comments' => 371},'releases' => 20,'size' => {'packed' => 51685,'unpacked' => 216883},'testers' => {'fail' => 1,'tests' => '292'},'uses' => ['','5.00503','5.005_62','B::Deparse','Carp','Class::MethodMaker','Config','Cwd','Data::Dumper','Env','Exporter','ExtUtils::MakeMaker','Fatal','Fcntl','File::Basename','File::Compare','File::Find','File::Path','File::Spec','File::Spec::Functions','FindBin','IO::File','IO::Handle','IO::Pipe','IO::Select','IPC::Run','POSIX','Pipeline::DataFlow','Sys::Syslog','Term::ProgressBar','Test','constant','happy','strict','syslog.ph','test','vars','warnings']},'Log-Log4perl-0.35.tar.gz' => {'author' => 'MSCHILLI','description' => 'Log4j implementation for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6460,'pod' => 4219,'pod_errors' => 0,'total' => 10679,'with_comments' => 954},'releases' => 20,'requires' => ['File-Spec-0.82.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Spec' => '0.82','Test::More' => '0.45','Test::Simple' => '0.43'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 155657,'unpacked' => 590288},'testers' => {'pass' => 3},'uses' => ['','5.006','Carp','DBI','Data::Dumper','File::Spec','LWP::UserAgent','Log::Dispatch::File','Log::Dispatch::FileRotate','Log::Dispatch::Screen','Log::Dispatch::Syslog','Safe','Sys::Hostname','Time::HiRes','XML::DOM','constant','strict','vars','warnings']},'Log-Log4perl-AutoCategorize-0.02.tar.gz' => {'author' => 'JCROMIE','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 853,'pod' => 500,'pod_errors' => 0,'total' => 1353,'with_comments' => 131},'releases' => 2,'size' => {'packed' => 39770,'unpacked' => 131310},'testers' => {'fail' => 1,'tests' => '789'},'uses' => ['Carp','Data::Dumper','Devel::Size','IO::File','Log::Dispatch::File','Log::Dispatch::Screen','Log::Log4perl','Log::Log4perl::Appender','YAML','strict','warnings::register']},'Log-LogLite-0.82.tar.gz' => {'author' => 'RANI','description' => 'The C<Log::LogLite> class helps us create simple logs for our application.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 298,'pod' => 144,'pod_errors' => 0,'total' => 442,'with_comments' => 98},'releases' => 5,'requires' => ['IO-LockedFile-0.23.tar.gz'],'requires_module' => {'IO::LockedFile' => '0.2'},'requires_recursive' => ['IO-1.20.tar.gz','IO-LockedFile-0.23.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5713,'unpacked' => 18248},'testers' => {'fail' => 1,'pass' => 11},'uses' => ['Carp','IO::LockedFile','strict','vars']},'Log-Logger-1.01.tar.gz' => {'author' => 'JLBEC','description' => 'OO interface to user defined logfile','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 211,'pod' => 127,'pod_errors' => 0,'total' => 338,'with_comments' => 57},'releases' => 1,'size' => {'packed' => 3134,'unpacked' => 7568},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['IO::File','strict','vars']},'Log-Message-0.01.tar.gz' => {'author' => 'KANE','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 659,'pod' => 512,'pod_errors' => 0,'total' => 1171,'with_comments' => 53},'releases' => 1,'requires' => ['File-Spec-0.82.tar.gz','Locale-Maketext-Simple-0.02.tar.gz','Module-Load-0.05.tar.gz','Params-Check-0.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Spec' => 0,'Locale::Maketext::Simple' => 0,'Module::Load' => 0,'Params::Check' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Locale-Maketext-Simple-0.02.tar.gz','Module-Load-0.05.tar.gz','Params-Check-0.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10879,'unpacked' => 37369},'testers' => {'pass' => 1},'uses' => ['FileHandle','Locale::Maketext::Simple','Module::Load','Params::Check','strict','vars']},'Log-Procmail-0.05.tar.gz' => {'author' => 'BOOK','description' => 'Perl extension for reading procmail logfiles.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 218,'pod' => 105,'pod_errors' => 0,'total' => 323,'with_comments' => 24},'releases' => 5,'size' => {'packed' => 9471,'unpacked' => 25642},'testers' => {'pass' => 1},'uses' => ['5.005','Carp','IO::File','strict','vars']},'Log-Simple-1.3.tar.gz' => {'author' => 'MOUNS','description' => 'Basic runtime logger','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 170,'pod' => 80,'pod_errors' => 0,'total' => 250,'with_comments' => 20},'releases' => 2,'size' => {'packed' => 2370,'unpacked' => 6752},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Log-Topics-0.02.tar.gz' => {'author' => 'JARW','description' => 'Control flow of topic based logging messages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 71,'pod_errors' => 0,'total' => 130,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2827,'unpacked' => 5778},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['Carp','Exporter']},'Log-TraceMessages-1.3.tar.gz' => {'author' => 'EDAVIS','description' => 'Print developer\'s trace messages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 76,'pod_errors' => 0,'total' => 228,'with_comments' => 4},'releases' => 4,'requires' => ['HTML-FromText-1.005.tar.gz'],'requires_module' => {'HTML::FromText' => '1.004'},'requires_recursive' => ['HTML-FromText-1.005.tar.gz'],'size' => {'packed' => 5207,'unpacked' => 14178},'testers' => {'pass' => 5},'uses' => ['AutoLoader','Data::Dumper','Exporter','FileHandle','HTML::FromText','strict','vars']},'LogCarp-1.12.tar.gz' => {'author' => 'MIKEKING','description' => 'Error, log, bug streams, httpd style format','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1030,'pod' => 676,'pod_errors' => 0,'total' => 1706,'with_comments' => 105},'releases' => 7,'size' => {'packed' => 18732,'unpacked' => 69076},'testers' => {'fail' => 6,'pass' => 1,'tests' => '24'},'uses' => ['5.004','Carp','Exporter','Fcntl','POSIX','SelectSaver','Symbol','strict','vars']},'Logfile-0.300.tar.gz' => {'author' => 'ULPFR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1200,'pod' => 194,'pod_errors' => 0,'total' => 1394,'with_comments' => 207},'releases' => 10,'size' => {'packed' => 31040,'unpacked' => 156478},'testers' => {'fail' => 11,'pass' => 4,'tests' => '56'},'uses' => ['Carp','GetDate','Logfile::Base','Time::Local','Time::ParseDate','strict','vars']},'Logfile-0.302.tar.gz' => {'author' => 'ULPFR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1204,'pod' => 198,'pod_errors' => 0,'total' => 1402,'with_comments' => 207},'releases' => 10,'size' => {'packed' => 31252,'unpacked' => 156809},'testers' => {'pass' => 2},'uses' => ['Carp','GetDate','Logfile::Apache','Logfile::Wn','Net::Country','Time::Local','Time::ParseDate','strict','vars']},'Logfile-Radius-1.14.tar.gz' => {'author' => 'PAULG','description' => 'Perl module for generating reports from Radius Accounting logfiles','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 123,'pod' => 35,'pod_errors' => 0,'total' => 158,'with_comments' => 33},'releases' => 1,'requires' => ['Logfile-0.302.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Copy' => '2.02','Logfile::Base' => 0},'requires_recursive' => ['Logfile-0.302.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3286,'unpacked' => 9667},'testers' => {'pass' => 1},'uses' => ['Carp','English','Logfile::Base','strict','vars']},'Logfile-Rotate-1.04.tar.gz' => {'author' => 'PAULG','description' => 'Perl module to rotate logfiles.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 326,'pod' => 113,'pod_errors' => 0,'total' => 439,'with_comments' => 49},'releases' => 4,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'File::Copy' => '2.02'},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 11932,'unpacked' => 46598},'testers' => {'pass' => 7},'uses' => ['Carp','Compress::Zlib','Config','Fcntl','File::Copy','IO::File','strict','vars']},'Logger-Simple-1.05.tar.gz' => {'author' => 'TSTANLEY','description' => 'Implementation of the Simran-Log-Log and Simran-Error-Error modules','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 139,'pod' => 88,'pod_errors' => 0,'total' => 227,'with_comments' => 0},'releases' => 6,'requires' => ['Data-Dumper-2.101.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => 0,'Fcntl' => 0,'FileHandle' => 0,'Time::HiRes' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3752,'unpacked' => 8187},'testers' => {'pass' => 8},'uses' => ['Carp','Data::Dumper','Fcntl','FileHandle','Time::HiRes','strict','vars']},'Loop-1.00.tar.gz' => {'author' => 'GSLONDON','description' => 'Smart, Simple, Recursive Iterators for Perl programming.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 203,'pod' => 100,'pod_errors' => 0,'total' => 303,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 4862,'unpacked' => 14312},'testers' => {'pass' => 2},'uses' => ['5.005_62','Carp','strict','warnings']},'Lucene-QueryParser-1.02.tar.gz' => {'author' => 'SIMON','description' => 'Turn a Lucene query into a Perl data structure','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 98,'pod' => 43,'pod_errors' => 0,'total' => 141,'with_comments' => 2},'releases' => 3,'requires' => ['Text-Balanced-1.95.tar.gz'],'requires_module' => {'Text::Balanced' => 0},'requires_recursive' => ['Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3356,'unpacked' => 8841},'testers' => {'pass' => 2},'uses' => ['5.00503','Carp','Exporter','Text::Balanced','strict','vars']},'Lufs-0.09.tar.gz' => {'author' => 'RLZWART','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 869,'pod' => 310,'pod_errors' => 0,'total' => 1179,'with_comments' => 32},'releases' => 1,'size' => {'packed' => 14776,'unpacked' => 62316},'testers' => {'pass' => 1},'uses' => ['constant','strict','vars','warnings']},'Lutherie-FretCalc-0.33.tar.gz' => {'author' => 'DSPARLING','description' => 'Calculate stringed instrument fret locations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 320,'pod' => 94,'pod_errors' => 0,'total' => 414,'with_comments' => 22},'releases' => 8,'size' => {'packed' => 8877,'unpacked' => 37784},'testers' => {'pass' => 5},'uses' => ['strict','vars']},'MAB2-0.05.tar.gz' => {'author' => 'ANDK','description' => 'Read a raw MAB2 file into a tied hash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4950,'pod' => 165,'pod_errors' => 0,'total' => 5115,'with_comments' => 77},'releases' => 1,'requires' => ['BerkeleyDB-0.23.tar.gz','Encode-1.97.tar.gz'],'requires_module' => {'BerkeleyDB' => '0.20','Encode' => '1.41'},'requires_recursive' => ['BerkeleyDB-0.23.tar.gz','Encode-1.97.tar.gz'],'size' => {'packed' => 65366,'unpacked' => 300585},'testers' => {'fail' => 1,'tests' => '21'},'uses' => ['BerkeleyDB','Data::Dumper','Dumpvalue','Encode::Encoding','Fcntl','Tie::Array','Tie::Hash','Unicode::Normalize','XSLoader','constant','overload','strict']},'MARC-1.15.tar.gz' => {'author' => 'ESUMMERS','description' => 'MAchine Readable Catalog (library bib. data)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3206,'pod' => 969,'pod_errors' => 0,'total' => 4175,'with_comments' => 930},'releases' => 24,'size' => {'packed' => 87940,'unpacked' => 394513},'testers' => {'pass' => 12},'uses' => ['5.004','Carp','Exporter','strict','vars']},'MARC-Charset-0.5.tar.gz' => {'author' => 'ESUMMERS','description' => 'A module for doing MARC-8/UTF8 translation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2122,'pod' => 823,'pod_errors' => 1,'total' => 2945,'with_comments' => 731},'releases' => 5,'requires' => ['DB_File-1.806.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DB_File' => 1,'Test::More' => 0},'requires_recursive' => ['DB_File-1.806.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 116384,'unpacked' => 643157},'testers' => {'pass' => 1},'uses' => ['','5.8.0','Carp','Config','DB_File','Exporter','constant','of','strict']},'MARC-Record-1.27.tar.gz' => {'author' => 'PETDANCE','description' => 'Perl extension for handling MARC records','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4681,'pod' => 1789,'pod_errors' => 0,'total' => 6470,'with_comments' => 127},'releases' => 34,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 107814,'unpacked' => 492476},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','MARC::Field','MARC::File::USMARC','MARC::Record','constant','integer','strict','vars']},'MARC-Record-1.29.tar.gz' => {'author' => 'PETDANCE','description' => 'Perl extension for handling MARC records','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4681,'pod' => 1786,'pod_errors' => 0,'total' => 6467,'with_comments' => 125},'releases' => 34,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 109187,'unpacked' => 495322},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','MARC::File','constant','integer','strict','vars']},'MARC-XML-0.4.tar.gz' => {'author' => 'BBIRTH','description' => 'MAchine Readable Catalog / XML Extension','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 689,'pod' => 229,'pod_errors' => 0,'total' => 918,'with_comments' => 227},'releases' => 3,'size' => {'packed' => 51839,'unpacked' => 204634},'testers' => {'fail' => 4,'pass' => 1,'tests' => '524'},'uses' => ['5.004','Carp','Exporter','MARC','XML::Parser','strict','vars']},'MCrypt-0.92.tar.gz' => {'author' => 'FKUO','description' => 'Perl extension for MCrypt Crypto library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 249,'pod_errors' => 0,'total' => 471,'with_comments' => 31},'releases' => 3,'size' => {'packed' => 11178,'unpacked' => 42991},'testers' => {},'uses' => ['5.005_62','AutoLoader','Carp','DynaLoader','Exporter','constant','strict','warnings']},'MD5-2.02.tar.gz' => {'author' => 'GAAS','description' => 'Perl interface to the MD5 Message-Digest Algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 21,'pod' => 33,'pod_errors' => 0,'total' => 54,'with_comments' => 2},'releases' => 6,'requires' => ['Digest-MD5-2.26.tar.gz'],'requires_module' => {'Digest::MD5' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 2776,'unpacked' => 6048},'testers' => {'pass' => 33},'uses' => ['Digest::MD5','strict','vars']},'MHonArc-2.6.6.tar.gz' => {'author' => 'EHOOD','description' => 'Character related utilties for MHonArc.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 252886,'pod' => 383,'pod_errors' => 0,'total' => 253269,'with_comments' => 119039},'releases' => 2,'size' => {'packed' => 1833022,'unpacked' => 7201502},'testers' => {'pass' => 1},'uses' => ['Carp','Encode','Unicode::MapUTF8','Unicode::String','strict','utf','vars']},'MHonArc2.5.14.tar.gz' => {'author' => 'EHOOD','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 3256,'pod' => 0,'pod_errors' => 0,'total' => 3256,'with_comments' => 2864},'releases' => 1,'size' => {'packed' => 590199,'unpacked' => 3301984},'testers' => {'pass' => 2},'uses' => ['Unicode::MapUTF8','Unicode::String','strict','utf']},'MHonArc2.5.2.tar.gz' => {'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2805,'pod' => 0,'pod_errors' => 0,'total' => 2805,'with_comments' => 2537},'releases' => 1,'testers' => {'fail' => 1,'pass' => 2},'uses' => ['strict']},'MIDI-Music-0.01.tar.gz' => {'author' => 'SETHJ','description' => 'Perl interface to /dev/music.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 559,'pod' => 280,'pod_errors' => 0,'total' => 839,'with_comments' => 80},'releases' => 1,'size' => {'packed' => 14570,'unpacked' => 61527},'testers' => {'pass' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','Fcntl','strict','vars']},'MIDI-Perl-0.8.tar.gz' => {'author' => 'SBURKE','description' => 'read, compose, modify, and write MIDI files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3547,'pod' => 1706,'pod_errors' => 0,'total' => 5253,'with_comments' => 659},'releases' => 16,'size' => {'packed' => 57443,'unpacked' => 186633},'testers' => {'pass' => 6},'uses' => ['5','5.004','Carp','Exporter','GD','strict','subs','vars']},'MIDI-Realtime-0.01.tar.gz' => {'author' => 'FOOCHRE','description' => 'Interacts with MIDI devices in realtime','files' => [],'lines' => {'nonpod' => 131,'pod' => 105,'pod_errors' => 0,'total' => 236,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 3819,'unpacked' => 7569},'testers' => {'fail' => 3,'pass' => 1},'uses' => ['Fcntl','strict','sys::soundcard.ph','vars']},'MIDI-Tools-0.01.tar.gz' => {'author' => 'CRENZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 143,'pod' => 65,'pod_errors' => 0,'total' => 208,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 3665,'unpacked' => 12297},'testers' => {'pass' => 11},'uses' => ['5.005','Exporter','strict','vars','warnings']},'MIDI-Trans-0.15.zip' => {'author' => 'CHURCH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 645,'pod' => 887,'pod_errors' => 0,'total' => 1532,'with_comments' => 23},'releases' => 1,'requires' => ['MIDI-Perl-0.8.tar.gz'],'requires_module' => {'MIDI::Simple' => ''},'requires_recursive' => ['MIDI-Perl-0.8.tar.gz'],'size' => {'packed' => 14913,'unpacked' => 46181},'testers' => {'pass' => 3},'uses' => ['5.006','Exporter','MIDI::Simple','strict','warnings']},'MIDI-XML-0.02.tar.gz' => {'author' => 'BMAMES','description' => 'Class MIDI Port messages.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5530,'pod' => 3252,'pod_errors' => 0,'total' => 8782,'with_comments' => 296},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz','MIDI-Perl-0.8.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'HTML::Entities' => 0,'MIDI' => '0.79','XML::Parser' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','MIDI-Perl-0.8.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 27408,'unpacked' => 231829},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.006','HTML::Entities','MIDI::Event','MIDI::Opus','MIDI::Track','strict','vars','warnings']},'MIME-Base64-2.20.tar.gz' => {'author' => 'GAAS','description' => 'Encode/decode Quoted-Printable','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 265,'pod' => 131,'pod_errors' => 0,'total' => 396,'with_comments' => 54},'releases' => 20,'size' => {'packed' => 15077,'unpacked' => 46934},'testers' => {'pass' => 7},'uses' => ['Carp','DynaLoader','Encode','Exporter','bytes','integer','strict','vars']},'MIME-Explode-0.24.tar.gz' => {'author' => 'HDIAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 406,'pod' => 100,'pod_errors' => 0,'total' => 506,'with_comments' => 11},'releases' => 24,'size' => {'packed' => 155930,'unpacked' => 324146},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','SelfLoader','constant','strict','vars']},'MIME-Fast-1.0.1.tar.gz' => {'author' => 'MAKLER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 446,'pod' => 1136,'pod_errors' => 1,'total' => 1582,'with_comments' => 17},'releases' => 6,'size' => {'packed' => 51994,'unpacked' => 230446},'testers' => {},'uses' => ['5.008','AutoLoader','Carp','DynaLoader','Exporter','Mail::Mailer','strict','vars','warnings']},'MIME-Lite-2.117.tar.gz' => {'author' => 'ERYQ','description' => 'low-calorie MIME generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2891,'pod' => 1611,'pod_errors' => 2,'total' => 4502,'with_comments' => 578},'releases' => 29,'size' => {'packed' => 107276,'unpacked' => 324176},'testers' => {'pass' => 74},'uses' => ['5.004','Carp','FileHandle','MIME::Lite','Mail::Address','Net::Config','Net::SMTP','Sys::Hostname','strict','vars']},'MIME-Lite-3.01.tar.gz' => {'author' => 'YVES','description' => 'Easily create MIME/SMTP mails w/attachements','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2927,'pod' => 1666,'pod_errors' => 2,'total' => 4593,'with_comments' => 576},'releases' => 29,'size' => {'packed' => 49778,'unpacked' => 148688},'testers' => {'pass' => 8},'uses' => ['5.004','Carp','FileHandle','MIME::Types','Mail::Address','Net::Config','Net::SMTP','Sys::Hostname','strict','vars']},'MIME-Lite-HTML-1.15.tar.gz' => {'author' => 'ALIAN','description' => 'Provide routine to transform HTML to MIME','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 785,'pod' => 321,'pod_errors' => 0,'total' => 1106,'with_comments' => 173},'releases' => 20,'requires' => ['HTML-Parser-3.28.tar.gz','MIME-Lite-3.01.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::LinkExtor' => 0,'LWP::UserAgent' => 0,'MIME::Lite' => 1,'Test::More' => 0,'URI::URL' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21597,'unpacked' => 95211},'testers' => {'pass' => 11},'uses' => ['Exporter','HTML::LinkExtor','MIME::Lite','URI::URL','strict','vars']},'MIME-Types-1.06.tar.gz' => {'author' => 'MARKOV','description' => 'Information and processing MIME types','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1063,'pod' => 293,'pod_errors' => 0,'total' => 1356,'with_comments' => 37},'releases' => 18,'size' => {'packed' => 14349,'unpacked' => 43762},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','overload','strict','vars']},'MIME-tools-5.411a.tar.gz' => {'author' => 'ERYQ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8067,'pod' => 4745,'pod_errors' => 0,'total' => 12812,'with_comments' => 1472},'releases' => 4,'requires' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Path' => 1,'File::Spec' => '0.6','IO::Stringy' => '1.211','MIME::Base64' => '2.04','MIME::QuotedPrint' => '2.03','Mail::Field' => '1.05','Mail::Header' => '1.01','Mail::Internet' => '1.0203'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 467432,'unpacked' => 1219094},'testers' => {'pass' => 81},'uses' => ['5.001','5.002','Benchmark','Carp','Config','Exporter','File::Path','File::Spec','FileHandle','IO::File','IO::InnerFile','IO::Lines','IO::Scalar','IO::ScalarArray','IO::Wrap','IPC::Open2','MIME::Base64','MIME::QuotedPrint','Mail::Field','Symbol','strict','vars']},'MLDBM-2.01.tar.gz' => {'author' => 'CHAMAS','description' => 'store multi-level hash structure in single level tied hash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 481,'pod' => 193,'pod_errors' => 0,'total' => 674,'with_comments' => 107},'releases' => 9,'requires' => ['Data-Dumper-2.101.tar.gz'],'requires_module' => {'Data::Dumper' => '2.08'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 9568,'unpacked' => 26750},'testers' => {'pass' => 29},'uses' => ['5.004','Carp','Data::Dumper','FreezeThaw','Storable','Tie::Hash','strict','vars']},'MLDBM-Sync-0.30.tar.gz' => {'author' => 'CHAMAS','description' => 'MLDBM wrapper to serialize concurrent access','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 603,'pod' => 241,'pod_errors' => 0,'total' => 844,'with_comments' => 31},'releases' => 14,'requires' => ['MLDBM-2.01.tar.gz'],'requires_module' => {'MLDBM' => 1},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','MLDBM-2.01.tar.gz'],'size' => {'packed' => 22058,'unpacked' => 69293},'testers' => {'pass' => 23},'uses' => ['Carp','Data::Dumper','Digest::MD5','Fcntl','MLDBM','SDBM_File','Tie::Cache','Time::HiRes','strict','vars']},'MLDBM-TinyDB-0.20.tar.gz' => {'author' => 'DADAMK','description' => 'more-than-flatfile-database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 764,'pod' => 256,'pod_errors' => 1,'total' => 1020,'with_comments' => 83},'releases' => 7,'requires' => ['MLDBM-2.01.tar.gz','Storable-2.07.tar.gz','Tie-IxHash-1.21.tar.gz'],'requires_module' => {'MLDBM' => '0','Storable' => '0','Tie::IxHash' => '0'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','MLDBM-2.01.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tie-IxHash-1.21.tar.gz'],'size' => {'packed' => 10271,'unpacked' => 37070},'testers' => {'pass' => 3},'uses' => ['Carp::Heavy','Exporter','Fcntl','MLDBM','MLDBM::Serializer::Storable','SDBM_File','Storable','Tie::IxHash','locale','strict','vars']},'MMM-OracleDump-0.01.tar.gz' => {'author' => 'MAXM','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 163,'pod' => 48,'pod_errors' => 0,'total' => 211,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 3572,'unpacked' => 7996},'testers' => {'fail' => 2},'uses' => ['Exporter','strict','vars']},'MMM-Text-Search-0.06.tar.gz' => {'author' => 'MAXM','description' => 'Perl module for indexing and searching text files and web objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 988,'pod' => 102,'pod_errors' => 1,'total' => 1090,'with_comments' => 117},'releases' => 1,'size' => {'packed' => 12747,'unpacked' => 34948},'testers' => {'fail' => 2,'pass' => 3},'uses' => ['5.005','AutoLoader','Exporter','Fcntl','IO::Socket::INET','strict','vars']},'MOP-1.00.tar.gz' => {'author' => 'ORTALO','description' => 'Perl extension providing a meta-object protocol for Perl modules.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 948,'pod' => 380,'pod_errors' => 3,'total' => 1328,'with_comments' => 203},'releases' => 1,'size' => {'packed' => 21177,'unpacked' => 65417},'testers' => {'fail' => 3,'tests' => '5'},'uses' => ['Carp','Config','Cwd','Data::Dumper','FileHandle','Filter::Util::Call','Socket','lib','strict','vars']},'MP3-Album-0.13.tar.gz' => {'author' => 'BMAVT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 688,'pod' => 296,'pod_errors' => 0,'total' => 984,'with_comments' => 4},'releases' => 2,'requires' => ['CDDB-1.08.tar.gz','MP3-Album-0.13.tar.gz','MP3-Info-1.02.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CDDB' => '1.08','File::Basename' => 0,'File::Copy' => 0,'MP3::Album::Layout' => 0,'MP3::Album::Layout::Fetcher' => 0,'MP3::Album::Layout::Fetcher::CDDB' => 0,'MP3::Album::Layout::Fetcher::Tag' => 0,'MP3::Album::Track' => 0,'MP3::Info' => '1.01'},'requires_recursive' => ['CDDB-1.08.tar.gz','File-Spec-0.82.tar.gz','MP3-Album-0.13.tar.gz','MP3-Info-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8418,'unpacked' => 25848},'testers' => {'pass' => 1},'uses' => ['CDDB','Data::Dumper','File::Basename','File::Copy','MP3::Info','strict']},'MP3-Daemon-0.63.tar.gz' => {'author' => 'BEPPU','description' => 'a daemon that possesses mpg123','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 832,'pod' => 583,'pod_errors' => 0,'total' => 1415,'with_comments' => 102},'releases' => 10,'requires' => ['Audio-Play-MPG123-0.62.tar.gz','IO-1.20.tar.gz','MP3-Info-1.02.tar.gz','PodParser-1.23.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Audio::Play::MPG123' => 0,'IO::Socket' => 0,'MP3::Info' => 0,'POSIX' => 0,'Pod::Usage' => 0},'requires_recursive' => ['Audio-Play-MPG123-0.62.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MP3-Info-1.02.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 26024,'unpacked' => 91315},'testers' => {'pass' => 7},'uses' => ['Audio::Play::MPG123','File::Basename','Getopt::Std','IO::Select','IO::Socket','MP3::Info','POSIX','constant','strict','vars']},'MP3-ID3Lib-0.12.tar.gz' => {'author' => 'LBROCARD','description' => 'ID3v1/ID3v2 Tagging of MP3 files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 344,'pod' => 100,'pod_errors' => 0,'total' => 444,'with_comments' => 0},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Copy' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 37886,'unpacked' => 67395},'testers' => {},'uses' => ['AutoLoader','DynaLoader','strict','vars']},'MP3-ID3v1Tag-1.11.tar.gz' => {'author' => 'SVANZOEST','description' => 'ID3v1 MP3 Tag Reader/Writer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 337,'pod' => 98,'pod_errors' => 0,'total' => 435,'with_comments' => 40},'releases' => 4,'size' => {'packed' => 6820,'unpacked' => 16577},'testers' => {'pass' => 6},'uses' => ['5.004','Carp','Exporter','IO::File','strict','vars']},'MP3-Info-1.02.tar.gz' => {'author' => 'CNANDOR','description' => 'Manipulate / fetch info from MP3 audio files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1363,'pod' => 245,'pod_errors' => 0,'total' => 1608,'with_comments' => 62},'releases' => 6,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 54611,'unpacked' => 195684},'testers' => {'pass' => 10},'uses' => ['Carp','Symbol','overload','strict','vars']},'MP3-M3U-0.01.tar.gz' => {'author' => 'ILIAL','description' => 'M3u playlist parser','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 58,'pod' => 49,'pod_errors' => 0,'total' => 107,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 1909,'unpacked' => 3263},'testers' => {'pass' => 4},'uses' => ['strict','vars']},'MP3-M3U-Parser-1.04.tar.gz' => {'author' => 'BURAK','description' => 'Perl extension for parsing m3u mp3 lists.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 678,'pod' => 345,'pod_errors' => 0,'total' => 1023,'with_comments' => 131},'releases' => 5,'requires' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'File::Spec' => 0,'IO::File' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz'],'size' => {'packed' => 12162,'unpacked' => 36858},'testers' => {'pass' => 2,'tests' => '0','unknown' => 6},'uses' => ['Data::Dumper','strict','vars']},'MP3-Mplib-0.01.tar.gz' => {'author' => 'VPARSEVAL','description' => 'Read and write access to v1 and v2 mp3-tags','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 350,'pod' => 578,'pod_errors' => 0,'total' => 928,'with_comments' => 13},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 80543,'unpacked' => 184855},'testers' => {'fail' => 1,'pass' => 2,'tests' => '76'},'uses' => ['5.005003','AutoLoader','Carp','DynaLoader','Errno','Exporter','strict','vars']},'MP3-Napster-0.96.tar.gz' => {'author' => 'LDS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3082,'pod' => 1501,'pod_errors' => 0,'total' => 4583,'with_comments' => 315},'releases' => 6,'requires' => ['Digest-MD5-2.26.tar.gz','MP3-Info-1.02.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Digest::MD5' => 0,'MP3::Info' => 0,'Thread' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','MP3-Info-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 91175,'unpacked' => 247031},'testers' => {},'uses' => ['Carp','Digest::MD5','Errno','Exporter','IO::File','IO::Select','IO::Socket','MP3::Info','MP3::Napster::Base','MP3::Napster::Channel','MP3::Napster::Listener','MP3::Napster::Registry','MP3::Napster::Song','MP3::Napster::User','Thread','Thread::Queue','Thread::Signal','constant','overload','strict','vars']},'MP3-Napster-2.04.tar.gz' => {'author' => 'LDS','description' => 'Perl interface to the Napster Server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5078,'pod' => 1514,'pod_errors' => 0,'total' => 6592,'with_comments' => 401},'releases' => 6,'requires' => ['Digest-MD5-2.26.tar.gz','MP3-Info-1.02.tar.gz'],'requires_module' => {'Digest::MD5' => 0,'MP3::Info' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','MP3-Info-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 120773,'unpacked' => 337157},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['5.6.0','AnyDBM_File','Carp','Digest::MD5','Errno','Exporter','File::Basename','File::Path','IO::Dir','IO::File','IO::Poll','IO::Select','IO::Socket','MP3::Info','MP3::Napster::Transfer','Symbol','Tk','Tk::LabEntry','Tk::Tree','Tk::widgets','constant','overload','strict','vars']},'MP3-Player-PktConcert-0.01.tar.gz' => {'author' => 'MIKEWONG','description' => 'A Perl OO wrapper to John Seagull\'s C API to the Intel Pocket Concert','files' => [],'lines' => {'nonpod' => 146,'pod' => 48,'pod_errors' => 0,'total' => 194,'with_comments' => 27},'releases' => 1,'size' => {'packed' => 13233,'unpacked' => 41309},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'MPE-CIvar-1.11.tar.gz' => {'author' => 'KAHIRSCH','description' => 'Perl extension for CI variables and JCWs on MPE/ix','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 110,'pod' => 117,'pod_errors' => 0,'total' => 227,'with_comments' => 2},'releases' => 5,'size' => {'packed' => 6737,'unpacked' => 24991},'testers' => {'fail' => 1,'tests' => '17'},'uses' => ['5.005_62','DynaLoader','Exporter','Tie::Hash','strict','warnings']},'MPE-File-0.06.tar.gz' => {'author' => 'KAHIRSCH','description' => 'Perl extension for accessing MPE File intrinsics','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 215,'pod' => 125,'pod_errors' => 0,'total' => 340,'with_comments' => 1},'releases' => 5,'size' => {'packed' => 13712,'unpacked' => 56697},'testers' => {},'uses' => ['5.005_62','DynaLoader','Exporter','strict','warnings']},'MPE-IMAGE-0.98a.tar.gz' => {'author' => 'DOKSNER','description' => 'Access MPEs TurboIMAGE/XL databases from within Perl','files' => [],'lines' => {'nonpod' => 898,'pod' => 337,'pod_errors' => 0,'total' => 1235,'with_comments' => 46},'releases' => 1,'size' => {'packed' => 25293,'unpacked' => 102001},'testers' => {'fail' => 1,'tests' => '0','unknown' => 3},'uses' => ['5.005_62','Carp','Config','DynaLoader','Exporter','strict','warnings']},'MPE-Process-0.01.tar.gz' => {'author' => 'KAHIRSCH','description' => 'Perl extension for MPE Process Handling','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 150,'pod' => 83,'pod_errors' => 0,'total' => 233,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 4262,'unpacked' => 10719},'testers' => {},'uses' => ['5.005_62','DynaLoader','Exporter','strict','warnings']},'MPE-Spoonfeed-0.01.tar.gz' => {'author' => 'KAHIRSCH','description' => 'Perl extension for "spoonfeeding" commands through a message file to MPE programs run as child process','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 217,'pod' => 84,'pod_errors' => 0,'total' => 301,'with_comments' => 0},'releases' => 1,'requires' => ['MPE-CIvar-1.11.tar.gz','MPE-File-0.06.tar.gz','MPE-Process-0.01.tar.gz'],'requires_module' => {'MPE::CIvar' => '1.01','MPE::File' => '0.04','MPE::Process' => '0.01'},'requires_recursive' => ['MPE-CIvar-1.11.tar.gz','MPE-File-0.06.tar.gz','MPE-Process-0.01.tar.gz'],'size' => {'packed' => 4499,'unpacked' => 11498},'testers' => {},'uses' => ['5.005_62','Exporter','MPE::File','MPE::Process','strict','warnings']},'MPE-Suprtool-0.51.tar.gz' => {'author' => 'KAHIRSCH','description' => 'Perl extension for calling Robelle Suprtool','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 108,'pod' => 160,'pod_errors' => 0,'total' => 268,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 5349,'unpacked' => 11808},'testers' => {'fail' => 1,'tests' => '11'},'uses' => ['5.005_62','DynaLoader','Exporter','strict','warnings']},'MPEG-Audio-Frame-0.03.tar.gz' => {'author' => 'NUFFIN','description' => 'a class for weeding out MPEG audio frames out of a file handle.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 179,'pod' => 106,'pod_errors' => 0,'total' => 285,'with_comments' => 66},'releases' => 3,'size' => {'packed' => 5659,'unpacked' => 20708},'testers' => {'pass' => 3},'uses' => ['integer','strict','warnings']},'MPEG-ID3v2Tag-0.36.tar.gz' => {'author' => 'MDIMEO','description' => 'OO, extensible ID3 v2.3 tagging module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1317,'pod' => 302,'pod_errors' => 0,'total' => 1619,'with_comments' => 278},'releases' => 6,'size' => {'packed' => 13933,'unpacked' => 46484},'testers' => {'pass' => 2},'uses' => ['Carp','Compress::Zlib','IO::File','strict','vars']},'MPEG-Info-1.00.tar.gz' => {'author' => 'BRG','description' => 'Basic MPEG bitstream attribute parser.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1878,'pod' => 227,'pod_errors' => 2,'total' => 2105,'with_comments' => 578},'releases' => 1,'requires' => ['Video-Info-0.993.tar.gz'],'requires_module' => {'Video::Info' => '0.06'},'requires_recursive' => ['Class-MakeMethods-1.006.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','MP3-Info-1.02.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Video-Info-0.993.tar.gz','Video-OpenQuicktime-1.02.tar.gz'],'size' => {'packed' => 333973,'unpacked' => 418064},'testers' => {'pass' => 2},'uses' => ['5.005_62','5.006','Data::Dumper','Exporter','MPEG::Info::System','Video::Info','Video::Info::Magic','constant','strict','vars','warnings']},'MPEG-LibMPEG3-0.01.tar.gz' => {'author' => 'BRG','description' => 'Perl interface to libmpeg3 module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 148,'pod' => 228,'pod_errors' => 0,'total' => 376,'with_comments' => 39},'releases' => 1,'size' => {'packed' => 407467,'unpacked' => 536466},'testers' => {},'uses' => ['DynaLoader','strict']},'MPEG-MP3Play-0.15.tar.gz' => {'author' => 'JRED','description' => 'Create your own MPEG audio player','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1219,'pod' => 553,'pod_errors' => 0,'total' => 1772,'with_comments' => 24},'releases' => 14,'size' => {'packed' => 37551,'unpacked' => 185378},'testers' => {},'uses' => ['Carp','Data::Dumper','DynaLoader','Exporter','strict','vars']},'MQSeries-1.20.tar.gz' => {'author' => 'HBIERSMA','description' => 'Perl extension for MQSeries support','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11812,'pod' => 5810,'pod_errors' => 1,'total' => 17622,'with_comments' => 2393},'releases' => 13,'size' => {'packed' => 310377,'unpacked' => 1316407},'testers' => {},'uses' => ['5.005','Carp','Convert::EBCDIC','DynaLoader','Exporter','IO::File','MQClient::MQSeries','MQServer::MQSeries','Storable','Time::Local','Win32::TieRegistry','overload','strict','vars']},'MRP-1.0.tar.gz' => {'author' => 'MPOCOCK','description' => 'some text utilities','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1263,'pod' => 725,'pod_errors' => 0,'total' => 1988,'with_comments' => 63},'releases' => 1,'size' => {'packed' => 18190,'unpacked' => 60218},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','strict','vars']},'MSDOS-Attrib-1.01.zip' => {'author' => 'CJM','description' => 'Get/set DOS file attributes in OS/2 or Win32','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 112,'pod' => 47,'pod_errors' => 0,'total' => 159,'with_comments' => 28},'releases' => 2,'size' => {'packed' => 7846,'unpacked' => 17280},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'MSDOS-Descript-1.001.zip' => {'author' => 'CJM','description' => 'Manage 4DOS style DESCRIPT.ION files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 224,'pod' => 77,'pod_errors' => 0,'total' => 301,'with_comments' => 68},'releases' => 2,'requires' => ['Tie-CPHash-1.001.tar.gz'],'requires_module' => {'Tie::CPHash' => 1},'requires_recursive' => ['Tie-CPHash-1.001.tar.gz'],'size' => {'packed' => 7053,'unpacked' => 14730},'testers' => {'pass' => 4},'uses' => ['5.000','Carp','Tie::CPHash','strict','vars']},'MTDB-0.1.0.tar.gz' => {'author' => 'THOMSON','description' => 'Multidimensional Transparent hash DataBase also kwon as: MTDB - Mark Thomson\'s DataBase','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 963,'pod' => 414,'pod_errors' => 0,'total' => 1377,'with_comments' => 101},'releases' => 2,'requires' => ['Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Data-Dumper-2.101.tar.gz'],'requires_module' => {'Crypt::Blowfish' => '2.09','Crypt::CBC' => '2.02','Data::Dumper' => '2.08'},'requires_recursive' => ['Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 7033,'unpacked' => 33064},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.004','Carp','Crypt::CBC','Data::Dumper','FreezeThaw','Storable','Tie::Hash','vars']},'MVS-JESFTP-1.1.tar.gz' => {'author' => 'MIKEO','description' => 'Perl extension for submitting JCL to MVS systems through FTP.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 133,'pod_errors' => 0,'total' => 282,'with_comments' => 12},'releases' => 3,'size' => {'packed' => 4768,'unpacked' => 14451},'testers' => {'fail' => 2},'uses' => ['Exporter','Net::FTP','strict','vars']},'MVS-VBFile-0.04.tar.gz' => {'author' => 'GROMMEL','description' => 'Read MVS VB (variable-length) files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 211,'pod' => 93,'pod_errors' => 0,'total' => 304,'with_comments' => 32},'releases' => 4,'size' => {'packed' => 6142,'unpacked' => 13960},'testers' => {'pass' => 7},'uses' => ['Carp','Exporter','strict','vars']},'Mac-AppleEvents-Simple-1.06.tar.gz' => {'author' => 'CNANDOR','description' => 'Simple access to Mac::AppleEvents','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 563,'pod' => 201,'pod_errors' => 0,'total' => 764,'with_comments' => 65},'releases' => 17,'requires' => ['Mac-Apps-Launch-1.81.tar.gz','Mac-Carbon-0.53.tar.gz','Mac-Errors-0.91.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Mac::AppleEvents' => '1.25','Mac::Apps::Launch' => '1.81','Mac::Errors' => '0.91','Mac::Processes' => '1.04','Test::More' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Mac-Apps-Launch-1.81.tar.gz','Mac-Carbon-0.53.tar.gz','Mac-Errors-0.91.tar.gz','Mac-Path-Util-0.09.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Data-0.92.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9973,'unpacked' => 28078},'testers' => {},'uses' => ['5.004','Carp','Exporter','Mac::AppleEvents','Mac::Apps::Launch','Mac::Errors','Mac::Files','Mac::Processes','Mac::Types','strict','vars']},'Mac-AppleScript-0.04.tar.gz' => {'author' => 'DSUGAL','description' => 'Perl extension to execute applescript commands on OS X','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 44,'pod' => 31,'pod_errors' => 0,'total' => 75,'with_comments' => 8},'releases' => 4,'size' => {'packed' => 3420,'unpacked' => 7107},'testers' => {'pass' => 1},'uses' => ['5.005_62','AutoLoader','DynaLoader','Exporter','strict','warnings']},'Mac-AppleScript-Glue-0.03.tar.gz' => {'author' => 'JLABOVITZ','description' => 'translate Perl into Applescript','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 976,'pod' => 403,'pod_errors' => 0,'total' => 1379,'with_comments' => 163},'releases' => 1,'requires' => ['Data-Dumper-2.101.tar.gz','IO-1.20.tar.gz','Mac-AppleScript-0.04.tar.gz','Test-Pod-0.95.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => 0,'IO::File' => 0,'Mac::AppleScript' => '0.03','Test::Pod' => 0,'Text::ParseWords' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','Mac-AppleScript-0.04.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13229,'unpacked' => 42627},'testers' => {},'uses' => ['5.6.0','Carp','Data::Dumper','Exporter','IO::File','Mac::AppleScript','Text::ParseWords','strict','warnings']},'Mac-AppleSingleDouble-1.0.tar.gz' => {'author' => 'JFLOURNOY','description' => 'Read Mac files in AppleSingle or AppleDouble format.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 478,'pod' => 147,'pod_errors' => 0,'total' => 625,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 16047,'unpacked' => 53337},'testers' => {'pass' => 4},'uses' => ['5','FileHandle']},'Mac-Apps-Anarchie-1.50.tar.gz' => {'author' => 'CNANDOR','description' => 'Interface to Anarchie 2.01+','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 501,'pod' => 221,'pod_errors' => 0,'total' => 722,'with_comments' => 56},'releases' => 3,'size' => {'packed' => 9018,'unpacked' => 34160},'testers' => {},'uses' => ['5.004','AutoLoader','Carp','Exporter','Mac::AppleEvents','Mac::Apps::Launch','strict','vars']},'Mac-Apps-Launch-1.81.tar.gz' => {'author' => 'CNANDOR','description' => 'Mac module to launch / quit apps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 48,'pod_errors' => 0,'total' => 209,'with_comments' => 14},'releases' => 7,'requires' => ['Mac-Carbon-0.53.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Mac::Processes' => '1.04','Test::More' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Mac-Carbon-0.53.tar.gz','Mac-Path-Util-0.09.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Data-0.92.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4304,'unpacked' => 10147},'testers' => {},'uses' => ['5.004','Exporter','Mac::AppleEvents','Mac::MoreFiles','Mac::Processes','strict','vars']},'Mac-Apps-MacPGP-1.20.tar.gz' => {'author' => 'CNANDOR','description' => 'Interface to MacPGP 2.6.3','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 575,'pod' => 542,'pod_errors' => 1,'total' => 1117,'with_comments' => 76},'releases' => 3,'size' => {'packed' => 93694,'unpacked' => 150399},'testers' => {},'uses' => ['5.004','Carp','Exporter','Mac::AppleEvents','Mac::Apps::Launch','strict','vars']},'Mac-Apps-PBar-1.30.tar.gz' => {'author' => 'CNANDOR','description' => 'An AppleEvent Module for Progress Bar 1.0.1','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 159,'pod_errors' => 0,'total' => 288,'with_comments' => 3},'releases' => 4,'size' => {'packed' => 4923,'unpacked' => 9962},'testers' => {},'uses' => ['5.00201','Carp','Exporter','Mac::AppleEvents','Mac::Apps::Launch','strict','vars']},'Mac-Carbon-0.53.tar.gz' => {'author' => 'CNANDOR','description' => 'Further file management routines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5535,'pod' => 3485,'pod_errors' => 15,'total' => 9020,'with_comments' => 43},'releases' => 9,'requires' => ['Mac-Path-Util-0.09.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Mac::Path::Util' => '0.09','Test::More' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Mac-Path-Util-0.09.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Data-0.92.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 286279,'unpacked' => 1165996},'testers' => {},'uses' => ['Carp','Config','DynaLoader','Exporter','Fcntl','IO::Handle','Mac::Path::Util','strict','vars']},'Mac-Comm-OT_PPP-1.20.tar.gz' => {'author' => 'CNANDOR','description' => 'Interface to Open Transport PPP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 96,'pod' => 119,'pod_errors' => 0,'total' => 215,'with_comments' => 10},'releases' => 3,'size' => {'packed' => 3640,'unpacked' => 8154},'testers' => {},'uses' => ['5.00201','AutoLoader','Carp','Exporter','Mac::AppleEvents','strict','vars']},'Mac-Conversions-1.04.tar.gz' => {'author' => 'SCHINDER','description' => 'A package for common MacOS file encoding/decoding tasks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 742,'pod' => 73,'pod_errors' => 0,'total' => 815,'with_comments' => 87},'releases' => 5,'requires' => ['Convert-BinHex-1.119.tar.gz'],'requires_module' => {'Convert::BinHex' => 0},'requires_recursive' => ['Convert-BinHex-1.119.tar.gz'],'size' => {'packed' => 54482,'unpacked' => 116793},'testers' => {'pass' => 1},'uses' => ['Carp','Convert::BinHex','Exporter','Fcntl','File::Basename','FileHandle','Mac::Files','POSIX','strict']},'Mac-Errors-0.91.tar.gz' => {'author' => 'PETDANCE','description' => 'MacErrors.h names, numbers, and descriptions','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 7866,'pod' => 6344,'pod_errors' => 0,'total' => 14210,'with_comments' => 2},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 46419,'unpacked' => 179075},'testers' => {'pass' => 3},'uses' => ['Exporter','Tie::Scalar','strict','vars']},'Mac-FileSpec-Unixish-1.11.tar.gz' => {'author' => 'SBURKE','description' => 'Unixish-compatability in filespecs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 245,'pod' => 116,'pod_errors' => 0,'total' => 361,'with_comments' => 31},'releases' => 2,'size' => {'packed' => 7031,'unpacked' => 18229},'testers' => {'pass' => 8},'uses' => ['5','Exporter','strict','vars']},'Mac-Glue-1.11.tar.gz' => {'author' => 'CNANDOR','description' => 'Control Mac apps with Apple event terminology','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3331,'pod' => 802,'pod_errors' => 0,'total' => 4133,'with_comments' => 223},'releases' => 10,'requires' => ['MLDBM-2.01.tar.gz','Mac-AppleEvents-Simple-1.06.tar.gz','Mac-Apps-Launch-1.81.tar.gz','Mac-Carbon-0.53.tar.gz','Mac-Errors-0.91.tar.gz','Mac-Path-Util-0.09.tar.gz','Storable-2.07.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'MLDBM' => 0,'Mac::AppleEvents' => '1.25','Mac::AppleEvents::Simple' => '1.03','Mac::Apps::Launch' => '1.81','Mac::Errors' => '0.91','Mac::Path::Util' => '0.09','Mac::Processes' => '1.04','Storable' => 0,'Test::More' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','MLDBM-2.01.tar.gz','Mac-AppleEvents-Simple-1.06.tar.gz','Mac-Apps-Launch-1.81.tar.gz','Mac-Carbon-0.53.tar.gz','Mac-Errors-0.91.tar.gz','Mac-Path-Util-0.09.tar.gz','Scalar-List-Utils-1.11.tar.gz','Storable-2.07.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Data-0.92.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 48262,'unpacked' => 156935},'testers' => {},'uses' => ['Carp','Cwd','Data::Dumper','Exporter','Fcntl','File::Basename','File::Path','File::Spec::Functions','Getopt::Std','Mac::AppleEvents::Simple','Mac::Apps::Launch','Mac::Errors','Mac::Files','Mac::Memory','Mac::MoreFiles','Mac::Path::Util','Mac::Processes','Mac::Resources','Mac::Types','MacPerl','Symbol','strict','vars']},'Mac-Macbinary-0.04.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Decodes MacBinary files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 163,'pod' => 134,'pod_errors' => 0,'total' => 297,'with_comments' => 10},'releases' => 4,'size' => {'packed' => 4557,'unpacked' => 13897},'testers' => {'pass' => 10},'uses' => ['FileHandle','strict','vars']},'Mac-OSA-Simple-1.06.tar.gz' => {'author' => 'CNANDOR','description' => 'Simple access to Mac::OSA','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 390,'pod' => 193,'pod_errors' => 0,'total' => 583,'with_comments' => 6},'releases' => 9,'requires' => ['Mac-Carbon-0.53.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Mac::AppleEvents' => '1.25','Mac::Components' => '1.02','Mac::Memory' => '1.22','Mac::OSA' => '1.03','Mac::Resources' => '1.03','Test::More' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Mac-Carbon-0.53.tar.gz','Mac-Path-Util-0.09.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Data-0.92.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7671,'unpacked' => 20223},'testers' => {},'uses' => ['Carp','Exporter','File::Basename','Mac::AppleEvents::Simple','Mac::Components','Mac::Memory','Mac::OSA','Mac::Processes','Mac::Resources','strict','vars']},'Mac-Path-Util-0.09.tar.gz' => {'author' => 'PETDANCE','description' => 'convert between darwin and Mac paths','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 281,'pod' => 85,'pod_errors' => 0,'total' => 366,'with_comments' => 8},'releases' => 5,'requires' => ['Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Test-Data-0.92.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Find' => '0','File::Spec' => '0','Test::Data' => '0','Test::More' => '0','base' => '0'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Data-0.92.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4467,'unpacked' => 11283},'testers' => {'pass' => 2},'uses' => ['Cwd','Exporter','constant','strict','vars']},'Mac-PropertyList-0.1.tar.gz' => {'author' => 'BDFOY','description' => 'work with MacOS X plist files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 311,'pod' => 120,'pod_errors' => 0,'total' => 431,'with_comments' => 3},'releases' => 10,'requires' => ['File-Find-Rule-0.10.tar.gz','MIME-Base64-2.20.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','MIME::Base64' => '0','Test::Manifest' => '0.91','Test::More' => '0','Test::Pod' => '0.9','Time::HiRes' => '0'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 11661,'unpacked' => 62112},'testers' => {'pass' => 1},'uses' => ['MIME::Base64','strict','vars']},'Mac-RecentDocuments-0.01.tar.gz' => {'author' => 'SBURKE','description' => '- add items to the MacOS Recent Documents menu','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 151,'pod' => 105,'pod_errors' => 0,'total' => 256,'with_comments' => 28},'releases' => 1,'size' => {'packed' => 4655,'unpacked' => 13278},'testers' => {'pass' => 3},'uses' => ['5','Exporter','Mac::Files','strict','vars']},'Mac-iTunes-0.82.tar.gz' => {'author' => 'BDFOY','description' => 'interact with and control iTunes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1969,'pod' => 886,'pod_errors' => 1,'total' => 2855,'with_comments' => 57},'releases' => 4,'requires' => ['File-Find-Rule-0.10.tar.gz','MP3-Info-1.02.tar.gz','Mac-AppleScript-0.04.tar.gz','Mac-Path-Util-0.09.tar.gz','Mac-PropertyList-0.1.tar.gz','Test-Data-0.92.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','MP3::Info' => '0','Mac::AppleScript' => '0.03','Mac::Path::Util' => '0.07','Mac::PropertyList' => '0','Test::Data' => '0','Test::Manifest' => '0.9','Test::More' => '0','Test::Pod' => '0.72','Test::Prereq' => '0.18','Time::HiRes' => '0'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MP3-Info-1.02.tar.gz','Mac-AppleScript-0.04.tar.gz','Mac-Path-Util-0.09.tar.gz','Mac-PropertyList-0.1.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Data-0.92.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 113510,'unpacked' => 228536},'testers' => {},'uses' => ['Carp','Data::Dumper','Exporter','File::Find','File::Spec','IPC::Open2','MP3::Info','Mac::AppleScript','Mac::Path::Util','Mac::PropertyList','constant','strict','vars']},'MacOSX-File-0.66.tar.gz' => {'author' => 'DANKOGAI','description' => 'A collection of modules to manipulate files on MacOS X','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 932,'pod' => 501,'pod_errors' => 0,'total' => 1433,'with_comments' => 60},'releases' => 12,'size' => {'packed' => 30565,'unpacked' => 102556},'testers' => {'pass' => 1},'uses' => ['5.005_62','5.6.0','AutoLoader','Carp','DynaLoader','Errno','Exporter','File::Basename','POSIX','constant','strict','warnings']},'Mail-Address-MobileJp-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'mobile email address in Japan','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 45,'pod_errors' => 0,'total' => 140,'with_comments' => 2},'releases' => 3,'requires' => ['MailTools-1.58.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Mail::Address' => 0,'Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2256,'unpacked' => 5410},'testers' => {'pass' => 1},'uses' => ['Exporter','strict','vars']},'Mail-Address-Tagged-0.01.tar.gz' => {'author' => 'NUANCE','description' => 'construct and validate email addresses with HMAC verification','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 370,'pod' => 316,'pod_errors' => 0,'total' => 686,'with_comments' => 21},'releases' => 1,'requires' => ['Digest-HMAC-1.01.tar.gz','Digest-SHA1-2.04.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Digest::HMAC' => '1.01','Digest::SHA1' => 2,'Test::More' => '0.17'},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8977,'unpacked' => 39580},'testers' => {'pass' => 4},'uses' => ['Digest::HMAC','Digest::SHA1','strict']},'Mail-AddressSort-1.tar.gz' => {'author' => 'CHRISJ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 228,'pod' => 73,'pod_errors' => 0,'total' => 301,'with_comments' => 31},'releases' => 1,'size' => {'packed' => 4804,'unpacked' => 11512},'testers' => {'pass' => 5},'uses' => ['strict','vars']},'Mail-Addressbook-Convert-1.1.tar.gz' => {'author' => 'INTERGURU','description' => 'convert to and from many e-mail addressbooks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2883,'pod' => 1780,'pod_errors' => 0,'total' => 4663,'with_comments' => 234},'releases' => 2,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Text::ParseWords' => '3.1'},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 30440,'unpacked' => 141168},'testers' => {'pass' => 3},'uses' => ['5.001','Carp','File::Basename','Text::ParseWords','strict','vars']},'Mail-Alias-1.12.tar.gz' => {'author' => 'ZELT','description' => 'Manipulate E-mail aliases and alias files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 731,'pod' => 55,'pod_errors' => 0,'total' => 786,'with_comments' => 160},'releases' => 3,'size' => {'packed' => 10650,'unpacked' => 31579},'testers' => {'pass' => 13},'uses' => ['Carp','Mail::Address','vars']},'Mail-Audit-2.1.tar.gz' => {'author' => 'SIMON','description' => 'Library for creating easy mail filters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1086,'pod' => 400,'pod_errors' => 4,'total' => 1486,'with_comments' => 153},'releases' => 14,'requires' => ['MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Fcntl' => 0,'MIME::Entity' => 0,'Mail::Internet' => 0,'Mail::Mailer' => 0,'Net::SMTP' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21669,'unpacked' => 61583},'testers' => {'fail' => 1,'pass' => 33},'uses' => ['Errno','Fcntl','File::Basename','File::Path','MIME::Entity','MIME::Parser','Mail::Internet','Mail::ListDetector','Mail::Mailer','Net::SMTP','POSIX','Razor::Agent','Razor::Client','Razor::String','Sys::Hostname','constant','strict','vars']},'Mail-Audit-Attach-0.93.tar.gz' => {'author' => 'CRENZ','description' => 'Mail::Audit plugin for attachment handling.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 254,'pod' => 124,'pod_errors' => 0,'total' => 378,'with_comments' => 10},'releases' => 4,'requires' => ['MIME-tools-5.411a.tar.gz','Mail-Audit-2.1.tar.gz','MailTools-1.58.tar.gz'],'requires_module' => {'MIME::Entity' => 5,'MIME::Head' => 5,'Mail::Audit' => 2,'Mail::Header' => 1},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','Mail-Audit-2.1.tar.gz','MailTools-1.58.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4545,'unpacked' => 13342},'testers' => {'pass' => 3},'uses' => ['File::Spec','MIME::Entity','MIME::Head','strict','vars']},'Mail-Audit-Qmail-0.90.tar.gz' => {'author' => 'ABH','description' => 'Mail::Audit plugin to resend using qmail-inject','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 33,'pod_errors' => 0,'total' => 65,'with_comments' => 0},'releases' => 1,'requires' => ['Mail-Audit-2.1.tar.gz'],'requires_module' => {'Mail::Audit' => 2},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','Mail-Audit-2.1.tar.gz','MailTools-1.58.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 1572,'unpacked' => 2727},'testers' => {'pass' => 4},'uses' => ['Mail::Audit','strict','vars']},'Mail-Box-1.324.tar.gz' => {'author' => 'MARKOV','description' => 'Manage a message-folder.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6060,'pod' => 3060,'pod_errors' => 1,'total' => 9120,'with_comments' => 617},'releases' => 82,'requires' => ['Errno-1.09.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','TimeDate-1.16.tar.gz'],'requires_module' => {'Date::Parse' => 0,'Errno' => 0,'File::Spec' => '0.7','IO::Scalar' => 0,'MIME::Tools' => 5,'Mail::Internet' => 1},'requires_recursive' => ['Errno-1.09.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 128102,'unpacked' => 473487},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Date::Parse','Errno','Exporter','Fcntl','File::Basename','File::Copy','File::Spec','FileHandle','IO::File','IO::InnerFile','IO::Scalar','MIME::Entity','MIME::Parser','Mail::Box','Mail::Box::Locker','Mail::Box::MH::Message','Mail::Box::Mbox::Message','Mail::Box::Message','POSIX','Sys::Hostname','overload','strict','vars','warnings']},'Mail-Box-2.043.tar.gz' => {'author' => 'MARKOV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 33189,'pod' => 37612,'pod_errors' => 0,'total' => 70801,'with_comments' => 1614},'releases' => 82,'requires' => ['Errno-1.09.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Types-1.06.tar.gz','MailTools-1.58.tar.gz','Object-Realize-Later-0.12.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Date::Parse' => 0,'Errno' => 0,'File::Spec' => '0.7','MIME::Base64' => 0,'MIME::Types' => '1.004','Mail::Address' => 0,'Object::Realize::Later' => '0.12','Scalar::Util' => '1.07','Sys::Hostname' => 0,'Test::More' => '0.47'},'requires_recursive' => ['Errno-1.09.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Types-1.06.tar.gz','MailTools-1.58.tar.gz','Object-Realize-Later-0.12.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 450522,'unpacked' => 2081382},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.007003','Carp','Cwd','Date::Parse','Errno','Exporter','Fcntl','File::Basename','File::Copy','File::Spec','HTML::FormatText','HTML::TreeBuilder','IO::File','IO::Lines','List::Util','MIME::Base64','MIME::Body','MIME::Entity','MIME::QuotedPrint','MIME::Types','Mail::Address','Mail::Header','Mail::Internet','Mail::Message::Construct','Mail::SpamAssassin','Mail::SpamAssassin::Message','Mail::Transport::Dbx','Net::Config','Net::Domain','Net::SMTP','Object::Realize::Later','POSIX','Scalar::Util','Sys::Hostname','Test::More','Text::Autoformat','integer','overload','strict','utf','vars','warnings']},'Mail-Box-MH-Resource-0.05.tgz' => {'author' => 'JPIERCE','description' => 'Manage an MH resource file such as the MH profile','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 109,'pod' => 73,'pod_errors' => 0,'total' => 182,'with_comments' => 2},'releases' => 1,'requires' => ['File-Spec-0.82.tar.gz','Mail-Box-2.043.tar.gz'],'requires_module' => {'File::Spec' => 0,'Mail::Reporter' => 0},'requires_recursive' => ['Errno-1.09.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Types-1.06.tar.gz','Mail-Box-2.043.tar.gz','MailTools-1.58.tar.gz','Object-Realize-Later-0.12.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3287,'unpacked' => 7134},'testers' => {'pass' => 2},'uses' => ['5.006','Cwd','Data::Dumper','File::Spec','Mail::Reporter']},'Mail-Box-Parser-C-2.034.tar.gz' => {'author' => 'MARKOV','description' => 'extends Mail::Box with the speed of C','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 155,'pod' => 21,'pod_errors' => 0,'total' => 176,'with_comments' => 20},'releases' => 2,'requires' => ['Mail-Box-2.043.tar.gz'],'requires_module' => {'Mail::Box' => '2.032'},'requires_recursive' => ['Errno-1.09.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Types-1.06.tar.gz','Mail-Box-2.043.tar.gz','MailTools-1.58.tar.gz','Object-Realize-Later-0.12.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7335,'unpacked' => 26956},'testers' => {'pass' => 1},'uses' => ['Carp','DynaLoader','Exporter','Mail::Box::Parser','Mail::Message::Field','strict','warnings']},'Mail-Bulkmail-3.09.tar.gz' => {'author' => 'JIMT','description' => 'Platform independent mailing list module','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 3706,'pod' => 3237,'pod_errors' => 2,'total' => 6943,'with_comments' => 463},'releases' => 19,'size' => {'packed' => 69027,'unpacked' => 238417},'testers' => {'pass' => 4},'uses' => ['5.6.0','Socket','strict','warnings']},'Mail-Cclient-1.1.tar.gz' => {'author' => 'MICB','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 336,'pod' => 581,'pod_errors' => 12,'total' => 917,'with_comments' => 10},'releases' => 13,'size' => {'packed' => 27199,'unpacked' => 90940},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Mail-Centipaid-1.0.tar.gz' => {'author' => 'AELFAKIH','description' => 'Mail::Audit plugin to check for email postage','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 266,'pod' => 157,'pod_errors' => 0,'total' => 423,'with_comments' => 42},'releases' => 1,'requires' => ['IO-1.20.tar.gz','Mail-Audit-2.1.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'IO::Socket' => 0,'Mail::Audit' => 0,'Net::hostent' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','Mail-Audit-2.1.tar.gz','MailTools-1.58.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8760,'unpacked' => 23351},'testers' => {'pass' => 3},'uses' => ['5.005','IO::Socket','Mail::Audit','Net::hostent','vars']},'Mail-CheckUser-1.19.tar.gz' => {'author' => 'ILYAM','description' => 'Check email addresses for validity','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 486,'pod' => 191,'pod_errors' => 0,'total' => 677,'with_comments' => 65},'releases' => 21,'requires' => ['IO-1.20.tar.gz','Net-DNS-0.38.tar.gz','Net-Ping-2.31.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'IO::Handle' => '1.21','Net::DNS' => '0.31','Net::Ping' => '2.24','Net::SMTP' => '2.13'},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','Net-Ping-2.31.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11227,'unpacked' => 33616},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','IO::Handle','Net::DNS','Net::Ping','Net::SMTP','constant','strict','vars']},'Mail-Classifier-0.11.tar.gz' => {'author' => 'DAGOLDEN','description' => 'Perl extension for probabilistic mail classification','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1037,'pod' => 644,'pod_errors' => 0,'total' => 1681,'with_comments' => 59},'releases' => 2,'requires' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','MLDBM-2.01.tar.gz','MLDBM-Sync-0.30.tar.gz','Mail-Box-2.043.tar.gz','MailTools-1.58.tar.gz','Storable-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Copy' => 0,'File::Spec' => 0,'File::Temp' => 0,'MLDBM' => 0,'MLDBM::Sync' => 0,'Mail::Address' => 0,'Mail::Box' => 0,'Storable' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Errno-1.09.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Types-1.06.tar.gz','MLDBM-2.01.tar.gz','MLDBM-Sync-0.30.tar.gz','Mail-Box-2.043.tar.gz','MailTools-1.58.tar.gz','Object-Realize-Later-0.12.tar.gz','Scalar-List-Utils-1.11.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 129111,'unpacked' => 502198},'testers' => {'pass' => 1},'uses' => ['5.008','Carp','Fcntl','File::Copy','File::Spec','File::Temp','MLDBM','MLDBM::Sync','Mail::Address','Mail::Box::Manager','Storable','strict','warnings']},'Mail-Date-0.08.tar.gz' => {'author' => 'HATA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 55,'pod' => 56,'pod_errors' => 0,'total' => 111,'with_comments' => 1},'releases' => 8,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Exporter' => '5.566'},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 3706,'unpacked' => 7939},'testers' => {'pass' => 3},'uses' => ['5.008','Carp','Exporter','strict','warnings']},'Mail-DeliveryStatus-BounceParser-1.4.tar.gz' => {'author' => 'FREESIDE','description' => 'Perl extension to analyze bounce messages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1100,'pod' => 165,'pod_errors' => 0,'total' => 1265,'with_comments' => 283},'releases' => 4,'requires' => ['MIME-tools-5.411a.tar.gz'],'requires_module' => {'MIME::Entity' => '5.404'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14702,'unpacked' => 46820},'testers' => {'pass' => 2},'uses' => ['5.00503','Data::Dumper','MIME::Parser','Mail::Header','strict','vars']},'Mail-EXPN-0.04.tar.gz' => {'author' => 'FLORIAN','description' => 'Perl extension for validation of email addresses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 57,'pod_errors' => 0,'total' => 163,'with_comments' => 2},'releases' => 3,'requires' => ['Net-DNS-0.38.tar.gz'],'requires_module' => {'Net::DNS' => 0},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3077,'unpacked' => 7306},'testers' => {'pass' => 5},'uses' => ['Exporter','IO::Socket','Net::DNS','Net::SMTP','strict','vars']},'Mail-ExpandAliases-0.44.tar.gz' => {'author' => 'DARREN','description' => 'Expand aliases from /etc/aliases files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 351,'pod' => 79,'pod_errors' => 0,'total' => 430,'with_comments' => 142},'releases' => 3,'size' => {'packed' => 11108,'unpacked' => 33512},'testers' => {'pass' => 2},'uses' => ['IO::File','constant','strict','vars']},'Mail-Field-Received-0.24.tar.gz' => {'author' => 'ASPIERS','description' => 'Parses Received headers as per RFC822','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 648,'pod' => 142,'pod_errors' => 0,'total' => 790,'with_comments' => 67},'releases' => 4,'requires' => ['MailTools-1.58.tar.gz'],'requires_module' => {'Mail::Field' => 0},'requires_recursive' => ['MailTools-1.58.tar.gz'],'size' => {'packed' => 10398,'unpacked' => 41001},'testers' => {'pass' => 3},'uses' => ['5.005','Carp','strict','vars']},'Mail-FilterXML-0.3.tar.gz' => {'author' => 'MATTMK','description' => 'Filter email based on a rules file written in XML.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 249,'pod' => 35,'pod_errors' => 0,'total' => 284,'with_comments' => 25},'releases' => 2,'size' => {'packed' => 4365,'unpacked' => 11357},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['Mail::Audit','XML::Parser','strict','vars']},'Mail-Freshmeat-1.20.tar.gz' => {'author' => 'FOX','description' => 'parses daily newsletters from http://freshmeat.net/','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 791,'pod' => 179,'pod_errors' => 1,'total' => 970,'with_comments' => 62},'releases' => 6,'requires' => ['MailTools-1.58.tar.gz'],'requires_module' => {'Mail::Internet' => 0},'requires_recursive' => ['MailTools-1.58.tar.gz'],'size' => {'packed' => 295167,'unpacked' => 940833},'testers' => {'fail' => 3,'pass' => 9},'uses' => ['5.005','Carp','Exporter','Mail::Internet','strict','vars']},'Mail-GnuPG-0.06.tar.gz' => {'author' => 'RSPIER','description' => 'MIME Email <-> GnuPG::Interface interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 701,'pod' => 205,'pod_errors' => 0,'total' => 906,'with_comments' => 85},'releases' => 6,'requires' => ['File-Temp-0.12.tar.gz','GnuPG-Interface-0.33.tar.gz','IO-1.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz'],'requires_module' => {'File::Temp' => 0,'GnuPG::Interface' => 0,'IO::Handle' => 0,'MIME::Entity' => 0,'MIME::Parser' => 0,'Mail::Address' => 0},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','GnuPG-Interface-0.33.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7608,'unpacked' => 26974},'testers' => {'pass' => 1},'uses' => ['5.006','File::Temp','GnuPG::Interface','IO::Handle','MIME::Entity','MIME::Parser','Mail::Address','strict','warnings']},'Mail-Graph-0.10.tar.gz' => {'author' => 'TELS','description' => 'draw graphical stats for mails/spams','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 970,'pod' => 104,'pod_errors' => 0,'total' => 1074,'with_comments' => 92},'releases' => 6,'requires' => ['Date-Calc-5.3.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','IO-stringy-2.108.tar.gz','MIME-tools-5.411a.tar.gz','Mail-MboxParser-0.38.tar.gz','MailTools-1.58.tar.gz'],'requires_module' => {'Date::Calc' => 5,'GD' => '1.38','GD::Graph' => '1.33','GD::Text' => '0.82','IO::Stringy' => '2.01','MIME::Tools' => '5.411','Mail::MboxParser' => '0.32','Mail::Util' => '1.44'},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Date-Calc-5.3.tar.gz','File-Spec-0.82.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','Mail-MboxParser-0.38.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18827,'unpacked' => 49559},'testers' => {'pass' => 1},'uses' => ['Data::Dumper','Date::Calc','Exporter','GD::Graph::Data','GD::Graph::Error','GD::Graph::bars','GD::Graph::colour','GD::Graph::lines','strict','vars']},'Mail-IMAPClient-2.2.8.tar.gz' => {'author' => 'DJKERNEN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6021,'pod' => 2591,'pod_errors' => 0,'total' => 8612,'with_comments' => 527},'releases' => 39,'requires' => ['Data-Dumper-2.101.tar.gz','Errno-1.09.tar.gz','IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => 0,'Errno' => 0,'Fcntl' => 0,'IO::File' => 0,'IO::Select' => 0,'IO::Socket' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Errno-1.09.tar.gz','IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 374554,'unpacked' => 1370222},'testers' => {'fail' => 2,'tests' => '8'},'uses' => ['Carp','Data::Dumper','Digest::HMAC_MD5','Errno','Exporter','Fcntl','MIME::Base64','Mail::IMAPClient::BodyStructure::Parse','Parse::RecDescent','constant','overload','vars']},'Mail-ISO2022JP-0.06.tar.gz' => {'author' => 'HATA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 400,'pod' => 143,'pod_errors' => 0,'total' => 543,'with_comments' => 39},'releases' => 6,'requires' => ['Encode-1.97.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'Encode' => '1.83','MIME::Base64' => '2.12'},'requires_recursive' => ['Encode-1.97.tar.gz','MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 6850,'unpacked' => 26823},'testers' => {'pass' => 2},'uses' => ['5.008','Carp','Encode','MIME::Base64','strict','warnings']},'Mail-IspMailGate-1.1011.tar.gz' => {'author' => 'JWIED','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2743,'pod' => 607,'pod_errors' => 0,'total' => 3350,'with_comments' => 636},'releases' => 7,'size' => {'packed' => 50692,'unpacked' => 195076},'testers' => {'fail' => 2,'pass' => 1,'tests' => '51'},'uses' => ['5.002','5.004','5.005','Data::Dumper','Exporter','File::Basename','File::Path','HTML::Parser','MIME::Decoder','MIME::Decoder::PGP','MIME::Parser','Mail::IspMailGate','Mail::IspMailGate::Config','Mail::IspMailGate::Filter','Mail::IspMailGate::Parser','Symbol','Sys::Syslog','attrs','strict','vars']},'Mail-IspMailGate-1.1013.tar.gz' => {'author' => 'JWIED','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2748,'pod' => 612,'pod_errors' => 0,'total' => 3360,'with_comments' => 640},'releases' => 7,'size' => {'packed' => 50845,'unpacked' => 195554},'testers' => {'fail' => 2,'pass' => 1,'tests' => '51'},'uses' => ['5.002','5.004','5.005','Data::Dumper','Exporter','File::Basename','File::Path','HTML::Parser','MIME::Decoder','MIME::Parser','Mail::IspMailGate::Config','Symbol','Sys::Syslog','attrs','strict','vars']},'Mail-LMLM-0.6.0.tar.gz' => {'author' => 'SHLOMIF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1823,'pod' => 223,'pod_errors' => 0,'total' => 2046,'with_comments' => 1},'releases' => 4,'size' => {'packed' => 14645,'unpacked' => 58137},'testers' => {'pass' => 1},'uses' => ['strict','vars']},'Mail-ListDetector-0.25.tar.gz' => {'author' => 'MSTEVENS','description' => 'Perl extension for detecting mailing list messages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 920,'pod' => 525,'pod_errors' => 0,'total' => 1445,'with_comments' => 19},'releases' => 16,'requires' => ['Email-Valid-0.14.tar.gz','MailTools-1.58.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Email::Valid' => '0.12','Mail::Internet' => '1.33','Test::More' => '0.08','URI' => '1.1'},'requires_recursive' => ['Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21815,'unpacked' => 81479},'testers' => {'pass' => 1},'uses' => ['AutoLoader','Carp','Email::Valid','Exporter','URI','strict','vars']},'Mail-ListDetector-Detector-Fml-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'FML message detector','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 47,'pod' => 33,'pod_errors' => 0,'total' => 80,'with_comments' => 2},'releases' => 3,'requires' => ['Mail-ListDetector-0.25.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'Mail::ListDetector' => '0.18','Test::More' => '0.32','URI' => 0},'requires_recursive' => ['Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','Mail-ListDetector-0.25.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2367,'unpacked' => 4823},'testers' => {'pass' => 3},'uses' => ['Mail::ListDetector','Mail::ListDetector::Detector::Base','URI','strict','vars']},'Mail-LocalDelivery-0.1.tar.gz' => {'author' => 'SIMON','description' => 'Deliver mail to a local mailbox','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 469,'pod' => 87,'pod_errors' => 0,'total' => 556,'with_comments' => 86},'releases' => 1,'size' => {'packed' => 7681,'unpacked' => 20558},'testers' => {'pass' => 7},'uses' => ['Carp','Errno','Fcntl','File::Basename','Mail::Internet','POSIX','Sys::Hostname','constant','strict','vars']},'Mail-MboxParser-0.17.tar.gz' => {'author' => 'VPARSEVAL','description' => 'read-only access to UNIX-mailboxes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 798,'pod' => 468,'pod_errors' => 0,'total' => 1266,'with_comments' => 73},'releases' => 31,'requires' => ['MIME-tools-5.411a.tar.gz'],'requires_module' => {'MIME::Tools' => 5},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 26002,'unpacked' => 83536},'testers' => {'pass' => 4},'uses' => ['5.004','Carp','Exporter','MIME::Parser','Mail::MboxParser::Base','Mail::MboxParser::Mail','Mail::MboxParser::Mail::Body','URI::Find','strict','vars']},'Mail-MboxParser-0.38.tar.gz' => {'author' => 'VPARSEVAL','description' => 'read-only access to UNIX-mailboxes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1416,'pod' => 831,'pod_errors' => 0,'total' => 2247,'with_comments' => 121},'releases' => 31,'requires' => ['MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz'],'requires_module' => {'MIME::QuotedPrint' => 0,'MIME::Tools' => 5},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 37488,'unpacked' => 128566},'testers' => {'pass' => 7},'uses' => ['5.004','Carp','Exporter','IO::File','MIME::Parser','MIME::QuotedPrint','MIME::Words','Symbol','URI::Find','strict','vars']},'Mail-Miner-1.01.tar.gz' => {'author' => 'SIMON','description' => 'Store and retrieve Useful Information from mail','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 707,'pod' => 177,'pod_errors' => 0,'total' => 884,'with_comments' => 31},'releases' => 6,'requires' => ['DBD-Pg-1.22.tar.gz','DBI-1.37.tar.gz','DateManip-5.42a.tar.gz','Lingua-EN-Keywords-2.0.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz'],'requires_module' => {'DBD::Pg' => 0,'DBI' => 0,'Date::Manip' => 0,'Lingua::EN::Keywords' => 0,'MIME::Parser' => 0,'Mail::Address' => 0},'requires_recursive' => ['DBD-Pg-1.22.tar.gz','DBI-1.37.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','Lingua-EN-Keywords-2.0.tar.gz','Lingua-EN-Tagger-0.02.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','PerlIO-gzip-0.15.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-German-0.03.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12438,'unpacked' => 34360},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['5.006','DBI','Date::Manip','Exporter','File::Spec::Functions','Lingua::EN::Keywords','MIME::Base64','MIME::Parser','Mail::Address','Mail::Miner','Mail::Miner::Assets','Mail::Miner::Attachment','Mail::Miner::DBI','strict','vars','warnings']},'Mail-Miner-2.3.tar.gz' => {'author' => 'SIMON','description' => 'Store and retrieve Useful Information from mail','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 564,'pod' => 101,'pod_errors' => 0,'total' => 665,'with_comments' => 33},'releases' => 6,'requires' => ['Class-DBI-0.93.tar.gz','Class-DBI-mysql-0.15.tar.gz','Date-PeriodParser-0.02.tar.gz','Lingua-EN-Keywords-2.0.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz'],'requires_module' => {'Class::DBI' => '0.9','Class::DBI::mysql' => 0,'Date::PeriodParser' => 0,'Lingua::EN::Keywords' => 0,'MIME::Parser' => 0,'Mail::Address' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-DBI-mysql-0.15.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Date-PeriodParser-0.02.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Lingua-EN-Keywords-2.0.tar.gz','Lingua-EN-Tagger-0.02.tar.gz','Lingua-EN-Words2Nums-0.11.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','PerlIO-gzip-0.15.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-German-0.03.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15292,'unpacked' => 42009},'testers' => {},'uses' => ['5.006','Carp','Class::DBI::mysql','Date::Manip','Date::PeriodParser','Exporter','File::Spec::Functions','Lingua::EN::Keywords','MIME::Parser','Mail::Address','strict','vars','warnings']},'Mail-MsgStore-1.51.tar.gz' => {'author' => 'FIVE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1120,'pod' => 265,'pod_errors' => 0,'total' => 1385,'with_comments' => 121},'releases' => 1,'requires' => ['Sys-UniqueID-1.0.tar.gz','Time-modules-2003.0211.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz','perl-ldap-0.29.tar.gz'],'requires_module' => {'Carp' => 0,'File::Find' => 0,'File::Path' => 0,'Net::LDAP' => 0,'Net::POP3' => '2.2','Sys::UniqueID' => 0,'Time::ParseDate' => 0},'requires_recursive' => ['Convert-ASN1-0.17.tar.gz','IO-1.20.tar.gz','Sys-HostIP-1.0.tar.gz','Sys-UniqueID-1.0.tar.gz','Time-modules-2003.0211.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz','perl-ldap-0.29.tar.gz'],'size' => {'packed' => 12852,'unpacked' => 39210},'testers' => {'fail' => 6},'uses' => ['Carp','Exporter','File::Find','File::Path','MIME::Entity','Mail::Address','Mail::Internet','Net::LDAP','Net::POP3','Sys::UniqueID','Time::ParseDate','strict','vars']},'Mail-POP3Client-2.14.tar.gz' => {'author' => 'SDOWD','description' => 'Support for clients of POP3 servers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1225,'pod' => 276,'pod_errors' => 0,'total' => 1501,'with_comments' => 218},'releases' => 1,'size' => {'packed' => 15907,'unpacked' => 58101},'testers' => {'pass' => 3},'uses' => ['Carp','Digest::HMAC_MD5','Digest::MD5','Exporter','IO::Socket','IO::Socket::SSL','MIME::Base64','strict','vars']},'Mail-POP3Server-2.22.tar.gz' => {'author' => 'MTIRAMANI','description' => '- A POP3 stand-alone forking daemon or inetd server mpopd complies with: RFC 1939 but one or two recommendations can be overridden in the configuration file: mpopd allows rejection of bogus UIDs as a configurable option. mpopd allows a timeout of n seconds as a configuration item. mpopd supports UIDL and TOP but not APOP. The documentation is minimal at present. There are pod docs in the mpopd, mpodctl and mpopd_test scripts.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1653,'pod' => 179,'pod_errors' => 0,'total' => 1832,'with_comments' => 204},'releases' => 2,'size' => {'packed' => 29968,'unpacked' => 92701},'testers' => {},'uses' => ['$config_file','Exporter','Socket','strict','vars']},'Mail-POPRelay-2.1.1.tar.gz' => {'author' => 'KHOERLING','description' => 'Dynamic Relay Access Control','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 573,'pod' => 295,'pod_errors' => 3,'total' => 868,'with_comments' => 58},'releases' => 5,'requires' => ['Data-Dumper-2.101.tar.gz','File-Tail-0.98.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => 0,'File::Tail' => 0,'POSIX' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Tail-0.98.tar.gz','IO-1.20.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13546,'unpacked' => 46088},'testers' => {'pass' => 3},'uses' => ['Data::Dumper','File::Tail','POSIX','constant','strict','vars']},'Mail-PopPwd-0.02.tar.gz' => {'author' => 'HDIAS','description' => 'Perl 5 module to talk to a poppasswd daemon','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 159,'pod_errors' => 0,'total' => 320,'with_comments' => 9},'releases' => 2,'requires' => ['Crypt-Cracklib-0.01.tar.gz'],'requires_module' => {'Crypt::Cracklib' => '0.01'},'requires_recursive' => ['Crypt-Cracklib-0.01.tar.gz'],'size' => {'packed' => 4303,'unpacked' => 10336},'testers' => {},'uses' => ['5','Crypt::Cracklib','Exporter','IO::Socket','strict','vars']},'Mail-Procmail-1.05.tar.gz' => {'author' => 'JV','description' => 'Procmail-like facility for creating easy mai','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 553,'pod' => 383,'pod_errors' => 0,'total' => 936,'with_comments' => 43},'releases' => 11,'requires' => ['Getopt-Long-2.33.tar.gz','LockFile-Simple-0.2.5.tar.gz','MailTools-1.58.tar.gz'],'requires_module' => {'Getopt::Long' => 2,'LockFile::Simple' => 0,'Mail::Internet' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','LockFile-Simple-0.2.5.tar.gz','MailTools-1.58.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 13845,'unpacked' => 38697},'testers' => {'pass' => 3},'uses' => ['5.005','Carp','Exporter','Fcntl','IO::File','LockFile::Simple','Mail::Internet','Sys::Hostname','constant','strict','vars']},'Mail-Procmailrc-1.04.tar.gz' => {'author' => 'SCOTTW','description' => '(OO) read/write/parse procmail(1) rc files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 849,'pod' => 429,'pod_errors' => 0,'total' => 1278,'with_comments' => 114},'releases' => 7,'size' => {'packed' => 22066,'unpacked' => 86615},'testers' => {'pass' => 4},'uses' => ['Carp','strict','vars']},'Mail-QmailQueue-0.03.tar.gz' => {'author' => 'IKEBE','description' => 'Perl extension to operate qmail-queue directly','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 131,'pod' => 76,'pod_errors' => 0,'total' => 207,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 2820,'unpacked' => 6450},'testers' => {'pass' => 4},'uses' => ['Carp','IO::Handle','IO::Pipe','strict','vars']},'Mail-QmailRemote-0.02.tar.gz' => {'author' => 'IKEBE','description' => 'send email using qmail-remote directly.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 91,'pod_errors' => 1,'total' => 240,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 2477,'unpacked' => 5287},'testers' => {'fail' => 3,'pass' => 2},'uses' => ['IPC::Open3','Net::DNS','strict','vars']},'Mail-Query-0.01.tar.gz' => {'author' => 'KWILLIAMS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 220,'pod' => 109,'pod_errors' => 0,'total' => 329,'with_comments' => 20},'releases' => 1,'requires' => ['Mail-Audit-2.1.tar.gz','Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Mail::Audit' => 0,'Parse::RecDescent' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','Mail-Audit-2.1.tar.gz','MailTools-1.58.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7516,'unpacked' => 21405},'testers' => {'fail' => 3,'pass' => 2},'uses' => ['5.005_62','Mail::Audit','Parse::RecDescent','strict','warnings']},'Mail-RBL-1.00.tar.gz' => {'author' => 'LUISMUNOZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 37,'pod_errors' => 0,'total' => 110,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2131,'unpacked' => 4406},'testers' => {'pass' => 6},'uses' => ['5.005_62','Carp','strict','warnings']},'Mail-RFC822-Address-0.3.tar.gz' => {'author' => 'PDWARREN','description' => 'Perl extension for validating email addresses according to RFC822','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 53,'pod_errors' => 0,'total' => 200,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 5239,'unpacked' => 12531},'testers' => {'pass' => 6},'uses' => ['Exporter','strict','vars']},'Mail-SMI-0.01.tar.gz' => {'author' => 'DFROZ','description' => 'SMTP and Mail Interface Module','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 253,'pod' => 86,'pod_errors' => 1,'total' => 339,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 3040,'unpacked' => 7957},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['POSIX','Socket','strict','vars']},'Mail-SPF-Query-1.4.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 327,'pod' => 126,'pod_errors' => 0,'total' => 453,'with_comments' => 49},'releases' => 4,'requires' => ['Net-DNS-0.38.tar.gz'],'requires_module' => {'Net::DNS' => '0.33'},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'testers' => {'pass' => 1},'uses' => ['5.006','strict','vars','warnings']},'Mail-Sender-0.8.06.tar.gz' => {'author' => 'JENDA','description' => 'socket() based mail with attachments, SMTP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1838,'pod' => 1175,'pod_errors' => 0,'total' => 3013,'with_comments' => 97},'releases' => 19,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::Base64' => 0},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 28409,'unpacked' => 100493},'testers' => {'pass' => 3},'uses' => ['Authen::NTLM','Carp','Digest::HMAC_MD5','Exporter','File::Basename','FileHandle','IO::Handle','MIME::Base64','MIME::QuotedPrint','Socket','Symbol','Tie::Handle','open','strict','vars','warnings']},'Mail-Sendmail-0.79.tar.gz' => {'author' => 'MIVKOVIC','description' => 'Simple platform independent mailer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 459,'pod' => 343,'pod_errors' => 0,'total' => 802,'with_comments' => 78},'releases' => 9,'size' => {'packed' => 16245,'unpacked' => 64742},'testers' => {'pass' => 12},'uses' => ['Exporter','Socket','Sys::Hostname','Time::Local','strict','vars']},'Mail-SimpleList-0.70.tar.gz' => {'author' => 'CHROMATIC','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 642,'pod' => 292,'pod_errors' => 0,'total' => 934,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 19135,'unpacked' => 66430},'testers' => {},'uses' => ['Carp','Fcntl','File::Path','File::Spec','Mail::Address','Mail::Internet','Mail::Mailer','YAML','strict','vars']},'Mail-Sort-2003.03.18.tar.gz' => {'author' => 'THEDEVIL','description' => 'Yet another procmail alike for to split mail','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 703,'pod' => 424,'pod_errors' => 0,'total' => 1127,'with_comments' => 15},'releases' => 10,'requires' => ['MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'FileHandle' => '2.00','Mail::Header' => '1.19','Mail::Internet' => '1.33','POSIX' => '1.03'},'requires_recursive' => ['MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 22094,'unpacked' => 65950},'testers' => {'pass' => 2},'uses' => ['Config','FileHandle','Mail::Header','Mail::Internet','Mail::SpamAssassin','POSIX','Razor::Client','Razor::Config','Razor::String','constant','strict']},'Mail-SpamAssassin-2.01.tar.gz' => {'author' => 'JMASON','description' => 'Mail::Audit spam detector plugin','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5722,'pod' => 766,'pod_errors' => 1,'total' => 6488,'with_comments' => 699},'releases' => 20,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'File::Copy' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 181135,'unpacked' => 560647},'testers' => {'fail' => 2,'pass' => 3,'tests' => '152'},'uses' => ['$file','5.001','AnyDBM_File','AutoLoader','Carp','Config','Cwd','DBI','Exporter','Fcntl','File::Basename','File::Copy','File::Path','File::Spec','IO::Socket','MIME::Base64','Mail::Audit','Mail::Internet','Mail::SpamAssassin','Mail::SpamAssassin::AuditMessage','Mail::SpamAssassin::AutoWhitelist','Mail::SpamAssassin::Conf','Mail::SpamAssassin::ConfSourceSQL','Mail::SpamAssassin::Dns','Mail::SpamAssassin::EncappedMessage','Mail::SpamAssassin::EvalTests','Mail::SpamAssassin::ExposedMessage','Mail::SpamAssassin::Locales','Mail::SpamAssassin::Message','Mail::SpamAssassin::NoMailAudit','Mail::SpamAssassin::PerMsgStatus','Mail::SpamAssassin::PersistentAddrList','Mail::SpamAssassin::PhraseFreqs','Mail::SpamAssassin::Replier','Mail::SpamAssassin::Reporter','Net::DNS','Net::DNS::Resolver','Net::SMTP','Razor::Agent','Razor::Client','Sys::Hostname','Time::Local','strict','vars']},'Mail-SpamAssassin-2.43.tar.gz' => {'author' => 'MSERGEANT','description' => 'Mail::Audit spam detector plugin','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10158,'pod' => 1163,'pod_errors' => 3,'total' => 11321,'with_comments' => 1394},'releases' => 20,'requires' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','PodParser-1.23.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Copy' => 0,'File::Spec' => '0.8','HTML::Parser' => 3,'Pod::Usage' => 0,'Text::Wrap' => 0,'Time::Local' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','PodParser-1.23.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 538505,'unpacked' => 1489340},'testers' => {'pass' => 4},'uses' => ['$file','5.002','5.005','AnyDBM_File','Archive::Tar','Carp','Config','Cwd','DBI','Exporter','Fcntl','File::Basename','File::Copy','File::Path','File::Spec','IO::Socket','IPC::Open2','MIME::Base64','MIME::Body','Mail::Audit','Mail::Internet','Mail::SpamAssassin','Mail::SpamAssassin::AuditMessage','Mail::SpamAssassin::AutoWhitelist','Mail::SpamAssassin::Conf','Mail::SpamAssassin::ConfSourceSQL','Mail::SpamAssassin::Dns','Mail::SpamAssassin::EncappedMessage','Mail::SpamAssassin::EvalTests','Mail::SpamAssassin::ExposedMessage','Mail::SpamAssassin::Locales','Mail::SpamAssassin::Message','Mail::SpamAssassin::NoMailAudit','Mail::SpamAssassin::PerMsgStatus','Mail::SpamAssassin::PersistentAddrList','Mail::SpamAssassin::PhraseFreqs','Mail::SpamAssassin::Replier','Mail::SpamAssassin::Reporter','Net::DNS','Net::DNS::Resolver','POSIX','Razor2::Client::Agent','Razor::Agent','Razor::Client','Sys::Hostname','Text::Wrap','Time::Local','integer','strict','vars']},'Mail-SpamAssassin-2.44.tar.gz' => {'author' => 'JMASON','description' => 'Mail::Audit spam detector plugin','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10167,'pod' => 1163,'pod_errors' => 3,'total' => 11330,'with_comments' => 1396},'releases' => 20,'requires' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','PodParser-1.23.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Copy' => 0,'File::Spec' => '0.8','HTML::Parser' => 3,'Pod::Usage' => 0,'Text::Wrap' => 0,'Time::Local' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','PodParser-1.23.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 525059,'unpacked' => 1437247},'testers' => {'pass' => 2},'uses' => ['$file','5.002','5.005','AnyDBM_File','Archive::Tar','Carp','Config','Cwd','DBI','Exporter','Fcntl','File::Basename','File::Copy','File::Path','File::Spec','IO::Socket','IPC::Open2','MIME::Base64','MIME::Body','Mail::Audit','Mail::Internet','Mail::SpamAssassin','Mail::SpamAssassin::AuditMessage','Mail::SpamAssassin::AutoWhitelist','Mail::SpamAssassin::Conf','Mail::SpamAssassin::ConfSourceSQL','Mail::SpamAssassin::Dns','Mail::SpamAssassin::EncappedMIME','Mail::SpamAssassin::EncappedMessage','Mail::SpamAssassin::EvalTests','Mail::SpamAssassin::HTML','Mail::SpamAssassin::Locales','Mail::SpamAssassin::MailingList','Mail::SpamAssassin::Message','Mail::SpamAssassin::NoMailAudit','Mail::SpamAssassin::PerMsgStatus','Mail::SpamAssassin::PersistentAddrList','Mail::SpamAssassin::Replier','Mail::SpamAssassin::Reporter','Mail::SpamAssassin::SHA1','Mail::SpamAssassin::TextCat','Net::DNS','Net::DNS::Resolver','POSIX','Razor2::Client::Agent','Razor::Agent','Razor::Client','Sys::Hostname','Text::Wrap','Time::Local','integer','strict','vars']},'Mail-SpamAssassin-2.50.tar.gz' => {'author' => 'JMASON','description' => 'Mail::Audit spam detector plugin','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14864,'pod' => 1525,'pod_errors' => 2,'total' => 16389,'with_comments' => 2194},'releases' => 20,'requires' => ['Errno-1.09.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','PodParser-1.23.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Errno' => 0,'ExtUtils::MakeMaker' => 0,'File::Copy' => 0,'File::Spec' => '0.8','HTML::Parser' => 3,'Pod::Usage' => 0,'Text::Wrap' => 0,'Time::Local' => 0},'requires_recursive' => ['Errno-1.09.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','PodParser-1.23.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 758165,'unpacked' => 2197456},'testers' => {'pass' => 2},'uses' => ['$file','5.002','AnyDBM_File','AutoSplit','Carp','Config','Cwd','DBI','Data::Dumper','Exporter','ExtUtils::Install','Fcntl','File::Basename','File::Compare','File::Copy','File::Path','File::Spec','Getopt::Long','IO::Select','IO::Socket','IPC::Open2','MIME::Base64','MIME::Body','Mail::Audit','Mail::Internet','Mail::SpamAssassin','Mail::SpamAssassin::Bayes','Mail::SpamAssassin::BayesStore','Mail::SpamAssassin::Conf','Mail::SpamAssassin::Dns','Mail::SpamAssassin::EncappedMIME','Mail::SpamAssassin::EncappedMessage','Mail::SpamAssassin::EvalTests','Mail::SpamAssassin::HTML','Mail::SpamAssassin::Locker','Mail::SpamAssassin::MailingList','Mail::SpamAssassin::NoMailAudit','Mail::SpamAssassin::PerMsgStatus','Mail::SpamAssassin::Reporter','Mail::SpamAssassin::SHA1','Mail::SpamAssassin::TextCat','Mail::SpamAssassin::UnixLocker','Mail::SpamAssassin::Util','Mail::SpamAssassin::Win32Locker','Net::DNS','Net::DNS::Resolver','POSIX','Pod::Usage','Razor2::Client::Agent','Razor::Agent','Razor::Client','Sys::Hostname','Text::Wrap','Time::Local','bytes','constant','integer','strict','vars']},'Mail-SpamAssassin-2.55.tar.gz' => {'author' => 'JMASON','description' => 'Mail::Audit spam detector plugin','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 15157,'pod' => 1577,'pod_errors' => 1,'total' => 16734,'with_comments' => 2271},'releases' => 20,'requires' => ['Errno-1.09.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','PodParser-1.23.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Errno' => 0,'ExtUtils::MakeMaker' => 0,'File::Copy' => 0,'File::Spec' => '0.8','HTML::Parser' => 3,'Pod::Usage' => 0,'Text::Wrap' => 0,'Time::Local' => 0},'requires_recursive' => ['Errno-1.09.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','PodParser-1.23.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 700610,'unpacked' => 2022920},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['$file','5.002','AnyDBM_File','AutoSplit','Carp','Config','Cwd','DBI','Data::Dumper','Exporter','ExtUtils::Install','Fcntl','File::Basename','File::Compare','File::Copy','File::Path','File::Spec','Getopt::Long','IO::Select','IO::Socket','IPC::Open2','MIME::Base64','Mail::Audit','Mail::Internet','Mail::SpamAssassin::ArchiveIterator','Mail::SpamAssassin::AuditMessage','Mail::SpamAssassin::AutoWhitelist','Mail::SpamAssassin::ConfSourceSQL','Mail::SpamAssassin::EncappedMIME','Mail::SpamAssassin::HTML','Mail::SpamAssassin::Locales','Mail::SpamAssassin::MailingList','Mail::SpamAssassin::Message','Mail::SpamAssassin::PerMsgLearner','Mail::SpamAssassin::PersistentAddrList','Mail::SpamAssassin::Replier','Mail::SpamAssassin::SHA1','Mail::SpamAssassin::TextCat','Net::DNS','Net::DNS::Resolver','POSIX','Pod::Usage','Razor2::Client::Agent','Razor::Agent','Razor::Client','Sys::Hostname','Text::Wrap','Time::Local','bytes','constant','integer','strict','vars']},'Mail-SpamTest-Bayesian-0.02.tar.gz' => {'author' => 'FIREDRAKE','description' => 'Perl extension for Bayesian spam-testing','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 305,'pod' => 92,'pod_errors' => 0,'total' => 397,'with_comments' => 4},'releases' => 2,'requires' => ['BerkeleyDB-0.23.tar.gz','MIME-tools-5.411a.tar.gz'],'requires_module' => {'BerkeleyDB' => '0.17','MIME::Parser' => '5.406'},'requires_recursive' => ['BerkeleyDB-0.23.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5676,'unpacked' => 14850},'testers' => {'pass' => 2},'uses' => ['5.006','BerkeleyDB','Exporter','MIME::Parser','strict','warnings']},'Mail-Spool-0.50.tar.gz' => {'author' => 'RHANDOM','description' => 'Extensible Perl Mail Spooler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1318,'pod' => 471,'pod_errors' => 0,'total' => 1789,'with_comments' => 283},'releases' => 1,'requires' => ['File-NFSLock-1.20.tar.gz','IO-1.20.tar.gz','MailTools-1.58.tar.gz','Net-DNS-0.38.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'File::NFSLock' => '1.10','IO::File' => 0,'Mail::Address' => 0,'Mail::Internet' => 0,'Net::DNS' => 0,'Net::SMTP' => 0},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-NFSLock-1.20.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MailTools-1.58.tar.gz','Net-DNS-0.38.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17603,'unpacked' => 65053},'testers' => {'pass' => 5},'uses' => ['Digest::MD5','strict','vars']},'Mail-Summary-0.02.tar.gz' => {'author' => 'STRYTOAST','description' => 'scan read your mail!','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 69,'pod_errors' => 0,'total' => 122,'with_comments' => 0},'releases' => 2,'requires' => ['Lingua-EN-Summarize-0.2.tar.gz','Mail-Box-2.043.tar.gz'],'requires_module' => {'Lingua::EN::Summarize' => '0.2','Mail::Box::Manager' => '2.013'},'requires_recursive' => ['Errno-1.09.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Summary-0.017.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','Lingua-EN-Summarize-0.2.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Types-1.06.tar.gz','Mail-Box-2.043.tar.gz','MailTools-1.58.tar.gz','Object-Realize-Later-0.12.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2587,'unpacked' => 4905},'testers' => {'pass' => 6},'uses' => ['Lingua::EN::Summarize','Mail::Box::Manager','strict']},'Mail-Thread-2.3.tar.gz' => {'author' => 'RCLAMP','description' => 'Perl implementation of JWZ\'s mail threading algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 502,'pod' => 135,'pod_errors' => 0,'total' => 637,'with_comments' => 47},'releases' => 8,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 39763,'unpacked' => 159815},'testers' => {'pass' => 3},'uses' => ['5.00503','Carp','strict','vars']},'Mail-Thread-Chronological-1.22.tar.gz' => {'author' => 'RCLAMP','description' => 'rearrange Mail::Thread::Containers into a Chronological structure','files' => ['Makefile.PL','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 197,'pod' => 87,'pod_errors' => 0,'total' => 284,'with_comments' => 47},'releases' => 2,'requires' => ['Mail-Thread-2.3.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz'],'requires_module' => {'Date::Parse' => '0','List::Util' => '0','Mail::Thread' => '0','Test::More' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Mail-Thread-2.3.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz'],'size' => {'packed' => 4532,'unpacked' => 10091},'testers' => {'pass' => 2},'uses' => ['Date::Parse','List::Util','constant','strict','vars']},'Mail-TieFolder-0.03.tar.gz' => {'author' => 'STEVEGT','description' => 'Tied hash interface for mail folders','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 63,'pod_errors' => 0,'total' => 237,'with_comments' => 13},'releases' => 2,'size' => {'packed' => 4512,'unpacked' => 10072},'testers' => {'fail' => 2,'pass' => 6,'tests' => '8'},'uses' => ['5.005_62','AutoLoader','Exporter','strict','vars','warnings']},'Mail-TieFolder-mh-0.04.tar.gz' => {'author' => 'STEVEGT','description' => 'Tied hash interface for mh mail folders','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 202,'pod' => 40,'pod_errors' => 0,'total' => 242,'with_comments' => 14},'releases' => 2,'size' => {'packed' => 4557,'unpacked' => 15377},'testers' => {'fail' => 3,'pass' => 1,'tests' => '43'},'uses' => ['5.005_62','Carp','File::Temp','Mail::Internet','strict','warnings']},'Mail-Transport-Dbx-0.04.tar.gz' => {'author' => 'VPARSEVAL','description' => 'Parse Outlook Express mailboxes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 111,'pod' => 423,'pod_errors' => 0,'total' => 534,'with_comments' => 17},'releases' => 4,'size' => {'packed' => 211523,'unpacked' => 381388},'testers' => {'pass' => 2},'uses' => ['5.00503','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Mail-Verify-0.02.tar.gz' => {'author' => 'PETEF','description' => 'Attempt to verify an email address','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 58,'pod' => 71,'pod_errors' => 5,'total' => 129,'with_comments' => 10},'releases' => 4,'requires' => ['IO-1.20.tar.gz','Net-DNS-0.38.tar.gz'],'requires_module' => {'IO::Socket' => '0.1','Net::DNS' => '0.1'},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2727,'unpacked' => 5988},'testers' => {'pass' => 4},'uses' => ['IO::Socket','Net::DNS','strict']},'Mail-Verp-0.01.tar.gz' => {'author' => 'GYEPI','description' => 'Perl extension for creating Variable Envelope Return Paths (VERP) addresses.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 47,'pod_errors' => 0,'total' => 144,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 11198,'unpacked' => 34216},'testers' => {'pass' => 2},'uses' => ['5.000','Carp','strict','vars']},'Mail-Vmailmgr-0.4.tar.gz' => {'author' => 'MARTIN','description' => 'A Perl module to use Vmailmgr daemon','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 466,'pod' => 95,'pod_errors' => 0,'total' => 561,'with_comments' => 76},'releases' => 1,'size' => {'packed' => 5488,'unpacked' => 15247},'testers' => {'pass' => 8},'uses' => ['Data::Dumper','IO::Socket','strict','vars']},'Mail-Webmail-Yahoo-0.401.tar.gz' => {'author' => 'SDRABBLE','description' => 'Enables bulk download of yahoo.com -based webmail.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1351,'pod' => 218,'pod_errors' => 0,'total' => 1569,'with_comments' => 173},'releases' => 13,'requires' => ['Class-MethodMaker-1.10.tar.gz','HTML-FormParser-0.11.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableContentParser-0.13.tar.gz','HTML-TableExtractor-0.11.tar.gz','HTML-Tree-3.17.tar.gz','MIME-Base64-2.20.tar.gz','MailTools-1.58.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Class::MethodMaker' => '0.1','HTML::Entities' => '0.1','HTML::FormParser' => '0.1','HTML::LinkExtor' => '0.1','HTML::TableContentParser' => '0.1','HTML::TableExtractor' => '0.1','HTML::Tree' => '3.14','HTTP::Cookies' => '0.1','HTTP::Headers' => '0.1','HTTP::Request' => '0.1','LWP::UserAgent' => '0.1','MIME::Base64' => '0.1','Mail::Internet' => '0.1'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','Digest-MD5-2.26.tar.gz','HTML-FormParser-0.11.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableContentParser-0.13.tar.gz','HTML-TableExtractor-0.11.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MailTools-1.58.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19410,'unpacked' => 55221},'testers' => {'pass' => 6},'uses' => ['5.006_000','CGI','Carp','Exporter','HTML::Entities','HTML::FormParser','HTML::LinkExtor','HTML::Parser','HTML::TableContentParser','HTML::TreeBuilder','HTTP::Cookies','HTTP::Headers','HTTP::Request','LWP::Debug','LWP::UserAgent','MIME::Base64','Mail::Internet','URI::URL','constant','strict','warnings']},'Mail-XML-0.03.tar.gz' => {'author' => 'MATTMK','description' => 'Adds a toXML() method to Mail::Internet.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 58,'pod' => 31,'pod_errors' => 0,'total' => 89,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 8158,'unpacked' => 39276},'testers' => {'fail' => 2,'pass' => 3},'uses' => ['Carp','Exporter','IO::Scalar','Mail::Internet','XML::Writer','strict','vars']},'MailFolder-0.07.tar.gz' => {'author' => 'KJOHNSON','description' => 'A folder-independant interface to email folders.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2902,'pod' => 1177,'pod_errors' => 1,'total' => 4079,'with_comments' => 172},'releases' => 6,'requires' => ['File-Sync-0.09.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','TimeDate-1.16.tar.gz'],'requires_module' => {'Date::Format' => '2.09','File::Sync' => '0.06','MIME::Tools' => '4.116','Mail::Internet' => '1.3'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Sync-0.09.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 52006,'unpacked' => 206734},'testers' => {'fail' => 7,'pass' => 1,'tests' => '570'},'uses' => ['5.00397','Carp','Date::Format','Date::Parse','DirHandle','File::BasicFlock','File::Sync','IO::File','MIME::Head','MIME::Parser','Mail::Address','Mail::Header','Mail::Internet','Net::NNTP','POSIX','Sys::Hostname','strict','vars']},'MailQuoteWrap0.01.tgz' => {'author' => 'CHARDIN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 443,'pod' => 255,'pod_errors' => 0,'total' => 698,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 5643,'unpacked' => 19858},'testers' => {'tests' => '0','unknown' => 27},'uses' => ['Text::Format','strict']},'MailStats-0.02.tar.gz' => {'author' => 'SDAGUE','description' => 'Perl module for getting quick statistics on procmail generated mailbox files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 225,'pod' => 46,'pod_errors' => 0,'total' => 271,'with_comments' => 10},'releases' => 1,'requires' => ['AppConfig-1.55.tar.gz'],'requires_module' => {'AppConfig' => 1},'requires_recursive' => ['AppConfig-1.55.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4430,'unpacked' => 9370},'testers' => {'pass' => 7},'uses' => ['AppConfig','Carp','strict','vars']},'MailTools-1.15.tar.gz' => {'author' => 'GBARR','description' => 'Parse mailcap files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3589,'pod' => 854,'pod_errors' => 0,'total' => 4443,'with_comments' => 272},'releases' => 36,'size' => {'packed' => 39585,'unpacked' => 123193},'testers' => {'pass' => 15},'uses' => ['5.000','5.002','AutoLoader','Carp','Config','Date::Format','Date::Parse','IO::Handle','Mac::InternetConfig','Mail::Address','Mail::Header','Mail::Mailer','Mail::Util','Net::Domain','Net::NNTP','Net::SMTP','happy','locale','strict','vars']},'MailTools-1.58.tar.gz' => {'author' => 'MARKOV','description' => 'Parse mailcap files as specified in RFC 1524','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3646,'pod' => 897,'pod_errors' => 0,'total' => 4543,'with_comments' => 273},'releases' => 36,'size' => {'packed' => 42906,'unpacked' => 133639},'testers' => {'pass' => 17},'uses' => ['5.000','5.002','AutoLoader','Carp','Config','Date::Format','Date::Parse','IO::Handle','Mac::InternetConfig','Mail::Mailer::rfc822','Net::Domain','Net::NNTP','Net::SMTP','happy','locale','strict','utf8','vars']},'Make-1.00.tar.gz' => {'author' => 'NI-S','description' => 'Makefile parsing, and \'make\' replacement','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1253,'pod' => 68,'pod_errors' => 0,'total' => 1321,'with_comments' => 142},'releases' => 4,'size' => {'packed' => 12425,'unpacked' => 36107},'testers' => {'pass' => 10},'uses' => ['5.005','Carp','Config','Cwd','File::Spec','strict','vars']},'Manip-END-0.06.tar.gz' => {'author' => 'FDALY','description' => 'Mess around with END blocks','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 145,'pod' => 115,'pod_errors' => 0,'total' => 260,'with_comments' => 1},'releases' => 6,'size' => {'packed' => 9156,'unpacked' => 23304},'testers' => {'pass' => 3},'uses' => ['Exporter','XSLoader','strict','warnings']},'MarekPodHtml-0.49.tar.gz' => {'author' => 'MAREKR','description' => 'convert Perl POD documents to HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1522,'pod' => 320,'pod_errors' => 0,'total' => 1842,'with_comments' => 250},'releases' => 10,'size' => {'packed' => 26696,'unpacked' => 86727},'testers' => {'pass' => 1},'uses' => ['Exporter','File::Basename','File::Path','HTML::Entities','HTML::FormatPS','HTML::TreeBuilder','Pod::Checker','Pod::Parser','strict','vars']},'Mariachi-0.41.tar.gz' => {'author' => 'RCLAMP','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 961,'pod' => 297,'pod_errors' => 0,'total' => 1258,'with_comments' => 69},'releases' => 6,'size' => {'packed' => 20665,'unpacked' => 58723},'testers' => {'pass' => 2},'uses' => ['Carp','Class::Accessor::Fast','Data::Dumper','Date::Parse','Digest::MD5','Email::Find','Email::Folder','Email::Simple','Email::Thread','File::Basename','File::Copy','File::Find','File::Find::Rule','File::Path','IO::File','Mail::Thread::Chronological','Memoize','Module::Build','Storable','Template','Template::Plugin::Filter','Time::HiRes','URI::Find::Schemeless::Stricter','strict','vars']},'MasonX-ApacheHandler-WithCallbacks-0.99.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1886,'pod' => 949,'pod_errors' => 0,'total' => 2835,'with_comments' => 225},'releases' => 11,'requires' => ['Apache-Test-1.03.tar.gz','HTML-Mason-1.22.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache::Test' => '1.03','HTML::Mason' => '1.10','Test::Simple' => '0.17','mod_perl' => '1.22'},'requires_recursive' => ['Apache-Test-1.03.tar.gz','File-Spec-0.82.tar.gz','HTML-Mason-1.22.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'testers' => {},'uses' => ['Apache::Constants','Apache::FakeRequest','Carp','Class::ISA','File::Spec::Functions','HTML::Mason','constant','strict','vars']},'MasonX-Lexer-MSP-0.02.tar.gz' => {'author' => 'JWILLIAMS','description' => 'Give Mason a more ASP/JSP compatible syntax','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 181,'pod' => 52,'pod_errors' => 0,'total' => 233,'with_comments' => 12},'releases' => 1,'requires' => ['HTML-Mason-1.22.tar.gz'],'requires_module' => {'HTML::Mason' => '1.1'},'requires_recursive' => ['HTML-Mason-1.22.tar.gz'],'size' => {'packed' => 11924,'unpacked' => 63260},'testers' => {'pass' => 1},'uses' => ['HTML::Mason::Lexer','Params::Validate','strict','warnings']},'MasonX-Request-WithApacheSession-0.21.tar.gz' => {'author' => 'DROLSKY','description' => 'Add a session to the Mason Request object','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 749,'pod' => 240,'pod_errors' => 0,'total' => 989,'with_comments' => 14},'releases' => 6,'size' => {'packed' => 10214,'unpacked' => 39665},'testers' => {},'uses' => ['5.005','Apache::Cookie','Apache::Session','CGI::Cookie','HTML::Mason','HTML::Mason::Request','Params::Validate','strict','vars']},'MasonX-Resolver-CVS-0.02.tar.gz' => {'author' => 'KORTY','description' => 'retrieve components from CVS','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 215,'pod' => 53,'pod_errors' => 0,'total' => 268,'with_comments' => 44},'releases' => 1,'size' => {'packed' => 5037,'unpacked' => 17728},'testers' => {'fail' => 1,'tests' => '13'},'uses' => ['Exporter','File::Spec','HTML::Mason::Component::FileBased','HTML::Mason::ComponentSource','HTML::Mason::Resolver::File','HTML::Mason::Tools','Params::Validate','constant','strict']},'MasonX-Resolver-PAR-0.2.tar.gz' => {'author' => 'MRAMBERG','description' => 'Get mason components from a PAR file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 193,'pod' => 42,'pod_errors' => 0,'total' => 235,'with_comments' => 24},'releases' => 3,'requires' => ['HTML-Mason-1.22.tar.gz','PAR-0.69.tar.gz'],'requires_module' => {'HTML::Mason' => '1.1','PAR' => '0.62'},'requires_recursive' => ['HTML-Mason-1.22.tar.gz','PAR-0.69.tar.gz'],'size' => {'packed' => 4874,'unpacked' => 10640},'testers' => {'pass' => 1},'uses' => ['Apache','Apache::Server','Archive::Zip','File::Basename','File::Spec','HTML::Mason::Component','HTML::Mason::ComponentSource','HTML::Mason::Resolver','Params::Validate','strict']},'Match-Any_0.03.tar.gz' => {'author' => 'KUNGFUFTR','description' => 'Match many regexes against a variable =head1 CHANGES Version 0.03: Pass match_any() a second arguement of matching options [NOTE: array reference only]','files' => ['Makefile.PL'],'lines' => {'nonpod' => 23,'pod' => 41,'pod_errors' => 0,'total' => 64,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1689,'unpacked' => 4187},'testers' => {'pass' => 5},'uses' => ['Exporter','strict','vars','warnings']},'Math-Amoeba-0.01.tar.gz' => {'author' => 'JARW','description' => 'Multidimensional Function Minimisation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 162,'pod' => 62,'pod_errors' => 0,'total' => 224,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 3557,'unpacked' => 8490},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['Carp','Exporter','strict']},'Math-Approx-0.200.tar.gz' => {'author' => 'ULPFR','description' => 'Approximate x,y-values by a function','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 132,'pod' => 78,'pod_errors' => 0,'total' => 210,'with_comments' => 23},'releases' => 2,'requires' => ['Math-Matrix-0.4.tar.gz'],'requires_module' => {'Math::Matrix' => 0},'requires_recursive' => ['Math-Matrix-0.4.tar.gz'],'size' => {'packed' => 2781,'unpacked' => 8043},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['5.004','Math::Matrix','strict','vars']},'Math-Base36-0.02.tar.gz' => {'author' => 'RHENSSEL','description' => 'Encoding and decoding of base36 strings','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 40,'pod_errors' => 0,'total' => 99,'with_comments' => 2},'releases' => 2,'requires' => ['Math-BigInt-1.64.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Math::BigInt' => 0},'requires_recursive' => ['Math-BigInt-1.64.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2327,'unpacked' => 4064},'testers' => {'fail' => 3,'pass' => 4},'uses' => ['5.005_62','AutoLoader','Carp','Exporter','Math::BigInt','strict','warnings']},'Math-Base85-0.2.tar.gz' => {'author' => 'TMONROE','description' => 'Perl extension for base 85 numbers, as referenced by RFC 1924','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 54,'pod_errors' => 0,'total' => 136,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 6495,'unpacked' => 14929},'testers' => {'fail' => 1,'pass' => 8},'uses' => ['Carp','Exporter','Math::BigInt','constant','strict','vars']},'Math-BaseArith-1.00.tar.gz' => {'author' => 'PUCKERING','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 148,'pod' => 176,'pod_errors' => 0,'total' => 324,'with_comments' => 16},'releases' => 1,'size' => {'packed' => 5977,'unpacked' => 22936},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','integer','strict','warnings']},'Math-BaseCalc-1.011.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Convert numbers between various bases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 117,'pod' => 84,'pod_errors' => 0,'total' => 201,'with_comments' => 9},'releases' => 4,'size' => {'packed' => 3706,'unpacked' => 8121},'testers' => {'pass' => 10},'uses' => ['Carp','strict','vars']},'Math-Bezier-0.01.tar.gz' => {'author' => 'ABW','description' => 'Solution of Bezier curves','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 76,'pod_errors' => 0,'total' => 220,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 3101,'unpacked' => 10412},'testers' => {'pass' => 24},'uses' => ['constant','strict','vars']},'Math-Bezier-Convert-0.01.tar.gz' => {'author' => 'YSAS','description' => 'convert cubic and quadratic bezier curve','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 257,'pod' => 76,'pod_errors' => 0,'total' => 333,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 5620,'unpacked' => 17109},'testers' => {'pass' => 8},'uses' => ['5.005_62','Carp','Exporter','strict','warnings']},'Math-Big-1.08.tar.gz' => {'author' => 'TELS','description' => 'routines (cos,sin,primes,hailstone,euler,fibbonaci etc) with big numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1050,'pod' => 268,'pod_errors' => 0,'total' => 1318,'with_comments' => 316},'releases' => 5,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.36','Math::BigInt' => '1.61'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 20682,'unpacked' => 65202},'testers' => {'pass' => 6},'uses' => ['5.005','Exporter','Math::BigFloat','Math::BigInt','strict','vars']},'Math-BigInt-1.63.tar.gz' => {'author' => 'TELS','description' => 'Arbitrary size integer math package','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7044,'pod' => 1898,'pod_errors' => 0,'total' => 8942,'with_comments' => 1875},'releases' => 28,'size' => {'packed' => 136968,'unpacked' => 493622},'testers' => {'pass' => 7},'uses' => ['$file','5.005','Carp','Exporter','File::Spec','Math::BigFloat','Math::BigInt','constant','integer','strict','vars','warnings']},'Math-BigInt-1.64.tar.gz' => {'author' => 'TELS','description' => 'Arbitrary size integer math package','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 7503,'pod' => 1960,'pod_errors' => 0,'total' => 9463,'with_comments' => 2039},'releases' => 28,'size' => {'packed' => 152744,'unpacked' => 541033},'testers' => {'fail' => 4,'pass' => 9,'tests' => '22249'},'uses' => ['$file','5.005','Carp','Exporter','File::Spec','constant','integer','strict','vars','warnings']},'Math-BigInt-BitVect-1.11.tar.gz' => {'author' => 'TELS','description' => 'Use Bit::Vector for Math::BigInt routines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 571,'pod' => 23,'pod_errors' => 0,'total' => 594,'with_comments' => 136},'releases' => 10,'requires' => ['Bit-Vector-6.3.tar.gz','Math-BigInt-1.64.tar.gz'],'requires_module' => {'Bit::Vector' => 6,'Math::BigFloat' => '1.35','Math::BigInt' => '1.6'},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 26568,'unpacked' => 94277},'testers' => {'pass' => 6},'uses' => ['5.005','Bit::Vector','strict','vars','warnings']},'Math-BigInt-Constant-1.04.tar.gz' => {'author' => 'TELS','description' => 'Arbitrary sized constant integers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 44,'pod' => 106,'pod_errors' => 0,'total' => 150,'with_comments' => 6},'releases' => 1,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.26','Math::BigInt' => '1.5'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 3792,'unpacked' => 8316},'testers' => {'pass' => 5},'uses' => ['Exporter','Math::BigInt','overload','strict']},'Math-BigInt-FastCalc-0.06.tar.gz' => {'author' => 'TELS','description' => 'Perl module with some XS to support Math::BigInt','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1679,'pod' => 127,'pod_errors' => 0,'total' => 1806,'with_comments' => 565},'releases' => 3,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigInt' => '1.62'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 46945,'unpacked' => 176237},'testers' => {'pass' => 3},'uses' => ['5.005','DynaLoader','constant','integer','strict','warnings']},'Math-BigInt-GMP-1.11.tar.gz' => {'author' => 'TELS','description' => 'Use the GMP library for Math::BigInt routines','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 131,'pod' => 25,'pod_errors' => 0,'total' => 156,'with_comments' => 30},'releases' => 9,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.38','Math::BigInt' => '1.64'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 28724,'unpacked' => 104044},'testers' => {},'uses' => ['5.005','DynaLoader','strict','vars','warnings']},'Math-BigInt-Lite-0.10.tar.gz' => {'author' => 'TELS','description' => 'What BigInt\'s are before they become big','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1122,'pod' => 122,'pod_errors' => 0,'total' => 1244,'with_comments' => 243},'releases' => 5,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigInt' => '1.57'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 21410,'unpacked' => 77088},'testers' => {'pass' => 3},'uses' => ['5.005_03','Exporter','Math::BigInt','integer','strict','vars']},'Math-BigInt-Named-0.02.tar.gz' => {'author' => 'TELS','description' => 'Math::BigInts that know their name in some languages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 469,'pod' => 132,'pod_errors' => 0,'total' => 601,'with_comments' => 56},'releases' => 2,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigInt' => '1.48'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 5700,'unpacked' => 19905},'testers' => {'pass' => 4},'uses' => ['5.005_02','Exporter','Math::BigInt','strict','vars']},'Math-BigInt-Pari-1.09.tar.gz' => {'author' => 'TELS','description' => 'Use Math::Pari for Math::BigInt routines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 178,'pod' => 29,'pod_errors' => 0,'total' => 207,'with_comments' => 22},'releases' => 9,'requires' => ['Math-BigInt-1.64.tar.gz','Math-Pari-2.010500.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.35','Math::BigInt' => '1.60','Math::Pari' => '2.001804'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz','Math-Pari-2.010500.tar.gz'],'size' => {'packed' => 23660,'unpacked' => 83680},'testers' => {'pass' => 5},'uses' => ['Math::Pari','strict','vars']},'Math-BigInteger-1.0.tar.gz' => {'author' => 'GARY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 396,'pod' => 192,'pod_errors' => 0,'total' => 588,'with_comments' => 49},'releases' => 1,'size' => {'packed' => 19869,'unpacked' => 75310},'testers' => {'fail' => 7,'pass' => 1},'uses' => ['Carp','DynaLoader','Exporter','integer','strict']},'Math-BigRat-0.09.tar.gz' => {'author' => 'TELS','description' => 'Arbitrary size rational numbers (fractions)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1069,'pod' => 188,'pod_errors' => 0,'total' => 1257,'with_comments' => 252},'releases' => 9,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.36','Math::BigInt' => '1.61'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 22956,'unpacked' => 87349},'testers' => {'fail' => 2,'pass' => 12,'tests' => '660'},'uses' => ['5.005_03','Exporter','Math::BigFloat','Math::BigInt','constant','overload','strict','vars']},'Math-BooleanEval-1.00.tar.gz' => {'author' => 'MIKO','description' => 'Parsing and evaluating Boolean expressions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 92,'pod_errors' => 0,'total' => 266,'with_comments' => 33},'releases' => 3,'size' => {'packed' => 3694,'unpacked' => 11232},'testers' => {'pass' => 7},'uses' => ['strict','vars']},'Math-Brent-0.01.tar.gz' => {'author' => 'JARW','description' => 'One-dimensional Function Minimisation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 165,'pod' => 53,'pod_errors' => 0,'total' => 218,'with_comments' => 30},'releases' => 1,'size' => {'packed' => 3852,'unpacked' => 8614},'testers' => {'tests' => '0','unknown' => 24},'uses' => ['Carp','Exporter','Math::Fortran','Math::VecStat','strict']},'Math-Business-BlackSch-0.01.tar.gz' => {'author' => 'ANDERS','description' => 'Black-Scholes option price model functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 154,'pod' => 73,'pod_errors' => 0,'total' => 227,'with_comments' => 8},'releases' => 1,'requires' => ['Math-CDF-0.1.tar.gz'],'requires_module' => {'Math::CDF' => '0.1'},'requires_recursive' => ['Math-CDF-0.1.tar.gz'],'size' => {'packed' => 3769,'unpacked' => 9689},'testers' => {'pass' => 4},'uses' => ['Exporter','Math::CDF','autouse','strict','vars']},'Math-Business-BlackScholes-0.05.tar.gz' => {'author' => 'ANDERS','description' => 'Black-Scholes option price model functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 335,'pod' => 101,'pod_errors' => 0,'total' => 436,'with_comments' => 19},'releases' => 4,'requires' => ['Math-CDF-0.1.tar.gz'],'requires_module' => {'Math::CDF' => '0.1'},'requires_recursive' => ['Math-CDF-0.1.tar.gz'],'size' => {'packed' => 6936,'unpacked' => 19958},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','Math::CDF','strict','vars']},'Math-Business-EMA-1.06.tar.gz' => {'author' => 'JETTERO','description' => 'An Exponential Moving Average Calculator','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 49,'pod_errors' => 0,'total' => 113,'with_comments' => 0},'releases' => 4,'requires' => ['Math-Business-SMA-0.99.tar.gz'],'requires_module' => {'Math::Business::SMA' => '0.99'},'requires_recursive' => ['Math-Business-SMA-0.99.tar.gz'],'size' => {'packed' => 3423,'unpacked' => 6382},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Math::Business::SMA','strict','warnings']},'Math-Business-MACD-1.10.tar.gz' => {'author' => 'JETTERO','description' => 'Perl extension for calculating MACDs','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 91,'pod' => 76,'pod_errors' => 0,'total' => 167,'with_comments' => 0},'releases' => 6,'requires' => ['Math-Business-EMA-1.06.tar.gz'],'requires_module' => {'Math::Business::EMA' => '1.06'},'requires_recursive' => ['Math-Business-EMA-1.06.tar.gz','Math-Business-SMA-0.99.tar.gz'],'size' => {'packed' => 3750,'unpacked' => 7803},'testers' => {'pass' => 1},'uses' => ['Carp','Math::Business::EMA','strict','warnings']},'Math-Business-SMA-0.99.tar.gz' => {'author' => 'JETTERO','description' => 'Perl extension for calculating simple moving averages.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 43,'pod_errors' => 0,'total' => 118,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2852,'unpacked' => 5096},'testers' => {'pass' => 2},'uses' => ['Carp','strict','warnings']},'Math-CDF-0.1.tar.gz' => {'author' => 'CALLAHAN','description' => 'Cumulative Distribution Functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 143,'pod' => 111,'pod_errors' => 0,'total' => 254,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 65855,'unpacked' => 316625},'testers' => {'pass' => 16},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Math-Calc-Euro-0.02.tar.gz' => {'author' => 'JUERD','description' => 'Convert between EUR and the old currencies','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 51,'pod' => 39,'pod_errors' => 0,'total' => 90,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 1907,'unpacked' => 3133},'testers' => {'pass' => 5},'uses' => ['Carp','strict','vars']},'Math-Calc-Units-1.02.tar.gz' => {'author' => 'SFINK','description' => 'Human-readable unit-aware calculator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2468,'pod' => 53,'pod_errors' => 0,'total' => 2521,'with_comments' => 371},'releases' => 3,'size' => {'packed' => 30721,'unpacked' => 87714},'testers' => {'pass' => 9},'uses' => ['5.004','Carp','Exporter','Time::Local','strict','vars']},'Math-Cephes-0.36.tar.gz' => {'author' => 'RKOBES','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1597,'pod' => 5689,'pod_errors' => 0,'total' => 7286,'with_comments' => 10},'releases' => 3,'size' => {'packed' => 301489,'unpacked' => 1096529},'testers' => {'fail' => 3,'pass' => 2,'tests' => '472'},'uses' => ['DynaLoader','Exporter','Math::Complex','Math::Fraction','strict','vars']},'Math-Currency-0.39.tar.gz' => {'author' => 'JPEACOCK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 420,'pod' => 138,'pod_errors' => 0,'total' => 558,'with_comments' => 57},'releases' => 13,'requires' => ['Math-BigInt-1.64.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.27','Test::More' => '0.02'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Math-BigInt-1.64.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 9760,'unpacked' => 27503},'testers' => {'fail' => 1,'pass' => 4,'tests' => '43'},'uses' => ['Exporter','Math::BigFloat','POSIX','strict','vars']},'Math-Curve-Hilbert-0.03.tar.gz' => {'author' => 'TEEJAY','description' => 'Perl Implementation of Hilberts space filling Curve','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 47,'pod_errors' => 0,'total' => 252,'with_comments' => 4},'releases' => 3,'size' => {'packed' => 3042,'unpacked' => 12539},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Math-Derivative-0.01.tar.gz' => {'author' => 'JARW','description' => '1st and 2nd order differentiation of data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 70,'pod' => 28,'pod_errors' => 0,'total' => 98,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 1935,'unpacked' => 4178},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['Exporter','strict']},'Math-ES-0.08.tar.gz' => {'author' => 'AHCHORN','description' => 'Evolution Strategy Optimizer','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1024,'pod' => 326,'pod_errors' => 5,'total' => 1350,'with_comments' => 145},'releases' => 5,'requires' => ['Math-Random-0.67.tar.gz'],'requires_module' => {'Math::Random' => 0},'requires_recursive' => ['Math-Random-0.67.tar.gz'],'size' => {'packed' => 14027,'unpacked' => 49060},'testers' => {'pass' => 2},'uses' => ['5.005_62','AutoLoader','Exporter','FileHandle','Math::Random','strict','warnings']},'Math-ErrorPropagation-0.01.tar.gz' => {'author' => 'ZBYS','description' => 'Error of a function of statistical data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 232,'pod' => 143,'pod_errors' => 0,'total' => 375,'with_comments' => 4},'releases' => 1,'requires' => ['Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Test::Harness' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3849,'unpacked' => 12530},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','strict','warnings']},'Math-Evol-1.02.tar.gz' => {'author' => 'PJB','description' => 'Evolution Search Optimisation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 377,'pod' => 133,'pod_errors' => 0,'total' => 510,'with_comments' => 35},'releases' => 3,'size' => {'packed' => 22645,'unpacked' => 71028},'testers' => {'pass' => 3},'uses' => ['Exporter']},'Math-Expr-LATEST.tar.gz' => {'author' => 'HAKANARDO','description' => 'Parses mathematical expressions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1759,'pod' => 496,'pod_errors' => 0,'total' => 2255,'with_comments' => 236},'releases' => 1,'size' => {'packed' => 21295,'unpacked' => 74061},'testers' => {'pass' => 9},'uses' => ['Exporter','Fcntl','MLDBM','strict','vars']},'Math-Expression-1.14.tar.gz' => {'author' => 'ADDW','description' => 'Evaluate arithmetic/string expressions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 637,'pod' => 253,'pod_errors' => 0,'total' => 890,'with_comments' => 159},'releases' => 3,'size' => {'packed' => 15295,'unpacked' => 47849},'testers' => {'pass' => 3},'uses' => ['Exporter','POSIX','vars']},'Math-FFT-0.25.tar.gz' => {'author' => 'RKOBES','description' => 'Perl extension for Fast Fourier Transforms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 694,'pod' => 384,'pod_errors' => 0,'total' => 1078,'with_comments' => 21},'releases' => 1,'size' => {'packed' => 28114,'unpacked' => 124469},'testers' => {'pass' => 12},'uses' => ['DynaLoader','strict','vars']},'Math-Fibonacci-1.5.tar.gz' => {'author' => 'VIPUL','description' => 'Fibonacci numbers.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 81,'pod' => 54,'pod_errors' => 0,'total' => 135,'with_comments' => 14},'releases' => 1,'size' => {'packed' => 4626,'unpacked' => 11383},'testers' => {'pass' => 7},'uses' => ['Exporter','POSIX','strict','vars']},'Math-Financial-0.76.tar.gz' => {'author' => 'FIXLER','description' => 'Calculates figures relating to loans and annuities.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 351,'pod' => 188,'pod_errors' => 3,'total' => 539,'with_comments' => 23},'releases' => 2,'size' => {'packed' => 6467,'unpacked' => 17753},'testers' => {'pass' => 8},'uses' => ['POSIX','constant','strict','vars']},'Math-FixedPrecision-0.21.tar.gz' => {'author' => 'JPEACOCK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 139,'pod' => 44,'pod_errors' => 0,'total' => 183,'with_comments' => 36},'releases' => 12,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.27'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 5282,'unpacked' => 13297},'testers' => {'pass' => 7},'uses' => ['5.005_02','Exporter','strict','vars']},'Math-Fleximal-0.03.tar.gz' => {'author' => 'TILLY','description' => 'Arithmetic with any base representation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 512,'pod' => 159,'pod_errors' => 0,'total' => 671,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 6276,'unpacked' => 16967},'testers' => {'pass' => 13},'uses' => ['Carp','integer','strict']},'Math-Fortran-0.01.tar.gz' => {'author' => 'JARW','description' => 'Implements Fortran log10 & sign functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13,'pod' => 41,'pod_errors' => 1,'total' => 54,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 1538,'unpacked' => 2518},'testers' => {'tests' => '0','unknown' => 27},'uses' => ['Exporter','strict']},'Math-Fractal-Curve-1.00.tar.gz' => {'author' => 'SMUELLER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 204,'pod' => 100,'pod_errors' => 0,'total' => 304,'with_comments' => 4},'releases' => 1,'requires' => ['Imager-0.41.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Exporter' => 0,'Imager' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Imager-0.41.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 153885,'unpacked' => 249321},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','strict','warnings']},'Math-Fractal-DLA-0.20.tar.gz' => {'author' => 'ARCOLF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 801,'pod' => 357,'pod_errors' => 0,'total' => 1158,'with_comments' => 79},'releases' => 1,'size' => {'packed' => 9823,'unpacked' => 40609},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Carp','Exporter','FileHandle','GD','strict','vars','warnings']},'Math-Fractal-Mandelbrot-0.02.tar.gz' => {'author' => 'TELS','description' => 'Calculate points in the mandelbrot fractal','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 47,'pod' => 85,'pod_errors' => 0,'total' => 132,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 5773,'unpacked' => 13929},'testers' => {},'uses' => ['5.005','DynaLoader','strict','vars','warnings']},'Math-GMP-2.03.tar.gz' => {'author' => 'CHIPT','description' => 'High speed arbitrary size integer math','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 280,'pod' => 106,'pod_errors' => 0,'total' => 386,'with_comments' => 25},'releases' => 12,'size' => {'packed' => 17019,'unpacked' => 52780},'testers' => {'fail' => 5},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Math-GSL-0.01.tar.gz' => {'author' => 'NI-S','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 12,'pod' => 0,'pod_errors' => 0,'total' => 12,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2050,'unpacked' => 3282},'testers' => {},'uses' => ['Exporter','XSLoader','vars']},'Math-Geometry-GPC-1.03.tar.gz' => {'author' => 'DVDPOL','description' => 'Perl wrapper for Alan Murta\'s gpc library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 144,'pod_errors' => 0,'total' => 180,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 24592,'unpacked' => 143603},'testers' => {'pass' => 4},'uses' => ['DynaLoader','Exporter','vars']},'Math-Geometry-Planar-1.12.tar.gz' => {'author' => 'DVDPOL','description' => 'A collection of planar geometry functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3737,'pod' => 229,'pod_errors' => 0,'total' => 3966,'with_comments' => 1040},'releases' => 12,'requires' => ['Math-Geometry-Planar-GPC-1.04.tar.gz','Math-Geometry-Planar-Offset-1.02.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '0','Math::Geometry::Planar::GPC' => '1.04','Math::Geometry::Planar::Offset' => '1.00','POSIX' => '0'},'requires_recursive' => ['Math-Geometry-Planar-GPC-1.04.tar.gz','Math-Geometry-Planar-Offset-1.02.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 31787,'unpacked' => 155327},'testers' => {},'uses' => ['5.005','Carp','Exporter','Math::Geometry::Planar::GPC','Math::Geometry::Planar::Offset','POSIX','strict','vars']},'Math-Geometry-Planar-GPC-1.04.tar.gz' => {'author' => 'DVDPOL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 144,'pod_errors' => 0,'total' => 180,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 24809,'unpacked' => 144969},'testers' => {},'uses' => ['DynaLoader','Exporter','vars']},'Math-Geometry-Planar-Offset-1.02.tar.gz' => {'author' => 'DVDPOL','description' => 'Calculate offset polygons','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 515,'pod' => 17,'pod_errors' => 0,'total' => 532,'with_comments' => 167},'releases' => 3,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '0'},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 8143,'unpacked' => 24456},'testers' => {'pass' => 2},'uses' => ['5.005','Carp','Exporter','Math::Geometry::Planar','strict','vars']},'Math-Gsl-0.08.tar.gz' => {'author' => 'LETO','description' => 'Perl Interface to The GNU Scientific Library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 223,'pod' => 146,'pod_errors' => 0,'total' => 369,'with_comments' => 13},'releases' => 3,'size' => {'packed' => 11868,'unpacked' => 58564},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','XSLoader','strict','vars']},'Math-HashSum-0.02.tar.gz' => {'author' => 'SPLICE','description' => 'Sum a list of key-value pairs on a per-key basis','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1369,'pod' => 965,'pod_errors' => 0,'total' => 2334,'with_comments' => 52},'releases' => 2,'size' => {'packed' => 19071,'unpacked' => 56135},'testers' => {'pass' => 5},'uses' => ['Exporter','strict']},'Math-Integral-Romberg-0_02.tar.gz' => {'author' => 'BOESCH','description' => 'scalar numerical integration','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 75,'pod_errors' => 0,'total' => 205,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 3446,'unpacked' => 8014},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Exporter','strict','vars']},'Math-Interpolate-1.05.tar.gz' => {'author' => 'BZAJAC','description' => 'Interpolate the value Y from X using a list of (X, Y) pairs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 471,'pod' => 145,'pod_errors' => 2,'total' => 616,'with_comments' => 48},'releases' => 6,'size' => {'packed' => 44323,'unpacked' => 129855},'testers' => {'pass' => 7},'uses' => ['5.004_01','Carp','Exporter','strict','vars']},'Math-LP-0.03.tar.gz' => {'author' => 'WIMV','description' => 'OO interface to linear programs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 589,'pod' => 392,'pod_errors' => 0,'total' => 981,'with_comments' => 108},'releases' => 2,'requires' => ['Math-LP-Solve-3.03.tar.gz','Math-LinearCombination-0.03.tar.gz','Math-SimpleVariable-0.03.tar.gz'],'requires_module' => {'Math::LP::Solve' => '3.02','Math::LinearCombination' => '0.01','Math::SimpleVariable' => '0.01'},'requires_recursive' => ['Math-LP-Solve-3.03.tar.gz','Math-LinearCombination-0.03.tar.gz','Math-SimpleVariable-0.03.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12067,'unpacked' => 43483},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['Exporter','Math::LP::Solve','Math::LinearCombination','Math::SimpleVariable','fields','strict','vars']},'Math-LP-Solve-3.03.tar.gz' => {'author' => 'WIMV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 753,'pod' => 191,'pod_errors' => 0,'total' => 944,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 39564,'unpacked' => 272285},'testers' => {'fail' => 1,'pass' => 9,'tests' => '28'},'uses' => ['DynaLoader','Exporter']},'Math-Libm-1.00.tar.gz' => {'author' => 'DSLEWART','description' => 'Perl extension for the C math library, libm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 114,'pod' => 85,'pod_errors' => 0,'total' => 199,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 4554,'unpacked' => 13120},'testers' => {'pass' => 10},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars','warnings']},'Math-LinearCombination-0.03.tar.gz' => {'author' => 'WIMV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 276,'pod' => 174,'pod_errors' => 0,'total' => 450,'with_comments' => 23},'releases' => 2,'requires' => ['Math-SimpleVariable-0.03.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => undef,'Math::SimpleVariable' => '0.03'},'requires_recursive' => ['Math-SimpleVariable-0.03.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6394,'unpacked' => 23549},'testers' => {'pass' => 12},'uses' => ['5.005_62','Carp','overload','strict','warnings']},'Math-LogRand-0.01.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 34,'pod_errors' => 0,'total' => 54,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1621,'unpacked' => 2445},'testers' => {'pass' => 4},'uses' => ['5.005_62','Exporter','strict','warnings']},'Math-Logic-1.19.tar.gz' => {'author' => 'SUMMER','description' => 'Provides pure 2, 3 or multi-value logic','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 649,'pod' => 439,'pod_errors' => 0,'total' => 1088,'with_comments' => 109},'releases' => 9,'size' => {'packed' => 12923,'unpacked' => 100254},'testers' => {'pass' => 12},'uses' => ['5.004','Carp','integer','strict','vars']},'Math-Logic-Predicate-0.03.tar.gz' => {'author' => 'LPALMER','description' => 'Query a Predicate Logic database','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 656,'pod' => 335,'pod_errors' => 0,'total' => 991,'with_comments' => 34},'releases' => 1,'requires' => ['Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Parse::RecDescent' => 0},'requires_recursive' => ['Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 17277,'unpacked' => 52958},'testers' => {'pass' => 5},'uses' => ['Carp','Parse::RecDescent','strict']},'Math-MVPoly-0.8b.tar.gz' => {'author' => 'BGUARRACI','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2918,'pod' => 713,'pod_errors' => 0,'total' => 3631,'with_comments' => 110},'releases' => 1,'size' => {'packed' => 23625,'unpacked' => 103974},'testers' => {'pass' => 7},'uses' => ['strict']},'Math-MagicSquare-2.00.tar.gz' => {'author' => 'FPIVARI','description' => 'Magic Square Checker','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 242,'pod' => 156,'pod_errors' => 0,'total' => 398,'with_comments' => 23},'releases' => 7,'size' => {'packed' => 4962,'unpacked' => 17434},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['Carp','GD','strict','vars']},'Math-MagicSquare-Generator-0.01.tar.gz' => {'author' => 'JUERD','description' => 'Magic Square Generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 126,'pod' => 84,'pod_errors' => 0,'total' => 210,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 2949,'unpacked' => 6307},'testers' => {'pass' => 4},'uses' => ['Carp','strict','vars']},'Math-Matlab-0.02.tar.gz' => {'author' => 'ZMAN','description' => 'An abstract base class for a simple Matlab API.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 567,'pod' => 524,'pod_errors' => 0,'total' => 1091,'with_comments' => 43},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.01'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 11937,'unpacked' => 39562},'testers' => {'fail' => 2,'tests' => '19'},'uses' => ['','Apache::Constants','Apache::Request','Cwd','Fcntl','HTTP::Request','HTTP::Response','LWP::UserAgent','URI::URL','strict','vars']},'Math-Matrix-0.4.tar.gz' => {'author' => 'ULPFR','description' => 'Matrix data type (transpose, multiply etc)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 386,'pod' => 126,'pod_errors' => 0,'total' => 512,'with_comments' => 56},'releases' => 4,'size' => {'packed' => 5676,'unpacked' => 17867},'testers' => {'pass' => 16},'uses' => ['overload','strict','vars']},'Math-MatrixBool-5.7.tar.gz' => {'author' => 'STBEY','description' => 'Matrix of booleans (Boolean Algebra)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1365,'pod' => 920,'pod_errors' => 0,'total' => 2285,'with_comments' => 42},'releases' => 2,'requires' => ['Bit-Vector-6.3.tar.gz'],'requires_module' => {'Bit::Vector' => '5.7'},'requires_recursive' => ['Bit-Vector-6.3.tar.gz'],'size' => {'packed' => 14140,'unpacked' => 64463},'testers' => {'pass' => 7},'uses' => ['Bit::Vector','Carp','Exporter','overload','strict','vars']},'Math-MatrixReal-1.9.tar.gz' => {'author' => 'LETO','description' => 'Manipulate NxN matrices','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3872,'pod' => 1767,'pod_errors' => 2,'total' => 5639,'with_comments' => 252},'releases' => 10,'size' => {'packed' => 52631,'unpacked' => 215150},'testers' => {'pass' => 17},'uses' => ['Carp','Exporter','overload','strict','vars']},'Math-MatrixReal-Ext1-0-04.tgz' => {'author' => 'MSOUTH','description' => 'Convenience extensions for Math::MatrixReal','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 168,'pod' => 81,'pod_errors' => 0,'total' => 249,'with_comments' => 21},'releases' => 1,'size' => {'packed' => 4172,'unpacked' => 11762},'testers' => {'fail' => 2,'pass' => 7},'uses' => ['Carp','Math::MatrixReal','strict','vars']},'Math-MatrixSparse-0.01.tar.gz' => {'author' => 'KESINGER','description' => 'Perl extension for sparse matrices.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2888,'pod' => 712,'pod_errors' => 0,'total' => 3600,'with_comments' => 105},'releases' => 1,'size' => {'packed' => 40888,'unpacked' => 212009},'testers' => {'pass' => 5},'uses' => ['5.006','Carp','Exporter','overload','strict','warnings']},'Math-NoCarry-1.03.tar.gz' => {'author' => 'BDFOY','description' => 'Perl extension for no carry arithmetic','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 99,'pod_errors' => 0,'total' => 218,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 2792,'unpacked' => 7042},'testers' => {'pass' => 8},'uses' => ['Exporter','vars']},'Math-NumberCruncher-5.00.tar.gz' => {'author' => 'SIFUKURT','description' => 'Collection of useful math-related functions.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1981,'pod' => 694,'pod_errors' => 0,'total' => 2675,'with_comments' => 20},'releases' => 14,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigInt' => '1.47'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 82311,'unpacked' => 221146},'testers' => {'fail' => 1,'pass' => 7},'uses' => ['Exporter','Math::BigFloat','strict','vars']},'Math-ODE-0.03.tar.gz' => {'author' => 'LETO','description' => 'Solve N-th Order Ordinary Differential Equations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 189,'pod' => 106,'pod_errors' => 0,'total' => 295,'with_comments' => 12},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz'],'requires_module' => {'Data::Dumper' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 5468,'unpacked' => 14978},'testers' => {'pass' => 4},'uses' => ['5.003','Carp','Data::Dumper','Exporter','strict','vars']},'Math-PRSG-1.0.tar.gz' => {'author' => 'GARY','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 40,'pod_errors' => 0,'total' => 76,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 4168,'unpacked' => 10120},'testers' => {'pass' => 4},'uses' => ['DynaLoader','Exporter']},'Math-Pari-2.010500.tar.gz' => {'author' => 'ILYAZ','description' => 'Perl interface to PARI.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2446,'pod' => 682,'pod_errors' => 0,'total' => 3128,'with_comments' => 362},'releases' => 31,'size' => {'packed' => 91295,'unpacked' => 283045},'testers' => {'pass' => 1},'uses' => ['Carp','Config','DynaLoader','Exporter','File::Basename','File::Copy','LWP::UserAgent','Net::FTP','Term::Gnuplot','autouse','overload','strict','subs','vars']},'Math-PartialOrder-0.01.tar.gz' => {'author' => 'MOOCOW','description' => 'abstract base class for datatype hierarchies.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6519,'pod' => 2142,'pod_errors' => 3,'total' => 8661,'with_comments' => 1416},'releases' => 1,'requires' => ['Bit-Vector-6.3.tar.gz','File-Temp-0.12.tar.gz','GraphViz-1.8.tar.gz','Storable-2.07.tar.gz','Tie-Cache-0.17.tar.gz'],'requires_module' => {'Bit::Vector' => 6,'File::Temp' => '0.12','GraphViz' => '1.3','Storable' => '0.611','Tie::Cache' => '0.15'},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','Heap-0.50.tar.gz','IPC-Run-0.75.tar.gz','Math-Bezier-0.01.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tie-Cache-0.17.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 61735,'unpacked' => 259340},'testers' => {'pass' => 3},'uses' => ['5.6.0','Bit::Vector','Carp','Exporter','File::Temp','FileHandle','GraphViz','Storable','Tie::Cache']},'Math-Polyhedra-0.7.tar.gz' => {'author' => 'HALLEY','description' => 'vertices, edges, faces of common polyhedra','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 884,'pod' => 165,'pod_errors' => 0,'total' => 1049,'with_comments' => 73},'releases' => 1,'size' => {'packed' => 12129,'unpacked' => 40064},'testers' => {'pass' => 2},'uses' => ['vars']},'Math-Polynomial-0.03.tar.gz' => {'author' => 'MATKIN','description' => 'Polynomials as objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 409,'pod' => 185,'pod_errors' => 0,'total' => 594,'with_comments' => 24},'releases' => 3,'size' => {'packed' => 67549,'unpacked' => 175482},'testers' => {'pass' => 16},'uses' => ['Carp','Exporter','strict']},'Math-Polynomial-Solve-1.00.tar.gz' => {'author' => 'JGAMBLE','description' => 'Solve polynomials up to degree 4','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 348,'pod' => 108,'pod_errors' => 0,'total' => 456,'with_comments' => 87},'releases' => 1,'size' => {'packed' => 7369,'unpacked' => 23512},'testers' => {'pass' => 10},'uses' => ['5.004_04','Carp','Exporter','Math::Complex','strict','vars']},'Math-Project3D-1.01.tar.gz' => {'author' => 'SMUELLER','description' => 'Project vectorial function from 3D to plane','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 883,'pod' => 234,'pod_errors' => 0,'total' => 1117,'with_comments' => 286},'releases' => 5,'requires' => ['Math-MatrixReal-1.9.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Math::MatrixReal' => '1.9','Test::More' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Math-MatrixReal-1.9.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 14907,'unpacked' => 50939},'testers' => {'fail' => 2,'pass' => 3,'tests' => '107'},'uses' => ['5.006','Carp','Math::MatrixReal','strict','vars','warnings']},'Math-Project3D-Plot-1.011.tar.gz' => {'author' => 'SMUELLER','description' => 'Plot projections of 3D functions with Imager','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 394,'pod' => 169,'pod_errors' => 0,'total' => 563,'with_comments' => 93},'releases' => 5,'requires' => ['Imager-0.41.tar.gz','Math-Project3D-1.01.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Imager' => '0.41','Math::Project3D' => '1.01','Test::More' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Imager-0.41.tar.gz','Math-MatrixReal-1.9.tar.gz','Math-Project3D-1.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 90414,'unpacked' => 104975},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Imager','Math::Project3D','strict','vars','warnings']},'Math-Quaternion-0.01.tar.gz' => {'author' => 'JCHIN','description' => 'handling of quaternions and rotations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 626,'pod' => 419,'pod_errors' => 0,'total' => 1045,'with_comments' => 42},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 14152,'unpacked' => 57701},'testers' => {'pass' => 3},'uses' => ['5.004','Carp','Exporter','Math::Trig','strict','warnings']},'Math-RPN-1.08.tar.gz' => {'author' => 'OWEN','description' => 'Reverse Polish Notation Expression Evaluator','files' => [],'lines' => {'nonpod' => 596,'pod' => 159,'pod_errors' => 0,'total' => 755,'with_comments' => 30},'releases' => 5,'size' => {'packed' => 8467,'unpacked' => 26309},'testers' => {'pass' => 6},'uses' => ['AutoLoader','Exporter','strict','vars']},'Math-Radical-0.01.zip' => {'author' => 'WILL','description' => 'Interface to Mathematic Radical Operations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 93,'pod' => 67,'pod_errors' => 0,'total' => 160,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 4367,'unpacked' => 6985},'testers' => {},'uses' => ['5.006','Exporter','strict','warnings']},'Math-Rand48-1.00.tar.gz' => {'author' => 'NI-S','description' => 'perl bindings for drand48() family of random functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 27,'pod' => 55,'pod_errors' => 0,'total' => 82,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2446,'unpacked' => 5447},'testers' => {'pass' => 5},'uses' => ['DynaLoader','Exporter','vars']},'Math-Random-0.67.tar.gz' => {'author' => 'GROMMEL','description' => 'Random Number Generators','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 670,'pod' => 455,'pod_errors' => 0,'total' => 1125,'with_comments' => 62},'releases' => 8,'size' => {'packed' => 44780,'unpacked' => 154396},'testers' => {'pass' => 3},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Math-Random-MT-1.00.tar.gz' => {'author' => 'AMS','description' => 'The Mersenne Twister PRNG','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 67,'pod_errors' => 0,'total' => 131,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 6566,'unpacked' => 17168},'testers' => {'pass' => 11},'uses' => ['Carp','DynaLoader','strict','vars']},'Math-Random-TT800-1.01.tar.gz' => {'author' => 'LENDL','description' => 'TT800 random number generator (C version)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 38,'pod' => 51,'pod_errors' => 0,'total' => 89,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 4020,'unpacked' => 9006},'testers' => {'pass' => 4},'uses' => ['DynaLoader','Exporter','strict','vars']},'Math-RandomOrg-0.02.tar.gz' => {'author' => 'GWILLIAMS','description' => 'Retrieve random numbers and data from random.org.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 101,'pod' => 73,'pod_errors' => 0,'total' => 174,'with_comments' => 5},'releases' => 1,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2851,'unpacked' => 6212},'testers' => {'fail' => 1,'pass' => 3,'tests' => '190'},'uses' => ['Carp','Exporter','Math::BigInt','integer','strict','vars']},'Math-Roman-1.05.tar.gz' => {'author' => 'TELS','description' => 'Arbitrary sized Roman numbers and conversion from and to Arabic.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 416,'pod' => 243,'pod_errors' => 0,'total' => 659,'with_comments' => 158},'releases' => 1,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.23','Math::BigInt' => '1.45'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 9309,'unpacked' => 23634},'testers' => {'pass' => 5},'uses' => ['5.005','Exporter','Math::BigInt','overload','strict','vars']},'Math-Round-0.05.tar.gz' => {'author' => 'GROMMEL','description' => 'Perl extension for rounding numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 266,'pod' => 99,'pod_errors' => 0,'total' => 365,'with_comments' => 19},'releases' => 5,'size' => {'packed' => 4888,'unpacked' => 15121},'testers' => {'pass' => 7},'uses' => ['Exporter','POSIX','strict','vars']},'Math-SO3-0.90.tar.gz' => {'author' => 'FISCH','description' => 'Perl extension for SO3 rotations (Useful for: implementing orientation in 3d scenes. One major nice feature of this package is to prevent numerical drift that makes rotation matrices nonorthogonal when combining lots of them. And no, this is a direct implementation, of SO3 it does not use quaternions and SU2->SO3 homomorphism.)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 249,'pod_errors' => 0,'total' => 369,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 14039,'unpacked' => 47316},'testers' => {'fail' => 1,'pass' => 6},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Math-SimpleVariable-0.03.tar.gz' => {'author' => 'WIMV','description' => 'simple representation of mathematical variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 115,'pod' => 80,'pod_errors' => 0,'total' => 195,'with_comments' => 12},'releases' => 2,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => undef},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 3506,'unpacked' => 9999},'testers' => {'pass' => 15},'uses' => ['5.005_62','Carp','strict','warnings']},'Math-Spline-0.01.tar.gz' => {'author' => 'JARW','description' => 'Cubic Spline Interpolation of data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 81,'pod' => 58,'pod_errors' => 0,'total' => 139,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 2667,'unpacked' => 5444},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['Carp','Exporter','Math::Derivative','strict']},'Math-Stat-0.1.tar.gz' => {'author' => 'GSCHLOSS','description' => 'Perform Sample Statistics on Arrays','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 256,'pod' => 58,'pod_errors' => 0,'total' => 314,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 9709,'unpacked' => 27872},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['AutoLoader','Exporter','strict','vars','warnings']},'Math-String-1.22.tar.gz' => {'author' => 'TELS','description' => 'Arbitrary sized integers having arbitrary charsets to calculate with password/key rooms.','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 3501,'pod' => 2905,'pod_errors' => 0,'total' => 6406,'with_comments' => 706},'releases' => 11,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.38','Math::BigInt' => '1.64'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 59596,'unpacked' => 223218},'testers' => {'pass' => 1},'uses' => ['5.005','Carp','Exporter','Math::BigInt','Math::String::Charset::Wordlist','constant','strict','vars']},'Math-String-Charset-Wordlist-0.05.tar.gz' => {'author' => 'TELS','description' => 'A dictionary charset for Math::String','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 544,'pod' => 263,'pod_errors' => 0,'total' => 807,'with_comments' => 103},'releases' => 3,'requires' => ['Math-BigInt-1.64.tar.gz','Math-String-1.22.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.38','Math::BigInt' => '1.64','Math::String' => '1.22','Test::Simple' => '0.48'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Math-BigInt-1.64.tar.gz','Math-String-1.22.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 17182,'unpacked' => 52611},'testers' => {},'uses' => ['5.005','Math::BigInt','Math::String::Charset','strict','vars']},'Math-Symbolic-0.110.tar.gz' => {'author' => 'SMUELLER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2575,'pod' => 941,'pod_errors' => 0,'total' => 3516,'with_comments' => 36},'releases' => 11,'requires' => ['Data-Dumper-2.101.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Exporter' => 0,'Parse::RecDescent' => 0,'Test::More' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 30650,'unpacked' => 143883},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Exporter','Parse::RecDescent','constant','strict','warnings']},'Math-Trig-Units-0.03.tar.gz' => {'author' => 'JFREEMAN','description' => 'Inverse and hyperbolic trigonemetric Functions in degrees, radians or gradians.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 270,'pod' => 325,'pod_errors' => 0,'total' => 595,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 9079,'unpacked' => 51824},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','vars']},'Math-TrulyRandom-1.0.tar.gz' => {'author' => 'GARY','description' => 'based on interrupt timing discrepancies','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 25,'pod' => 27,'pod_errors' => 0,'total' => 52,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 4272,'unpacked' => 8232},'testers' => {'pass' => 4},'uses' => ['DynaLoader','Exporter']},'Math-Units-1.2.tar.gz' => {'author' => 'KENFOX','description' => 'Unit conversion','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 970,'pod' => 23,'pod_errors' => 0,'total' => 993,'with_comments' => 193},'releases' => 1,'size' => {'packed' => 12148,'unpacked' => 36176},'testers' => {'fail' => 7},'uses' => ['Carp','Exporter','strict','vars']},'Math-VecStat-0.08.tar.gz' => {'author' => 'ASPINELLI','description' => 'Some basic numeric stats on vectors','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 187,'pod' => 160,'pod_errors' => 0,'total' => 347,'with_comments' => 23},'releases' => 6,'size' => {'packed' => 4539,'unpacked' => 13558},'testers' => {'pass' => 5},'uses' => ['Exporter','strict']},'Math-Vector-SortIndexes-0.02.tar.gz' => {'author' => 'SPLICE','description' => 'Sort the indices of a numeric vector','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1366,'pod' => 964,'pod_errors' => 0,'total' => 2330,'with_comments' => 53},'releases' => 2,'size' => {'packed' => 18985,'unpacked' => 56300},'testers' => {'pass' => 5},'uses' => ['Exporter']},'Math-VectorReal-1.02.tar.gz' => {'author' => 'ANTHONY','description' => 'Handling 3D Vector Mathematics','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 443,'pod' => 197,'pod_errors' => 0,'total' => 640,'with_comments' => 64},'releases' => 3,'size' => {'packed' => 12703,'unpacked' => 41046},'testers' => {'pass' => 7},'uses' => ['Carp','Exporter','Math::MatrixReal','strict','vars']},'Math-XOR-0.02.tar.gz' => {'author' => 'CRAKRJACK','description' => 'Package to handle XOR encryption of string b','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 37,'pod' => 34,'pod_errors' => 0,'total' => 71,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2039,'unpacked' => 3495},'testers' => {'pass' => 6},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Math-ematica-1.006.tar.gz' => {'author' => 'ULPFR','description' => 'Interface to the powerful Mathematica system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 363,'pod' => 131,'pod_errors' => 1,'total' => 494,'with_comments' => 71},'releases' => 6,'size' => {'packed' => 12398,'unpacked' => 49225},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter']},'Mcrypt-2.4.8.2.tar.gz' => {'author' => 'JESUS','description' => 'Perl extension for the Mcrypt cryptography library','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 221,'pod' => 99,'pod_errors' => 0,'total' => 320,'with_comments' => 15},'releases' => 2,'size' => {'packed' => 6384,'unpacked' => 31444},'testers' => {},'uses' => ['5.004','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'MegaHAL-0.03.tar.gz' => {'author' => 'CSPENCER','description' => 'Perl interface to the MegaHAL natural language conversation simulator.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 128,'pod' => 84,'pod_errors' => 0,'total' => 212,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 3871,'unpacked' => 9247},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'MemHandle-0.06.tar.gz' => {'author' => 'SCR','description' => 'supply memory-based FILEHANDLE methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 246,'pod' => 119,'pod_errors' => 0,'total' => 365,'with_comments' => 14},'releases' => 6,'size' => {'packed' => 5058,'unpacked' => 17013},'testers' => {'pass' => 3},'uses' => ['5.000','Exporter','IO::Handle','IO::Seekable','Symbol','strict','vars']},'Memo32-1.01a.zip' => {'author' => 'WARTHURT','description' => 'Read & Write Palm Memo32 (pn32) pdbs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 155,'pod' => 65,'pod_errors' => 0,'total' => 220,'with_comments' => 40},'releases' => 2,'size' => {'packed' => 3892,'unpacked' => 6339},'testers' => {'fail' => 2,'tests' => '1'},'uses' => ['strict','vars']},'Memoize-1.01.tar.gz' => {'author' => 'MJD','description' => 'Make functions faster by trading space for time','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1245,'pod' => 721,'pod_errors' => 0,'total' => 1966,'with_comments' => 127},'releases' => 19,'size' => {'packed' => 47495,'unpacked' => 143786},'testers' => {'fail' => 2,'pass' => 20,'tests' => '179'},'uses' => ['5.00556','Carp','Config','Exporter','NDBM_File','SDBM_File','strict','vars']},'Memoize-ExpireLRU-0.55.tar.gz' => {'author' => 'BPOWERS','description' => 'Provide LRU Expiration for Memoize','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 347,'pod' => 48,'pod_errors' => 0,'total' => 395,'with_comments' => 64},'releases' => 3,'requires' => ['Memoize-1.01.tar.gz'],'requires_module' => {'Memoize' => '0.52'},'requires_recursive' => ['Memoize-1.01.tar.gz'],'size' => {'packed' => 5887,'unpacked' => 16259},'testers' => {'pass' => 8},'uses' => ['AutoLoader','Carp','strict','vars']},'Merge-HashRef-0.01.tar.gz' => {'author' => 'STRYTOAST','description' => 'make one hashref out of many!','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 62,'pod' => 43,'pod_errors' => 0,'total' => 105,'with_comments' => 0},'releases' => 1,'requires' => ['Exporter-Simple-1.10.tar.gz','Test-Class-0.03.tar.gz'],'requires_module' => {'Exporter::Simple' => '1.1','Test::Class' => '0.03'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Attribute-Handlers-0.78.tar.gz','Class-ISA-0.32.tar.gz','Exporter-Simple-1.10.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Storable-2.07.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Class-0.03.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz'],'size' => {'packed' => 2119,'unpacked' => 3750},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter::Simple','Test::Class','Test::More','strict','warnings']},'MersenneTwister-1.0.1.tar.gz' => {'author' => 'JESUS','description' => 'Perl extension for a Mersenne Twister PRGN implementation with context.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 102,'pod' => 55,'pod_errors' => 0,'total' => 157,'with_comments' => 14},'releases' => 2,'size' => {'packed' => 3938,'unpacked' => 9247},'testers' => {'pass' => 3},'uses' => ['5.004','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Meschach-0.03.tar.gz' => {'author' => 'EGROSS','description' => 'Links PDL to meschach matrix library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1004,'pod' => 295,'pod_errors' => 1,'total' => 1299,'with_comments' => 136},'releases' => 2,'size' => {'packed' => 336403,'unpacked' => 1381424},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','PDL','PDL::Core','strict','vars']},'Meta-0.03.tar.gz' => {'author' => 'VELTZER','description' => 'data structure that represents a set.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 31322,'pod' => 29222,'pod_errors' => 0,'total' => 60544,'with_comments' => 3312},'releases' => 6,'requires' => ['ANSIColor-1.07.tar.gz','Archive-Tar-1.03.tar.gz','Class-Fields-0.16.tar.gz','Class-MethodMaker-1.10.tar.gz','Compress-Zlib-1.22.tar.gz','DBI-1.37.tar.gz','DB_File-1.806.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','Expect-1.15.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','Frontier-RPC-0.06.tar.gz','Getopt-Long-2.33.tar.gz','GraphViz-1.8.tar.gz','Gtk-Perl-0.7009.tar.gz','HTML-Parser-3.28.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','Mail-Sendmail-0.79.tar.gz','PerlMagick-5.56.tar.gz','Pod-LaTeX-0.55.tar.gz','PodParser-1.23.tar.gz','SOAP-Lite-0.55.tar.gz','SQL-Statement-1.005.tar.gz','Template-Toolkit-2.10.tar.gz','Time-Local-1.07.tar.gz','XML-AutoWriter-0.37.tar.gz','XML-DOM-1.42.tar.gz','XML-Driver-HTML-0.06.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz','XML-XQL-0.68.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-enno-1.02.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'requires_module' => {'Archive::Tar' => '0.22','Carp' => 0,'Class::MethodMaker' => '1.02','Compress::Zlib' => '1.16','Cwd' => '2.04','DBI' => '1.201','DB_File' => '1.802','Date::Manip' => '5.4','Digest::MD5' => '2.16','DirHandle' => 0,'Expect' => '1.12','ExtUtils::MM_Unix' => '1.12603','ExtUtils::MakeMaker' => '5.45','File::Basename' => '2.6','File::Copy' => '2.03','File::Find' => 0,'File::Path' => '1.0404','File::Spec::Functions' => '1.1','File::stat' => 0,'Frontier::Client' => 0,'Frontier::Daemon' => 0,'Getopt::Long' => '2.26','GraphViz' => '1.5','Gtk' => '0.7008','HTML::Form' => '0.03','HTML::LinkExtor' => '1.31','HTTP::Request' => '1.3','HTTP::Request::Common' => '1.19','IO' => '1.2','IO::File' => '1.08','IO::Handle' => '1.21','IO::Pipe' => '1.12','IO::Socket::INET' => '1.25','IO::String' => '1.01','Image::Magick' => '5.41','LWP::UserAgent' => '2.001','Mail::Sendmail' => '0.78','Net::FTP' => '2.62','POSIX' => '1.03','Pod::Checker' => '1.2','Pod::Html' => '1.03','Pod::LaTeX' => '0.53','Pod::Man' => '1.32','Pod::Parser' => '1.13','Pod::Text' => '2.18','SOAP::Lite' => '0.52','SOAP::Transport::TCP' => '0.52','SQL::Statement' => '0.1021','Sys::Hostname' => '1.1','Template' => '2.06','Term::ANSIColor' => '1.04','Term::ReadLine' => 0,'Time::Local' => 0,'Time::localtime' => '1.01','XML::Checker::Parser' => 0,'XML::DOM' => '1.36','XML::DOM::ValParser' => 0,'XML::Doctype' => '0.11','XML::Driver::HTML' => '0.05','XML::Handler::BuildDOM' => 0,'XML::Parser' => '2.3','XML::Parser::Expat' => '2.3','XML::ValidWriter' => '0.37','XML::Writer' => '0.4','XML::XQL' => '0.66','XML::XQL::DOM' => 0,'XMLRPC::Lite' => '0.52','XMLRPC::Transport::HTTP' => '0.52','base' => '1.97','strict' => '1.01'},'requires_recursive' => ['ANSIColor-1.07.tar.gz','Archive-Tar-1.03.tar.gz','Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-MethodMaker-1.10.tar.gz','Compress-Zlib-1.22.tar.gz','DBI-1.37.tar.gz','DB_File-1.806.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','Expect-1.15.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','Frontier-RPC-0.06.tar.gz','Getopt-Long-2.33.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','Gtk-Perl-0.7009.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','Heap-0.50.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','IO-Tty-1.02.tar.gz','IPC-Run-0.75.tar.gz','MIME-Base64-2.20.tar.gz','Mail-Sendmail-0.79.tar.gz','Math-Bezier-0.01.tar.gz','Parse-Yapp-1.05.tar.gz','PerlMagick-5.56.tar.gz','Pod-LaTeX-0.55.tar.gz','PodParser-1.23.tar.gz','SOAP-Lite-0.55.tar.gz','SQL-Statement-1.005.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz','URI-1.24.tar.gz','XML-AutoWriter-0.37.tar.gz','XML-DOM-1.42.tar.gz','XML-Driver-HTML-0.06.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','XML-Writer-0.4.tar.gz','XML-XQL-0.68.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-enno-1.02.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'size' => {'packed' => 229978,'unpacked' => 1375881},'testers' => {},'uses' => ['Archive::Tar','Carp','Class::MethodMaker','Compress::Zlib','Cwd','DBI','DB_File','Date::Manip','Digest::MD5','DirHandle','Expect','ExtUtils::MM_Unix','ExtUtils::MakeMaker','File::Basename','File::Copy','File::Find','File::Path','File::Spec::Functions','File::stat','Frontier::Client','Frontier::Daemon','Getopt::Long','GraphViz','Gtk','HTML::Form','HTML::LinkExtor','HTTP::Request','HTTP::Request::Common','IO','IO::File','IO::Handle','IO::Pipe','IO::Socket::INET','IO::String','Image::Magick','LWP::UserAgent','Mail::Sendmail','Meta::Archive::MyTar','Meta::Archive::Tar','Meta::Baseline::Aegis','Meta::Baseline::Arch','Meta::Baseline::Cook','Meta::Baseline::Lang','Meta::Baseline::Lang::Aegi','Meta::Baseline::Lang::Aspe','Meta::Baseline::Lang::Awkx','Meta::Baseline::Lang::Bins','Meta::Baseline::Lang::Ccxx','Meta::Baseline::Lang::Chec','Meta::Baseline::Lang::Chun','Meta::Baseline::Lang::Clas','Meta::Baseline::Lang::Conf','Meta::Baseline::Lang::Cook','Meta::Baseline::Lang::Cssx','Meta::Baseline::Lang::Cxxx','Meta::Baseline::Lang::Data','Meta::Baseline::Lang::Dbxx','Meta::Baseline::Lang::Deps','Meta::Baseline::Lang::Dirx','Meta::Baseline::Lang::Dlls','Meta::Baseline::Lang::Dslx','Meta::Baseline::Lang::Dtdx','Meta::Baseline::Lang::Dvix','Meta::Baseline::Lang::Epsx','Meta::Baseline::Lang::Gzxx','Meta::Baseline::Lang::Html','Meta::Baseline::Lang::Info','Meta::Baseline::Lang::Java','Meta::Baseline::Lang::Jpgx','Meta::Baseline::Lang::Late','Meta::Baseline::Lang::Libs','Meta::Baseline::Lang::Lily','Meta::Baseline::Lang::Lyxx','Meta::Baseline::Lang::Manx','Meta::Baseline::Lang::Midi','Meta::Baseline::Lang::Mifx','Meta::Baseline::Lang::Nrfx','Meta::Baseline::Lang::Objs','Meta::Baseline::Lang::Pack','Meta::Baseline::Lang::Pdfx','Meta::Baseline::Lang::Perl','Meta::Baseline::Lang::Pngx','Meta::Baseline::Lang::Psxx','Meta::Baseline::Lang::Pyob','Meta::Baseline::Lang::Pyth','Meta::Baseline::Lang::Rcxx','Meta::Baseline::Lang::Rtfx','Meta::Baseline::Lang::Rule','Meta::Baseline::Lang::Sgml','Meta::Baseline::Lang::Swig','Meta::Baseline::Lang::Targ','Meta::Baseline::Lang::Temp','Meta::Baseline::Lang::Texx','Meta::Baseline::Lang::Txtx','Meta::Baseline::Lang::Xmlx','Meta::Baseline::Utils','Meta::Chess::Board','Meta::Chess::Side','Meta::Chess::Tuple','Meta::Class::MethodMaker','Meta::Db::Connection','Meta::Db::Connections','Meta::Db::Constraint','Meta::Db::Constraints','Meta::Db::Dbi','Meta::Db::Def','Meta::Db::Enum','Meta::Db::Enums','Meta::Db::Field','Meta::Db::Fields','Meta::Db::Info','Meta::Db::Member','Meta::Db::Ops','Meta::Db::Parents','Meta::Db::Set','Meta::Db::Sets','Meta::Db::Table','Meta::Db::Tables','Meta::Db::Type','Meta::Db::User','Meta::Db::Users','Meta::Development::Deps','Meta::Development::Link','Meta::Development::Links','Meta::Development::PackModule','Meta::Distrib::File','Meta::Distrib::Files','Meta::Distrib::Machine','Meta::Distrib::Machines','Meta::Ds::Array','Meta::Ds::Connected','Meta::Ds::Dgraph','Meta::Ds::Dhash','Meta::Ds::Enum','Meta::Ds::Enumerated','Meta::Ds::Graph','Meta::Ds::Hash','Meta::Ds::Ochash','Meta::Ds::Ohash','Meta::Ds::Oset','Meta::Ds::Set','Meta::Ds::Stack','Meta::Ds::String','Meta::Geo::Pos2d','Meta::Info::Address','Meta::Info::Affiliation','Meta::Info::Author','Meta::Info::Credit','Meta::Lang::Cpp::Libs','Meta::Lang::Docb::Params','Meta::Lang::Html::Html','Meta::Lang::Perl::Deps','Meta::Lang::Perl::Interface','Meta::Lang::Perl::Perl','Meta::Lang::Perl::Perlpkg','Meta::Lang::Perl::Perlpkgs','Meta::Lang::Sgml::Sgml','Meta::Lang::Xml::Xml','Meta::Math::Matrix','Meta::Math::Pad','Meta::Pdmt::BuildInfo','Meta::Pdmt::Graph','Meta::Pdmt::Handlers','Meta::Pdmt::Listen','Meta::Revision::Entry','Meta::Revision::Revision','Meta::Sql::Stat','Meta::Sql::Stats','Meta::Tool::Aegis','Meta::Tool::Aspell','Meta::Tool::Cincl','Meta::Tool::Docbook2','Meta::Tool::Dvi','Meta::Tool::Editor','Meta::Tool::Gcc','Meta::Tool::Gzip','Meta::Tool::Jade','Meta::Tool::Lilypond','Meta::Tool::Nsgmls','Meta::Tool::Onsgmls','Meta::Tool::Openjade','Meta::Tool::Sgml2','Meta::Tool::Sgmltools','Meta::Tool::Sgmltoolslite','Meta::Utils::Arg','Meta::Utils::Color','Meta::Utils::Debug','Meta::Utils::Env','Meta::Utils::File::Collect','Meta::Utils::File::Copy','Meta::Utils::File::Dir','Meta::Utils::File::File','Meta::Utils::File::Fs','Meta::Utils::File::Mkdir','Meta::Utils::File::Move','Meta::Utils::File::Path','Meta::Utils::File::Patho','Meta::Utils::File::Prop','Meta::Utils::File::Purge','Meta::Utils::File::Remove','Meta::Utils::File::Symlink','Meta::Utils::File::Touch','Meta::Utils::Hash','Meta::Utils::List','Meta::Utils::Net::Cp','Meta::Utils::Net::Hostname','Meta::Utils::Net::Md','Meta::Utils::Net::Rm','Meta::Utils::Options','Meta::Utils::Opts::Sopt','Meta::Utils::Output','Meta::Utils::Parse::Text','Meta::Utils::Pc','Meta::Utils::Progname','Meta::Utils::String','Meta::Utils::System','Meta::Utils::Text::Lines','Meta::Utils::Text::Unique','Meta::Utils::Time','Meta::Utils::Unix','Meta::Utils::Utils','Meta::Xml::Parsers::Author','Meta::Xml::Parsers::Base','Meta::Xml::Parsers::Checker','Meta::Xml::Parsers::Connections','Meta::Xml::Parsers::Dbdata','Meta::Xml::Parsers::Def','Meta::Xml::Parsers::Deps','Meta::Xml::Parsers::Graph','Meta::Xml::Parsers::Links','Meta::Xml::Parsers::Perlpkgs','Meta::Xml::Parsers::Type','Meta::Xml::Writer','Net::FTP','POSIX','Pod::Checker','Pod::Html','Pod::LaTeX','Pod::Man','Pod::Parser','Pod::Text','SOAP::Lite','SOAP::Transport::TCP','SQL::Statement','Sys::Hostname','Template','Term::ANSIColor','Term::ReadLine','Time::Local','Time::localtime','XML::Checker::Parser','XML::DOM','XML::DOM::ValParser','XML::Doctype','XML::Driver::HTML','XML::Handler::BuildDOM','XML::Parser','XML::Parser::Expat','XML::ValidWriter','XML::Writer','XML::XQL','XML::XQL::DOM','XMLRPC::Lite','XMLRPC::Transport::HTTP','strict']},'Meta-0.05.tar.gz' => {'author' => 'VELTZER','description' => 'data structure that represents a set.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 35733,'pod' => 34555,'pod_errors' => 0,'total' => 70288,'with_comments' => 3900},'releases' => 6,'requires' => ['ANSIColor-1.07.tar.gz','Archive-Tar-1.03.tar.gz','BerkeleyDB-0.23.tar.gz','CGI.pm-2.98.tar.gz','Chess-PGN-Parse-0.17.tgz','Class-Fields-0.16.tar.gz','Class-MethodMaker-1.10.tar.gz','Compress-Zlib-1.22.tar.gz','Convert-UU-0.52.tar.gz','DBI-1.37.tar.gz','DB_File-1.806.tar.gz','Data-DumpXML-1.05.tar.gz','Data-ShowTable-3.3.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','Expect-1.15.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-MMagic-1.19.tar.gz','Frontier-RPC-0.06.tar.gz','GD-2.07.tar.gz','Getopt-Long-2.33.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','GraphViz-ISA-0.01.tar.gz','Gtk-Perl-0.7000.tar.gz','Gtk-Perl-0.7008.tar.gz','Gtk-Perl-0.7009.tar.gz','HTML-DOMbo-3.08.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','Image-GD-Thumbnail-0.02.tar.gz','Image-Size-2.992.tar.gz','MIME-Base64-2.20.tar.gz','Mail-Sendmail-0.79.tar.gz','Module-Info-0.20.tar.gz','Parse-RecDescent-1.94.tar.gz','PerlMagick-5.56.tar.gz','Pod-LaTeX-0.55.tar.gz','Pod-POM-0.15.tar.gz','PodParser-1.23.tar.gz','SGI-FAM-1.002.tar.gz','SOAP-Lite-0.55.tar.gz','SQL-Statement-1.005.tar.gz','Template-Toolkit-2.10.tar.gz','TermReadKey-2.21.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','Time-Object-1.00.tar.gz','Time-modules-2003.0211.tar.gz','TimeDate-1.16.tar.gz','Tk-800.024.tar.gz','XML-AutoWriter-0.37.tar.gz','XML-DOM-1.42.tar.gz','XML-Driver-HTML-0.06.tar.gz','XML-Dumper-0.4.tar.gz','XML-Generator-0.93.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','XML-Parser-2.31.tar.gz','XML-Simple-2.08.tar.gz','XML-Writer-0.4.tar.gz','XML-XPath-1.13.tar.gz','XML-XQL-0.68.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-enno-1.02.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'requires_module' => {'Archive::Tar' => '0.22','BerkeleyDB' => '0.19','CGI' => '2.81','Carp' => undef,'Chess::PGN::Parse' => '0.07','Class::MethodMaker' => '1.06','Compress::Zlib' => '1.16','Convert::UU' => '0.4','Cwd' => '2.04','DBI' => '1.28','DB_File' => '1.804','Data::DumpXML' => '1.03','Data::ShowTable' => undef,'Date::Manip' => '5.4','Date::Parse' => '2.23','Digest::MD5' => '2.2','DirHandle' => undef,'Expect' => '1.15','ExtUtils::Installed' => '0.06','ExtUtils::MM_Unix' => '1.33','ExtUtils::MakeMaker' => '6.03','Fcntl' => '1.03','File::Basename' => '2.6','File::Copy' => '2.03','File::Find' => undef,'File::MMagic' => '1.15','File::Path' => '1.0404','File::Spec::Functions' => '1.1','File::stat' => undef,'Frontier::Client' => undef,'Frontier::Daemon' => undef,'GD' => '1.4','Getopt::Long' => '2.32','Gnome' => '0.7008','Graph::Directed' => undef,'GraphViz' => '1.5','GraphViz::ISA' => '0.01','Gtk' => '0.7008','Gtk::Gdk' => undef,'Gtk::Gdk::ImlibImage' => '0.7008','HTML::DOMbo' => '3.08','HTML::Form' => '0.03','HTML::LinkExtor' => '1.31','HTML::TreeBuilder' => '3.11','HTTP::Request' => '1.3','HTTP::Request::Common' => '1.19','IO' => '1.2','IO::File' => '1.08','IO::Handle' => '1.21','IO::Pipe' => '1.121','IO::Socket::INET' => '1.25','IO::String' => '1.01','Image::GD::Thumbnail' => '0.02','Image::Magick' => '5.41','Image::Size' => '2.99','LWP::UserAgent' => '2.001','MIME::Base64' => '2.12','Mail::Sendmail' => '0.78','Module::Info' => '0.12','Net::FTP' => '2.65','POSIX' => '1.03','Parse::RecDescent' => '1.8','Pod::Checker' => '1.2','Pod::Html' => '1.03','Pod::LaTeX' => '0.53','Pod::Man' => '1.33','Pod::POM' => '0.15','Pod::Parser' => '1.13','Pod::Text' => '2.19','SGI::FAM' => '1.002','SOAP::Lite' => '0.55','SOAP::Transport::TCP' => '0.55','SQL::Statement' => '0.1021','Symbol' => '1.02','Sys::Hostname' => '1.1','Sys::Syslog' => '0.01','Template' => '2.07','Template::Parser' => '2.53','Term::ANSIColor' => '1.04','Term::ReadKey' => '2.2','Term::ReadLine' => undef,'Text::Wrap' => '2001.0929','Time::Local' => undef,'Time::Object' => 1,'Time::Timezone' => '101.062101','Time::localtime' => '1.01','Tk' => '800.024','XML::Checker::Parser' => undef,'XML::DOM' => '1.39','XML::DOM::ValParser' => undef,'XML::Doctype' => '0.11','XML::Driver::HTML' => '0.05','XML::Dumper' => '0.4','XML::Generator' => '0.91','XML::Handler::BuildDOM' => undef,'XML::Handler::YAWriter' => '0.23','XML::Parser' => '2.31','XML::Parser::Expat' => '2.31','XML::Simple' => '1.08','XML::ValidWriter' => '0.37','XML::Writer' => '0.4','XML::XPath::XMLParser' => undef,'XML::XQL' => '0.67','XML::XQL::DOM' => undef,'XMLRPC::Lite' => '0.55','base' => '1.01','strict' => '1.01'},'requires_recursive' => ['ANSIColor-1.07.tar.gz','Archive-Tar-1.03.tar.gz','Array-RefElem-0.02.tar.gz','BerkeleyDB-0.23.tar.gz','CGI.pm-2.98.tar.gz','Carp-Assert-0.17.tar.gz','Chess-PGN-Parse-0.17.tgz','Class-Fields-0.16.tar.gz','Class-MethodMaker-1.10.tar.gz','Compress-Zlib-1.22.tar.gz','Convert-UU-0.52.tar.gz','DBI-1.37.tar.gz','DB_File-1.806.tar.gz','Data-DumpXML-1.05.tar.gz','Data-Dumper-2.101.tar.gz','Data-ShowTable-3.3.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','Expect-1.15.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-MMagic-1.19.tar.gz','File-PathConvert-0.9.tar.gz','File-Spec-0.82.tar.gz','Frontier-RPC-0.06.tar.gz','GD-2.07.tar.gz','Getopt-Long-2.33.tar.gz','Getopt-Mixed-1.008.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','GraphViz-ISA-0.01.tar.gz','Gtk-Perl-0.7000.tar.gz','Gtk-Perl-0.7008.tar.gz','Gtk-Perl-0.7009.tar.gz','HTML-DOMbo-3.08.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','Heap-0.50.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','IO-Tty-1.02.tar.gz','IPC-Run-0.75.tar.gz','Image-GD-Thumbnail-0.02.tar.gz','Image-Size-2.992.tar.gz','MD5-2.02.tar.gz','MIME-Base64-2.20.tar.gz','Mail-Sendmail-0.79.tar.gz','Math-Bezier-0.01.tar.gz','Module-Info-0.20.tar.gz','Parse-RecDescent-1.94.tar.gz','Parse-Yapp-1.05.tar.gz','PerlMagick-5.56.tar.gz','Pod-LaTeX-0.55.tar.gz','Pod-POM-0.15.tar.gz','PodParser-1.23.tar.gz','SGI-FAM-1.002.tar.gz','SOAP-Lite-0.55.tar.gz','SQL-Statement-1.005.tar.gz','Template-Toolkit-2.10.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','Time-Object-1.00.tar.gz','Time-modules-2003.0211.tar.gz','TimeDate-1.16.tar.gz','Tk-800.024.tar.gz','URI-1.24.tar.gz','XML-AutoWriter-0.37.tar.gz','XML-DOM-1.42.tar.gz','XML-Driver-HTML-0.06.tar.gz','XML-Dumper-0.4.tar.gz','XML-Generator-0.93.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','XML-Simple-2.08.tar.gz','XML-Writer-0.4.tar.gz','XML-XPath-1.13.tar.gz','XML-XQL-0.68.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-enno-1.02.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'size' => {'packed' => 369082,'unpacked' => 2562960},'testers' => {},'uses' => ['Archive::Tar','Carp','Class::MethodMaker','Compress::Zlib','Cwd','DBI','DB_File','Data::Dumper','Date::Manip','Digest::MD5','DirHandle','Expect','ExtUtils::MM_Unix','ExtUtils::MakeMaker','File::Basename','File::Copy','File::Find','File::Path','File::Spec::Functions','File::stat','Frontier::Client','Frontier::Daemon','Getopt::Long','Graph::Directed','GraphViz','Gtk','HTML::Form','HTML::LinkExtor','HTTP::Request','HTTP::Request::Common','HTTP::Status','IO','IO::File','IO::Handle','IO::Pipe','IO::Socket::INET','IO::String','Image::Magick','LWP::UserAgent','Mail::Sendmail','Meta::Archive::MyTar','Meta::Archive::Tar','Meta::Baseline::Aegis','Meta::Baseline::Arch','Meta::Baseline::Cook','Meta::Baseline::Lang','Meta::Baseline::Lang::Aegi','Meta::Baseline::Lang::Ascx','Meta::Baseline::Lang::Aspe','Meta::Baseline::Lang::Awkx','Meta::Baseline::Lang::Bdbx','Meta::Baseline::Lang::Bins','Meta::Baseline::Lang::Ccxx','Meta::Baseline::Lang::Chec','Meta::Baseline::Lang::Chun','Meta::Baseline::Lang::Clas','Meta::Baseline::Lang::Conf','Meta::Baseline::Lang::Cook','Meta::Baseline::Lang::Cssx','Meta::Baseline::Lang::Cxxx','Meta::Baseline::Lang::Data','Meta::Baseline::Lang::Dbxx','Meta::Baseline::Lang::Deps','Meta::Baseline::Lang::Dirx','Meta::Baseline::Lang::Dlls','Meta::Baseline::Lang::Dslx','Meta::Baseline::Lang::Dtdx','Meta::Baseline::Lang::Dvix','Meta::Baseline::Lang::Epsx','Meta::Baseline::Lang::Gzxx','Meta::Baseline::Lang::Html','Meta::Baseline::Lang::Info','Meta::Baseline::Lang::Java','Meta::Baseline::Lang::Jpgx','Meta::Baseline::Lang::Late','Meta::Baseline::Lang::Libs','Meta::Baseline::Lang::Lily','Meta::Baseline::Lang::Lyxx','Meta::Baseline::Lang::Manx','Meta::Baseline::Lang::Midi','Meta::Baseline::Lang::Mifx','Meta::Baseline::Lang::Nrfx','Meta::Baseline::Lang::Objs','Meta::Baseline::Lang::Pack','Meta::Baseline::Lang::Patc','Meta::Baseline::Lang::Pdfx','Meta::Baseline::Lang::Perl','Meta::Baseline::Lang::Pgnx','Meta::Baseline::Lang::Pngx','Meta::Baseline::Lang::Psxx','Meta::Baseline::Lang::Pyob','Meta::Baseline::Lang::Pyth','Meta::Baseline::Lang::Rcxx','Meta::Baseline::Lang::Rtfx','Meta::Baseline::Lang::Rule','Meta::Baseline::Lang::Sgml','Meta::Baseline::Lang::Swig','Meta::Baseline::Lang::Targ','Meta::Baseline::Lang::Temp','Meta::Baseline::Lang::Texx','Meta::Baseline::Lang::Txtx','Meta::Baseline::Lang::Xmlx','Meta::Baseline::Lang::Xslt','Meta::Baseline::Utils','Meta::Chess::Board','Meta::Chess::Side','Meta::Chess::Tuple','Meta::Class::MethodMaker','Meta::Db::Connection','Meta::Db::Connections','Meta::Db::Constraint','Meta::Db::Constraints','Meta::Db::Dbi','Meta::Db::Def','Meta::Db::Enum','Meta::Db::Enums','Meta::Db::Field','Meta::Db::Fields','Meta::Db::Info','Meta::Db::Member','Meta::Db::Ops','Meta::Db::Parents','Meta::Db::Set','Meta::Db::Sets','Meta::Db::Table','Meta::Db::Tables','Meta::Db::Type','Meta::Db::User','Meta::Db::Users','Meta::Development::Deps','Meta::Development::Link','Meta::Development::Links','Meta::Development::Module','Meta::Development::PackModule','Meta::Development::Verbose','Meta::Digest::MD5','Meta::Distrib::File','Meta::Distrib::Files','Meta::Distrib::Machine','Meta::Distrib::Machines','Meta::Ds::Array','Meta::Ds::Connected','Meta::Ds::Dhash','Meta::Ds::Enum','Meta::Ds::Enumerated','Meta::Ds::Graph','Meta::Ds::Hash','Meta::Ds::Ochash','Meta::Ds::Ohash','Meta::Ds::Oset','Meta::Ds::Set','Meta::Ds::Stack','Meta::Ds::String','Meta::Geo::Pos2d','Meta::Graph::Directed','Meta::Info::Address','Meta::Info::Affiliation','Meta::Info::Author','Meta::Info::Credit','Meta::Lang::Cpp::Libs','Meta::Lang::Docb::Params','Meta::Lang::Html::Html','Meta::Lang::Lily::InfoParser','Meta::Lang::Perl::Deps','Meta::Lang::Perl::Interface','Meta::Lang::Perl::Perl','Meta::Lang::Perl::Perlpkg','Meta::Lang::Perl::Perlpkgs','Meta::Lang::Sgml::Sgml','Meta::Lang::Tt::Tt','Meta::Lang::Xml::Xml','Meta::Math::Matrix','Meta::Math::Pad','Meta::Module::Info','Meta::Pdmt::BuildInfo','Meta::Pdmt::Graph','Meta::Pdmt::Handlers','Meta::Pdmt::Listen','Meta::Pdmt::Node','Meta::Revision::Entry','Meta::Revision::Revision','Meta::Sql::Stat','Meta::Sql::Stats','Meta::Tool::Aegis','Meta::Tool::Aspell','Meta::Tool::Cincl','Meta::Tool::Docbook2','Meta::Tool::Dvi','Meta::Tool::Editor','Meta::Tool::Gcc','Meta::Tool::Gzip','Meta::Tool::Jade','Meta::Tool::Lilypond','Meta::Tool::Nsgmls','Meta::Tool::Onsgmls','Meta::Tool::Openjade','Meta::Tool::Sgml2','Meta::Tool::Sgmltools','Meta::Tool::Sgmltoolslite','Meta::Utils::Arg','Meta::Utils::Color','Meta::Utils::Debug','Meta::Utils::Env','Meta::Utils::File::Collect','Meta::Utils::File::Copy','Meta::Utils::File::Dir','Meta::Utils::File::File','Meta::Utils::File::Fs','Meta::Utils::File::Mkdir','Meta::Utils::File::Move','Meta::Utils::File::Path','Meta::Utils::File::Patho','Meta::Utils::File::Prop','Meta::Utils::File::Purge','Meta::Utils::File::Remove','Meta::Utils::File::Symlink','Meta::Utils::File::Time','Meta::Utils::File::Touch','Meta::Utils::Hash','Meta::Utils::List','Meta::Utils::Net::Cp','Meta::Utils::Net::Hostname','Meta::Utils::Net::Md','Meta::Utils::Net::Rm','Meta::Utils::Options','Meta::Utils::Opts::Sopt','Meta::Utils::Output','Meta::Utils::Parse::Text','Meta::Utils::Pc','Meta::Utils::Progname','Meta::Utils::String','Meta::Utils::System','Meta::Utils::Text::Checker','Meta::Utils::Text::Counter','Meta::Utils::Text::Lines','Meta::Utils::Text::Unique','Meta::Utils::Time','Meta::Utils::Unix','Meta::Utils::Utils','Meta::Xml::Dom','Meta::Xml::Parsers::Author','Meta::Xml::Parsers::Base','Meta::Xml::Parsers::Checker','Meta::Xml::Parsers::Collector','Meta::Xml::Parsers::Connections','Meta::Xml::Parsers::Dbdata','Meta::Xml::Parsers::Def','Meta::Xml::Parsers::Deps','Meta::Xml::Parsers::Dom','Meta::Xml::Parsers::Graph','Meta::Xml::Parsers::Links','Meta::Xml::Parsers::Perlpkgs','Meta::Xml::Parsers::Type','Meta::Xml::Parsers::User','Meta::Xml::Writer','Module::Info','Net::FTP','POSIX','Parse::RecDescent','Pod::Checker','Pod::Html','Pod::LaTeX','Pod::Man','Pod::POM','Pod::POM::View::Pod','Pod::Parser','Pod::Text','SOAP::Lite','SOAP::Transport::TCP','SQL::Statement','Symbol','Sys::Hostname','Template','Term::ANSIColor','Term::ReadLine','Time::Local','Time::localtime','XML::Checker::Parser','XML::DOM','XML::DOM::ValParser','XML::Doctype','XML::Driver::HTML','XML::Handler::BuildDOM','XML::Parser::Expat','XML::Simple','XML::ValidWriter','XML::Writer','XML::XQL','XML::XQL::DOM','XMLRPC::Lite','XMLRPC::Transport::HTTP','strict','sys::ioctl.ph']},'Meta-0.06.tar.gz' => {'author' => 'VELTZER','description' => 'data structure that represents a set.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 37787,'pod' => 36433,'pod_errors' => 0,'total' => 74220,'with_comments' => 4155},'releases' => 6,'requires' => ['ANSIColor-1.07.tar.gz','Archive-Tar-1.03.tar.gz','BerkeleyDB-0.23.tar.gz','CGI.pm-2.98.tar.gz','Cache-Cache-1.02.tar.gz','Chess-PGN-Parse-0.17.tgz','Class-DBI-0.93.tar.gz','Class-Fields-0.16.tar.gz','Class-MethodMaker-1.10.tar.gz','Compress-Bzip2-1.00.tar.gz','Compress-Zlib-1.22.tar.gz','Convert-UU-0.52.tar.gz','DBI-1.37.tar.gz','DB_File-1.806.tar.gz','Data-DumpXML-1.05.tar.gz','Data-Dumper-2.101.tar.gz','Data-ShowTable-3.3.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','Expect-1.15.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','Frontier-RPC-0.06.tar.gz','GD-2.07.tar.gz','Getopt-Long-2.33.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','GraphViz-ISA-0.01.tar.gz','Gtk-Perl-0.7000.tar.gz','Gtk-Perl-0.7008.tar.gz','Gtk-Perl-0.7009.tar.gz','HTML-DOMbo-3.08.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','IO-Filter-0.01.tar.gz','IO-String-1.02.tar.gz','Image-GD-Thumbnail-0.02.tar.gz','Image-Size-2.992.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Types-1.06.tar.gz','Mail-Sendmail-0.79.tar.gz','Module-Info-0.20.tar.gz','OpenFrame-2.12.tar.gz','OpenFrame-3.02.tar.gz','OpenFrame-3.03.tar.gz','Parse-RecDescent-1.94.tar.gz','PerlMagick-5.56.tar.gz','Pipeline-3.04.tar.gz','Pod-LaTeX-0.55.tar.gz','Pod-POM-0.15.tar.gz','PodParser-1.23.tar.gz','SGI-FAM-1.002.tar.gz','SOAP-Lite-0.55.tar.gz','SQL-Statement-1.005.tar.gz','Template-Toolkit-2.10.tar.gz','TermReadKey-2.21.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','Time-Object-1.00.tar.gz','Time-modules-2003.0211.tar.gz','TimeDate-1.16.tar.gz','Tk-800.024.tar.gz','XML-AutoWriter-0.37.tar.gz','XML-DOM-1.42.tar.gz','XML-Driver-HTML-0.06.tar.gz','XML-Dumper-0.4.tar.gz','XML-Generator-0.93.tar.gz','XML-Handler-Dtd2Html-0.32.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-Parser-2.31.tar.gz','XML-Simple-2.08.tar.gz','XML-Writer-0.4.tar.gz','XML-XPath-1.13.tar.gz','XML-XQL-0.68.tar.gz','XML-XSLT-0.40.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-enno-1.02.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'requires_module' => {'Archive::Tar' => '0.22','BerkeleyDB' => '0.19','CGI' => '2.81','Cache::MemoryCache' => undef,'Carp' => undef,'Chess::PGN::Parse' => '0.07','Class::DBI' => '0.89','Class::MethodMaker' => '1.06','Compress::Bzip2' => 1,'Compress::Zlib' => '1.16','Convert::UU' => '0.4','Cwd' => '2.04','DBI' => '1.3','DB_File' => '1.804','Data::DumpXML' => '1.03','Data::Dumper' => '2.102','Data::ShowTable' => undef,'Date::Manip' => '5.4','Date::Parse' => '2.23','Digest::MD5' => '2.2','DirHandle' => undef,'Expect' => '1.15','ExtUtils::Installed' => '0.06','ExtUtils::MM_Unix' => '1.33','ExtUtils::MakeMaker' => '6.03','Fcntl' => '1.03','File::Basename' => '2.6','File::Copy' => '2.03','File::Find' => undef,'File::MMagic' => '1.15','File::Path' => '1.0404','File::Spec' => '0.82','File::Spec::Functions' => '1.1','File::stat' => undef,'Frontier::Client' => undef,'Frontier::Daemon' => undef,'GD' => '1.41','Getopt::Long' => '2.32','Gnome' => '0.7008','Graph::Directed' => undef,'GraphViz' => '1.5','GraphViz::ISA' => '0.01','Gtk' => '0.7008','Gtk::Gdk' => undef,'Gtk::Gdk::ImlibImage' => '0.7008','HTML::DOMbo' => '3.08','HTML::Form' => '0.03','HTML::LinkExtor' => '1.31','HTML::TreeBuilder' => '3.13','HTTP::Daemon' => '1.25','HTTP::Headers' => '1.43','HTTP::Request' => '1.3','HTTP::Request::Common' => '1.19','HTTP::Response' => '1.36','HTTP::Status' => '1.26','IO' => '1.2','IO::File' => '1.08','IO::Filter::gunzip' => '0.01','IO::Filter::sort' => '0.01','IO::Handle' => '1.21','IO::Pipe' => '1.121','IO::Socket::INET' => '1.25','IO::String' => '1.01','Image::GD::Thumbnail' => '0.02','Image::Magick' => '5.41','Image::Size' => '2.99','LWP::Simple' => '1.35','LWP::UserAgent' => '2.001','MIME::Base64' => '2.12','MIME::Types' => '1.002','Mail::Sendmail' => '0.78','Module::Info' => '0.12','Net::FTP' => '2.65','OpenFrame' => '3.01','OpenFrame::Constants' => undef,'OpenFrame::Response' => '3.01','OpenFrame::Segment::ContentLoader' => undef,'OpenFrame::Segment::HTTP::Request' => undef,'OpenFrame::Server::HTTP' => '2.12','OpenFrame::Slot' => '2.12','POSIX' => '1.03','Parse::RecDescent' => '1.8','Pipeline' => '2.01','Pod::Checker' => '1.2','Pod::Html' => '1.03','Pod::LaTeX' => '0.53','Pod::Man' => '1.34','Pod::POM' => '0.15','Pod::Parser' => '1.13','Pod::Text' => '2.21','SGI::FAM' => '1.002','SOAP::Lite' => '0.55','SOAP::Transport::TCP' => '0.55','SQL::Statement' => '1.004','Symbol' => '1.02','Sys::Hostname' => '1.1','Sys::Syslog' => '0.01','Template' => '2.08','Template::Parser' => '2.66','Term::ANSIColor' => '1.05','Term::ReadKey' => '2.21','Term::ReadLine' => undef,'Text::Wrap' => '2001.0929','Time::Local' => undef,'Time::Object' => 1,'Time::Timezone' => '101.062101','Time::localtime' => '1.01','Tk' => '800.024','XML::Checker::Parser' => undef,'XML::DOM' => '1.39','XML::DOM::ValParser' => undef,'XML::Doctype' => '0.11','XML::Driver::HTML' => '0.06','XML::Dumper' => '0.4','XML::Generator' => '0.91','XML::Handler::BuildDOM' => undef,'XML::Handler::Dtd2Html' => '0.11','XML::Handler::YAWriter' => '0.23','XML::LibXML' => '1.52','XML::LibXSLT' => '1.51','XML::Parser' => '2.31','XML::Parser::Expat' => '2.31','XML::Parser::PerlSAX' => '0.07','XML::Simple' => '1.08','XML::ValidWriter' => '0.37','XML::Writer' => '0.4','XML::XPath' => '1.12','XML::XQL' => '0.67','XML::XQL::DOM' => undef,'XML::XSLT' => '0.4','XMLRPC::Lite' => '0.55','base' => '1.01','strict' => '1.01'},'requires_recursive' => ['ANSIColor-1.07.tar.gz','Archive-Tar-1.03.tar.gz','Array-RefElem-0.02.tar.gz','BerkeleyDB-0.23.tar.gz','CGI.pm-2.98.tar.gz','Cache-Cache-1.02.tar.gz','Carp-Assert-0.17.tar.gz','Chatbot-Eliza-1.04.tar.gz','Chess-PGN-Parse-0.17.tgz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-ISA-0.32.tar.gz','Class-MethodMaker-1.10.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','Compress-Bzip2-1.00.tar.gz','Compress-Zlib-1.22.tar.gz','Convert-UU-0.52.tar.gz','DBI-1.37.tar.gz','DB_File-1.806.tar.gz','Data-Denter-0.15.tar.gz','Data-DumpXML-1.05.tar.gz','Data-Dumper-2.101.tar.gz','Data-ShowTable-3.3.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','Expect-1.15.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-MMagic-1.19.tar.gz','File-PathConvert-0.9.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Frontier-RPC-0.06.tar.gz','GD-2.07.tar.gz','Games-GuessWord-0.15.tar.gz','Getopt-Long-2.33.tar.gz','Getopt-Mixed-1.008.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','GraphViz-ISA-0.01.tar.gz','Gtk-Perl-0.7000.tar.gz','Gtk-Perl-0.7008.tar.gz','Gtk-Perl-0.7009.tar.gz','HTML-DOMbo-3.08.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Template-2.6.tar.gz','HTML-Tree-3.17.tar.gz','Heap-0.50.tar.gz','IO-1.20.tar.gz','IO-Filter-0.01.tar.gz','IO-Null-0.02.tar.gz','IO-String-1.02.tar.gz','IO-Tty-1.02.tar.gz','IO-stringy-2.108.tar.gz','IPC-Run-0.75.tar.gz','Ima-DBI-0.29.tar.gz','Image-GD-Thumbnail-0.02.tar.gz','Image-Size-2.992.tar.gz','MD5-2.02.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Types-1.06.tar.gz','Mail-Sendmail-0.79.tar.gz','Math-Bezier-0.01.tar.gz','Module-Info-0.20.tar.gz','OpenFrame-2.12.tar.gz','OpenFrame-3.02.tar.gz','OpenFrame-3.03.tar.gz','Parse-RecDescent-1.94.tar.gz','Parse-Yapp-1.05.tar.gz','PerlMagick-5.56.tar.gz','Pipeline-3.04.tar.gz','Pod-LaTeX-0.55.tar.gz','Pod-POM-0.15.tar.gz','PodParser-1.23.tar.gz','SGI-FAM-1.002.tar.gz','SOAP-Lite-0.55.tar.gz','SQL-Statement-1.005.tar.gz','Scalar-List-Utils-1.11.tar.gz','Storable-2.07.tar.gz','Template-Toolkit-2.10.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-Iconv-1.2.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz','Time-Object-1.00.tar.gz','Time-modules-2003.0211.tar.gz','TimeDate-1.16.tar.gz','Tk-800.024.tar.gz','URI-1.24.tar.gz','XML-AutoWriter-0.37.tar.gz','XML-DOM-1.42.tar.gz','XML-Driver-HTML-0.06.tar.gz','XML-Dumper-0.4.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-Generator-0.93.tar.gz','XML-Handler-Dtd2Html-0.32.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Expat-0.37.tar.gz','XML-SAX-Writer-0.44.tar.gz','XML-Simple-2.08.tar.gz','XML-Writer-0.4.tar.gz','XML-XPath-1.13.tar.gz','XML-XQL-0.68.tar.gz','XML-XSLT-0.40.tar.gz','YAML-0.35.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-enno-1.02.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'size' => {'packed' => 417168,'unpacked' => 2917823},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Archive::Tar','CGI','Cache::MemoryCache','Carp','Class::DBI','Class::MethodMaker','Compress::Zlib','Cwd','DBI','DB_File','Data::Dumper','Date::Manip','Digest::MD5','DirHandle','Expect','ExtUtils::MM_Unix','ExtUtils::MakeMaker','File::Basename','File::Copy','File::Find','File::MMagic','File::Path','File::Spec','File::Spec::Functions','File::stat','Frontier::Client','Frontier::Daemon','Getopt::Long','Graph::Directed','GraphViz','Gtk','HTML::Form','HTML::LinkExtor','HTTP::Request','HTTP::Request::Common','HTTP::Status','IO','IO::File','IO::Handle','IO::Pipe','IO::Socket::INET','IO::String','Image::Magick','LWP::Simple','LWP::UserAgent','Mail::Sendmail','Meta::Archive::MyTar','Meta::Archive::Tar','Meta::Baseline::Aegis','Meta::Baseline::Arch','Meta::Baseline::Cook','Meta::Baseline::Lang','Meta::Baseline::Lang::Aegi','Meta::Baseline::Lang::Ascx','Meta::Baseline::Lang::Aspe','Meta::Baseline::Lang::Awkx','Meta::Baseline::Lang::Bdbx','Meta::Baseline::Lang::Bins','Meta::Baseline::Lang::Ccxx','Meta::Baseline::Lang::Chec','Meta::Baseline::Lang::Chun','Meta::Baseline::Lang::Clas','Meta::Baseline::Lang::Conf','Meta::Baseline::Lang::Cook','Meta::Baseline::Lang::Cssx','Meta::Baseline::Lang::Cxxx','Meta::Baseline::Lang::Data','Meta::Baseline::Lang::Dbxx','Meta::Baseline::Lang::Deps','Meta::Baseline::Lang::Dirx','Meta::Baseline::Lang::Dlls','Meta::Baseline::Lang::Dslx','Meta::Baseline::Lang::Dtdx','Meta::Baseline::Lang::Dvix','Meta::Baseline::Lang::Epsx','Meta::Baseline::Lang::Gzxx','Meta::Baseline::Lang::Html','Meta::Baseline::Lang::Info','Meta::Baseline::Lang::Java','Meta::Baseline::Lang::Jpgx','Meta::Baseline::Lang::Late','Meta::Baseline::Lang::Libs','Meta::Baseline::Lang::Lily','Meta::Baseline::Lang::Lyxx','Meta::Baseline::Lang::Manx','Meta::Baseline::Lang::Midi','Meta::Baseline::Lang::Mifx','Meta::Baseline::Lang::Nrfx','Meta::Baseline::Lang::Objs','Meta::Baseline::Lang::Pack','Meta::Baseline::Lang::Patc','Meta::Baseline::Lang::Pdfx','Meta::Baseline::Lang::Perl','Meta::Baseline::Lang::Pgnx','Meta::Baseline::Lang::Pngx','Meta::Baseline::Lang::Psxx','Meta::Baseline::Lang::Pyob','Meta::Baseline::Lang::Pyth','Meta::Baseline::Lang::Rcxx','Meta::Baseline::Lang::Rtfx','Meta::Baseline::Lang::Rule','Meta::Baseline::Lang::Sgml','Meta::Baseline::Lang::Swig','Meta::Baseline::Lang::Targ','Meta::Baseline::Lang::Temp','Meta::Baseline::Lang::Texx','Meta::Baseline::Lang::Txtx','Meta::Baseline::Lang::Xmlx','Meta::Baseline::Lang::Xslt','Meta::Baseline::Utils','Meta::Chess::Board','Meta::Chess::Side','Meta::Chess::Tuple','Meta::Class::DBI','Meta::Class::MethodMaker','Meta::Db::Connection','Meta::Db::Connections','Meta::Db::Constraint','Meta::Db::Constraints','Meta::Db::Dbi','Meta::Db::Def','Meta::Db::Defs','Meta::Db::Enum','Meta::Db::Enums','Meta::Db::Field','Meta::Db::Fields','Meta::Db::Info','Meta::Db::Member','Meta::Db::Ops','Meta::Db::Parents','Meta::Db::Set','Meta::Db::Sets','Meta::Db::Table','Meta::Db::Tables','Meta::Db::Type','Meta::Db::User','Meta::Db::Users','Meta::Development::Deps','Meta::Development::Link','Meta::Development::Links','Meta::Development::Module','Meta::Development::PackModule','Meta::Development::Verbose','Meta::Digest::MD5','Meta::Distrib::File','Meta::Distrib::Files','Meta::Distrib::Machine','Meta::Distrib::Machines','Meta::Ds::Array','Meta::Ds::Connected','Meta::Ds::Dhash','Meta::Ds::Graph','Meta::Ds::Hash','Meta::Ds::Ochash','Meta::Ds::Ohash','Meta::Ds::Oset','Meta::Ds::Set','Meta::Ds::Stack','Meta::Ds::String','Meta::File::MMagic','Meta::Geo::Pos2d','Meta::Graph::Directed','Meta::Info::Address','Meta::Info::Affiliation','Meta::Info::Author','Meta::Info::Authors','Meta::Info::Credit','Meta::Lang::Cpp::Libs','Meta::Lang::Docb::Params','Meta::Lang::Dtd::Html','Meta::Lang::Html::Html','Meta::Lang::Lily::InfoParser','Meta::Lang::Perl::Deps','Meta::Lang::Perl::Interface','Meta::Lang::Perl::Perl','Meta::Lang::Perl::Perlpkg','Meta::Lang::Perl::Perlpkgs','Meta::Lang::Sgml::Sgml','Meta::Lang::Tt::Tt','Meta::Lang::Xml::Resolver','Meta::Lang::Xml::Xml','Meta::Math::Matrix','Meta::Math::Pad','Meta::Module::Info','Meta::Pdmt::BuildInfo','Meta::Pdmt::Graph','Meta::Pdmt::Handlers','Meta::Pdmt::Listen','Meta::Pdmt::Node','Meta::Revision::Entry','Meta::Revision::Revision','Meta::Sql::Stat','Meta::Sql::Stats','Meta::Tool::Aegis','Meta::Tool::Aspell','Meta::Tool::Cincl','Meta::Tool::Docbook2','Meta::Tool::Dvi','Meta::Tool::Editor','Meta::Tool::Gcc','Meta::Tool::Gzip','Meta::Tool::Jade','Meta::Tool::Lilypond','Meta::Tool::Nsgmls','Meta::Tool::Onsgmls','Meta::Tool::Openjade','Meta::Tool::Ps2Pdf','Meta::Tool::Sgml2','Meta::Tool::Sgmltools','Meta::Tool::Sgmltoolslite','Meta::Utils::Arg','Meta::Utils::Color','Meta::Utils::Debug','Meta::Utils::Env','Meta::Utils::File::Collect','Meta::Utils::File::Copy','Meta::Utils::File::Dir','Meta::Utils::File::File','Meta::Utils::File::Fs','Meta::Utils::File::Mkdir','Meta::Utils::File::Move','Meta::Utils::File::Path','Meta::Utils::File::Patho','Meta::Utils::File::Prop','Meta::Utils::File::Purge','Meta::Utils::File::Remove','Meta::Utils::File::Symlink','Meta::Utils::File::Time','Meta::Utils::File::Touch','Meta::Utils::Hash','Meta::Utils::List','Meta::Utils::Net::Cp','Meta::Utils::Net::Hostname','Meta::Utils::Net::Md','Meta::Utils::Net::Rm','Meta::Utils::Options','Meta::Utils::Opts::Sopt','Meta::Utils::Output','Meta::Utils::Parse::Text','Meta::Utils::Pc','Meta::Utils::Progname','Meta::Utils::String','Meta::Utils::System','Meta::Utils::Text::Checker','Meta::Utils::Text::Counter','Meta::Utils::Text::Lines','Meta::Utils::Text::Unique','Meta::Utils::Time','Meta::Utils::Unix','Meta::Utils::Utils','Meta::Xml::Dom','Meta::Xml::Parsers::Author','Meta::Xml::Parsers::Base','Meta::Xml::Parsers::Checker','Meta::Xml::Parsers::Collector','Meta::Xml::Parsers::Connections','Meta::Xml::Parsers::Dbdata','Meta::Xml::Parsers::Def','Meta::Xml::Parsers::Deps','Meta::Xml::Parsers::Dom','Meta::Xml::Parsers::Graph','Meta::Xml::Parsers::Links','Meta::Xml::Parsers::Perlpkgs','Meta::Xml::Parsers::Type','Meta::Xml::Parsers::User','Meta::Xml::Writer','Module::Info','Net::FTP','OpenFrame::Constants','OpenFrame::Response','OpenFrame::Slot','POSIX','Parse::RecDescent','Pod::Checker','Pod::Html','Pod::LaTeX','Pod::Man','Pod::POM','Pod::POM::View::Pod','Pod::Parser','Pod::Text','SOAP::Lite','SOAP::Transport::TCP','SQL::Statement','Symbol','Sys::Hostname','Template','Term::ANSIColor','Term::ReadLine','Time::Local','Time::localtime','XML::Checker::Parser','XML::DOM','XML::DOM::ValParser','XML::Doctype','XML::Driver::HTML','XML::Handler::BuildDOM','XML::Handler::Dtd2Html','XML::Parser::Expat','XML::Parser::PerlSAX','XML::Simple','XML::ValidWriter','XML::Writer','XML::XQL','XML::XQL::DOM','XMLRPC::Lite','XMLRPC::Transport::HTTP','strict','sys::ioctl.ph']},'Meta-0.08.tar.gz' => {'author' => 'VELTZER','description' => 'perform various initialization tasks.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 44212,'pod' => 42998,'pod_errors' => 0,'total' => 87210,'with_comments' => 4840},'releases' => 6,'requires' => ['ANSIColor-1.07.tar.gz','Archive-Tar-1.03.tar.gz','BerkeleyDB-0.23.tar.gz','CGI.pm-2.98.tar.gz','Cache-Cache-1.02.tar.gz','Chess-PGN-Parse-0.17.tgz','Class-DBI-0.93.tar.gz','Class-Fields-0.16.tar.gz','Class-MethodMaker-1.10.tar.gz','Compress-Bzip2-1.00.tar.gz','Compress-Zlib-1.22.tar.gz','Convert-UU-0.52.tar.gz','Crypt-GPG-1.42.tar.gz','Curses-1.06.tar.gz','Curses-UI-0.74.tar.gz','CursesWidgets-1.997.tar.gz','DBI-1.37.tar.gz','DB_File-1.806.tar.gz','Data-DumpXML-1.05.tar.gz','Data-Dumper-2.101.tar.gz','Data-ShowTable-3.3.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','Expect-1.15.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','Frontier-RPC-0.06.tar.gz','GD-2.07.tar.gz','Getopt-Long-2.33.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','GraphViz-ISA-0.01.tar.gz','Gtk-Perl-0.7000.tar.gz','Gtk-Perl-0.7008.tar.gz','Gtk-Perl-0.7009.tar.gz','HTML-DOMbo-3.08.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tree-3.17.tar.gz','Heap-0.50.tar.gz','IO-1.20.tar.gz','IO-Filter-0.01.tar.gz','IO-String-1.02.tar.gz','Image-GD-Thumbnail-0.02.tar.gz','Image-Size-2.992.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Types-1.06.tar.gz','Mail-Sendmail-0.79.tar.gz','Module-Info-0.20.tar.gz','Net-SCP-0.06.tar.gz','OpenFrame-3.02.tar.gz','OpenFrame-3.03.tar.gz','Parse-RecDescent-1.94.tar.gz','Perl-RPM-0.40.tar.gz','PerlMagick-5.56.tar.gz','Pipeline-3.04.tar.gz','Pod-LaTeX-0.55.tar.gz','Pod-POM-0.15.tar.gz','PodParser-1.23.tar.gz','SGI-FAM-1.002.tar.gz','SOAP-Lite-0.55.tar.gz','SQL-Statement-1.005.tar.gz','Template-Toolkit-2.10.tar.gz','TermReadKey-2.21.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-Local-1.07.tar.gz','Time-Piece-1.08.tar.gz','Time-modules-2003.0211.tar.gz','TimeDate-1.16.tar.gz','Tk-800.024.tar.gz','URI-1.24.tar.gz','WebService-FreeDB-0.56.tar.gz','XML-AutoWriter-0.37.tar.gz','XML-DOM-1.42.tar.gz','XML-Driver-HTML-0.06.tar.gz','XML-Dumper-0.4.tar.gz','XML-Generator-0.93.tar.gz','XML-Handler-Dtd2Html-0.32.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-Parser-2.31.tar.gz','XML-Simple-2.08.tar.gz','XML-Writer-0.4.tar.gz','XML-XPath-1.13.tar.gz','XML-XQL-0.68.tar.gz','XML-XSLT-0.40.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-enno-1.02.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'requires_module' => {'Archive::Tar' => '0.22','BerkeleyDB' => '0.2','CGI' => '2.89','Cache::MemoryCache' => undef,'Carp' => '1.01','Chess::PGN::Parse' => '0.1','Class::DBI' => '0.9','Class::MethodMaker' => '1.08','Compress::Bzip2' => 1,'Compress::Zlib' => '1.19','Convert::UU' => '0.4','Crypt::GPG' => '1.42','Curses' => '1.06','Curses::UI' => '0.71','Curses::Widgets' => '1.997','Curses::Widgets::TextField' => '1.103','Cwd' => '2.06','DBI' => '1.32','DB_File' => '1.806','Data::DumpXML' => '1.03','Data::Dumper' => '2.12','Data::ShowTable' => undef,'Date::Manip' => '5.4','Date::Parse' => '2.24','Digest::MD5' => '2.2','DirHandle' => 1,'Error' => '0.15','Expect' => '1.15','ExtUtils::Installed' => '0.06','ExtUtils::MM_Unix' => '1.34','ExtUtils::MakeMaker' => '6.05','Fcntl' => '1.04','File::Basename' => '2.71','File::Copy' => '2.05','File::Find' => '1.04','File::MMagic' => '1.16','File::Path' => '1.05','File::Spec' => '0.83','File::Spec::Functions' => '1.2','File::stat' => 1,'Frontier::Client' => undef,'Frontier::Daemon' => undef,'GD' => '2.05','Getopt::Long' => '2.32','Gnome' => '0.7008','Graph::Directed' => undef,'GraphViz' => '1.5','GraphViz::ISA' => '0.01','Gtk' => '0.7008','Gtk::Gdk' => undef,'Gtk::Gdk::ImlibImage' => '0.7008','HTML::DOMbo' => '3.08','HTML::Form' => '0.03','HTML::LinkExtor' => '1.31','HTML::TreeBuilder' => '3.13','HTTP::Daemon' => '1.25','HTTP::Headers' => '1.43','HTTP::Request' => '1.3','HTTP::Request::Common' => '1.19','HTTP::Response' => '1.36','HTTP::Status' => '1.26','Heap::Elem::Num' => '0.01','Heap::Elem::NumRev' => '0.01','Heap::Fibonacci' => '0.01','IO' => '1.2','IO::Dir' => '1.03','IO::File' => '1.09','IO::Filter::gunzip' => '0.01','IO::Handle' => '1.21','IO::Pipe' => '1.122','IO::Socket::INET' => '1.26','IO::String' => '1.02','Image::GD::Thumbnail' => '0.02','Image::Magick' => '5.48','Image::Size' => '2.99','LWP::Simple' => '1.35','LWP::UserAgent' => '2.001','MIME::Base64' => '2.12','MIME::Types' => '1.005','Mail::Sendmail' => '0.78','Module::Info' => '0.15','Net::FTP' => '2.65','Net::SCP' => '0.06','OpenFrame' => '3.02','OpenFrame::Response' => '3.01','OpenFrame::Segment::ContentLoader' => undef,'OpenFrame::Segment::HTTP::Request' => undef,'POSIX' => '1.05','Parse::RecDescent' => '1.8','Pipeline' => '2.05','Pipeline::Segment' => '2.05','Pod::Checker' => '1.4','Pod::Html' => '1.04','Pod::LaTeX' => '0.54','Pod::Man' => '1.34','Pod::POM' => '0.15','Pod::Parser' => '1.13','Pod::Text' => '2.21','RPM::Database' => '1.18','SGI::FAM' => '1.002','SOAP::Lite' => '0.55','SOAP::Transport::TCP' => '0.55','SQL::Statement' => '0.1021','Symbol' => '1.04','Sys::Hostname' => '1.1','Sys::Syslog' => '0.03','Template' => '2.08','Template::Parser' => '2.66','Term::ANSIColor' => '1.06','Term::ReadKey' => '2.21','Term::ReadLine' => 1,'Text::Wrap' => '2001.0929','Time::Local' => '1.04','Time::Piece' => '1.08','Time::Timezone' => '101.062101','Time::localtime' => '1.02','Tk' => '800.024','URI' => '1.22','WebService::FreeDB' => '0.4','XML::Checker::Parser' => undef,'XML::DOM' => '1.42','XML::DOM::ValParser' => undef,'XML::Doctype' => '0.11','XML::Driver::HTML' => '0.06','XML::Dumper' => '0.4','XML::Generator' => '0.91','XML::Handler::BuildDOM' => undef,'XML::Handler::Dtd2Html' => '0.24','XML::Handler::YAWriter' => '0.23','XML::LibXML' => '1.53','XML::LibXSLT' => '1.5','XML::Parser' => '2.31','XML::Parser::Expat' => '2.31','XML::Parser::PerlSAX' => '0.07','XML::Simple' => '2.02','XML::ValidWriter' => '0.37','XML::Writer' => '0.4','XML::XPath' => '1.12','XML::XQL' => '0.67','XML::XQL::DOM' => undef,'XML::XSLT' => '0.4','XMLRPC::Lite' => '0.55','base' => '1.03','strict' => '1.02'},'requires_recursive' => ['ANSIColor-1.07.tar.gz','Archive-Tar-1.03.tar.gz','Array-RefElem-0.02.tar.gz','BerkeleyDB-0.23.tar.gz','CGI.pm-2.98.tar.gz','Cache-Cache-1.02.tar.gz','Carp-Assert-0.17.tar.gz','Chess-PGN-Parse-0.17.tgz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-ISA-0.32.tar.gz','Class-MethodMaker-1.10.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','Compress-Bzip2-1.00.tar.gz','Compress-Zlib-1.22.tar.gz','Convert-UU-0.52.tar.gz','Crypt-GPG-1.42.tar.gz','Curses-1.06.tar.gz','Curses-UI-0.74.tar.gz','CursesWidgets-1.997.tar.gz','DBI-1.37.tar.gz','DB_File-1.806.tar.gz','Data-DumpXML-1.05.tar.gz','Data-Dumper-2.101.tar.gz','Data-ShowTable-3.3.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','Expect-1.15.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-MMagic-1.19.tar.gz','File-PathConvert-0.9.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Frontier-RPC-0.06.tar.gz','GD-2.07.tar.gz','Getopt-Long-2.33.tar.gz','Getopt-Mixed-1.008.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','GraphViz-ISA-0.01.tar.gz','Gtk-Perl-0.7000.tar.gz','Gtk-Perl-0.7008.tar.gz','Gtk-Perl-0.7009.tar.gz','HTML-DOMbo-3.08.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Template-2.6.tar.gz','HTML-Tree-3.17.tar.gz','Heap-0.50.tar.gz','IO-1.20.tar.gz','IO-Filter-0.01.tar.gz','IO-Null-0.02.tar.gz','IO-String-1.02.tar.gz','IO-Tty-1.02.tar.gz','IO-stringy-2.108.tar.gz','IPC-Run-0.75.tar.gz','Ima-DBI-0.29.tar.gz','Image-GD-Thumbnail-0.02.tar.gz','Image-Size-2.992.tar.gz','MD5-2.02.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Types-1.06.tar.gz','Mail-Sendmail-0.79.tar.gz','Math-Bezier-0.01.tar.gz','Module-Info-0.20.tar.gz','Net-SCP-0.06.tar.gz','Net-SSH-0.07.tar.gz','OpenFrame-3.02.tar.gz','OpenFrame-3.03.tar.gz','Parse-RecDescent-1.94.tar.gz','Parse-Yapp-1.05.tar.gz','Perl-RPM-0.40.tar.gz','PerlMagick-5.56.tar.gz','Pipeline-3.04.tar.gz','Pod-LaTeX-0.55.tar.gz','Pod-POM-0.15.tar.gz','PodParser-1.23.tar.gz','SGI-FAM-1.002.tar.gz','SOAP-Lite-0.55.tar.gz','SQL-Statement-1.005.tar.gz','Scalar-List-Utils-1.11.tar.gz','Storable-2.07.tar.gz','String-ShellQuote-1.00.tar.gz','Template-Toolkit-2.10.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-Iconv-1.2.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz','Time-Piece-1.08.tar.gz','Time-modules-2003.0211.tar.gz','TimeDate-1.16.tar.gz','Tk-800.024.tar.gz','URI-1.24.tar.gz','WebService-FreeDB-0.56.tar.gz','XML-AutoWriter-0.37.tar.gz','XML-DOM-1.42.tar.gz','XML-Driver-HTML-0.06.tar.gz','XML-Dumper-0.4.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-Generator-0.93.tar.gz','XML-Handler-Dtd2Html-0.32.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Expat-0.37.tar.gz','XML-SAX-Writer-0.44.tar.gz','XML-Simple-2.08.tar.gz','XML-Writer-0.4.tar.gz','XML-XPath-1.13.tar.gz','XML-XQL-0.68.tar.gz','XML-XSLT-0.40.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-enno-1.02.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'size' => {'packed' => 465279,'unpacked' => 3189852},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Archive::Tar','CGI','CLASS','Cache::MemoryCache','Carp','Class::DBI','Class::MethodMaker','Compress::Zlib','Cwd','DBI','DB_File','Data::Dumper','Date::Manip','Digest::MD5','DirHandle','Error','Expect','ExtUtils::MM_Unix','ExtUtils::MakeMaker','File::Basename','File::Copy','File::Find','File::MMagic','File::Path','File::Spec','File::Spec::Functions','File::stat','Frontier::Client','Frontier::Daemon','Getopt::Long','Graph::Directed','GraphViz','Gtk','HTML::Form','HTML::LinkExtor','HTTP::Request','HTTP::Request::Common','HTTP::Status','IO','IO::Dir','IO::File','IO::Handle','IO::Pipe','IO::Socket::INET','IO::String','Image::Magick','LWP::Simple','LWP::UserAgent','Mail::Sendmail','Module::Info','Net::FTP','OpenFrame::Response','POSIX','Parse::RecDescent','Pipeline::Segment','Pod::Checker','Pod::Html','Pod::LaTeX','Pod::Man','Pod::POM','Pod::POM::View::Pod','Pod::Parser','Pod::Text','SOAP::Lite','SOAP::Transport::TCP','SQL::Statement','Symbol','Sys::Hostname','Template','Term::ANSIColor','Term::ReadLine','Time::Local','Time::localtime','URI','XML::Checker::Parser','XML::DOM','XML::DOM::ValParser','XML::Doctype','XML::Driver::HTML','XML::Handler::BuildDOM','XML::Handler::Dtd2Html','XML::LibXML','XML::LibXML::SAX','XML::Parser','XML::Parser::Expat','XML::Parser::PerlSAX','XML::SAX::Expat','XML::SAX::PurePerl','XML::Simple','XML::ValidWriter','XML::Writer','XML::XPath','XML::XQL','XML::XQL::DOM','XMLRPC::Lite','XMLRPC::Transport::HTTP','strict','sys::ioctl.ph']},'Meta-Widget-Gtk-Sprite-0.01.tar.gz' => {'author' => 'JEPRICE','description' => 'Perl module to do C64 style sprites','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 306,'pod' => 113,'pod_errors' => 0,'total' => 419,'with_comments' => 25},'releases' => 1,'requires' => ['Gtk-Perl-0.7000.tar.gz','Gtk-Perl-0.7009.tar.gz'],'requires_module' => {'Gnome' => '0.7','Gtk' => '0.7'},'requires_recursive' => ['Gtk-Perl-0.7000.tar.gz','Gtk-Perl-0.7009.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 7793,'unpacked' => 35405},'testers' => {},'uses' => ['5.006','Data::Dumper','Exporter','Gnome','Gtk','Gtk::Gdk::ImlibImage','Sprite','strict','warnings']},'Metadata-0.24.tar.gz' => {'author' => 'DJBECKETT','description' => 'Base metadata functionality','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1187,'pod' => 439,'pod_errors' => 3,'total' => 1626,'with_comments' => 140},'releases' => 6,'size' => {'packed' => 18089,'unpacked' => 62279},'testers' => {'pass' => 10},'uses' => ['5.004','Carp','Date::Format','Date::Parse','Text::Wrap','Time::Local','strict','vars']},'Mhash-0.90.tar.gz' => {'author' => 'FKUO','description' => 'Perl extension for Mhash Hash library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 165,'pod' => 155,'pod_errors' => 0,'total' => 320,'with_comments' => 14},'releases' => 1,'size' => {'packed' => 7755,'unpacked' => 23548},'testers' => {},'uses' => ['5.005_62','AutoLoader','Carp','DynaLoader','Exporter','constant','strict','warnings']},'Mknod-0.02.tar.gz' => {'author' => 'RLZWART','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 45,'pod_errors' => 0,'total' => 90,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 7591,'unpacked' => 19214},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','XSLoader','strict','warnings']},'Mmap-a2.tar.gz' => {'author' => 'MICB','description' => 'uses mmap to map in a file as a perl variable','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 70,'pod' => 48,'pod_errors' => 0,'total' => 118,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 10678,'unpacked' => 28459},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Mobile-Executive-2.03.tar.gz' => {'author' => 'BARRYPJ','description' => 'used to signal the intention to relocate a Scooby mobile agent from the current Location to some other (possibly remote) Location.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 57,'pod_errors' => 0,'total' => 149,'with_comments' => 29},'releases' => 1,'requires' => ['Crypt-RSA-1.50.tar.gz','Devel-Scooby-4.12.tar.gz','File-Spec-0.82.tar.gz','Mobile-Location-4.02.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Crypt::RSA' => '1.5','Devel::Scooby' => '4.07','File::Spec' => 0,'Mobile::Location' => '4.01','constant' => 0},'requires_recursive' => ['Class-Loader-2.02.tar.gz','Compress-Zlib-1.22.tar.gz','Convert-ASCII-Armour-1.4.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Crypt-DES-2.03.tar.gz','Crypt-Primes-0.50.tar.gz','Crypt-RSA-1.50.tar.gz','Crypt-Random-1.13.tar.gz','Data-Buffer-0.04.tar.gz','Data-Dumper-2.101.tar.gz','Devel-Scooby-4.12.tar.gz','Digest-MD2-2.02.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Math-Pari-2.010500.tar.gz','Mobile-Location-4.02.tar.gz','PadWalker-0.09.tar.gz','Sort-Versions-1.4.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tie-EncryptedHash-1.21.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9030,'unpacked' => 26627},'testers' => {'pass' => 2},'uses' => ['Exporter','File::Spec','constant']},'Mobile-Location-4.02.tar.gz' => {'author' => 'BARRYPJ','description' => 'a class that provides for the creation of Scooby mobile agent environments (aka Location, Site or Place).','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1042,'pod' => 147,'pod_errors' => 0,'total' => 1189,'with_comments' => 289},'releases' => 1,'requires' => ['Crypt-RSA-1.50.tar.gz','Devel-Scooby-4.12.tar.gz','IO-1.20.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Crypt::RSA' => '1.5','Devel::Scooby' => '4.07','HTTP::Daemon' => '1.26','HTTP::Status' => '1.26','IO::Socket' => 0,'POSIX' => 0,'Socket' => 0,'Sys::Hostname' => 0,'constant' => 0},'requires_recursive' => ['Class-Loader-2.02.tar.gz','Compress-Zlib-1.22.tar.gz','Convert-ASCII-Armour-1.4.tar.gz','Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Crypt-DES-2.03.tar.gz','Crypt-Primes-0.50.tar.gz','Crypt-RSA-1.50.tar.gz','Crypt-Random-1.13.tar.gz','Data-Buffer-0.04.tar.gz','Data-Dumper-2.101.tar.gz','Devel-Scooby-4.12.tar.gz','Digest-MD2-2.02.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Math-Pari-2.010500.tar.gz','PadWalker-0.09.tar.gz','Sort-Versions-1.4.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tie-EncryptedHash-1.21.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18986,'unpacked' => 62002},'testers' => {'pass' => 2},'uses' => ['Crypt::RSA','HTTP::Daemon','HTTP::Status','IO::Socket','Mobile::Executive','POSIX','Socket','Sys::Hostname','constant','ops','strict']},'Modem-VBox-0.05.tar.gz' => {'author' => 'MLEHMANN','description' => 'Perl module for creation of voiceboxes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 561,'pod' => 21,'pod_errors' => 0,'total' => 582,'with_comments' => 30},'releases' => 3,'size' => {'packed' => 15954,'unpacked' => 44233},'testers' => {'fail' => 5,'pass' => 1,'tests' => '1'},'uses' => ['Carp','Event','Event::Watcher','Exporter','Fcntl','POSIX','Time::HiRes','bytes','strict']},'Modem-Vgetty-0.03.tar.gz' => {'author' => 'YENYA','description' => 'Interface to voice modems using vgetty','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 536,'pod' => 453,'pod_errors' => 0,'total' => 989,'with_comments' => 27},'releases' => 3,'size' => {'packed' => 11763,'unpacked' => 34439},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','FileHandle','POSIX','strict','vars']},'ModsPragma-0.004.tar.gz' => {'author' => 'JGLICK','description' => 'easy one-stop module shopping','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 72,'pod_errors' => 0,'total' => 207,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 3866,'unpacked' => 7714},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['$filename','Carp','Foo','integer','strict','vars']},'Module-Build-0.19.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Build and install Perl modules','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 3681,'pod' => 1291,'pod_errors' => 0,'total' => 4972,'with_comments' => 208},'releases' => 19,'size' => {'packed' => 74015,'unpacked' => 231818},'testers' => {'pass' => 6},'uses' => ['Archive::Tar','AutoSplit','CPAN','Config','Cwd','ExtUtils::Install','ExtUtils::MakeMaker','ExtUtils::Manifest','ExtUtils::Mkbootstrap','ExtUtils::Mksymlists','ExtUtils::ParseXS','File::Basename','File::Spec','IO::File','MacPerl','Module::Signature','Pod::Man','Test::Harness','YAML','only','strict','vars','warnings']},'Module-CPANTS-0.20030718.tar.gz' => {'author' => 'LBROCARD','description' => 'CPAN Module Testing','files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 49,'pod' => 106,'pod_errors' => 0,'total' => 155,'with_comments' => 3},'releases' => 10,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.01'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 548310,'unpacked' => 3421506},'testers' => {'pass' => 2},'uses' => ['ModuleBundle','X','XYZ','Y','Z','strict','vars']},'Module-CPANTS-Generator-0.005.tar.gz' => {'author' => 'LBROCARD','description' => 'Generate Module::CPANTS','files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 503,'pod' => 119,'pod_errors' => 0,'total' => 622,'with_comments' => 18},'releases' => 5,'requires' => ['CPANPLUS-0.042.tar.gz','File-Find-Rule-0.10.tar.gz','Pod-POM-0.15.tar.gz','String-Approx-3.20.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'CPANPLUS' => '0.042','File::Find::Rule' => '0.01','Pod::POM' => '0.01','String::Approx' => '0.01','Template' => '2.08','Test::More' => '0.01'},'requires_recursive' => ['CPANPLUS-0.042.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','Pod-POM-0.15.tar.gz','String-Approx-3.20.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 12232,'unpacked' => 35457},'testers' => {'fail' => 2,'tests' => '1'},'uses' => ['Carp','Cwd','DB_File','File::Copy','File::Find::Rule','File::Path','File::Spec::Functions','Net::NNTP','Pod::POM','Storable','String::Approx','strict','vars']},'Module-Check_Args-1.1.tar.gz' => {'author' => 'KVAIL','description' => 'a quick way to check argument counts for methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 183,'pod' => 99,'pod_errors' => 0,'total' => 282,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 3768,'unpacked' => 11517},'testers' => {'pass' => 6},'uses' => ['5.000','Carp','constant','strict','vars']},'Module-CoreList-1.91.tar.gz' => {'author' => 'RCLAMP','description' => 'what modules shipped with versions of perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1900,'pod' => 44,'pod_errors' => 0,'total' => 1944,'with_comments' => 1085},'releases' => 8,'size' => {'packed' => 15483,'unpacked' => 110196},'testers' => {'pass' => 10},'uses' => ['Carp','strict','vars']},'Module-CryptSource-0.02.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Encrypt and Decrypt source for Binary Packagers','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 83,'pod' => 46,'pod_errors' => 0,'total' => 129,'with_comments' => 6},'releases' => 2,'requires' => ['Crypt-Rijndael-0.05.tar.gz','Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz','TermReadKey-2.21.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Crypt::Rijndael' => '0','Digest::MD5' => '0','MIME::Base64' => '0','Storable' => '0','Term::ReadKey' => '0','Test::More' => '0'},'requires_recursive' => ['Crypt-Rijndael-0.05.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3553,'unpacked' => 7184},'testers' => {'pass' => 7},'uses' => ['Crypt::Rijndael','Digest::MD5','MIME::Base64','Storable','Term::ReadKey','strict']},'Module-Dependency-1.13.tar.gz' => {'author' => 'PKENT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1077,'pod' => 429,'pod_errors' => 0,'total' => 1506,'with_comments' => 61},'releases' => 5,'requires' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Find' => 0,'File::Spec' => 0,'Storable' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 57827,'unpacked' => 180660},'testers' => {'fail' => 3,'pass' => 2,'tests' => '92'},'uses' => ['File::Find','File::Spec','GD','PostScript::Simple','Storable','constant','strict','vars']},'Module-Dependency-1.8.tar.gz' => {'author' => 'PKENT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 780,'pod' => 299,'pod_errors' => 0,'total' => 1079,'with_comments' => 38},'releases' => 5,'requires' => ['GD-2.07.tar.gz','Storable-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Find' => 0,'GD' => 0,'Storable' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','GD-2.07.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 44633,'unpacked' => 127674},'testers' => {'pass' => 2},'uses' => ['File::Find','GD','Module::Dependency::Info','PostScript::Simple','Storable','vars']},'Module-ExtractUse-0.10.tar.gz' => {'author' => 'DOMM','description' => 'Find out what modules are used','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 151,'pod' => 98,'pod_errors' => 0,'total' => 249,'with_comments' => 14},'releases' => 2,'requires' => ['Parse-RecDescent-1.94.tar.gz','Pod-Simple-0.96.tar.gz'],'requires_module' => {'Parse::RecDescent' => 0,'Pod::Simple' => 0},'requires_recursive' => ['Parse-RecDescent-1.94.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Text-Balanced-1.95.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 5164,'unpacked' => 12440},'testers' => {'pass' => 2},'uses' => ['5.006','Module::ExtractUseGrammar','Parse::RecDescent','Pod::Simple','strict','vars','warnings']},'Module-Husbandry-0.002.tar.gz' => {'author' => 'RBS','description' => 'build and manage perl modules in a Perl module distribution','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1332,'pod' => 243,'pod_errors' => 0,'total' => 1575,'with_comments' => 56},'releases' => 2,'size' => {'packed' => 15759,'unpacked' => 59115},'testers' => {'pass' => 9},'uses' => ['Carp','Cwd','Exporter','Fatal','File::Basename','File::Copy','File::Find','File::Path','File::Spec','strict','vars']},'Module-Info-0.20.tar.gz' => {'author' => 'MBARBON','description' => 'Information about Perl modules','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2900,'pod' => 1500,'pod_errors' => 0,'total' => 4400,'with_comments' => 119},'releases' => 20,'requires' => ['File-Spec-0.82.tar.gz'],'requires_module' => {'File::Spec' => '0.8'},'requires_recursive' => ['File-Spec-0.82.tar.gz'],'size' => {'packed' => 40453,'unpacked' => 131390},'testers' => {'pass' => 7},'uses' => ['$mod_file','$quoted_file','5.004','5.006','B','B::Utils','Carp','Config','File::Spec','IPC::Open3','strict','vars','warnings']},'Module-Install-0.22.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Standalone, extensible Perl module installer','files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 5220,'pod' => 839,'pod_errors' => 1,'total' => 6059,'with_comments' => 378},'releases' => 3,'size' => {'packed' => 65078,'unpacked' => 242322},'testers' => {'pass' => 2},'uses' => ['$self->{path}::$self->{dispatch}','5.004','Archive::Zip','CPAN','CPANPLUS','CPANPLUS::Backend','Carp','Config','Cwd','Exporter','ExtUtils::MM_Unix','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Basename','File::Find','File::Path','File::Spec','FileHandle','LWP::Simple','Module::Build','Module::CoreList','Module::ScanDeps','Net::FTP','Socket','Test::Builder','YAML','strict','threads::shared','vars']},'Module-InstalledVersion-0.05.tar.gz' => {'author' => 'SKUD','description' => 'Find version number of installed module','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 30,'pod_errors' => 0,'total' => 80,'with_comments' => 3},'releases' => 5,'requires' => ['File-Spec-0.82.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Spec' => '0.82','Test::More' => '0.18'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2226,'unpacked' => 4163},'testers' => {'fail' => 1,'pass' => 7},'uses' => ['strict','vars']},'Module-Load-0.05.tar.gz' => {'author' => 'KANE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 66,'pod_errors' => 0,'total' => 171,'with_comments' => 2},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3108,'unpacked' => 6448},'testers' => {'pass' => 3},'uses' => ['strict']},'Module-Load-Conditional-0.03.tar.gz' => {'author' => 'KANE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 325,'pod' => 148,'pod_errors' => 0,'total' => 473,'with_comments' => 41},'releases' => 2,'requires' => ['Locale-Maketext-Simple-0.02.tar.gz','Module-Load-0.05.tar.gz','Params-Check-0.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Locale::Maketext::Simple' => 0,'Module::Load' => 0,'Params::Check' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Locale-Maketext-Simple-0.02.tar.gz','Module-Load-0.05.tar.gz','Params-Check-0.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6307,'unpacked' => 18281},'testers' => {'pass' => 2},'uses' => ['Exporter','Locale::Maketext::Simple','Module::Load','Params::Check','strict','vars']},'Module-MagicUse-0.3.tar.gz' => {'author' => 'BROQ','description' => 'Automagically include files by invoking their constructor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 56,'pod_errors' => 0,'total' => 145,'with_comments' => 4},'releases' => 1,'requires' => ['Regexp-Common-2.113.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Regexp::Common' => '0.1','Text::Balanced' => '1.83'},'requires_recursive' => ['Regexp-Common-2.113.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3300,'unpacked' => 6409},'testers' => {'pass' => 3},'uses' => ['Carp','IO::File','Regexp::Common','Text::Balanced','strict']},'Module-MakeDist-1.05.tgz' => {'author' => 'RSAVAGE','description' => 'Convert module into distros (*.tgz, *.zip)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 592,'pod' => 180,'pod_errors' => 0,'total' => 772,'with_comments' => 94},'releases' => 6,'size' => {'packed' => 9738,'unpacked' => 35393},'testers' => {'pass' => 2},'uses' => ['5.005_62','Archive::Tar','Archive::Zip','Carp','Compress::Zlib','Config','Exporter','File::Copy','File::Find','File::Path','File::Spec','warnings']},'Module-MetaInfo-0.03.tar.gz' => {'author' => 'MIKEDLR','description' => 'Report meta information from perl module distribution files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 961,'pod' => 329,'pod_errors' => 0,'total' => 1290,'with_comments' => 98},'releases' => 1,'size' => {'packed' => 177309,'unpacked' => 461577},'testers' => {'fail' => 3,'tests' => '50'},'uses' => ['Carp','Cwd','File::Find','Symbol','strict','vars','warnings']},'Module-Reload-1.07.tar.gz' => {'author' => 'JPRIT','description' => 'Reloads files in %INC based on timestamps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 29,'pod_errors' => 0,'total' => 79,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 1860,'unpacked' => 3961},'testers' => {'pass' => 10},'uses' => ['strict','vars']},'Module-Reload-Sel-1.02.tar.gz' => {'author' => 'CHTHORMAN','description' => 'Reload perl modules during development','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 376,'pod' => 282,'pod_errors' => 0,'total' => 658,'with_comments' => 51},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz'],'requires_module' => {'Data::Dumper' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 10584,'unpacked' => 38970},'testers' => {'pass' => 8},'uses' => ['Apache::Symbol','Data::Dumper','strict','vars']},'Module-Require-0.04.tar.gz' => {'author' => 'JSMITH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 154,'pod' => 77,'pod_errors' => 1,'total' => 231,'with_comments' => 4},'releases' => 4,'size' => {'packed' => 3710,'unpacked' => 11299},'testers' => {'pass' => 7},'uses' => ['strict','vars']},'Module-ScanDeps-0.19.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Recursively scan Perl code for dependencies','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 467,'pod' => 127,'pod_errors' => 0,'total' => 594,'with_comments' => 13},'releases' => 10,'size' => {'packed' => 11242,'unpacked' => 33987},'testers' => {'pass' => 5},'uses' => ['Config','Exporter','File::Find','constant','strict','vars']},'Module-Signature-0.26.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Module signature file manipulation','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 999,'pod' => 168,'pod_errors' => 0,'total' => 1167,'with_comments' => 50},'releases' => 24,'size' => {'packed' => 17600,'unpacked' => 61237},'testers' => {'fail' => 2,'pass' => 2,'tests' => '3'},'uses' => ['$self->{path}::$self->{dispatch}','CPAN','CPANPLUS','Config','Crypt::OpenPGP','Digest','Exporter','ExtUtils::MM_Unix','ExtUtils::MakeMaker','File::Basename','File::Find','File::Path','File::Spec','Module::Install','Module::Install::Base','Text::Diff','YAML','constant','inc::Module::Install','strict','vars']},'Module-Use-0.05.tar.gz' => {'author' => 'JSMITH','description' => 'Tracks modules loaded by a script','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 214,'pod' => 164,'pod_errors' => 1,'total' => 378,'with_comments' => 8},'releases' => 5,'size' => {'packed' => 3642,'unpacked' => 10115},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['5.005','Carp','Tie::DB_FileLock','Tie::Hash','Tie::StdHash','strict','vars']},'Module-Versions-Report-1.02.tar.gz' => {'author' => 'SBURKE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 104,'pod' => 53,'pod_errors' => 0,'total' => 157,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 4671,'unpacked' => 11067},'testers' => {'pass' => 3},'uses' => ['5']},'ModuleBundle-0.01.tar.gz' => {'author' => 'MJD','description' => 'Combine several other modules into one package =head1 SYNOPSIS Create a package that looks like this: 	package XYZ; 	use X; 	use Y; 	use Z; 	use ModuleBundle; 	@ISA = \'ModuleBundle; 	1; Now if you say 	use XYZ; that is the same as saying 	use X; 	use Y; 	use Z;','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 35,'pod_errors' => 0,'total' => 69,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 937,'unpacked' => 1218},'testers' => {'tests' => '0','unknown' => 6},'uses' => []},'Mon-0.11.tar.gz' => {'author' => 'TROCKIJ','description' => 'Network monitoring client','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2212,'pod' => 496,'pod_errors' => 0,'total' => 2708,'with_comments' => 114},'releases' => 7,'size' => {'packed' => 23433,'unpacked' => 85042},'testers' => {'pass' => 2,'tests' => '0','unknown' => 9},'uses' => ['5.004','Convert::BER','Exporter','IO::File','Socket','Text::ParseWords']},'Money-ChangeMaker-0.1.tar.gz' => {'author' => 'AVIF','description' => 'A module to make change based on a monetary quantity.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 461,'pod' => 234,'pod_errors' => 0,'total' => 695,'with_comments' => 59},'releases' => 1,'size' => {'packed' => 8560,'unpacked' => 24165},'testers' => {'pass' => 3},'uses' => ['5','strict','vars']},'Monkeywrench-1.0.tar.gz' => {'author' => 'CNATION','description' => 'Web testing application','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 363,'pod' => 249,'pod_errors' => 0,'total' => 612,'with_comments' => 18},'releases' => 1,'requires' => ['CGI.pm-2.98.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'CGI' => 0,'HTTP::Cookies' => 0,'LWP::UserAgent' => 0,'Net::SMTP' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14849,'unpacked' => 41212},'testers' => {'pass' => 7},'uses' => ['CGI','Data::Dumper','HTTP::Cookies','LWP::Debug','LWP::UserAgent','Net::SMTP','Time::HiRes','strict','vars']},'Morale-0.002.tar.gz' => {'author' => 'GREGOR','description' => 'Perl module for managing individual and calculating group morale.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 283,'pod' => 60,'pod_errors' => 0,'total' => 343,'with_comments' => 50},'releases' => 2,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 6904,'unpacked' => 14882},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars']},'Mortal-Kombat-1.00.tar.gz' => {'author' => 'PINYAN','description' => 'Mortal Kombat program termination','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 27,'pod' => 36,'pod_errors' => 0,'total' => 63,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 1686,'unpacked' => 3088},'testers' => {'pass' => 5},'uses' => ['Exporter','strict','vars']},'MsgQ-1.01.tar.gz' => {'author' => 'SPIRITSKY','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 1395,'pod' => 0,'pod_errors' => 0,'total' => 1395,'with_comments' => 197},'releases' => 1,'size' => {'packed' => 15215,'unpacked' => 110658},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.6.1','File::Copy','File::Path','IO::Select','IO::Socket','Sys::Hostname','strict','vars','warnings']},'Msgcat-1.03.tar.gz' => {'author' => 'CHRWOLF','description' => 'Access to XPG4 message catalog functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 50,'pod_errors' => 0,'total' => 89,'with_comments' => 8},'releases' => 4,'size' => {'packed' => 3249,'unpacked' => 6627},'testers' => {'pass' => 11},'uses' => ['DynaLoader','Exporter','strict','vars']},'Msql-Mysql-modules-1.1835.tar.gz' => {'author' => 'JWIED','description' => 'Perl interfaces to the mSQL and mysql databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1405,'pod' => 1508,'pod_errors' => 0,'total' => 2913,'with_comments' => 72},'releases' => 53,'size' => {'packed' => 190477,'unpacked' => 734708},'testers' => {},'uses' => ['Msql::Statement','Mysql::Statement','strict','vars']},'Msql-Mysql-modules-1.2219.tar.gz' => {'author' => 'JWIED','description' => 'Perl interfaces to the mSQL and mysql databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3493,'pod' => 3095,'pod_errors' => 0,'total' => 6588,'with_comments' => 186},'releases' => 53,'size' => {'packed' => 195634,'unpacked' => 699644},'testers' => {'fail' => 1,'pass' => 5,'tests' => '746'},'uses' => ['5.004','Carp','Config','DBD::mysql','DBI','DynaLoader','Exporter','ExtUtils::MakeMaker','File::Basename','File::Path','IO::File','Mysql::Statement','strict','vars']},'MsqlCGI-0.8.tar.gz' => {'author' => 'ALTITUDE','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 772,'pod' => 0,'pod_errors' => 0,'total' => 772,'with_comments' => 158},'releases' => 1,'size' => {'packed' => 45656,'unpacked' => 188398},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['$subFileName','sub.Error','sub.OperationsMenu','sub.PreliminaryResults','sub.RecordActions','sub.RecordCreateProcess','sub.RecordCreateSetup','sub.RecordDeleteProcess','sub.RecordDisplay','sub.RecordModifyProcess','sub.RecordModifySetup','sub.RecordSearchSetup','sub.Template']},'Mt-0.01.tar.gz' => {'author' => 'ROMM','description' => 'Provide a wrapper for the tape manager \'mt\' program','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 73,'pod_errors' => 0,'total' => 170,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 8097,'unpacked' => 22658},'testers' => {'fail' => 2,'tests' => '1'},'uses' => ['5.006','Carp','strict']},'MultiTail-0.5.tar.gz' => {'author' => 'SGMIANO','description' => 'Tail multiple files for Unix systems','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1314,'pod' => 288,'pod_errors' => 0,'total' => 1602,'with_comments' => 502},'releases' => 5,'size' => {'packed' => 13530,'unpacked' => 57249},'testers' => {'pass' => 3},'uses' => ['Carp','DirHandle','File::Basename','File::stat','FileHandle','strict','vars']},'Music-Scales-0.03.tar.gz' => {'author' => 'BDAGLISH','description' => 'supply necessary notes / offsets for musical scales','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 171,'pod' => 116,'pod_errors' => 0,'total' => 287,'with_comments' => 43},'releases' => 3,'size' => {'packed' => 12503,'unpacked' => 31778},'testers' => {'pass' => 2},'uses' => ['Text::Abbrev','strict','vars']},'MusicBrainz-Client-0.06.tar.gz' => {'author' => 'SVANZOEST','description' => 'MusicBrainz Client API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 183,'pod' => 298,'pod_errors' => 0,'total' => 481,'with_comments' => 26},'releases' => 4,'requires' => ['MusicBrainz-Queries-0.05.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'MusicBrainz::Queries' => '0.01','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','MusicBrainz-Queries-0.05.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 17663,'unpacked' => 59769},'testers' => {},'uses' => ['5.6.1','AutoLoader','Carp','DynaLoader','Exporter','XSLoader','strict','warnings']},'MusicBrainz-Queries-0.05.tar.gz' => {'author' => 'SVANZOEST','description' => 'MusicBrainz RDF Query Constants','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 275,'pod' => 377,'pod_errors' => 0,'total' => 652,'with_comments' => 19},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 16817,'unpacked' => 76118},'testers' => {},'uses' => ['5.6.1','AutoLoader','Carp','Exporter','XSLoader','strict','warnings']},'MusicBrainz-TRM-0.01.tar.gz' => {'author' => 'SVANZOEST','description' => 'MusicBrainz TRM Acoustic Fingerprint API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 100,'pod_errors' => 0,'total' => 169,'with_comments' => 9},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4622,'unpacked' => 10369},'testers' => {},'uses' => ['5.006001','Exporter','XSLoader','strict','warnings']},'MyConText-0.49.tar.gz' => {'author' => 'JANPAZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1421,'pod' => 319,'pod_errors' => 0,'total' => 1740,'with_comments' => 84},'releases' => 1,'size' => {'packed' => 68278,'unpacked' => 245353},'testers' => {'fail' => 1,'pass' => 1,'tests' => '7'},'uses' => ['Data::Dumper','LWP::UserAgent','locale','strict','vars']},'MySQL-Config-1.02.tar.gz' => {'author' => 'DARREN','description' => 'Parse and utilize MySQL\'s /etc/my.cnf and ~/.my.cnf files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 65,'pod_errors' => 0,'total' => 225,'with_comments' => 26},'releases' => 1,'size' => {'packed' => 3296,'unpacked' => 9532},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','strict','vars']},'MySQL-DateFormat-1.01.tar.gz' => {'author' => 'TONKIN','description' => '- Manipulate dates back and forth between human-readable and MySQL formats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 168,'pod_errors' => 0,'total' => 288,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 4606,'unpacked' => 11405},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['Carp','Date::Calc','strict','vars']},'MySQL-Diff-0.33.tar.gz' => {'author' => 'ASPIERS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 679,'pod' => 0,'pod_errors' => 0,'total' => 679,'with_comments' => 31},'releases' => 3,'requires' => ['Class-MakeMethods-1.006.tar.gz'],'requires_module' => {'Class::MakeMethods::Template' => 0},'requires_recursive' => ['Class-MakeMethods-1.006.tar.gz'],'size' => {'packed' => 12071,'unpacked' => 40092},'testers' => {'fail' => 2,'tests' => '42'},'uses' => ['Carp','Exporter','strict','vars']},'MySQL-Easy-1.2.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 192,'pod' => 118,'pod_errors' => 0,'total' => 310,'with_comments' => 31},'releases' => 6,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'DBD::mysql' => 0,'DBI' => 0},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz'],'testers' => {'pass' => 3},'uses' => ['AutoLoader','Carp','DBI','strict','vars','warnings']},'MySQL-GUI-0.33.tar.gz' => {'author' => 'JETTERO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 712,'pod' => 184,'pod_errors' => 0,'total' => 896,'with_comments' => 8},'releases' => 2,'requires' => ['Date-Lima-1.1.tar.gz','Gtk-Perl-0.7009.tar.gz'],'requires_module' => {'Date::Lima' => 0,'Gtk' => 0},'requires_recursive' => ['Date-Lima-1.1.tar.gz','Gtk-Perl-0.7009.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 8538,'unpacked' => 27251},'testers' => {},'uses' => ['5.005_62','AutoLoader','Carp','DBI','Date::Lima','Exporter','Gtk','strict','warnings']},'MySQL-TableInfo-1.01.tar.gz' => {'author' => 'SHERZODR','description' => 'Access to MySQL table\'s meta data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 323,'pod' => 140,'pod_errors' => 0,'total' => 463,'with_comments' => 62},'releases' => 3,'size' => {'packed' => 5663,'unpacked' => 15516},'testers' => {'fail' => 3,'pass' => 2},'uses' => ['Carp','Data::Dumper','strict']},'Mysql-Locker-1.00.tar.gz' => {'author' => 'CMANLEY','description' => 'Safe way of locking and unlocking MySQL tables.','files' => ['Makefile.PL'],'lines' => {'nonpod' => 68,'pod' => 47,'pod_errors' => 0,'total' => 115,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 2978,'unpacked' => 9812},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','strict']},'Mysql-NameLocker-1.00.tar.gz' => {'author' => 'CMANLEY','description' => 'Safe way of locking and unlocking MySQL tables using named locks.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 83,'pod' => 67,'pod_errors' => 0,'total' => 150,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3833,'unpacked' => 12633},'testers' => {'pass' => 4},'uses' => ['Carp','strict']},'NBU-0.90f.tar.gz' => {'author' => 'DUTCHMAN','description' => 'Main entry point for NetBackup OO Modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5597,'pod' => 35,'pod_errors' => 0,'total' => 5632,'with_comments' => 343},'releases' => 1,'size' => {'packed' => 61806,'unpacked' => 226312},'testers' => {'fail' => 3,'tests' => '1'},'uses' => ['5.005','AutoLoader','Carp','Date::Parse','IPC::Open2','Time::Local','strict','vars']},'NCAR-0.01.tar.gz' => {'author' => 'PHILOU','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 480,'pod' => 199,'pod_errors' => 0,'total' => 679,'with_comments' => 61},'releases' => 1,'requires' => ['PDL-2.4.0.tar.gz'],'requires_module' => {'PDL' => '2.3.4'},'requires_recursive' => ['PDL-2.4.0.tar.gz'],'size' => {'packed' => 1237455,'unpacked' => 4041840},'testers' => {},'uses' => ['','5.005_62','Carp','DynaLoader','Exporter','PDL','PDL::Core','strict','warnings']},'NCBI-0.10.zip' => {'author' => 'TSIRKIN','description' => undef,'files' => [],'lines' => {'nonpod' => 757,'pod' => 33,'pod_errors' => 0,'total' => 790,'with_comments' => 70},'releases' => 1,'size' => {'packed' => 8002,'unpacked' => 23363},'testers' => {},'uses' => ['5.006','CGI::Cookie','Carp','Exporter','HTTP::Cookies','LWP::UserAgent','POSIX','strict','vars','warnings']},'NEXT-0.50.tar.gz' => {'author' => 'DCONWAY','description' => 'Perl5 implementation of NEXT (RFC190)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 190,'pod_errors' => 0,'total' => 309,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 6304,'unpacked' => 21998},'testers' => {'pass' => 12},'uses' => ['Carp','strict']},'NIS-DBM-0.02.tar.gz' => {'author' => 'JSMITH','description' => 'Perl module implementing a NIS daemon.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 837,'pod' => 195,'pod_errors' => 1,'total' => 1032,'with_comments' => 42},'releases' => 2,'size' => {'packed' => 12942,'unpacked' => 47762},'testers' => {'fail' => 3},'uses' => ['Carp','Fcntl','IPC::Open3','IniConf','LockFile::Simple','NDBM_File','Net::NIS','strict','vars']},'NIS-a2.tar.gz' => {'author' => 'RIK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 160,'pod_errors' => 0,'total' => 307,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 5856,'unpacked' => 17489},'testers' => {'fail' => 3},'uses' => ['AutoLoader','DynaLoader','Exporter','Net::NIS']},'NISPlus-0.06-alpha.tar.gz' => {'author' => 'RIK','description' => 'Interface to Sun\'s NIS+','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 820,'pod' => 107,'pod_errors' => 0,'total' => 927,'with_comments' => 37},'releases' => 3,'size' => {'packed' => 20410,'unpacked' => 74203},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter']},'NNML-1.13.tar.gz' => {'author' => 'ULPFR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1613,'pod' => 80,'pod_errors' => 0,'total' => 1693,'with_comments' => 129},'releases' => 10,'requires' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'IO::File' => 0,'IO::Select' => 0,'IO::Socket' => '1.13','Net::Cmd' => '2.07'},'requires_recursive' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 24194,'unpacked' => 81628},'testers' => {},'uses' => ['Carp','Exporter','File::Path','IO::File','IO::Pipe','IO::Select','IO::Socket','NNML::Config','Net::Cmd','Socket','Sys::Hostname','Text::Abbrev','Time::Local','strict','vars']},'NNTPClient-0.37.tar.gz' => {'author' => 'RVA','description' => 'Support for clients of NNTP servers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1091,'pod' => 608,'pod_errors' => 0,'total' => 1699,'with_comments' => 160},'releases' => 6,'size' => {'packed' => 15380,'unpacked' => 49587},'testers' => {'fail' => 3,'pass' => 8},'uses' => ['5.000','5.002','Carp','Socket','strict','vars']},'NPRG-0.31.zip' => {'author' => 'IFROL','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 1178,'pod' => 289,'pod_errors' => 18,'total' => 1467,'with_comments' => 151},'releases' => 4,'size' => {'packed' => 26667,'unpacked' => 107772},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Alias','Carp','DynaLoader','Exporter','integer','strict','vars']},'NTLM-1.02.tar.gz' => {'author' => 'MARKBUSH','description' => 'An NTLM authentication module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 705,'pod' => 87,'pod_errors' => 0,'total' => 792,'with_comments' => 27},'releases' => 3,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::Base64' => 0},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 8589,'unpacked' => 23750},'testers' => {'pass' => 6},'uses' => ['Exporter','MIME::Base64','vars']},'NVDefined-0.02.tar.gz' => {'author' => 'BPOWERS','description' => 'Perl extension for non-vivifying exists and defined functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 33,'pod_errors' => 0,'total' => 67,'with_comments' => 3},'releases' => 2,'requires' => ['Hash-NoVivify-0.01.tar.gz'],'requires_module' => {'Hash::NoVivify' => '0.01'},'requires_recursive' => ['Hash-NoVivify-0.01.tar.gz'],'size' => {'packed' => 1937,'unpacked' => 3807},'testers' => {'pass' => 7},'uses' => ['Exporter','Hash::NoVivify','strict','vars']},'Nagios-Config-0.02.tar.gz' => {'author' => 'PATL','description' => 'Parse Nagios configuration files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 604,'pod' => 225,'pod_errors' => 0,'total' => 829,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 18720,'unpacked' => 65669},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Dumper','Nagios::Config::Object','strict','warnings']},'Nagios-WebTransact-0.03.tar.gz' => {'author' => 'HOPCROFTS','description' => 'Class for generating Nagios service checks of Web transactions.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 418,'pod' => 206,'pod_errors' => 0,'total' => 624,'with_comments' => 82},'releases' => 3,'size' => {'packed' => 10449,'unpacked' => 32765},'testers' => {'pass' => 2},'uses' => ['Carp','Dumpvalue','HTTP::Cookies','HTTP::Request::Common','LWP::UserAgent','constant','strict','vars']},'Nagios-WebTransact-Timed-0.01.tar.gz' => {'author' => 'HOPCROFTS','description' => 'An object that provides a check method (usually called by a Nagios service check) to determine if a sequence of URLs can be got inside a time threshold, returning the times for each.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 83,'pod_errors' => 0,'total' => 220,'with_comments' => 7},'releases' => 1,'requires' => ['Nagios-WebTransact-0.03.tar.gz','Time-HiRes-1.49.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => 0,'Nagios::WebTransact' => 0,'Time::HiRes' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Nagios-WebTransact-0.03.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6145,'unpacked' => 16394},'testers' => {'pass' => 1},'uses' => ['Carp','HTTP::Cookies','HTTP::Request::Common','LWP::UserAgent','Nagios::WebTransact','Time::HiRes','constant','strict','vars']},'NestedMap-1.0.tar.gz' => {'author' => 'DCANTRELL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 46,'pod' => 77,'pod_errors' => 0,'total' => 123,'with_comments' => 0},'releases' => 1,'requires' => ['Getopt-Declare-1.09.tar.gz'],'requires_module' => {'Getopt::Declare' => '1.09'},'requires_recursive' => ['Getopt-Declare-1.09.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 2780,'unpacked' => 5149},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','warnings']},'Net-ACL-0.07.tar.gz' => {'author' => 'LORENSEN','description' => 'Class representing a generic access-list/route-map','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 2628,'pod' => 1373,'pod_errors' => 0,'total' => 4001,'with_comments' => 263},'releases' => 7,'requires' => ['Cisco-Reconfig-0.6.tar.gz','IO-String-1.02.tar.gz','Net-Netmask-1.9002.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Signature-1.04.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Cisco::Reconfig' => '0.5','IO::String' => '1.02','List::Util' => '1.01','Net::Netmask' => '1.9004','Test::Harness' => '2.00','Test::More' => '0.47','Test::Signature' => '1.04'},'requires_recursive' => ['Cisco-Reconfig-0.6.tar.gz','File-Spec-0.82.tar.gz','IO-String-1.02.tar.gz','Net-Netmask-1.9002.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Signature-1.04.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 28525,'unpacked' => 118530},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['Carp','Cisco::Reconfig','Exporter','Net::BGP::NLRI','Net::Netmask','Scalar::Util','strict','vars']},'Net-AIM-1.22.tar.gz' => {'author' => 'ARYEH','description' => 'Perl extension for AOL Instant Messenger TOC protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1501,'pod' => 414,'pod_errors' => 2,'total' => 1915,'with_comments' => 141},'releases' => 7,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'IO::File' => 0,'IO::Select' => 0,'IO::Socket' => 0,'Socket' => 0,'Sys::Hostname' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21261,'unpacked' => 67697},'testers' => {'tests' => '0','unknown' => 10},'uses' => ['5.004','Carp','IO::Select','Socket','Symbol','strict','vars']},'Net-AIMTOC-0.94.tar.gz' => {'author' => 'ALIZTA','description' => 'Perl implementation of the AIM TOC protocol =head1 DESCRIPTION The C<Net::AIMTOC> module implements in AIM TOC protocol in such a way which make it simple for using when writing bots or AIM clients in Perl. All of the code regarding the connection is abstracted in order to simplify the AIM connection down to merely sending and receiving instant messages and toc commands.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 697,'pod' => 200,'pod_errors' => 0,'total' => 897,'with_comments' => 18},'releases' => 5,'size' => {'packed' => 7303,'unpacked' => 22734},'testers' => {'pass' => 5,'tests' => '0','unknown' => 6},'uses' => ['IO::Socket::INET','constant','strict']},'Net-AOLIM-1.4.tar.gz' => {'author' => 'RWAHBY','description' => 'AOL Instant Messenger OO Interface (TOC)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2115,'pod' => 439,'pod_errors' => 1,'total' => 2554,'with_comments' => 509},'releases' => 7,'size' => {'packed' => 34569,'unpacked' => 124655},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.001','IO::Select','IO::Socket','vars']},'Net-APP-0.2.tar.gz' => {'author' => 'IVAN','description' => 'Critical Path Account Provisioning Protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 214,'pod' => 155,'pod_errors' => 0,'total' => 369,'with_comments' => 8},'releases' => 2,'requires' => ['libnet-1.16.tar.gz'],'requires_module' => {'Net::Cmd' => 0},'requires_recursive' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5232,'unpacked' => 13669},'testers' => {'fail' => 2,'tests' => '0','unknown' => 3},'uses' => ['Carp','IO::Socket','Net::Cmd','Text::CSV_XS','strict','vars']},'Net-Amazon-0.11.tar.gz' => {'author' => 'MSCHILLI','description' => 'Framework for accessing amazon.com via SOAP and XML/HTTP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1316,'pod' => 947,'pod_errors' => 0,'total' => 2263,'with_comments' => 194},'releases' => 9,'requires' => ['Data-Dumper-2.101.tar.gz','Log-Log4perl-0.35.tar.gz','URI-1.24.tar.gz','XML-Simple-2.08.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Data::Dumper' => undef,'LWP::UserAgent' => 2,'Log::Log4perl' => '0.3','URI' => undef,'XML::Simple' => '2.08'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','Log-Log4perl-0.35.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-Simple-2.08.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21223,'unpacked' => 98000},'testers' => {'pass' => 1},'uses' => ['5.006','Data::Dumper','HTTP::Request::Common','LWP::UserAgent','Log::Log4perl','Text::Wrap','URI','XML::Simple','strict','warnings']},'Net-Arping-0.02.tar.gz' => {'author' => 'RIIKI','description' => 'Ping remote host by ARP packets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 127,'pod' => 61,'pod_errors' => 0,'total' => 188,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 4891,'unpacked' => 12415},'testers' => {'fail' => 1},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Net-BGP-0.04.tar.gz' => {'author' => 'LORENSEN','description' => 'Border Gateway Protocol version 4 speaker/listener library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4552,'pod' => 1016,'pod_errors' => 0,'total' => 5568,'with_comments' => 336},'releases' => 5,'requires' => ['Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'List::Util' => '1.01','Test::Harness' => '2.00','Test::More' => '0.47'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 39516,'unpacked' => 169629},'testers' => {'pass' => 5},'uses' => ['Carp','Errno','Exporter','IO::Select','IO::Socket','Net::BGP::ASPath','Net::BGP::NLRI','Net::BGP::Notification','Net::BGP::Peer','Net::BGP::Refresh','Net::BGP::Transport','Net::BGP::Update','Scalar::Util','strict','vars']},'Net-BGP-0.05.tar.gz' => {'author' => 'LORENSEN','description' => 'Border Gateway Protocol version 4 speaker/listener library','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 4561,'pod' => 998,'pod_errors' => 0,'total' => 5559,'with_comments' => 338},'releases' => 5,'requires' => ['Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'List::Util' => '1.01','Test::Harness' => '2.00','Test::More' => '0.47'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 40879,'unpacked' => 171844},'testers' => {'pass' => 5},'uses' => ['Carp','Errno','Exporter','IO::Select','IO::Socket','Scalar::Util','strict','vars']},'Net-BGP-Router-0.04.tar.gz' => {'author' => 'LORENSEN','description' => 'A BGP Router based on Net::BGP','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 819,'pod' => 395,'pod_errors' => 0,'total' => 1214,'with_comments' => 64},'releases' => 1,'requires' => ['Module-Signature-0.26.tar.gz','Net-ACL-0.07.tar.gz','Net-BGP-0.05.tar.gz','Net-Patricia-1.010.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Signature-1.04.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'List::Util' => '1.01','Module::Signature' => '0.22','Net::ACL' => '0.06','Net::BGP' => '0.04','Net::Patricia' => '1.010','Test::Harness' => '2.00','Test::More' => '0.47','Test::Signature' => '1.04'},'requires_recursive' => ['Cisco-Reconfig-0.6.tar.gz','File-Spec-0.82.tar.gz','IO-String-1.02.tar.gz','Module-Signature-0.26.tar.gz','Net-ACL-0.07.tar.gz','Net-BGP-0.05.tar.gz','Net-Netmask-1.9002.tar.gz','Net-Patricia-1.010.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Signature-1.04.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10088,'unpacked' => 33681},'testers' => {'pass' => 3},'uses' => ['Carp','Net::BGP::Peer','Net::BGP::RIB','Net::Patricia','Scalar::Util','strict','vars','warnings']},'Net-Bind-0.01.tar.gz' => {'author' => 'KJOHNSON','description' => 'load various Net::Bind modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 524,'pod' => 254,'pod_errors' => 0,'total' => 778,'with_comments' => 43},'releases' => 5,'size' => {'packed' => 8990,'unpacked' => 32004},'testers' => {'pass' => 3},'uses' => ['5.003','Carp','Exporter','IO::File','Net::Bind::Utils','strict','vars']},'Net-Bind-0.05.tar.gz' => {'author' => 'BBB','description' => 'Interface to bind daemon related files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 551,'pod' => 262,'pod_errors' => 0,'total' => 813,'with_comments' => 52},'releases' => 5,'size' => {'packed' => 10985,'unpacked' => 38895},'testers' => {'pass' => 14},'uses' => ['5.003','Carp','Exporter','IO::File','Net::Bind::Resolv','strict','vars']},'Net-Blogger-0.86.tar.gz' => {'author' => 'ASCOPE','description' => 'an OOP-ish interface for accessing a weblog via the Blogger XML-RPC API.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2308,'pod' => 1707,'pod_errors' => 0,'total' => 4015,'with_comments' => 34},'releases' => 11,'requires' => ['CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','SOAP-Lite-0.55.tar.gz','TermReadKey-2.21.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI' => 0,'Carp' => 0,'Digest::MD5' => 0,'Error' => 0,'HTTP::Cookies' => 0,'SOAP::Lite' => '0.55','Term::ReadKey' => 0,'URI' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','SOAP-Lite-0.55.tar.gz','TermReadKey-2.21.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19755,'unpacked' => 84941},'testers' => {},'uses' => ['CGI','Carp','Digest::MD5','Error','Exporter','File::Basename','FileHandle','HTTP::Cookies','SOAP::Lite','URI','constant','strict','vars']},'Net-CDDBScan-2.01.tar.gz' => {'author' => 'DSHULTZ','description' => 'String search interface to CDDB datbase','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 304,'pod' => 127,'pod_errors' => 0,'total' => 431,'with_comments' => 41},'releases' => 2,'requires' => ['URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::Simple' => '1.32','URI::Escape' => '3.16'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5470,'unpacked' => 14836},'testers' => {'fail' => 6,'pass' => 3,'tests' => '4'},'uses' => ['5.004','Data::Dumper','Exporter','HTTP::Status','LWP::Simple','URI::Escape','strict','vars']},'Net-CIDR-0.07.tar.gz' => {'author' => 'MRSAM','description' => 'Manipulate netblock lists in CIDR notation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 974,'pod' => 201,'pod_errors' => 0,'total' => 1175,'with_comments' => 71},'releases' => 4,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 8085,'unpacked' => 24673},'testers' => {'pass' => 3},'uses' => ['5.000','AutoLoader','Carp','Exporter','Math::BigInt','strict','warnings']},'Net-CIDR-Lite-0.15.tar.gz' => {'author' => 'DOUGW','description' => 'Perl extension for merging IPv4 or IPv6 CIDR addresses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 445,'pod' => 149,'pod_errors' => 1,'total' => 594,'with_comments' => 13},'releases' => 14,'size' => {'packed' => 8099,'unpacked' => 23776},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'Net-CUPS-0.25.tar.gz' => {'author' => 'DHAGEMAN','description' => 'CUPS C API Interface.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 341,'pod' => 207,'pod_errors' => 0,'total' => 548,'with_comments' => 87},'releases' => 3,'requires' => ['Exporter-Cluster-0.31.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Exporter::Cluster' => 0,'Test::More' => 0},'requires_recursive' => ['Exporter-Cluster-0.31.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 39506,'unpacked' => 165050},'testers' => {},'uses' => ['5.006','Carp','Exporter','Exporter::Cluster','XSLoader','strict','warnings']},'Net-DHCP-0.11.tar.gz' => {'author' => 'FVANDUN','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 664,'pod' => 249,'pod_errors' => 4,'total' => 913,'with_comments' => 75},'releases' => 1,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'IO::Select' => 0,'IO::Socket::INET' => 0,'Sys::Hostname' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7272,'unpacked' => 25443},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','IO::Select','IO::Socket::INET','Socket','Sys::Hostname','bytes','in','strict','vars']},'Net-DHCP-Watch-2.02.tar.gz' => {'author' => 'EJDRS','description' => 'A class for monitoring a remote DHCPD server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 286,'pod' => 107,'pod_errors' => 0,'total' => 393,'with_comments' => 81},'releases' => 8,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.47'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8442,'unpacked' => 21122},'testers' => {'pass' => 2},'uses' => ['Carp','Config','Exporter','IO::Socket','Net::hostent','Socket','strict','vars']},'Net-DHCPClient-1.0.tar.gz' => {'author' => 'JWALGENB','description' => 'Interface to DHCP as a client','files' => ['Makefile.PL'],'lines' => {'nonpod' => 551,'pod' => 148,'pod_errors' => 0,'total' => 699,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 5428,'unpacked' => 15600},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','Data::Dumper','FileHandle','Net::RawIP','strict','vars']},'Net-DLookup-1.01.tar.gz' => {'author' => 'DJASMINE','description' => 'Lookup domains on Internic and 2-letter TLDs','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 729,'pod' => 136,'pod_errors' => 1,'total' => 865,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 10546,'unpacked' => 37222},'testers' => {'pass' => 10},'uses' => ['Exporter','Socket','strict','vars']},'Net-DNAT-0.04.tar.gz' => {'author' => 'BBB','description' => 'Psuedo Layer7 Packet Processer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 373,'pod' => 165,'pod_errors' => 0,'total' => 538,'with_comments' => 44},'releases' => 12,'requires' => ['IO-Multiplex-1.04.tar.gz','Net-Server-0.85.tar.gz'],'requires_module' => {'IO::Multiplex' => '1.02','Net::Server' => '0.82'},'requires_recursive' => ['IO-1.20.tar.gz','IO-Multiplex-1.04.tar.gz','Net-Server-0.85.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10552,'unpacked' => 31915},'testers' => {'fail' => 1,'pass' => 1,'tests' => '2'},'uses' => ['Apache::Constants','Carp','Exporter','IO::Socket','Net::Server::Multiplex','Socket','strict','vars']},'Net-DNAT-0.13.tar.gz' => {'author' => 'BBB','description' => 'Psuedo Layer7 Packet Processer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 565,'pod' => 173,'pod_errors' => 0,'total' => 738,'with_comments' => 56},'releases' => 12,'requires' => ['IO-Multiplex-1.04.tar.gz','Net-Server-0.85.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'IO::Multiplex' => '1.02','Net::Server' => '0.85','mod_perl' => 0},'requires_recursive' => ['IO-1.20.tar.gz','IO-Multiplex-1.04.tar.gz','Net-Server-0.85.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17280,'unpacked' => 47190},'testers' => {'fail' => 1,'tests' => '2'},'uses' => ['Apache::Connection','Apache::Constants','Exporter','IO::Socket','Net::Ping','Net::Server::Multiplex','Socket','strict','vars']},'Net-DNS-0.19.tar.gz' => {'author' => 'BBB','description' => 'Perl interface to the DNS resolver','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5891,'pod' => 2648,'pod_errors' => 0,'total' => 8539,'with_comments' => 399},'releases' => 33,'requires' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Digest::HMAC_MD5' => 1,'Digest::MD5' => '2.12','FileHandle' => 2,'IO::Select' => '1.14','IO::Socket' => '1.26','MIME::Base64' => '2.11','Socket' => '1.72'},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 79511,'unpacked' => 331102},'testers' => {'pass' => 3},'uses' => ['5.6.0','AnyDBM_File','Carp','Config','Digest::HMAC_MD5','Exporter','Fcntl','FileHandle','IO::Select','IO::Socket','MIME::Base64','Net::DNS','Net::DNS::Header','Net::DNS::Packet','Net::DNS::Question','Net::DNS::RR','Net::DNS::RR::A','Net::DNS::RR::AAAA','Net::DNS::RR::AFSDB','Net::DNS::RR::CNAME','Net::DNS::RR::EID','Net::DNS::RR::HINFO','Net::DNS::RR::ISDN','Net::DNS::RR::LOC','Net::DNS::RR::MB','Net::DNS::RR::MG','Net::DNS::RR::MINFO','Net::DNS::RR::MR','Net::DNS::RR::MX','Net::DNS::RR::NAPTR','Net::DNS::RR::NIMLOC','Net::DNS::RR::NS','Net::DNS::RR::NSAP','Net::DNS::RR::NULL','Net::DNS::RR::PTR','Net::DNS::RR::PX','Net::DNS::RR::RP','Net::DNS::RR::RT','Net::DNS::RR::SOA','Net::DNS::RR::SRV','Net::DNS::RR::TXT','Net::DNS::RR::X25','Net::DNS::Resolver','Net::DNS::Update','Socket','Tie::Hash','constant','strict','vars']},'Net-DNS-0.38.tar.gz' => {'author' => 'CREIN','description' => 'Interface to the DNS resolver','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7150,'pod' => 2971,'pod_errors' => 0,'total' => 10121,'with_comments' => 504},'releases' => 33,'requires' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Digest::HMAC_MD5' => 1,'Digest::MD5' => '2.12','IO::Socket' => 0,'MIME::Base64' => '2.11','Test::More' => '0.18'},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 91831,'unpacked' => 360057},'testers' => {'fail' => 1,'pass' => 5,'tests' => '663'},'uses' => ['Carp','Config','Data::Dumper','Digest::HMAC_MD5','DynaLoader','Exporter','IO::Select','IO::Socket','MIME::Base64','Net::DNS::Header','Net::DNS::Packet','Net::DNS::Question','Net::DNS::RR','Net::DNS::RR::DS','Net::DNS::RR::KEY','Net::DNS::RR::NXT','Net::DNS::RR::SIG','Net::DNS::Resolver','Net::DNS::Select','Net::DNS::Update','Socket','Text::ParseWords','constant','strict','vars']},'Net-DNS-Method-2.00.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Base class for Net::DNS::Server methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 875,'pod' => 424,'pod_errors' => 0,'total' => 1299,'with_comments' => 52},'releases' => 1,'requires' => ['Net-DNS-0.38.tar.gz','NetAddr-IP-3.14.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Find' => 0,'Net::DNS' => '0.38','NetAddr::IP' => 3},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','NetAddr-IP-3.14.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11884,'unpacked' => 45477},'testers' => {'pass' => 2},'uses' => ['5.005_62','Carp','Exporter','File::Find','Net::DNS','NetAddr::IP','constant','strict','vars','warnings']},'Net-DNS-SEC-0.10.tar.gz' => {'author' => 'OLAF','description' => 'DNSSEC extensions to Net::DNS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2584,'pod' => 585,'pod_errors' => 1,'total' => 3169,'with_comments' => 259},'releases' => 9,'requires' => ['Crypt-OpenSSL-DSA-0.11.tar.gz','Crypt-OpenSSL-RSA-0.19.tar.gz','Digest-BubbleBabble-0.01.tar.gz','MIME-Base64-2.20.tar.gz','Math-BigInt-1.64.tar.gz','Net-DNS-0.38.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Crypt::OpenSSL::DSA' => '0.1','Crypt::OpenSSL::RSA' => '0.17','Digest::BubbleBabble' => '0.01','File::Basename' => 0,'MIME::Base64' => 0,'Math::BigInt' => 0,'Net::DNS' => '0.32','Test::More' => '0.47','Time::Local' => 0},'requires_recursive' => ['Crypt-OpenSSL-DSA-0.11.tar.gz','Crypt-OpenSSL-RSA-0.19.tar.gz','Crypt-OpenSSL-Random-0.03.tar.gz','Digest-BubbleBabble-0.01.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Math-BigInt-1.64.tar.gz','Net-DNS-0.38.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 40209,'unpacked' => 129192},'testers' => {},'uses' => ['Carp','Crypt::OpenSSL::DSA','Crypt::OpenSSL::RSA','Cwd','Digest::BubbleBabble','Digest::SHA1','Exporter','File::Basename','MIME::Base64','Math::BigInt','Net::DNS','Net::DNS::Packet','Time::Local','integer','strict','vars']},'Net-DNS-Server-1.45.tar.gz' => {'author' => 'LUISMUNOZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 310,'pod' => 112,'pod_errors' => 0,'total' => 422,'with_comments' => 6},'releases' => 1,'requires' => ['Net-DNS-0.38.tar.gz','Net-DNS-Method-2.00.tar.gz','NetAddr-IP-3.14.tar.gz'],'requires_module' => {'Net::DNS' => '0.38','Net::DNS::Method' => 0,'NetAddr::IP' => 3},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','Net-DNS-Method-2.00.tar.gz','NetAddr-IP-3.14.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6096,'unpacked' => 14738},'testers' => {'pass' => 1},'uses' => ['5.005_62','Carp','IO::Select','IO::Socket::INET','Net::DNS','Net::DNS::Method','NetAddr::IP','strict','warnings']},'Net-DNS-ZoneFile-1.04.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Perl extension to convert a zone file to a collection of RRs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 452,'pod' => 80,'pod_errors' => 0,'total' => 532,'with_comments' => 27},'releases' => 3,'requires' => ['NetAddr-IP-3.14.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'NetAddr::IP' => '3.07','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','NetAddr-IP-3.14.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7795,'unpacked' => 30350},'testers' => {'fail' => 3,'tests' => '1'},'uses' => ['5.005_62','IO::File','Net::DNS::RR','NetAddr::IP','strict','warnings']},'Net-DNSServer-0.04.tar.gz' => {'author' => 'BBB','description' => 'Perl module to be used as a name server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1030,'pod' => 34,'pod_errors' => 0,'total' => 1064,'with_comments' => 147},'releases' => 8,'requires' => ['IPC-SharedCache-1.3.tar.gz','Net-DNS-0.38.tar.gz','Net-Server-0.85.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'IPC::SharedCache' => '1.3','Net::DNS' => '0.19','Net::Server' => '0.62','Storable' => 1},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','IPC-ShareLite-0.09.tar.gz','IPC-SharedCache-1.3.tar.gz','IPC-SysV-1.03.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','Net-Server-0.85.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12182,'unpacked' => 41876},'testers' => {'pass' => 1},'uses' => ['AnyDBM_File','Carp','Exporter','Fcntl','Getopt::Long','IO::File','IO::Socket','IPC::SharedCache','Net::DNS','Net::DNS::Packet','Net::DNS::RR','Net::DNSServer::Base','Net::Server::MultiType','POSIX','Storable','strict','vars']},'Net-DNSServer-0.11.tar.gz' => {'author' => 'BBB','description' => 'Perl module to be used as a name server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1607,'pod' => 479,'pod_errors' => 0,'total' => 2086,'with_comments' => 216},'releases' => 8,'requires' => ['DBI-1.37.tar.gz','IPC-SharedCache-1.3.tar.gz','Net-Bind-0.05.tar.gz','Net-DNS-0.38.tar.gz','Net-Server-0.85.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'DBI' => 0,'IPC::SharedCache' => '1.3','Net::Bind' => '0.03','Net::DNS' => '0.19','Net::Server' => '0.62','Storable' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','IPC-ShareLite-0.09.tar.gz','IPC-SharedCache-1.3.tar.gz','IPC-SysV-1.03.tar.gz','MIME-Base64-2.20.tar.gz','Net-Bind-0.05.tar.gz','Net-DNS-0.38.tar.gz','Net-Server-0.85.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 25566,'unpacked' => 89672},'testers' => {'pass' => 2},'uses' => ['Carp','DBI','Exporter','Fcntl','GDBM_File','Getopt::Long','IO::File','IO::Socket','IPC::SharedCache','Net::Bind','Net::DNS','Net::DNS::Packet','Net::DNS::RR','Net::Server::MultiType','Storable','Sys::Hostname','strict','vars']},'Net-Daemon-0.37.tar.gz' => {'author' => 'JWIED','description' => 'Perl extension for portable daemons','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1288,'pod' => 597,'pod_errors' => 0,'total' => 1885,'with_comments' => 260},'releases' => 22,'size' => {'packed' => 30228,'unpacked' => 100640},'testers' => {'fail' => 3,'pass' => 14,'tests' => '43'},'uses' => ['5.004','Thread','Win32','Win32::EventLog','Win32::Process','strict','vars']},'Net-Daemon-SSL-1.0.tar.gz' => {'author' => 'MKUL','description' => 'SSL extension for Net::Daemon','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 93,'pod' => 56,'pod_errors' => 0,'total' => 149,'with_comments' => 2},'releases' => 1,'requires' => ['IO-Socket-SSL-0.94.tar.gz','Net-Daemon-0.37.tar.gz'],'requires_module' => {'IO::Socket::SSL' => '0.73','Net::Daemon' => '0.30'},'requires_recursive' => ['IO-Socket-SSL-0.94.tar.gz','Net-Daemon-0.37.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 2394,'unpacked' => 5522},'testers' => {'pass' => 5},'uses' => ['IO::Socket::SSL','Net::Daemon','POSIX','strict']},'Net-Dict-2.07.tar.gz' => {'author' => 'NEILB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 636,'pod' => 263,'pod_errors' => 0,'total' => 899,'with_comments' => 87},'releases' => 12,'requires' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'IO::Socket' => 0,'Net::Cmd' => 0},'requires_recursive' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 30284,'unpacked' => 122437},'testers' => {'pass' => 2},'uses' => ['Carp','Digest::MD5','IO::Socket','Net::Cmd','strict','vars']},'Net-Divert-0.01.tgz' => {'author' => 'ATRAK','description' => 'Divert socket module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 101,'pod_errors' => 0,'total' => 339,'with_comments' => 60},'releases' => 1,'size' => {'packed' => 4683,'unpacked' => 11559},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'Net-Dnet-0.73.tar.gz' => {'author' => 'SPIDB','description' => 'DECnet-specific socket usage','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 422,'pod' => 0,'pod_errors' => 0,'total' => 422,'with_comments' => 103},'releases' => 1,'size' => {'packed' => 12299,'unpacked' => 38627},'testers' => {},'uses' => ['5.00393','AutoLoader','Carp','DynaLoader','Exporter','Net::Gen','Socket','strict','vars']},'Net-Domain-ExpireDate-0.15.tgz' => {'author' => 'DESPAIR','description' => 'Perl extension for obtaining expiration date of domain names','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 284,'pod' => 46,'pod_errors' => 0,'total' => 330,'with_comments' => 62},'releases' => 14,'requires' => ['Net-Whois-Raw-0.23.tar.gz','Time-Piece-1.08.tar.gz'],'requires_module' => {'Net::Whois::Raw' => 0,'Time::Piece' => 1},'requires_recursive' => ['IO-1.20.tar.gz','Net-Whois-Raw-0.23.tar.gz','Time-Piece-1.08.tar.gz'],'size' => {'packed' => 6015,'unpacked' => 21795},'testers' => {'pass' => 1},'uses' => ['Exporter','Net::Whois::Raw','Time::Piece','Time::Seconds','strict','vars']},'Net-Domain-TLD-1.3.tar.gz' => {'author' => 'ALEXP','description' => 'Gives ability to retrieve currently available tld names/descriptions and perform verification of given tld name','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 350,'pod' => 72,'pod_errors' => 0,'total' => 422,'with_comments' => 4},'releases' => 3,'requires' => ['Memoize-1.01.tar.gz'],'requires_module' => {'Memoize' => 0},'requires_recursive' => ['Memoize-1.01.tar.gz'],'size' => {'packed' => 4872,'unpacked' => 12968},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['Memoize','constant','strict','warnings']},'Net-EMI-Client-1.02.tar.gz' => {'author' => 'SCHAFFTER','description' => 'Provide a Client to send SMS msgs to an SMSC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 559,'pod' => 199,'pod_errors' => 0,'total' => 758,'with_comments' => 103},'releases' => 3,'requires' => ['Net-EMI-Common-1.01.tar.gz'],'requires_module' => {'Net::EMI::Common' => '1.0'},'requires_recursive' => ['Net-EMI-Common-1.01.tar.gz'],'size' => {'packed' => 8824,'unpacked' => 34901},'testers' => {'fail' => 3,'pass' => 2},'uses' => ['Carp','IO::Socket','Net::EMI::Common','constant','strict','vars']},'Net-EMI-Common-1.01.tar.gz' => {'author' => 'SCHAFFTER','description' => 'Common routines for EMI clients and servers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 121,'pod' => 69,'pod_errors' => 0,'total' => 190,'with_comments' => 25},'releases' => 2,'size' => {'packed' => 3213,'unpacked' => 7447},'testers' => {'pass' => 11},'uses' => ['constant','strict','vars']},'Net-ESMTP-0.1.tar.gz' => {'author' => 'MAKLER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 593,'pod' => 747,'pod_errors' => 0,'total' => 1340,'with_comments' => 16},'releases' => 1,'size' => {'packed' => 36754,'unpacked' => 146040},'testers' => {},'uses' => ['5.008','AutoLoader','Carp','Exporter','XSLoader','strict','warnings']},'Net-Ewtoo-Bot-0.16.tar.gz' => {'author' => 'GBROWN','description' => 'a Ewtoo-compatible talker robot client module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 189,'pod' => 129,'pod_errors' => 0,'total' => 318,'with_comments' => 9},'releases' => 4,'size' => {'packed' => 6593,'unpacked' => 16240},'testers' => {'pass' => 3},'uses' => ['IO::Handle','IO::Socket','strict','vars']},'Net-FTP-Common-3.1.tar.gz' => {'author' => 'TBONE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 455,'pod' => 403,'pod_errors' => 0,'total' => 858,'with_comments' => 35},'releases' => 26,'requires' => ['libnet-1.16.tar.gz'],'requires_module' => {'Net::FTP' => 1},'requires_recursive' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17201,'unpacked' => 54848},'testers' => {'pass' => 1},'uses' => ['Carp','Data::Dumper','Net::FTP','strict','vars']},'Net-FTP-Recursive-1.5.tar.gz' => {'author' => 'JDLEE','description' => 'Recursive FTP Client class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 740,'pod' => 182,'pod_errors' => 0,'total' => 922,'with_comments' => 98},'releases' => 7,'requires' => ['libnet-1.16.tar.gz'],'requires_module' => {'Net::FTP' => 0},'requires_recursive' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8828,'unpacked' => 30556},'testers' => {'pass' => 4},'uses' => ['Net::FTP','strict']},'Net-FTPServer-1.112.tar.gz' => {'author' => 'RWMJ','description' => 'A secure, extensible and configurable Perl FTP server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9516,'pod' => 2825,'pod_errors' => 22,'total' => 12341,'with_comments' => 1341},'releases' => 42,'requires' => ['version-0.29.tar.gz','xisofs-1.3.tar.gz'],'requires_module' => {'status' => 'optional','version' => '0.11'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','version-0.29.tar.gz','xisofs-1.3.tar.gz'],'size' => {'packed' => 120917,'unpacked' => 490922},'testers' => {'fail' => 1,'tests' => '550'},'uses' => ['Archive::Zip','Authen::PAM','BSD::Resource','Carp','Config','DBI','Digest::MD5','DynaLoader','Fcntl','File::Sync','Getopt::Long','IO::Dir','IO::File','IO::Scalar','IO::Seekable','IO::Select','IO::Socket','IPC::Open2','POSIX','Socket','Sys::Hostname','Sys::Syslog','strict','succeeds','vars']},'Net-FTPServer-PWP-1.21.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'The FTP server for PWP (personal web pages) service.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 969,'pod' => 495,'pod_errors' => 3,'total' => 1464,'with_comments' => 105},'releases' => 4,'requires' => ['Net-FTPServer-1.112.tar.gz','Net-Radius-1.44.tar.gz','NetAddr-IP-3.14.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'Net::FTPServer' => 0,'Net::Radius::Dictionary' => '1.43','Net::Radius::Packet' => '1.43','NetAddr::IP' => 3,'Time::HiRes' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Net-FTPServer-1.112.tar.gz','Net-Radius-1.44.tar.gz','NetAddr-IP-3.14.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','version-0.29.tar.gz','xisofs-1.3.tar.gz'],'size' => {'packed' => 15346,'unpacked' => 47203},'testers' => {'fail' => 1,'tests' => '4'},'uses' => ['5.00500','Exporter','IO::Select','IO::Socket::INET','Net::FTPServer','Net::FTPServer::Full::DirHandle','Net::FTPServer::Full::FileHandle','Net::FTPServer::Handle','Net::Radius::Dictionary','Net::Radius::Packet','NetAddr::IP','Time::HiRes','strict','vars']},'Net-FTPServer-XferLog-1.1.tgz' => {'author' => 'TBONE','description' => 'parse FTP server xfer logs.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 105,'pod_errors' => 0,'total' => 183,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 3181,'unpacked' => 7085},'testers' => {'pass' => 2},'uses' => ['5.006','Exporter','strict','warnings']},'Net-FileShare-0.18.tar.gz' => {'author' => 'GRAVALO','description' => 'Object oriented interface for the creation of file sharing clients and servers.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 738,'pod' => 232,'pod_errors' => 1,'total' => 970,'with_comments' => 124},'releases' => 4,'size' => {'packed' => 13144,'unpacked' => 39330},'testers' => {'pass' => 3},'uses' => ['5.004','Carp','Exporter','Fcntl','IO::Socket::INET','POSIX','Test::Builder','strict','vars']},'Net-Finger-1.06.tar.gz' => {'author' => 'FIMM','description' => 'a Perl implementation of a finger client.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 67,'pod_errors' => 0,'total' => 205,'with_comments' => 15},'releases' => 7,'size' => {'packed' => 3511,'unpacked' => 6997},'testers' => {'pass' => 6},'uses' => ['Carp','Exporter','Socket','strict','vars']},'Net-FreeDB-0.06.tar.gz' => {'author' => 'DSHULTZ','description' => 'OOP interface to the FreeDB database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 269,'pod' => 153,'pod_errors' => 1,'total' => 422,'with_comments' => 12},'releases' => 1,'requires' => ['CDDB-File-1.03.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'CDDB::File' => '1.01','Net::Cmd' => '2.12'},'requires_recursive' => ['CDDB-File-1.03.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17516,'unpacked' => 58851},'testers' => {'pass' => 1},'uses' => ['5.006','AutoLoader','CDDB::File','Carp','Data::Dumper','DynaLoader','Exporter','IO::Socket','Net::Cmd','strict','warnings']},'Net-FreeDB2-0.8.2.6.tar.gz' => {'author' => 'ZOCCAV','description' => 'FreeDB generic connection class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2826,'pod' => 1746,'pod_errors' => 2,'total' => 4572,'with_comments' => 319},'releases' => 2,'requires' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Error' => 0,'HTTP::Request' => 0,'IO::Socket::INET' => 0,'LWP::UserAgent' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 31373,'unpacked' => 164351},'testers' => {'pass' => 3},'uses' => ['5.005_62','AutoLoader','Error','Exporter','HTTP::Request','IO::File','IO::Socket::INET','Sys::Hostname','strict','warnings']},'Net-Gadu-0.9.tar.gz' => {'author' => 'KRZAK','description' => 'Interfejs do biblioteki libgadu.so (czesc ekg)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 154,'pod_errors' => 0,'total' => 298,'with_comments' => 5},'releases' => 10,'size' => {'packed' => 8092,'unpacked' => 23641},'testers' => {},'uses' => ['5.006','AutoLoader','DynaLoader','Exporter','Socket','strict','warnings']},'Net-Gnats-0.03.tar.gz' => {'author' => 'MHOOLEHAN','description' => 'Perl interface to GNU Gnats daemon','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1051,'pod' => 472,'pod_errors' => 0,'total' => 1523,'with_comments' => 59},'releases' => 4,'size' => {'packed' => 8048,'unpacked' => 40271},'testers' => {'pass' => 2},'uses' => ['5.005_62','AutoLoader','Carp','Exporter','IO::Handle','Net::Gnats','Socket','strict','warnings']},'Net-Gnats-0.04.tar.gz' => {'author' => 'MHOOLEHAN','description' => 'Perl interface to GNU Gnats daemon','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1001,'pod' => 337,'pod_errors' => 0,'total' => 1338,'with_comments' => 59},'releases' => 4,'size' => {'packed' => 8671,'unpacked' => 35123},'testers' => {'pass' => 3},'uses' => ['5.005_62','AutoLoader','Carp','Exporter','IO::Handle','Net::Gnats::PR','Socket','strict','warnings']},'Net-Gnutella-0.1.tar.gz' => {'author' => 'IWADE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1686,'pod' => 0,'pod_errors' => 0,'total' => 1686,'with_comments' => 69},'releases' => 1,'size' => {'packed' => 12020,'unpacked' => 49032},'testers' => {'pass' => 6},'uses' => ['Carp','Exporter','HTTP::Date','HTTP::Request','HTTP::Status','IO::File','IO::Select','IO::Socket','LWP::MediaTypes','Socket','URI::URL','constant','strict','vars']},'Net-Goofey-1.4.tar.gz' => {'author' => 'GOSSAMER','description' => 'Communicate with a Goofey server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 361,'pod' => 133,'pod_errors' => 13,'total' => 494,'with_comments' => 44},'releases' => 5,'size' => {'packed' => 31314,'unpacked' => 90802},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','Fcntl','IO::Socket','Symbol','Sys::Hostname','strict','vars']},'Net-Google-0.60.tar.gz' => {'author' => 'ASCOPE','description' => 'simple OOP-ish interface to the Google SOAP API','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1415,'pod' => 971,'pod_errors' => 0,'total' => 2386,'with_comments' => 65},'releases' => 10,'requires' => ['SOAP-Lite-0.55.tar.gz','Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '0','Cwd' => '0','LWP::Protocol::file' => '0','SOAP::Lite' => '0','Test::More' => '0'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','SOAP-Lite-0.55.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15134,'unpacked' => 58086},'testers' => {'fail' => 1,'tests' => '18'},'uses' => ['Carp','Cwd','Exporter','File::Spec','SOAP::Lite','constant','strict','vars']},'Net-Gopher-0.35.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1727,'pod' => 370,'pod_errors' => 0,'total' => 2097,'with_comments' => 364},'releases' => 13,'requires' => ['URI-1.24.tar.gz'],'requires_module' => {'URI' => '1.11'},'requires_recursive' => ['URI-1.24.tar.gz'],'testers' => {'pass' => 1},'uses' => ['5.005','Carp','Exporter','IO::Select','IO::Socket','Time::Local','URI','strict','vars','warnings']},'Net-GrpNetworks-1.08.tar.gz' => {'author' => 'ARVIEGAS','description' => 'Perl extension to determine in which network group a IP belongs to.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 162,'pod' => 44,'pod_errors' => 0,'total' => 206,'with_comments' => 21},'releases' => 3,'size' => {'packed' => 3119,'unpacked' => 7285},'testers' => {'pass' => 7},'uses' => ['Exporter','strict','vars']},'Net-HL7-0.62.tar.gz' => {'author' => 'DDOKTER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 731,'pod' => 415,'pod_errors' => 4,'total' => 1146,'with_comments' => 81},'releases' => 6,'size' => {'packed' => 8276,'unpacked' => 28880},'testers' => {'pass' => 2},'uses' => ['5.004','IO::Socket','IO::Socket::INET','Net::HL7::Connection','Net::HL7::Message','Net::HL7::Messages::ACK','Net::HL7::Request','Net::HL7::Response','Net::HL7::Segment','Net::HL7::Segments::MSH','POSIX','Sys::Hostname','strict','warnings']},'Net-HL7-0.66.tar.gz' => {'author' => 'DDOKTER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 836,'pod' => 388,'pod_errors' => 4,'total' => 1224,'with_comments' => 85},'releases' => 6,'size' => {'packed' => 9977,'unpacked' => 35757},'testers' => {'pass' => 2},'uses' => ['5.004','IO::Socket','IO::Socket::INET','POSIX','Sys::Hostname','strict','warnings']},'Net-HTTPServer-0.4.tar.gz' => {'author' => 'REATMON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2772,'pod' => 1291,'pod_errors' => 0,'total' => 4063,'with_comments' => 274},'releases' => 4,'requires' => ['URI-1.24.tar.gz'],'requires_module' => {'URI' => 0},'requires_recursive' => ['URI-1.24.tar.gz'],'size' => {'packed' => 45086,'unpacked' => 146566},'testers' => {'pass' => 2},'uses' => ['Carp','FileHandle','IO::Select','IO::Socket','IO::Socket::SSL','POSIX','URI','URI::QueryParam','strict','vars']},'Net-HTTPTunnel-0.4.tar.gz' => {'author' => 'RWAHBY','description' => 'Tunnel through HTTP proxies with CONNECT','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 150,'pod' => 76,'pod_errors' => 0,'total' => 226,'with_comments' => 27},'releases' => 4,'size' => {'packed' => 10042,'unpacked' => 32216},'testers' => {'pass' => 1},'uses' => ['5.001','IO::Socket','vars']},'Net-Hesiod-1.11.tar.gz' => {'author' => 'PAYERLE','description' => 'Interface to Hesiod library API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 246,'pod' => 117,'pod_errors' => 0,'total' => 363,'with_comments' => 27},'releases' => 2,'size' => {'packed' => 21182,'unpacked' => 67304},'testers' => {},'uses' => ['5','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Net-Hotline-0.83.tar.gz' => {'author' => 'JSIRACUSA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6642,'pod' => 1344,'pod_errors' => 1,'total' => 7986,'with_comments' => 470},'releases' => 25,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'IO::File' => 0,'IO::Socket' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 58557,'unpacked' => 274466},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','Exporter','IO::File','IO::Handle','IO::Socket','Mac::Files','Mac::MoreFiles','POSIX','constant','strict','vars']},'Net-IANA-PortNumbers-1.16.tar.gz' => {'author' => 'FOX','description' => 'object-based representation of a specific port','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 10310,'pod' => 246,'pod_errors' => 0,'total' => 10556,'with_comments' => 150},'releases' => 3,'size' => {'packed' => 115655,'unpacked' => 390848},'testers' => {'pass' => 2},'uses' => ['$self->{path}::$self->{dispatch}','CPAN','CPANPLUS','CPANPLUS::Backend','Carp','Config','Cwd','ExtUtils::Install','ExtUtils::MM_Unix','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Basename','File::Find','File::Path','File::Spec','FileHandle','LWP::Simple','Module::Install','Module::Install::Base','Net::FTP','Socket','YAML','inc::Module::Install','strict','vars']},'Net-ICB-1.62.tar.gz' => {'author' => 'JMV','description' => 'ICB style chat server interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 354,'pod' => 142,'pod_errors' => 0,'total' => 496,'with_comments' => 75},'releases' => 1,'size' => {'packed' => 7407,'unpacked' => 19717},'testers' => {'fail' => 1,'pass' => 5,'tests' => '19'},'uses' => ['5.004','Carp','Exporter','IO::Socket','strict','vars']},'Net-ICQ-0.16.tar.gz' => {'author' => 'JMUHLICH','description' => 'Client interface to ICQ messaging','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1887,'pod' => 120,'pod_errors' => 0,'total' => 2007,'with_comments' => 339},'releases' => 10,'size' => {'packed' => 19049,'unpacked' => 66338},'testers' => {'pass' => 9},'uses' => ['Carp','IO::Select','IO::Socket','Math::BigInt','Time::Local','strict','vars']},'Net-ICQV5-1.20.tar.gz' => {'author' => 'SNEMAROV','description' => 'Module to send and receive ICQ messages.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 928,'pod' => 30,'pod_errors' => 0,'total' => 958,'with_comments' => 207},'releases' => 1,'requires' => ['Net-ICQV5CD-1.02.tar.gz'],'requires_module' => {'Net::ICQV5CD' => '1.02'},'requires_recursive' => ['Net-ICQV5CD-1.02.tar.gz'],'size' => {'packed' => 28189,'unpacked' => 95059},'testers' => {'pass' => 3},'uses' => ['Carp','Data::Dumper','Exporter','Fcntl','IO::Select','IO::Socket','Net::ICQV5CD','Symbol','Sys::Hostname','strict','vars']},'Net-ICQV5CD-1.02.tar.gz' => {'author' => 'SNEMAROV','description' => 'Crypt/decrypt ICQ protocol V5 packets','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 257,'pod' => 57,'pod_errors' => 0,'total' => 314,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 3670,'unpacked' => 12113},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['Exporter','strict','vars']},'Net-ICal-0.11.tar.gz' => {'author' => 'EBUSBOOM','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6275,'pod' => 0,'pod_errors' => 0,'total' => 6275,'with_comments' => 307},'releases' => 5,'size' => {'packed' => 76716,'unpacked' => 792501},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','ICAL:Component','Net::ICal','Time::Local']},'Net-ICal-0.14.tar.gz' => {'author' => 'SRL','description' => '- Interface to RFC2445 (iCalendar) calendaring and scheduling protocol.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5244,'pod' => 1633,'pod_errors' => 16,'total' => 6877,'with_comments' => 1048},'releases' => 5,'requires' => ['Class-MethodMapper-1.0.tar.gz','Date-Calc-5.3.tar.gz','Date-ICal-1.72.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::MethodMapper' => 1,'Date::Calc' => '4.3','Date::ICal' => '1.20','Test::More' => 0},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Class-MethodMapper-1.0.tar.gz','Data-Dumper-2.101.tar.gz','Date-Calc-5.3.tar.gz','Date-ICal-1.72.tar.gz','Date-Leapyear-1.71.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 123229,'unpacked' => 489721},'testers' => {},'uses' => ['Carp','Class::MethodMapper','Data::Dumper','Date::Calc','Date::ICal','Exporter','Net::Domain','Net::ICal::Attendee','Net::ICal::Calendar','Net::ICal::Component','Net::ICal::ETJ','Net::ICal::Event','Net::ICal::Freebusy','Net::ICal::Period','Net::ICal::Property','Net::ICal::Recurrence','Net::ICal::Time','Net::ICal::Trigger','Net::ICal::Util','POSIX','Time::Local','UNIVERSAL','constant','strict']},'Net-ICal-0.15.tar.gz' => {'author' => 'SRL','description' => '- Interface to RFC2445 (iCalendar) calendaring and scheduling protocol.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5699,'pod' => 1658,'pod_errors' => 22,'total' => 7357,'with_comments' => 1111},'releases' => 5,'requires' => ['Class-MethodMapper-1.0.tar.gz','Date-Calc-5.3.tar.gz','Date-ICal-1.72.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::MethodMapper' => 1,'Date::Calc' => '4.3','Date::ICal' => '1.27','Test::Simple' => '0.10'},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Class-MethodMapper-1.0.tar.gz','Data-Dumper-2.101.tar.gz','Date-Calc-5.3.tar.gz','Date-ICal-1.72.tar.gz','Date-Leapyear-1.71.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 116977,'unpacked' => 465706},'testers' => {'fail' => 2,'pass' => 2,'tests' => '65'},'uses' => ['Carp','Class::MethodMapper','Data::Dumper','Date::Calc','Date::ICal','Exporter','Net::Domain','Net::ICal::Calendar','Net::ICal::Component','Net::ICal::Duration','Net::ICal::Journal','Net::ICal::Property','Net::ICal::Todo','POSIX','Time::Local','UNIVERSAL','constant','strict']},'Net-ICal-VTIMEZONES-0.02.tar.gz' => {'author' => 'SRL','description' => 'Perl extension for ICalendar date objects.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 41,'pod' => 22,'pod_errors' => 0,'total' => 63,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 37938,'unpacked' => 210203},'testers' => {'fail' => 1},'uses' => ['Net::ICal::Config','vars']},'Net-IDN-Nameprep-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'IDN nameprep tools','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1050,'pod' => 72,'pod_errors' => 0,'total' => 1122,'with_comments' => 1},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','Unicode-Normalize-0.23.tar.gz'],'requires_module' => {'Test::More' => '0.18','Unicode::Normalize' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Unicode-Normalize-0.23.tar.gz'],'size' => {'packed' => 7466,'unpacked' => 26272},'testers' => {'fail' => 2,'pass' => 3,'tests' => '12'},'uses' => ['Carp','Unicode::Normalize','strict','v5.6.0']},'Net-IMAP-Simple-0.93.tar.gz' => {'author' => 'JPAF','description' => 'Only implements the basic IMAP features','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 624,'pod' => 88,'pod_errors' => 0,'total' => 712,'with_comments' => 98},'releases' => 4,'size' => {'packed' => 3355,'unpacked' => 14370},'testers' => {'pass' => 10},'uses' => ['IO::File','IO::Socket','strict','vars']},'Net-IP-1.20.tar.gz' => {'author' => 'MANU','description' => 'Perl extension for manipulating IPv4/IPv6 addresses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2443,'pod' => 724,'pod_errors' => 0,'total' => 3167,'with_comments' => 583},'releases' => 11,'size' => {'packed' => 24630,'unpacked' => 87109},'testers' => {'pass' => 3},'uses' => ['Exporter','IP::Authority','Math::BigInt','integer','strict','vars']},'Net-IP-Match-0.01.tar.gz' => {'author' => 'MARCEL','description' => 'Efficiently match IP addresses against IP ranges','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 71,'pod' => 100,'pod_errors' => 0,'total' => 171,'with_comments' => 2},'releases' => 1,'requires' => ['Filter-Simple-0.78.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Filter::Simple' => '0.77','Test::More' => '0.42'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 10233,'unpacked' => 31605},'testers' => {'pass' => 3},'uses' => ['5.005_62','Filter::Simple','strict','warnings']},'Net-IPAddr-Find-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Find IP addresses in plain text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 16,'pod' => 25,'pod_errors' => 0,'total' => 41,'with_comments' => 0},'releases' => 2,'requires' => ['NetAddr-IP-3.14.tar.gz','NetAddr-IP-Find-0.03.tar.gz'],'requires_module' => {'NetAddr::IP' => 0,'NetAddr::IP::Find' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','NetAddr-IP-3.14.tar.gz','NetAddr-IP-Find-0.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1883,'unpacked' => 3180},'testers' => {'pass' => 3},'uses' => ['Exporter','NetAddr::IP::Find','strict','vars']},'Net-IPv4Addr-0.10.tar.gz' => {'author' => 'FRAJULAC','description' => 'Perl extension for manipulating IPv4 addresses.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 231,'pod' => 154,'pod_errors' => 0,'total' => 385,'with_comments' => 33},'releases' => 5,'size' => {'packed' => 8429,'unpacked' => 25137},'testers' => {'pass' => 11},'uses' => ['AutoLoader','Carp','Exporter','strict','vars']},'Net-IPv6Addr-0.2.tar.gz' => {'author' => 'TMONROE','description' => '- check validity of IPv6 addresses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 579,'pod' => 257,'pod_errors' => 0,'total' => 836,'with_comments' => 21},'releases' => 2,'requires' => ['Math-Base85-0.2.tar.gz','Net-IPv4Addr-0.10.tar.gz'],'requires_module' => {'Math::Base85' => 0,'Net::IPv4Addr' => 0},'requires_recursive' => ['Math-Base85-0.2.tar.gz','Net-IPv4Addr-0.10.tar.gz'],'size' => {'packed' => 28062,'unpacked' => 109763},'testers' => {'pass' => 4},'uses' => ['Carp','Math::Base85','Math::BigInt','Net::IPv4Addr','strict','vars']},'Net-IRC-0.70.tar.gz' => {'author' => 'FIMM','description' => 'Perl interface to the Internet Relay Chat protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3867,'pod' => 586,'pod_errors' => 8,'total' => 4453,'with_comments' => 1124},'releases' => 22,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'IO::File' => 0,'IO::Select' => 0,'IO::Socket' => 0,'Socket' => 0,'Sys::Hostname' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 56122,'unpacked' => 166989},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['5.004','Carp','IO::File','IO::Select','IO::Socket','Socket','Symbol','Sys::Hostname','strict','vars']},'Net-IRC-0.73.tar.gz' => {'author' => 'JEEK','description' => 'Internet Relay Chat interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3902,'pod' => 586,'pod_errors' => 8,'total' => 4488,'with_comments' => 1158},'releases' => 22,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'IO::File' => 0,'IO::Select' => 0,'IO::Socket' => 0,'Socket' => 0,'Sys::Hostname' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 56367,'unpacked' => 170565},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['5.004','Carp','IO::File','IO::Select','IO::Socket','Net::IRC::Connection','Net::IRC::DCC','Net::IRC::Event','Socket','Symbol','strict','vars']},'Net-IRCService-0.02.tar.gz' => {'author' => 'KAYSB','description' => 'Perl extension for creating a irc services for: o ircd-hybrid-6.3.1 o ircd-hybrid-7rc3 o bahamut-1.4.33','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1154,'pod' => 69,'pod_errors' => 0,'total' => 1223,'with_comments' => 260},'releases' => 1,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Fcntl' => 0,'IO::Select' => 0,'IO::Socket' => 0,'POSIX' => 0,'Socket' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17890,'unpacked' => 61005},'testers' => {'fail' => 1,'pass' => 8},'uses' => ['5.006','Exporter','Net::IRCService::Bahamut3','Net::IRCService::Hybrid6','Net::IRCService::Hybrid7','strict','warnings']},'Net-ITE.pm-0.05.tar.gz' => {'author' => 'ASCOPE','description' => 'OOP-ish interface to the Internet Topic Exchange','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 294,'pod' => 134,'pod_errors' => 0,'total' => 428,'with_comments' => 0},'releases' => 2,'requires' => ['Net-TrackBack-0.21.tar.gz','XML-RSS-1.02.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request' => '0','LWP::UserAgent' => '0','Net::TrackBack' => '0.21','XML::RSS' => '0.96'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-TrackBack-0.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','XML-RSS-1.02.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3621,'unpacked' => 9212},'testers' => {'pass' => 2},'uses' => ['HTTP::Request','LWP::UserAgent','Net::TrackBack','XML::RSS','constant','strict']},'Net-Ident-1.20.tar.gz' => {'author' => 'JPC','description' => 'Performs ident (rfc1413) lookups','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 766,'pod' => 263,'pod_errors' => 0,'total' => 1029,'with_comments' => 165},'releases' => 3,'size' => {'packed' => 24983,'unpacked' => 75777},'testers' => {'fail' => 3,'pass' => 6,'tests' => '9'},'uses' => ['Carp','Config','Exporter','Fcntl','FileHandle','Socket','strict','vars']},'Net-Ifconfig-Wrapper-0.03.tar.gz' => {'author' => 'TPABA','description' => 'provides a unified way to configure network interfaces on FreeBSD, OpenBSD, Solaris, Linux, WinNT (from Win2K). I<Version 0.03>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 772,'pod' => 366,'pod_errors' => 0,'total' => 1138,'with_comments' => 101},'releases' => 3,'size' => {'packed' => 12248,'unpacked' => 48586},'testers' => {'pass' => 2},'uses' => ['Exporter','POSIX','Win32::API','Win32::WinError','strict','vars']},'Net-Interface-0.04.tar.gz' => {'author' => 'SRZ','description' => 'ifconfig(1) implementation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 67,'pod' => 26,'pod_errors' => 0,'total' => 93,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 5231,'unpacked' => 12351},'testers' => {'fail' => 7},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Net-Jabber-1.28.tar.gz' => {'author' => 'REATMON','description' => 'Jabber Perl Library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10079,'pod' => 5512,'pod_errors' => 0,'total' => 15591,'with_comments' => 2029},'releases' => 17,'requires' => ['Digest-SHA1-2.04.tar.gz','XML-Stream-1.16.tar.gz'],'requires_module' => {'Digest::SHA1' => '1.02','XML::Stream' => '1.16'},'requires_recursive' => ['Digest-SHA1-2.04.tar.gz','XML-Stream-1.16.tar.gz'],'size' => {'packed' => 130462,'unpacked' => 675087},'testers' => {'pass' => 4},'uses' => ['5.003','5.005','5.006_001','Carp','Digest::SHA1','Exporter','FileHandle','POSIX','Time::Local','XML::Stream','strict','vars']},'Net-LDAP-Express-0.02.tar.gz' => {'author' => 'BRONTO','description' => 'Simplified interface for Net::LDAP','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 452,'pod' => 202,'pod_errors' => 0,'total' => 654,'with_comments' => 41},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','perl-ldap-0.29.tar.gz'],'requires_module' => {'Net::LDAP' => '0.23','Test::More' => 0},'requires_recursive' => ['Convert-ASN1-0.17.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-ldap-0.29.tar.gz'],'size' => {'packed' => 10232,'unpacked' => 30185},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Net::LDAP','constant','strict','warnings']},'Net-LDAPapi-1.42.tar.gz' => {'author' => 'CDONLEY','description' => 'Interface to UMICH and Netscape LDAP C API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1075,'pod' => 697,'pod_errors' => 1,'total' => 1772,'with_comments' => 16},'releases' => 2,'size' => {'packed' => 49676,'unpacked' => 180891},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Net-LMTP-0.02.tar.gz' => {'author' => 'LHOWARD','description' => 'LMTP Protocol - RFC2033','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 434,'pod' => 176,'pod_errors' => 0,'total' => 610,'with_comments' => 17},'releases' => 2,'size' => {'packed' => 5633,'unpacked' => 14711},'testers' => {'pass' => 6},'uses' => ['5.001','Carp','IO::Socket','Net::Cmd','Net::Domain','Socket','strict','vars']},'Net-LPR-1.004.tar.gz' => {'author' => 'DMLLOYD','description' => 'Connect to an RFC1179 line printer daemon','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1833,'pod' => 428,'pod_errors' => 2,'total' => 2261,'with_comments' => 8},'releases' => 5,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'IO::Socket' => 1,'IO::Socket::INET' => 1,'Socket' => 1,'Sys::Hostname' => 1},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10893,'unpacked' => 61633},'testers' => {'pass' => 3},'uses' => ['5.00500','Carp','IO::Socket','IO::Socket::INET','Socket','Sys::Hostname','strict','vars']},'Net-Lyskom-1.0.tar.gz' => {'author' => 'CDYBED','description' => 'Perl module used to talk to LysKOM servers.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2936,'pod' => 1150,'pod_errors' => 1,'total' => 4086,'with_comments' => 33},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 23308,'unpacked' => 94007},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Dumper','Exporter','IO::Socket','Time::Local','strict','vars','warnings']},'Net-MDNS-Client-0.02.tar.gz' => {'author' => 'JEPRICE','description' => 'Perl extension for the multicast DNS client.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 105,'pod_errors' => 0,'total' => 187,'with_comments' => 17},'releases' => 2,'size' => {'packed' => 32826,'unpacked' => 114411},'testers' => {'fail' => 1,'tests' => '2'},'uses' => ['5.008','AutoLoader','Carp','Exporter','XSLoader','strict','warnings']},'Net-MDNS-Server-0.02.tar.gz' => {'author' => 'JEPRICE','description' => 'Perl extension for a multicast DNS server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 93,'pod_errors' => 0,'total' => 183,'with_comments' => 17},'releases' => 2,'size' => {'packed' => 31187,'unpacked' => 107975},'testers' => {'fail' => 1,'tests' => '1'},'uses' => ['5.008','AutoLoader','Carp','Exporter','XSLoader','strict','warnings']},'Net-Meerkat-1.06.tar.gz' => {'author' => 'DARREN','description' => 'Perl interface to O\'ReillyNet\'s Meerkat','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 546,'pod' => 414,'pod_errors' => 0,'total' => 960,'with_comments' => 160},'releases' => 1,'size' => {'packed' => 14233,'unpacked' => 53185},'testers' => {'pass' => 2},'uses' => ['Data::Dumper','IO::File','LWP::Simple','URI','URI::Escape','constant','strict','vars']},'Net-MySQL-0.08.tar.gz' => {'author' => 'OYAMA','description' => 'Pure Perl MySQL network protocol interface.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 764,'pod' => 251,'pod_errors' => 0,'total' => 1015,'with_comments' => 1},'releases' => 7,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO::Socket' => 0},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 9434,'unpacked' => 29487},'testers' => {'pass' => 5},'uses' => ['5.004','Carp','IO::Socket','constant','strict','vars']},'Net-NBName-0.24.tar.gz' => {'author' => 'JMACFARLA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 488,'pod' => 423,'pod_errors' => 0,'total' => 911,'with_comments' => 14},'releases' => 5,'size' => {'packed' => 8505,'unpacked' => 30171},'testers' => {},'uses' => ['Socket','strict','vars','warnings']},'Net-NIS-0.34.tar.gz' => {'author' => 'ESM','description' => 'Interface to Sun\'s NIS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 449,'pod' => 238,'pod_errors' => 0,'total' => 687,'with_comments' => 94},'releases' => 4,'size' => {'packed' => 16124,'unpacked' => 44143},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars','warnings']},'Net-NIS-Listgroup-1.0.0.tar.gz' => {'author' => 'MPREWITT','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 180,'pod' => 81,'pod_errors' => 0,'total' => 261,'with_comments' => 35},'releases' => 1,'requires' => ['Getopt-Long-2.33.tar.gz','Net-NIS-0.34.tar.gz'],'requires_module' => {'Getopt::Long' => 0,'Net::NIS' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','Net-NIS-0.34.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 14538,'unpacked' => 45019},'testers' => {},'uses' => ['Exporter','Net::NIS','strict','vars']},'Net-NISplusTied-0.02.tgz' => {'author' => 'IKETRIS','description' => '- TIEHASH() interface to NIS+ tables','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 169,'pod' => 105,'pod_errors' => 0,'total' => 274,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 5503,'unpacked' => 14090},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Net-Nessus-0.08.tar.gz' => {'author' => 'JWIED','description' => 'A Nessus client module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 757,'pod' => 378,'pod_errors' => 0,'total' => 1135,'with_comments' => 65},'releases' => 5,'size' => {'packed' => 15959,'unpacked' => 55257},'testers' => {},'uses' => ['5.004','Carp','Net::Telnet','strict']},'Net-Netid-0.01.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1210,'pod' => 732,'pod_errors' => 1,'total' => 1942,'with_comments' => 161},'releases' => 1,'requires' => ['Data-Str2Num-0.02.tar.gz','File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Proc-Command-0.03.tar.gz'],'requires_module' => {'Data::Str2Num' => '0','File::Package' => '1.1','File::SmartNL' => '1.1','File::TestPath' => '1.1','Proc::Command' => '0','Test::Tech' => '1.1'},'requires_recursive' => ['Data-Str2Num-0.02.tar.gz','File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Proc-Command-0.03.tar.gz'],'size' => {'packed' => 14989,'unpacked' => 74571},'testers' => {'fail' => 1,'tests' => '18'},'uses' => ['5.001','Data::Str2Num','Exporter','File::Spec','IO::Socket','Proc::Command','SelfLoader','attributes','strict','vars','warnings','warnings::register']},'Net-Netmask-1.9002.tar.gz' => {'author' => 'MUIR','description' => 'Understand and manipulate network blocks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 489,'pod' => 244,'pod_errors' => 0,'total' => 733,'with_comments' => 2},'releases' => 12,'size' => {'packed' => 10792,'unpacked' => 44363},'testers' => {'pass' => 7},'uses' => ['5.004','Carp','Exporter','strict','vars']},'Net-Nsca-1.5.tar.gz' => {'author' => 'PKENT','description' => 'a perl way to send status checks to NetSaint, locally and remotely','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 341,'pod' => 48,'pod_errors' => 0,'total' => 389,'with_comments' => 70},'releases' => 1,'size' => {'packed' => 16350,'unpacked' => 47225},'testers' => {'pass' => 5},'uses' => ['IO::Socket','constant','vars']},'Net-Nslookup-1.14.tar.gz' => {'author' => 'DARREN','description' => 'Provide nslookup(1)-like capabilities','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 215,'pod' => 58,'pod_errors' => 0,'total' => 273,'with_comments' => 43},'releases' => 7,'size' => {'packed' => 5839,'unpacked' => 15264},'testers' => {'pass' => 1},'uses' => ['Carp','Data::Dumper','Exporter','Net::DNS','Socket','strict','vars']},'Net-OSCAR-0.62.tar.gz' => {'author' => 'MATTHEWG','description' => 'Implementation of AOL\'s OSCAR protocol for instant messaging','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3691,'pod' => 1010,'pod_errors' => 1,'total' => 4701,'with_comments' => 122},'releases' => 16,'requires' => ['Digest-MD5-2.26.tar.gz','Filter-1.29.tar.gz','Scalar-List-Utils-1.11.tar.gz'],'requires_module' => {'Digest::MD5' => 2,'Filter::Util::Call' => 1,'Scalar::Util' => 1},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','Filter-1.29.tar.gz','Scalar-List-Utils-1.11.tar.gz'],'size' => {'packed' => 58442,'unpacked' => 199717},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['Carp','Digest::MD5','Exporter','Fcntl','Filter::Util::Call','POSIX','Scalar::Util','Socket','Symbol','constant','overload','strict','vars']},'Net-PH-2.21.tar.gz' => {'author' => 'GBARR','description' => 'CCSO Nameserver Client class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 537,'pod' => 252,'pod_errors' => 0,'total' => 789,'with_comments' => 14},'releases' => 1,'requires' => ['libnet-1.16.tar.gz'],'requires_module' => {'Net::Cmd' => '0.01'},'requires_recursive' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6402,'unpacked' => 18342},'testers' => {'pass' => 2,'tests' => '0','unknown' => 18},'uses' => ['5.001','Carp','IO::Socket','Net::Cmd','Socket','integer','strict','vars']},'Net-POP3_auth-0.03.tar.gz' => {'author' => 'APLEINER','description' => 'Post Office Protocol 3 Client with AUTHentication','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 72,'pod_errors' => 0,'total' => 232,'with_comments' => 16},'releases' => 2,'requires' => ['Authen-SASL-2.04.tar.gz','Digest-HMAC-1.01.tar.gz','MIME-Base64-2.20.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'Authen::SASL' => '2.03','Digest::HMAC_MD5' => 1,'MIME::Base64' => 2,'Net::POP3' => 2},'requires_recursive' => ['Authen-SASL-2.04.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5200,'unpacked' => 11779},'testers' => {},'uses' => ['5.001','Authen::SASL','Carp','Digest::HMAC_MD5','IO::Socket','MIME::Base64','Net::Cmd','Net::Config','Net::POP3','Socket','strict','vars']},'Net-Pager-2.00.tar.gz' => {'author' => 'ROOTLEVEL','description' => 'Send Numeric/AlphaNumeric Pages to any pager/phone around the world through the SimpleWire network.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1526,'pod' => 80,'pod_errors' => 0,'total' => 1606,'with_comments' => 296},'releases' => 2,'requires' => ['XML-DOM-1.42.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Headers' => 0,'HTTP::Request::Common' => 0,'LWP::UserAgent' => 0,'XML::DOM' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13643,'unpacked' => 67008},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.002','HTTP::Headers','HTTP::Request::Common','LWP::UserAgent','Net::Pager::Common','XML::DOM']},'Net-ParseWhois-0.62.tar.gz' => {'author' => 'ABEROHAM','description' => 'An extendable alternative to Net::Whois for parsing whois information.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1287,'pod' => 153,'pod_errors' => 0,'total' => 1440,'with_comments' => 76},'releases' => 2,'size' => {'packed' => 11554,'unpacked' => 43070},'testers' => {'pass' => 11},'uses' => ['5.004','Carp','Exporter','IO::File','IO::Socket','strict','vars']},'Net-Patricia-1.010.tar.gz' => {'author' => 'PLONKA','description' => 'Patricia Trie perl module for fast IP addres','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 140,'pod_errors' => 0,'total' => 287,'with_comments' => 21},'releases' => 3,'size' => {'packed' => 23499,'unpacked' => 76890},'testers' => {'pass' => 13},'uses' => ['Carp','DynaLoader','strict','vars']},'Net-Pcap-0.04.tar.gz' => {'author' => 'TIMPOTTER','description' => 'An interface for LBL\'s packet capture lib','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 207,'pod_errors' => 0,'total' => 313,'with_comments' => 15},'releases' => 4,'size' => {'packed' => 9980,'unpacked' => 41113},'testers' => {'fail' => 4,'pass' => 2,'tests' => '24'},'uses' => ['DynaLoader','Exporter','vars']},'Net-PcapUtils-0.01.tar.gz' => {'author' => 'TIMPOTTER','description' => 'Utility routines for Net::Pcap module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 221,'pod' => 104,'pod_errors' => 0,'total' => 325,'with_comments' => 69},'releases' => 1,'requires' => ['Net-Pcap-0.04.tar.gz'],'requires_module' => {'Net::Pcap' => '0.03'},'requires_recursive' => ['Net-Pcap-0.04.tar.gz'],'size' => {'packed' => 4370,'unpacked' => 11687},'testers' => {},'uses' => ['Net::Pcap','vars']},'Net-Peep-0.4.1.1.tar.gz' => {'author' => 'STARKY','description' => 'Perl extension for Peep: The Network Auralizer.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2945,'pod' => 1249,'pod_errors' => 0,'total' => 4194,'with_comments' => 253},'releases' => 10,'size' => {'packed' => 41644,'unpacked' => 155817},'testers' => {'fail' => 1,'tests' => '6'},'uses' => ['5.005_62','Carp','Data::Dumper','Exporter','File::Tail','Getopt::Long','Net::Peep::BC','Net::Peep::Client','Net::Peep::Conf','Net::Peep::Log','Pod::Text','Socket','Sys::Hostname','Time::HiRes','constant','strict','vars','warnings']},'Net-Peep-0.4.4.tar.gz' => {'author' => 'STARKY','description' => 'Perl extension for Peep: The Network Auralizer.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6498,'pod' => 2505,'pod_errors' => 0,'total' => 9003,'with_comments' => 694},'releases' => 10,'requires' => ['File-Tail-0.98.tar.gz','Filesys-DiskFree-0.06.tar.gz','Net-Ping-External-0.11.tar.gz','Proc-ProcessTable-0.38.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'File::Tail' => '0.98','Filesys::DiskFree' => '0.06','Net::Ping::External' => '0.06','Proc::ProcessTable' => '0.32','Time::HiRes' => '1.2'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Tail-0.98.tar.gz','Filesys-DiskFree-0.06.tar.gz','IO-1.20.tar.gz','Net-Ping-External-0.11.tar.gz','Proc-ProcessTable-0.38.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 83967,'unpacked' => 318832},'testers' => {'fail' => 1},'uses' => ['5.005','5.00503','Carp','Data::Dumper','Exporter','File::Tail','Filesys::DiskFree','Getopt::Long','Net::Peep::BC','Net::Peep::Client','Net::Peep::Client::Logparser::Event','Net::Peep::Client::Pinger::Host','Net::Peep::Client::Sysmonitor::Disk','Net::Peep::Client::Sysmonitor::Proc','Net::Peep::Client::Sysmonitor::Uptime','Net::Peep::Conf','Net::Peep::Host','Net::Peep::Host::Pool','Net::Peep::Log','Net::Peep::Mail','Net::Peep::Notifier','Net::Peep::Parser','Net::Peep::Scheduler','Net::Ping::External','Net::SMTP','Pod::Text','Proc::ProcessTable','Socket','Sys::Hostname','Time::HiRes','constant','strict','vars','warnings']},'Net-Peep-0.4.5.1.tar.gz' => {'author' => 'STARKY','description' => 'Perl extension for Peep: The Network Auralizer.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6499,'pod' => 2537,'pod_errors' => 0,'total' => 9036,'with_comments' => 690},'releases' => 10,'requires' => ['File-Tail-0.98.tar.gz','Filesys-DiskFree-0.06.tar.gz','Net-Ping-External-0.11.tar.gz','Proc-ProcessTable-0.38.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'File::Tail' => '0.98','Filesys::DiskFree' => '0.06','Net::Ping::External' => '0.06','Proc::ProcessTable' => '0.32','Time::HiRes' => '1.2'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Tail-0.98.tar.gz','Filesys-DiskFree-0.06.tar.gz','IO-1.20.tar.gz','Net-Ping-External-0.11.tar.gz','Proc-ProcessTable-0.38.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 84002,'unpacked' => 320542},'testers' => {'pass' => 3},'uses' => ['5.005','5.00503','Carp','Data::Dumper','Exporter','File::Tail','Filesys::DiskFree','Getopt::Long','Net::Peep::Notification','Net::Ping::External','Net::SMTP','Pod::Text','Proc::ProcessTable','Socket','Sys::Hostname','Time::HiRes','constant','strict','vars','warnings']},'Net-Ping-2.31.tar.gz' => {'author' => 'BBB','description' => 'TCP, UDP, or ICMP ping','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1515,'pod' => 229,'pod_errors' => 0,'total' => 1744,'with_comments' => 357},'releases' => 32,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Socket' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 33580,'unpacked' => 111902},'testers' => {'pass' => 3},'uses' => ['5.002','Carp','Exporter','Fcntl','FileHandle','Net::Ping::External','POSIX','Socket','asm::socket.ph','constant','strict','vars']},'Net-Ping-External-0.11.tar.gz' => {'author' => 'COLINM','description' => 'Cross-platform interface to "ping" utilities','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 259,'pod' => 153,'pod_errors' => 0,'total' => 412,'with_comments' => 42},'releases' => 11,'size' => {'packed' => 6377,'unpacked' => 16473},'testers' => {'fail' => 1,'pass' => 12},'uses' => ['Carp','Exporter','Socket','vars']},'Net-Printer-0.32.tar.gz' => {'author' => 'CFUHRMAN','description' => 'Direct to lpd printing','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 902,'pod' => 92,'pod_errors' => 0,'total' => 994,'with_comments' => 281},'releases' => 5,'size' => {'packed' => 25215,'unpacked' => 73963},'testers' => {'pass' => 3},'uses' => ['5.006','AutoLoader','Carp','Exporter','FileHandle','IO::Socket','POSIX','Sys::Hostname','strict','warnings']},'Net-ProxyMod-0.01.tgz' => {'author' => 'ATRAK','description' => 'Small TCP proxy module for packet alteration.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 310,'pod' => 69,'pod_errors' => 0,'total' => 379,'with_comments' => 72},'releases' => 1,'size' => {'packed' => 4932,'unpacked' => 12128},'testers' => {'pass' => 2},'uses' => ['Exporter','POSIX','strict','vars']},'Net-QMQP-0.01.tar.gz' => {'author' => 'KOBAYASI','description' => 'Interface to Quick Mail Queueing Protocol','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 69,'pod_errors' => 0,'total' => 147,'with_comments' => 1},'releases' => 1,'requires' => ['Class-Accessor-0.18.tar.gz','IO-1.20.tar.gz'],'requires_module' => {'Class::Accessor' => 0,'IO::Socket' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2261,'unpacked' => 3995},'testers' => {'pass' => 3},'uses' => ['','Carp','Class::Accessor','IO::Socket','strict','vars']},'Net-QMTP-0.05.tar.gz' => {'author' => 'JRAFTERY','description' => 'Interface to Quick Mail Transfer Protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 483,'pod' => 192,'pod_errors' => 0,'total' => 675,'with_comments' => 50},'releases' => 4,'size' => {'packed' => 8149,'unpacked' => 23446},'testers' => {'fail' => 1,'pass' => 1,'tests' => '7'},'uses' => ['5.001','Carp','IO::Socket','Text::Netstring','strict']},'Net-RBLClient-0.1.tar.gz' => {'author' => 'ABLUM','description' => 'Queries multiple Realtime Blackhole Lists in parallel','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 231,'pod' => 88,'pod_errors' => 0,'total' => 319,'with_comments' => 11},'releases' => 1,'requires' => ['IO-1.20.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'IO::Socket' => 0,'Time::HiRes' => 0},'requires_recursive' => ['IO-1.20.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 3853,'unpacked' => 9109},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['IO::Socket','Net::DNS::Packet','Time::HiRes','strict','vars']},'Net-RMI-0.02.tar.gz' => {'author' => 'PANDICH','description' => 'Perl Remote Method Invocation (RMI) base class and utilities.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 608,'pod' => 280,'pod_errors' => 3,'total' => 888,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 6656,'unpacked' => 20886},'testers' => {},'uses' => ['5.004','Carp','Exporter','IO::Socket','POSIX','strict','vars']},'Net-RRP-0.03.tar.gz' => {'author' => 'MKUL','description' => 'there are file for RRP protocol and operations.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2338,'pod' => 2524,'pod_errors' => 0,'total' => 4862,'with_comments' => 44},'releases' => 4,'requires' => ['IO-Socket-SSL-0.94.tar.gz','Net-Daemon-SSL-1.0.tar.gz'],'requires_module' => {'IO::Socket::SSL' => '0.73','Net::Daemon::SSL' => '1.00'},'requires_recursive' => ['IO-Socket-SSL-0.94.tar.gz','Net-Daemon-0.37.tar.gz','Net-Daemon-SSL-1.0.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 16465,'unpacked' => 116285},'testers' => {'pass' => 4},'uses' => ['Errno','Error','Exporter','Fcntl','IO::Socket::SSL','Net::Daemon','Net::Daemon::SSL','Net::RRP::Entity','Net::RRP::Exception','Net::RRP::Exception::IOError','Net::RRP::Exception::InvalidAttributeName','Net::RRP::Exception::InvalidCommandName','Net::RRP::Exception::InvalidCommandOption','Net::RRP::Exception::InvalidCommandSequence','Net::RRP::Exception::InvalidEntityValue','Net::RRP::Exception::InvalidOptionValue','Net::RRP::Exception::MissingCommandOption','Net::RRP::Exception::MissingRequiredAttribute','Net::RRP::Exception::MissingRequiredEntity','Net::RRP::Exception::ServerError','Net::RRP::Protocol','Net::RRP::Request','Net::RRP::Response','Net::RRP::Response::n200','Net::RRP::Response::n420','Net::RRP::Toolkit','constant','strict']},'Net-RRP-0.05.tar.gz' => {'author' => 'MKUL','description' => 'there are file for RRP protocol and operations.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2787,'pod' => 2746,'pod_errors' => 0,'total' => 5533,'with_comments' => 45},'releases' => 4,'requires' => ['IO-Socket-SSL-0.94.tar.gz','Net-Daemon-SSL-1.0.tar.gz','Proc-Application-0.01.tar.gz'],'requires_module' => {'IO::Socket::SSL' => '0.73','Net::Daemon::SSL' => '1.00','Proc::Application' => '0.01'},'requires_recursive' => ['IO-Socket-SSL-0.94.tar.gz','Net-Daemon-0.37.tar.gz','Net-Daemon-SSL-1.0.tar.gz','Net_SSLeay.pm-1.23.tar.gz','Proc-Application-0.01.tar.gz'],'size' => {'packed' => 18441,'unpacked' => 133367},'testers' => {'pass' => 1},'uses' => ['Data::Dumper','Errno','Error','Exporter','Fcntl','IO::Socket::INET','IO::Socket::SSL','Net::RRP::Codec','Net::RRP::Exception::EntityNotAvailable','Proc::Application::Daemon','constant','strict']},'Net-Radius-1.44.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Object-oriented Perl interface to RADIUS packets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 548,'pod' => 286,'pod_errors' => 0,'total' => 834,'with_comments' => 50},'releases' => 6,'size' => {'packed' => 63914,'unpacked' => 317735},'testers' => {'pass' => 3},'uses' => ['Carp','Digest::MD5','Exporter','Socket','strict','vars','warnings']},'Net-RawIP-0.1.tar.gz' => {'author' => 'SKOLYCHEV','description' => 'Perl extension for manipulate raw ip packets with interface to B<libpcap>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 764,'pod' => 325,'pod_errors' => 0,'total' => 1089,'with_comments' => 42},'releases' => 7,'size' => {'packed' => 32431,'unpacked' => 112270},'testers' => {'pass' => 5},'uses' => ['AutoLoader','Carp','Class::Struct','DynaLoader','Exporter','subs','vars']},'Net-Rexec-0.12.tar.gz' => {'author' => 'FKOLODNY','description' => 'Perl extension for the client side of the REXEC protocol.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 61,'pod' => 23,'pod_errors' => 0,'total' => 84,'with_comments' => 1},'releases' => 3,'requires' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'IO::Socket' => 0,'Net::Netrc' => 0},'requires_recursive' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2085,'unpacked' => 3598},'testers' => {'pass' => 2},'uses' => ['Exporter','IO::Socket','Net::Netrc','strict','vars']},'Net-Rsh-0.02.tar.gz' => {'author' => 'RIIKI','description' => 'perl client for Rsh protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 61,'pod' => 30,'pod_errors' => 0,'total' => 91,'with_comments' => 0},'releases' => 2,'requires' => ['Errno-1.09.tar.gz','IO-1.20.tar.gz'],'requires_module' => {'Errno' => 0,'IO::Socket' => 0},'requires_recursive' => ['Errno-1.09.tar.gz','IO-1.20.tar.gz'],'size' => {'packed' => 1940,'unpacked' => 4633},'testers' => {'pass' => 2},'uses' => ['Carp','Errno','Exporter','IO::Socket','strict','vars']},'Net-SCP-0.06.tar.gz' => {'author' => 'IVAN','description' => 'Perl extension for secure copy protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 217,'pod' => 138,'pod_errors' => 0,'total' => 355,'with_comments' => 3},'releases' => 6,'requires' => ['IO-1.20.tar.gz','Net-SSH-0.07.tar.gz','String-ShellQuote-1.00.tar.gz'],'requires_module' => {'IO::Handle' => 0,'Net::SSH' => 0,'String::ShellQuote' => 0},'requires_recursive' => ['IO-1.20.tar.gz','Net-SSH-0.07.tar.gz','String-ShellQuote-1.00.tar.gz'],'size' => {'packed' => 4811,'unpacked' => 11346},'testers' => {'pass' => 6},'uses' => ['Carp','Exporter','File::Basename','IO::Handle','IPC::Open3','Net::SSH','String::ShellQuote','strict','vars']},'Net-SCP-Expect-0.09.tar.gz' => {'author' => 'DJBERG','description' => 'Wrapper for scp that allows passwords via Expect.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 315,'pod' => 161,'pod_errors' => 0,'total' => 476,'with_comments' => 31},'releases' => 9,'requires' => ['Expect-1.15.tar.gz','Term-ReadPassword-0.01.tar.gz'],'requires_module' => {'Expect' => '1.14','Term::ReadPassword' => '0.01'},'requires_recursive' => ['Expect-1.15.tar.gz','IO-Tty-1.02.tar.gz','Term-ReadPassword-0.01.tar.gz'],'size' => {'packed' => 159500,'unpacked' => 43253713},'testers' => {},'uses' => ['Carp','Cwd','Expect','File::Basename','POSIX','strict','vars']},'Net-SFTP-0.05.tar.gz' => {'author' => 'BTROTT','description' => 'Secure File Transfer Protocol client','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 978,'pod' => 384,'pod_errors' => 0,'total' => 1362,'with_comments' => 23},'releases' => 5,'requires' => ['Net-SSH-Perl-1.23.tar.gz'],'requires_module' => {'Net::SSH::Perl' => '1.13'},'requires_recursive' => ['Net-SSH-Perl-1.23.tar.gz'],'size' => {'packed' => 14786,'unpacked' => 50642},'testers' => {'pass' => 1},'uses' => ['','Carp','Exporter','Net::SSH::Perl','Net::SSH::Perl::Buffer','Net::SSH::Perl::Constants','Net::SSH::Perl::Util','constant','strict','vars']},'Net-SMPP-1.03.tar.gz' => {'author' => 'SAMPO','description' => 'Protocol for sending SMS (to GSM or CDMA).','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2734,'pod' => 695,'pod_errors' => 0,'total' => 3429,'with_comments' => 674},'releases' => 8,'size' => {'packed' => 44103,'unpacked' => 251278},'testers' => {'pass' => 3},'uses' => ['5.005','Carp','Data::Dumper','IO::Socket','Socket','Symbol','constant','strict','vars']},'Net-SMS-1.00.tar.gz' => {'author' => 'ROOTLEVEL','description' => 'Send SMS messages to ANY device.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 763,'pod' => 456,'pod_errors' => 0,'total' => 1219,'with_comments' => 249},'releases' => 6,'requires' => ['Net-Pager-2.00.tar.gz','XML-DOM-1.42.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Headers' => 0,'HTTP::Request::Common' => 0,'LWP::UserAgent' => 0,'Net::Pager' => 0,'XML::DOM' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-Pager-2.00.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11639,'unpacked' => 48150},'testers' => {'fail' => 1},'uses' => ['5.002','HTTP::Headers','HTTP::Request::Common','LWP::UserAgent','Net::Pager','Net::Pager::Request','Net::Pager::Response','Net::SMS::Common','Net::SMS::Dev','XML::DOM']},'Net-SMS-2.13.tar.gz' => {'author' => 'ROOTLEVEL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1549,'pod' => 322,'pod_errors' => 0,'total' => 1871,'with_comments' => 183},'releases' => 6,'requires' => ['XML-DOM-1.42.tar.gz'],'requires_module' => {'XML::DOM' => '0'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 16809,'unpacked' => 65879},'testers' => {},'uses' => ['5.002','Errno','Fcntl','Socket','XML::DOM','strict','vars']},'Net-SMS-2.51.tar.gz' => {'author' => 'ROOTLEVEL','description' => 'Send SMS wireless text-messages.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2633,'pod' => 317,'pod_errors' => 0,'total' => 2950,'with_comments' => 485},'releases' => 6,'requires' => ['Unicode-String-2.07.tar.gz','XML-DOM-1.42.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request' => 0,'HTTP::Response' => 0,'LWP::UserAgent' => 0,'Unicode::String' => '2.06','XML::DOM' => '1.25'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','Unicode-String-2.07.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 274310,'unpacked' => 476867},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['5.002','HTTP::Request','HTTP::Response','LWP::UserAgent','Unicode::String','XML::DOM']},'Net-SMS-Mtnsms-0.003.tar.gz' => {'author' => 'AWRIGLEY','description' => 'a module to send SMS messages using the Mtnsms web2sms gateway (L<http://www.mtnsms.com/>).','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 211,'pod' => 85,'pod_errors' => 0,'total' => 296,'with_comments' => 33},'releases' => 3,'requires' => ['Net-SMS-Web-0.015.tar.gz'],'requires_module' => {'Net::SMS::Web' => 0},'requires_recursive' => ['CGI-Enurl-1.07.tar.gz','CGI-Lite-2.001-emergencyrelease.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-SMS-Web-0.015.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3157,'unpacked' => 8354},'testers' => {'pass' => 3},'uses' => ['Net::SMS::Web','strict','vars']},'Net-SMS-O2-0.019.tar.gz' => {'author' => 'AWRIGLEY','description' => 'Send SMS messages using the Genie gateway','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 278,'pod' => 97,'pod_errors' => 0,'total' => 375,'with_comments' => 28},'releases' => 4,'requires' => ['Crypt-SSLeay-0.51.tar.gz','Net-SMS-Web-0.015.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'Crypt::SSLeay' => 0,'Net::SMS::Web' => 0,'URI::Escape' => 0},'requires_recursive' => ['CGI-Enurl-1.07.tar.gz','CGI-Lite-2.001-emergencyrelease.tar.gz','Crypt-SSLeay-0.51.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-SMS-Web-0.015.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4683,'unpacked' => 12220},'testers' => {'pass' => 3},'uses' => ['Carp','Net::SMS::Web','URI::Escape','strict','vars']},'Net-SMS-Web-0.015.tar.gz' => {'author' => 'AWRIGLEY','description' => 'generic module for sending SMS via web','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 234,'pod' => 51,'pod_errors' => 0,'total' => 285,'with_comments' => 45},'releases' => 9,'requires' => ['CGI-Enurl-1.07.tar.gz','CGI-Lite-2.001-emergencyrelease.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI::Enurl' => 0,'CGI::Lite' => 0,'Class::Struct' => 0,'LWP::UserAgent' => 0,'URI' => 0},'requires_recursive' => ['CGI-Enurl-1.07.tar.gz','CGI-Lite-2.001-emergencyrelease.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3125,'unpacked' => 8433},'testers' => {'pass' => 8},'uses' => ['CGI::Enurl','CGI::Lite','Class::Struct','LWP::UserAgent','URI','strict','vars','warnings']},'Net-SMTP-Multipart-1.5.tar.gz' => {'author' => 'DROBERTS','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 191,'pod' => 99,'pod_errors' => 0,'total' => 290,'with_comments' => 35},'releases' => 5,'requires' => ['MIME-Base64-2.20.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'MIME::Base64' => 0,'Net::SMTP' => 0},'requires_recursive' => ['IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3719,'unpacked' => 9094},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','MIME::Base64','Net::SMTP','strict','vars']},'Net-SMTP-Receive-0.3.tar.gz' => {'author' => 'MUIR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 773,'pod' => 210,'pod_errors' => 0,'total' => 983,'with_comments' => 55},'releases' => 3,'requires' => ['File-Flock-101.060501.tar.gz','File-Slurp-2002.1031.tar.gz','File-Sync-0.09.tar.gz','Net-Ident-1.20.tar.gz','Storable-2.07.tar.gz','Time-modules-2003.0211.tar.gz'],'requires_module' => {'File::Flock' => '101.051801','File::Slurp' => '96.042202','File::Sync' => '0.09','Net::Ident' => '1.2','Storable' => '0.611','Time::CTime' => '99.062201'},'requires_recursive' => ['File-Flock-101.060501.tar.gz','File-Slurp-2002.1031.tar.gz','File-Spec-0.82.tar.gz','File-Sync-0.09.tar.gz','Net-Ident-1.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz'],'size' => {'packed' => 9372,'unpacked' => 30537},'testers' => {},'uses' => ['File::Flock','File::Slurp','File::Sync','IO::Socket','Net::Ident','POSIX','Socket','Storable','Sys::Hostname','Sys::Syslog','Time::CTime','strict','vars']},'Net-SMTP-Server-Client2-0.2.tar.gz' => {'author' => 'DAVIDNICO','description' => 'A better client for Net::SMTP::Server.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 245,'pod' => 92,'pod_errors' => 0,'total' => 337,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 4037,'unpacked' => 8632},'testers' => {'pass' => 4},'uses' => ['5.001','Carp','IO::Socket','strict','vars']},'Net-SMTP_auth-0.06.tar.gz' => {'author' => 'APLEINER','description' => 'Simple Mail Transfer Protocol Client with AUTHentication','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 76,'pod_errors' => 0,'total' => 201,'with_comments' => 12},'releases' => 2,'requires' => ['Authen-SASL-2.04.tar.gz','Digest-HMAC-1.01.tar.gz','MIME-Base64-2.20.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'Authen::SASL' => '2.03','Digest::HMAC_MD5' => 1,'MIME::Base64' => 2,'Net::SMTP' => 2},'requires_recursive' => ['Authen-SASL-2.04.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4979,'unpacked' => 11507},'testers' => {},'uses' => ['5.001','Authen::SASL','Carp','Digest::HMAC_MD5','IO::Socket','MIME::Base64','Net::Cmd','Net::Config','Net::SMTP','Socket','strict','vars']},'Net-SNMP-4.1.0.tar.gz' => {'author' => 'DTOWN','description' => 'Object oriented interface to SNMP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8688,'pod' => 855,'pod_errors' => 0,'total' => 9543,'with_comments' => 1085},'releases' => 15,'requires' => ['Crypt-DES-2.03.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz'],'requires_module' => {'Crypt::DES' => '2.03','Digest::HMAC' => '1.00','Digest::MD5' => '2.11','Digest::SHA1' => '1.02'},'requires_recursive' => ['Crypt-DES-2.03.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz'],'size' => {'packed' => 69909,'unpacked' => 324216},'testers' => {'pass' => 5},'uses' => ['IO::Socket::INET','Sys::Hostname','strict']},'Net-SNMP-HostInfo-0.01.tar.gz' => {'author' => 'JMACFARLA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 981,'pod' => 729,'pod_errors' => 0,'total' => 1710,'with_comments' => 54},'releases' => 1,'requires' => ['Net-SNMP-4.1.0.tar.gz'],'requires_module' => {'Net::SNMP' => 0},'requires_recursive' => ['Crypt-DES-2.03.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','Net-SNMP-4.1.0.tar.gz'],'size' => {'packed' => 10568,'unpacked' => 43968},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','Data::Dumper','Net::SNMP','strict','warnings']},'Net-SNMP-Interfaces-0.4.tar.gz' => {'author' => 'JSTOWE','description' => 'provide simple methods to gain interface data via SNMP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 962,'pod' => 358,'pod_errors' => 1,'total' => 1320,'with_comments' => 58},'releases' => 3,'requires' => ['Net-SNMP-4.1.0.tar.gz'],'requires_module' => {'Net::SNMP' => '3.5'},'requires_recursive' => ['Crypt-DES-2.03.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','Net-SNMP-4.1.0.tar.gz'],'size' => {'packed' => 12366,'unpacked' => 47261},'testers' => {'pass' => 3},'uses' => ['Carp','Net::SNMP','strict','vars']},'Net-SNPP-1.11.tar.gz' => {'author' => 'GBARR','description' => 'Simple Network Pager Protocol Client','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 436,'pod' => 97,'pod_errors' => 0,'total' => 533,'with_comments' => 23},'releases' => 4,'requires' => ['libnet-1.16.tar.gz'],'requires_module' => {'Net::Cmd' => '0.01'},'requires_recursive' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4673,'unpacked' => 11524},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.001','Carp','IO::Socket','Net::Cmd','Net::Config','Net::SNPP','Socket','strict','vars']},'Net-SNPP-1.14.tar.gz' => {'author' => 'DREDD','description' => 'Client interface to SNPP protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 496,'pod' => 121,'pod_errors' => 0,'total' => 617,'with_comments' => 26},'releases' => 4,'requires' => ['libnet-1.16.tar.gz'],'requires_module' => {'Net::Cmd' => '0.01'},'requires_recursive' => ['IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5549,'unpacked' => 14081},'testers' => {'pass' => 2},'uses' => ['5.001','Carp','IO::Socket','Net::Cmd','Net::Config','Socket','strict','vars']},'Net-SSH-0.07.tar.gz' => {'author' => 'IVAN','description' => 'Perl extension for secure shell','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 134,'pod' => 121,'pod_errors' => 0,'total' => 255,'with_comments' => 0},'releases' => 7,'size' => {'packed' => 3913,'unpacked' => 8594},'testers' => {'pass' => 10},'uses' => ['Exporter','IO::File','IPC::Open2','IPC::Open3','strict','vars']},'Net-SSH-Perl-1.23.tar.gz' => {'author' => 'BTROTT','description' => 'Perl client Interface to SSH','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7006,'pod' => 1839,'pod_errors' => 0,'total' => 8845,'with_comments' => 99},'releases' => 32,'size' => {'packed' => 82862,'unpacked' => 312758},'testers' => {'fail' => 2,'pass' => 3,'tests' => '115'},'uses' => ['','Carp','Compress::Zlib','Convert::PEM','Crypt::DES','Crypt::DH','Crypt::DSA','Crypt::DSA::Key','Crypt::IDEA','Crypt::RSA','Crypt::RSA::DataFormat','Crypt::RSA::Key','Crypt::RSA::Key::Private','Crypt::RSA::Key::Public','Crypt::RSA::Primitives','Crypt::RSA::SS::PKCS1v15','Digest::HMAC_MD5','Digest::HMAC_SHA1','Digest::MD5','Digest::SHA1','Fcntl','File::Basename','File::Path','IO::Select','IO::Socket','MIME::Base64','Math::GMP','Math::Pari','POSIX','Socket','String::CRC32','Symbol','Sys::Hostname','Term::ReadKey','Tie::Handle','constant','strict','vars']},'Net-SSH-W32Perl-0.05.tar.gz' => {'author' => 'SCOTTS','description' => 'MSWin32 compatibility layer for Net::SSH::Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 122,'pod' => 50,'pod_errors' => 0,'total' => 172,'with_comments' => 0},'releases' => 3,'requires' => ['Convert-ASCII-Armour-1.4.tar.gz','Data-Buffer-0.04.tar.gz','Digest-BubbleBabble-0.01.tar.gz','IO-Select-Trap-0.03.tar.gz','IO-String-1.02.tar.gz','Net-SSH-Perl-1.23.tar.gz'],'requires_module' => {'Convert::ASCII::Armour' => '1.4','Data::Buffer' => '0.04','Digest::BubbleBabble' => '0.01','IO::Select::Trap' => '0.02','IO::String' => '1.01','Net::SSH::Perl' => '1.23'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Convert-ASCII-Armour-1.4.tar.gz','Data-Buffer-0.04.tar.gz','Digest-BubbleBabble-0.01.tar.gz','Digest-MD5-2.26.tar.gz','IO-Select-Trap-0.03.tar.gz','IO-String-1.02.tar.gz','MIME-Base64-2.20.tar.gz','Net-SSH-Perl-1.23.tar.gz'],'size' => {'packed' => 3280,'unpacked' => 7175},'testers' => {},'uses' => ['Carp','IO::Select::Trap','IO::Socket','IO::String','Net::SSH::Perl','Net::SSH::Perl::Constants','Net::SSH::Perl::SSH2','constant','strict','vars']},'Net-SenderBase-1.00.tar.gz' => {'author' => 'MSERGEANT','description' => 'Query the senderbase service','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 297,'pod' => 253,'pod_errors' => 0,'total' => 550,'with_comments' => 8},'releases' => 2,'requires' => ['Net-DNS-0.38.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Net::DNS' => '0.23','Test::More' => 0},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5817,'unpacked' => 15361},'testers' => {'pass' => 1},'uses' => ['IO::Select','IO::Socket','Net::DNS','Socket','strict','vars']},'Net-SenderBase-1.01.tar.gz' => {'author' => 'MSERGEANT','description' => 'Query the senderbase service','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 302,'pod' => 253,'pod_errors' => 0,'total' => 555,'with_comments' => 9},'releases' => 2,'requires' => ['Net-DNS-0.38.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Net::DNS' => '0.23','Test::More' => 0},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5890,'unpacked' => 15539},'testers' => {'pass' => 1},'uses' => ['IO::Select','IO::Socket','Net::DNS','Net::SenderBase::Query','Socket','strict','vars']},'Net-Server-0.80.tar.gz' => {'author' => 'BBB','description' => 'Extensible, general Perl server engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4620,'pod' => 1852,'pod_errors' => 0,'total' => 6472,'with_comments' => 884},'releases' => 15,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'IO::Socket' => 0,'POSIX' => 0,'Socket' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 63714,'unpacked' => 250209},'testers' => {'fail' => 2,'pass' => 2,'tests' => '42'},'uses' => ['Carp','Data::Dumper','IO::Multiplex','IPC::Semaphore','IPC::SysV','Net::Server','Net::Server::Daemonize','Net::Server::PreForkSimple','Net::Server::SIG','POSIX','Socket','Sys::Syslog','Unix::Syslog','strict','vars']},'Net-Server-0.85.tar.gz' => {'author' => 'RHANDOM','description' => 'Extensible, general Perl server engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4792,'pod' => 1873,'pod_errors' => 0,'total' => 6665,'with_comments' => 898},'releases' => 15,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'IO::Socket' => 0,'POSIX' => 0,'Socket' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 71056,'unpacked' => 269756},'testers' => {'fail' => 1,'pass' => 7,'tests' => '42'},'uses' => ['Carp','Data::Dumper','IO::Multiplex','IO::Socket::UNIX','IPC::Semaphore','IPC::SysV','POSIX','Socket','Sys::Syslog','Unix::Syslog','strict','vars']},'Net-Server-Mail-0.08.tar.gz' => {'author' => 'RSOLIV','description' => 'Class to easily create a mail server','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1587,'pod' => 694,'pod_errors' => 0,'total' => 2281,'with_comments' => 64},'releases' => 7,'size' => {'packed' => 13676,'unpacked' => 59494},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','IO::Handle','IO::Select','Sys::Hostname','strict']},'Net-Server-NonBlocking-0.047.tar.gz' => {'author' => 'ROMERUN','description' => 'An object interface to non-blocking I/O server engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 573,'pod' => 483,'pod_errors' => 0,'total' => 1056,'with_comments' => 53},'releases' => 10,'size' => {'packed' => 9356,'unpacked' => 31035},'testers' => {'pass' => 3},'uses' => ['5.000503','Data::Dumper','Fcntl','IO::Select','IO::Socket','POSIX','Socket','Tie::RefHash','strict','vars','warnings']},'Net-Shared-0.30.tar.gz' => {'author' => 'JRYAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 591,'pod' => 167,'pod_errors' => 0,'total' => 758,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 7797,'unpacked' => 27935},'testers' => {'pass' => 5},'uses' => ['Carp','IO::Socket','Storable','strict','vars','warnings']},'Net-Socket-NonBlock-0.15.tar.gz' => {'author' => 'TPABA','description' => 'Perl extension for easy creation multi-socket single-thread application, especially non-forking TCP servers I<Version 0.15>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1099,'pod' => 527,'pod_errors' => 0,'total' => 1626,'with_comments' => 15},'releases' => 10,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'IO::Select' => '0.01','IO::Socket' => '0.01','POSIX' => '0.01'},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15728,'unpacked' => 62575},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','IO::Select','IO::Socket','POSIX','strict','vars']},'Net-Spooler-0.02.tar.gz' => {'author' => 'JWIED','description' => 'A Perl extension for writing spooling daemons','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 547,'pod' => 195,'pod_errors' => 2,'total' => 742,'with_comments' => 75},'releases' => 1,'requires' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Net-Daemon-0.37.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'File::Spec' => 0,'Net::Daemon' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Net-Daemon-0.37.tar.gz'],'size' => {'packed' => 13698,'unpacked' => 43567},'testers' => {'fail' => 3,'pass' => 3,'tests' => '32'},'uses' => ['5.004','strict']},'Net-Starnet-DataAccounting-1.2.tar.gz' => {'author' => 'SPOON','description' => 'interface to the SDA protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 296,'pod' => 221,'pod_errors' => 0,'total' => 517,'with_comments' => 13},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz','IO-1.20.tar.gz','Module-Info-0.20.tar.gz','Pod-Coverage-0.11.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => '2.102','Getopt::Std' => '1.02','IO::Socket' => '1.26','Module::Info' => '0.12','Pod::Coverage' => '0.09','Socket' => '1.72','Test::More' => '0.41','constant' => '1.02'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Devel-Symdump-2.03.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Module-Info-0.20.tar.gz','Pod-Coverage-0.11.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9588,'unpacked' => 33394},'testers' => {'pass' => 1},'uses' => ['5.006001','Carp','IO::Socket','Socket','Sys::Hostname','constant','strict','warnings']},'Net-Subnet-Count-1.20.tar.gz' => {'author' => 'LUISMUNOZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 76,'pod_errors' => 0,'total' => 228,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 3966,'unpacked' => 12039},'testers' => {'fail' => 3,'pass' => 4},'uses' => ['Carp','Exporter','IP::Address','strict','vars']},'Net-Syslog-0.03.tar.gz' => {'author' => 'LHOWARD','description' => 'Forwarded syslog protocol','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 122,'pod' => 35,'pod_errors' => 0,'total' => 157,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 2483,'unpacked' => 4573},'testers' => {'pass' => 10},'uses' => ['Exporter','IO::Socket','vars']},'Net-TFTP-0.16.tar.gz' => {'author' => 'GBARR','description' => 'Interface to Trivial File Transfer Protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 756,'pod' => 127,'pod_errors' => 0,'total' => 883,'with_comments' => 82},'releases' => 5,'size' => {'packed' => 7285,'unpacked' => 21997},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','IO::File','IO::Select','IO::Socket','strict','vars']},'Net-Telnet-3.03.tar.gz' => {'author' => 'JROGERS','description' => 'Interact with TELNET port or other TCP ports','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4047,'pod' => 1205,'pod_errors' => 0,'total' => 5252,'with_comments' => 501},'releases' => 4,'size' => {'packed' => 35641,'unpacked' => 141519},'testers' => {'pass' => 28},'uses' => ['5.002','FileHandle','Socket','Symbol','vars']},'Net-Telnet-Cisco-1.10.tar.gz' => {'author' => 'JOSHUA','description' => 'Automate telnet sessions w/ routers&switches','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 885,'pod' => 438,'pod_errors' => 0,'total' => 1323,'with_comments' => 147},'releases' => 9,'requires' => ['Net-Telnet-3.03.tar.gz','TermReadKey-2.21.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Cwd' => undef,'Net::Telnet' => '3.02','Term::ReadKey' => 2,'Test::More' => undef},'requires_recursive' => ['File-Spec-0.82.tar.gz','Net-Telnet-3.03.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17579,'unpacked' => 50972},'testers' => {'pass' => 4},'uses' => ['5.005','AutoLoader','Carp','Net::Telnet','strict','vars']},'Net-Traceroute-1.07.tar.gz' => {'author' => 'HAG','description' => 'Trace routes in IPv4, v6','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 752,'pod' => 233,'pod_errors' => 0,'total' => 985,'with_comments' => 129},'releases' => 9,'size' => {'packed' => 10950,'unpacked' => 30851},'testers' => {'pass' => 7},'uses' => ['Data::Dumper','Exporter','IO::Pipe','IO::Select','Socket','Symbol','constant','strict','vars']},'Net-Traceroute-PurePerl-0.02.tar.gz' => {'author' => 'TSCANLAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 342,'pod' => 231,'pod_errors' => 0,'total' => 573,'with_comments' => 45},'releases' => 1,'requires' => ['Net-RawIP-0.1.tar.gz','Net-Traceroute-1.07.tar.gz'],'requires_module' => {'Net::RawIP' => '0.09','Net::Traceroute' => '1.05'},'requires_recursive' => ['Net-RawIP-0.1.tar.gz','Net-Traceroute-1.07.tar.gz'],'size' => {'packed' => 7379,'unpacked' => 20092},'testers' => {'pass' => 1},'uses' => ['Net::RawIP','Net::Traceroute','Socket','strict','vars','warnings']},'Net-Traceroute6-0.03.tar.gz' => {'author' => 'MOHACSI','description' => 'Interface to IPv6 traceroute','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 807,'pod' => 196,'pod_errors' => 0,'total' => 1003,'with_comments' => 140},'releases' => 3,'size' => {'packed' => 10163,'unpacked' => 28678},'testers' => {'fail' => 7},'uses' => ['Config','Data::Dumper','Exporter','IO::Pipe','IO::Select','Socket','Socket6','strict','vars']},'Net-TrackBack-0.21.tar.gz' => {'author' => 'TIMA','description' => 'A modularized implementation of core TrackBack 1x functionality.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 117,'pod_errors' => 0,'total' => 284,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 4664,'unpacked' => 10618},'testers' => {'pass' => 3},'uses' => ['LWP::UserAgent','strict','vars']},'Net-Wake-0.02.tar.gz' => {'author' => 'CLINTDW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 33,'pod_errors' => 0,'total' => 76,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 2269,'unpacked' => 4561},'testers' => {'pass' => 2},'uses' => ['IO::Socket','strict','vars']},'Net-Whois-1.9.tar.gz' => {'author' => 'DHUDES','description' => 'Get+parse "whois" domain data from InterNIC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 377,'pod' => 50,'pod_errors' => 0,'total' => 427,'with_comments' => 58},'releases' => 13,'size' => {'packed' => 6105,'unpacked' => 14321},'testers' => {'pass' => 15},'uses' => ['5.004','Carp','Exporter','IO::File','IO::Socket','strict','vars']},'Net-Whois-IANA-0.02.tar.gz' => {'author' => 'ROMM','description' => 'A universal WHOIS data extractor.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 314,'pod' => 141,'pod_errors' => 0,'total' => 455,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 4795,'unpacked' => 14547},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','Exporter','IO::Socket','strict','warnings']},'Net-Whois-IP-0.35.tar.gz' => {'author' => 'BSCHMITZ','description' => 'IP whois information lookup','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 187,'pod' => 44,'pod_errors' => 0,'total' => 231,'with_comments' => 25},'releases' => 6,'size' => {'packed' => 3759,'unpacked' => 8539},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','IO::Socket','strict','vars']},'Net-Whois-RIPE-1.19.tar.gz' => {'author' => 'PAULG','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 884,'pod' => 442,'pod_errors' => 2,'total' => 1326,'with_comments' => 98},'releases' => 1,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO' => '1.2'},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 67947,'unpacked' => 339328},'testers' => {'fail' => 6,'tests' => '759'},'uses' => ['Carp','IO::Socket','constant','strict','vars']},'Net-Whois-Raw-0.23.tar.gz' => {'author' => 'CORRIS','description' => 'Perl extension for unparsed raw whois information','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 618,'pod' => 126,'pod_errors' => 0,'total' => 744,'with_comments' => 12},'releases' => 19,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO::Socket' => 1},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 10253,'unpacked' => 36921},'testers' => {'pass' => 3},'uses' => ['Exporter','IO::Socket','strict','vars']},'Net-XWhois-0.90.tar.gz' => {'author' => 'VIPUL','description' => 'Whois Client Interface for Perl5.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 806,'pod' => 268,'pod_errors' => 0,'total' => 1074,'with_comments' => 107},'releases' => 11,'size' => {'packed' => 17750,'unpacked' => 57590},'testers' => {'pass' => 4},'uses' => ['Carp','Data::Dumper','IO::Socket','it','vars']},'Net-YMSG-1.2.tar.gz' => {'author' => 'VARUNK','description' => 'Interface to the Yahoo! Messenger IM protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1968,'pod' => 335,'pod_errors' => 2,'total' => 2303,'with_comments' => 32},'releases' => 3,'requires' => ['Crypt-PasswdMD5-1.2.tar.gz','Digest-MD5-2.26.tar.gz'],'requires_module' => {'Crypt::PasswdMD5' => 0,'Digest::MD5' => 0},'requires_recursive' => ['Crypt-PasswdMD5-1.2.tar.gz','Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 15817,'unpacked' => 55253},'testers' => {'fail' => 2,'pass' => 4,'tests' => '7'},'uses' => ['Carp','Crypt::PasswdMD5','Digest::MD5','IO::Select','IO::Socket','constant','strict','vars']},'Net-YahooMessenger-0.13.tar.gz' => {'author' => 'OYAMA','description' => 'Interface to the Yahoo!Messenger IM protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1635,'pod' => 273,'pod_errors' => 0,'total' => 1908,'with_comments' => 14},'releases' => 3,'requires' => ['Digest-MD5-2.26.tar.gz'],'requires_module' => {'Digest::MD5' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 14079,'unpacked' => 54700},'testers' => {'pass' => 5},'uses' => ['Carp','Crypt::PasswdMD5','Digest::MD5','IO::Select','IO::Socket','constant','strict','vars']},'Net-Z3950-0.33.tar.gz' => {'author' => 'MIRK','description' => 'Perl extension for talking to Z39.50 servers.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2540,'pod' => 1089,'pod_errors' => 0,'total' => 3629,'with_comments' => 375},'releases' => 18,'requires' => ['Event-0.87.tar.gz'],'requires_module' => {'Event' => '0.77'},'requires_recursive' => ['Event-0.87.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 70094,'unpacked' => 208393},'testers' => {},'uses' => ['AutoLoader','Carp','Data::Dumper','DynaLoader','Errno','Event','Exporter','IO::Handle','MARC','Net::Z3950::APDU','Net::Z3950::Connection','Net::Z3950::Manager','Net::Z3950::Record','Net::Z3950::ResultSet','strict','vars']},'Net-Z3950-0.35.tar.gz' => {'author' => 'MIRK','description' => 'OO interface (ZOOM) to Yaz Z39.50 toolkit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2660,'pod' => 1109,'pod_errors' => 0,'total' => 3769,'with_comments' => 385},'releases' => 18,'requires' => ['Event-0.87.tar.gz'],'requires_module' => {'Event' => '0.77'},'requires_recursive' => ['Event-0.87.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 71839,'unpacked' => 214717},'testers' => {},'uses' => ['AutoLoader','Carp','Data::Dumper','DynaLoader','Errno','Event','Exporter','IO::Handle','MARC','strict','vars']},'Net-Z3950-AsyncZ-0.06.tar.gz' => {'author' => 'TURNERMM','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3298,'pod' => 2916,'pod_errors' => 6,'total' => 6214,'with_comments' => 264},'releases' => 3,'requires' => ['Event-0.87.tar.gz','IPC-ShareLite-0.09.tar.gz','MARC-Record-1.29.tar.gz','Net-Z3950-0.35.tar.gz'],'requires_module' => {'Event' => '0.86','IPC::ShareLite' => '0.09','MARC::Record' => '1.15','Net::Z3950' => '0.31'},'requires_recursive' => ['Event-0.87.tar.gz','File-Spec-0.82.tar.gz','IPC-ShareLite-0.09.tar.gz','MARC-Record-1.29.tar.gz','Net-Z3950-0.35.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 129914,'unpacked' => 507176},'testers' => {},'uses' => ['Carp','Event','Exporter','IPC::ShareLite','MARC::Base','MARC::Charset','Net::Z3950','POSIX','Symbol','sigtrap','strict','vars']},'Net-ext-1.011.tar.gz' => {'author' => 'SPIDB','description' => 'TCP-specific socket usage','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8404,'pod' => 2147,'pod_errors' => 0,'total' => 10551,'with_comments' => 714},'releases' => 21,'size' => {'packed' => 174058,'unpacked' => 625908},'testers' => {'fail' => 1,'pass' => 12},'uses' => ['5.002','5.004_04','AutoLoader','Benchmark','Carp','Config','Devel::CoreStack','Exporter','Fcntl','FileHandle','Socket','Symbol','strict','vars','vmsish']},'Net-vCard-0.5.tar.gz' => {'author' => 'JLAWRENC','description' => 'Read and write vCard files (RFC 2426). vCard files hold personal information that you would typically find on a business card. Name, numbers, addresses, and even logos. This module can also serve as a base class for other vFile readers.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 610,'pod' => 267,'pod_errors' => 0,'total' => 877,'with_comments' => 24},'releases' => 4,'size' => {'packed' => 18191,'unpacked' => 50978},'testers' => {'pass' => 3},'uses' => ['DateTime::Format::ICal','Encode','strict','warnings']},'NetAddr-IP-3.14.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Manipulation and operations on IP addresses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1239,'pod' => 476,'pod_errors' => 1,'total' => 1715,'with_comments' => 42},'releases' => 23,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 24211,'unpacked' => 81101},'testers' => {'fail' => 1,'pass' => 12,'tests' => '557'},'uses' => ['5.005_62','Carp','Socket','strict','warnings']},'NetAddr-IP-Count-2.01.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Count hosts in named subnets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 76,'pod_errors' => 0,'total' => 228,'with_comments' => 6},'releases' => 2,'requires' => ['NetAddr-IP-3.14.tar.gz'],'requires_module' => {'NetAddr::IP' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','NetAddr-IP-3.14.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3728,'unpacked' => 11268},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','NetAddr::IP','strict','vars']},'NetAddr-IP-Find-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Find IP addresses in plain text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 52,'pod' => 71,'pod_errors' => 0,'total' => 123,'with_comments' => 0},'releases' => 2,'requires' => ['NetAddr-IP-3.14.tar.gz'],'requires_module' => {'NetAddr::IP' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','NetAddr-IP-3.14.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2858,'unpacked' => 6812},'testers' => {'pass' => 2},'uses' => ['Exporter','NetAddr::IP','strict','vars']},'NetIcecast-1.02.zip' => {'author' => 'IGREC','description' => undef,'files' => [],'lines' => {'nonpod' => 485,'pod' => 71,'pod_errors' => 0,'total' => 556,'with_comments' => 52},'releases' => 3,'size' => {'packed' => 4606,'unpacked' => 13019},'testers' => {'pass' => 1,'tests' => '0','unknown' => 3},'uses' => ['Exporter','IO::Socket','strict','vars']},'NetPacket-0.03.tar.gz' => {'author' => 'TIMPOTTER','description' => ' Address Resolution Protocol','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1655,'pod' => 1294,'pod_errors' => 0,'total' => 2949,'with_comments' => 502},'releases' => 5,'size' => {'packed' => 11627,'unpacked' => 66887},'testers' => {'pass' => 1,'tests' => '0','unknown' => 24},'uses' => ['constant','vars']},'NetPacket-LACP-0.01.tar.gz' => {'author' => 'CGANESAN','description' => 'Assemble and disassemble IEEE 802.1D Spanning Tree protocol packets.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 393,'pod' => 197,'pod_errors' => 0,'total' => 590,'with_comments' => 76},'releases' => 1,'requires' => ['NetPacket-0.03.tar.gz','NetPacket-LLC-0.01.tar.gz'],'requires_module' => {'NetPacket::Ethernet' => '0.04','NetPacket::LLC' => '0.01'},'requires_recursive' => ['NetPacket-0.03.tar.gz','NetPacket-LLC-0.01.tar.gz'],'size' => {'packed' => 5757,'unpacked' => 16800},'testers' => {'pass' => 1},'uses' => ['strict','vars','warnings']},'NetPacket-LLC-0.01.tar.gz' => {'author' => 'CGANESAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 239,'pod' => 144,'pod_errors' => 0,'total' => 383,'with_comments' => 52},'releases' => 1,'requires' => ['NetPacket-0.03.tar.gz'],'requires_module' => {'NetPacket::Ethernet' => '0.04'},'requires_recursive' => ['NetPacket-0.03.tar.gz'],'size' => {'packed' => 4346,'unpacked' => 11958},'testers' => {'pass' => 1},'uses' => ['strict','vars','warnings']},'NetPacket-SpanningTree-0.01.tar.gz' => {'author' => 'CGANESAN','description' => 'Assemble and disassemble IEEE 802.1D Spanning Tree protocol packets.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 378,'pod' => 197,'pod_errors' => 0,'total' => 575,'with_comments' => 67},'releases' => 1,'requires' => ['NetPacket-0.03.tar.gz','NetPacket-LLC-0.01.tar.gz'],'requires_module' => {'NetPacket::Ethernet' => '0.04','NetPacket::LLC' => '0.01'},'requires_recursive' => ['NetPacket-0.03.tar.gz','NetPacket-LLC-0.01.tar.gz'],'size' => {'packed' => 5796,'unpacked' => 18245},'testers' => {'pass' => 1},'uses' => ['strict','vars','warnings']},'NetServer-Generic-1.03.tar.gz' => {'author' => 'CHSTROSS','description' => 'generic OOP class for internet servers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 987,'pod' => 325,'pod_errors' => 0,'total' => 1312,'with_comments' => 135},'releases' => 7,'size' => {'packed' => 18949,'unpacked' => 66996},'testers' => {'pass' => 7},'uses' => ['Carp','Data::Dumper','Exporter','Fcntl','IO::File','IO::Handle','IO::Pipe','IO::Select','IO::Socket','POSIX','Socket','Tie::RefHash','Time::HiRes','strict']},'NetServer-Portal-1.08.tar.gz' => {'author' => 'JPRIT','description' => 'Interactively Manipulate Daemon Processes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1172,'pod' => 84,'pod_errors' => 0,'total' => 1256,'with_comments' => 55},'releases' => 6,'requires' => ['Event-0.87.tar.gz','Event-Stats-0.7.tar.gz','Scalar-List-Utils-1.11.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'Event' => '0.70','Event::Stats' => '0.8','Scalar::Util' => '0.1','Storable' => '0.6'},'requires_recursive' => ['Event-0.87.tar.gz','Event-Stats-0.7.tar.gz','File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Storable-2.07.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 13112,'unpacked' => 36349},'testers' => {'fail' => 1,'pass' => 7},'uses' => ['Carp','Cwd','Data::Dumper','Event','Event::Stats','Exporter','Scalar::Util','Socket','Storable','Symbol','Sys::Hostname','Term::Cap','constant','strict','vars']},'NetServer-SMTP-0.01.tar.gz' => {'author' => 'CHSTROSS','description' => 'basic SMTP server class for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 459,'pod' => 152,'pod_errors' => 1,'total' => 611,'with_comments' => 31},'releases' => 1,'size' => {'packed' => 10905,'unpacked' => 28947},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','Data::Dumper','File::Flock','FreezeThaw','IO::File','IO::Handle','Net::SMTP','Time::CTime']},'Net_SSLeay.pm-1.23.tar.gz' => {'author' => 'SAMPO','description' => 'Secure Socket Layer (based on OpenSSL)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1645,'pod' => 766,'pod_errors' => 0,'total' => 2411,'with_comments' => 220},'releases' => 25,'size' => {'packed' => 75196,'unpacked' => 252549},'testers' => {'pass' => 2},'uses' => ['5.005_03','AutoLoader','Carp','DynaLoader','Errno','Exporter','Socket','strict','vars']},'Net_TCLink.pm-3.3.1.tar.gz' => {'author' => 'TRUSTCOM','description' => 'Perl interface to the TrustCommerce payment gateway','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 86,'pod' => 26,'pod_errors' => 0,'total' => 112,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 55313,'unpacked' => 199069},'testers' => {'pass' => 5},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Netscape-Bookmarks-1.5.tar.gz' => {'author' => 'BDFOY','description' => 'parse, manipulate, or create Netscape Bookmarks files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1166,'pod' => 462,'pod_errors' => 0,'total' => 1628,'with_comments' => 70},'releases' => 7,'requires' => ['HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'HTML::Entities' => undef,'HTML::Parser' => undef,'URI::URL' => undef},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','URI-1.24.tar.gz'],'size' => {'packed' => 24144,'unpacked' => 115967},'testers' => {'pass' => 4},'uses' => ['Exporter','HTML::Entities','HTML::Parser','Netscape::Bookmarks','Netscape::Bookmarks::Category','URI::URL','constant','strict','subs','vars']},'Netscape-Cache-0.45.tar.gz' => {'author' => 'SREZIC','description' => 'Access Netscape cache files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 502,'pod' => 291,'pod_errors' => 0,'total' => 793,'with_comments' => 22},'releases' => 10,'size' => {'packed' => 16704,'unpacked' => 48112},'testers' => {'pass' => 4},'uses' => ['DB_File','strict','vars']},'Netscape-History-3.01.tar.gz' => {'author' => 'NEILB','description' => 'Like a URI::URL, but with visit time','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 606,'pod' => 273,'pod_errors' => 0,'total' => 879,'with_comments' => 173},'releases' => 8,'size' => {'packed' => 9010,'unpacked' => 35773},'testers' => {'pass' => 13},'uses' => ['5.004','Carp','Config','Env','URI::URL','overload','strict','vars']},'Netscreen-1.1.tar.gz' => {'author' => 'MRAMBERG','description' => 'interact with a Netscreen firewall','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 694,'pod' => 83,'pod_errors' => 0,'total' => 777,'with_comments' => 107},'releases' => 1,'requires' => ['Net-Telnet-3.03.tar.gz'],'requires_module' => {'Net::Telnet' => '3.02'},'requires_recursive' => ['Net-Telnet-3.03.tar.gz'],'size' => {'packed' => 9932,'unpacked' => 28811},'testers' => {'pass' => 3},'uses' => ['AutoLoader','Carp','Net::Telnet','strict','vars']},'Network-IPv4Addr-0.05.tar.gz' => {'author' => 'FRAJULAC','description' => 'Perl extension for manipulating IPv4 addresses.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 230,'pod' => 154,'pod_errors' => 0,'total' => 384,'with_comments' => 36},'releases' => 1,'size' => {'packed' => 6229,'unpacked' => 18672},'testers' => {'pass' => 6},'uses' => ['AutoLoader','Carp','Exporter','strict','vars']},'NetworkInfo-Discovery-0.09.tar.gz' => {'author' => 'TSCANLAN','description' => 'Modules for network discovery and mapping','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1584,'pod' => 482,'pod_errors' => 0,'total' => 2066,'with_comments' => 159},'releases' => 6,'requires' => ['Graph-0.20101.tar.gz','Graph-ReadWrite-1.07.tar.gz','Net-Pcap-0.04.tar.gz','Net-Traceroute-1.07.tar.gz','NetPacket-0.03.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'requires_module' => {'Graph' => '0.20101','Graph::Reader' => 0,'Graph::Writer' => 0,'Net::Pcap' => '0.04','Net::Traceroute' => '1.05','NetPacket' => '0.03','XML::Parser' => '2.31','XML::Writer' => '0.4'},'requires_recursive' => ['Graph-0.20101.tar.gz','Graph-ReadWrite-1.07.tar.gz','Heap-0.50.tar.gz','IO-1.20.tar.gz','Net-Pcap-0.04.tar.gz','Net-Traceroute-1.07.tar.gz','NetPacket-0.03.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 17097,'unpacked' => 60426},'testers' => {'pass' => 1},'uses' => ['Graph::Reader::XML','Graph::Undirected','Graph::Writer::XML','Net::Pcap','Net::Traceroute','NetPacket::ARP','NetPacket::Ethernet','NetPacket::ICMP','NetPacket::IP','NetPacket::TCP','NetPacket::UDP','NetworkInfo::Discovery::Detect','NetworkInfo::Discovery::Sniff','POSIX','Socket','strict','vars','warnings']},'NetworkInfo-Discovery-0.11.tar.gz' => {'author' => 'TSCANLAN','description' => 'Modules for network discovery and mapping','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2268,'pod' => 401,'pod_errors' => 0,'total' => 2669,'with_comments' => 319},'releases' => 6,'requires' => ['Net-Pcap-0.04.tar.gz','Net-Traceroute-1.07.tar.gz','NetPacket-0.03.tar.gz'],'requires_module' => {'Net::Pcap' => '0.04','Net::Traceroute' => '1.05','NetPacket' => '0.03'},'requires_recursive' => ['Net-Pcap-0.04.tar.gz','Net-Traceroute-1.07.tar.gz','NetPacket-0.03.tar.gz'],'size' => {'packed' => 23390,'unpacked' => 85336},'testers' => {'fail' => 1},'uses' => ['Data::Dumper','Graph::Reader::XML','Graph::Undirected','Net::Pcap','Net::Traceroute','NetPacket::ARP','NetPacket::Ethernet','NetPacket::ICMP','NetPacket::IP','NetPacket::TCP','NetPacket::UDP','Socket','Storable','Tk','Tk::Canvas','strict','vars','warnings']},'Netx-WebRadio-0.03.tar.gz' => {'author' => 'NATHANAEL','description' => 'receive one or more webradio-stations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 528,'pod' => 312,'pod_errors' => 1,'total' => 840,'with_comments' => 21},'releases' => 2,'requires' => ['Class-MethodMaker-1.10.tar.gz'],'requires_module' => {'Class::MethodMaker' => 0},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz'],'size' => {'packed' => 14119,'unpacked' => 43266},'testers' => {'fail' => 1,'pass' => 6,'tests' => '4'},'uses' => ['Carp','Errno','IO::Poll','IO::Socket','MP3::Tag','strict','vars','warnings']},'NetxAP-0.01.tar.gz' => {'author' => 'KJOHNSON','description' => 'An interface to the protocol beneath IMAP, ACAP, and ICAP. B<WARNING: This code is in alpha release. Expect the interface to change.>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1605,'pod' => 164,'pod_errors' => 0,'total' => 1769,'with_comments' => 209},'releases' => 2,'size' => {'packed' => 14921,'unpacked' => 56842},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.004','Carp','Data::Dumper','IO::Socket','Net::xAP','strict','vars']},'NetxAP-0.02.tar.gz' => {'author' => 'KJOHNSON','description' => 'Interface to IMAP,ACAP,ICAP substrate','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2649,'pod' => 1215,'pod_errors' => 4,'total' => 3864,'with_comments' => 112},'releases' => 2,'requires' => ['MD5-2.02.tar.gz','MIME-Base64-2.20.tar.gz'],'requires_module' => {'MD5' => '2.01','MIME::Base64' => '2.11'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','MD5-2.02.tar.gz','MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 33374,'unpacked' => 125967},'testers' => {'fail' => 5,'pass' => 1,'tests' => '73'},'uses' => ['5.005','Carp','Data::Dumper','Digest::HMAC_MD5','IO::Socket','MIME::Base64','constant','strict','vars']},'Neuron-0.0.1.tar.gz' => {'author' => 'YKOSTYLEV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 436,'pod' => 11,'pod_errors' => 0,'total' => 447,'with_comments' => 41},'releases' => 1,'size' => {'packed' => 3302,'unpacked' => 14595},'testers' => {'pass' => 3},'uses' => []},'News-Article-1.27.tar.gz' => {'author' => 'AGIERTH','description' => 'Object for handling Usenet articles in mail or news form.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1842,'pod' => 394,'pod_errors' => 0,'total' => 2236,'with_comments' => 510},'releases' => 3,'size' => {'packed' => 20046,'unpacked' => 62446},'testers' => {'pass' => 11},'uses' => ['Fcntl','IPC::Open3','Net::Domain','PGP::Sign','POSIX','SelfLoader','integer','strict','subs','vars']},'News-Collabra-0.06.tar.gz' => {'author' => 'NATE','description' => 'Access to Collabra administrative functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 534,'pod' => 99,'pod_errors' => 0,'total' => 633,'with_comments' => 69},'releases' => 2,'size' => {'packed' => 7867,'unpacked' => 24407},'testers' => {'fail' => 3},'uses' => ['5.006','Carp','Data::Dumper','HTTP::Cookies','HTTP::Request::Common','IO::Socket','LWP::UserAgent','News::NNTPClient','URI','URI::Escape','strict','warnings']},'News-GnusFilter-0.55.tar.gz' => {'author' => 'JOESUF','description' => 'gnus MIME-hook filter to score usenet posts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 883,'pod' => 301,'pod_errors' => 0,'total' => 1184,'with_comments' => 92},'releases' => 2,'size' => {'packed' => 15952,'unpacked' => 44188},'testers' => {'pass' => 6},'uses' => ['5.006','Exporter','strict']},'News-Newsrc-1.08.tar.gz' => {'author' => 'SWMCD','description' => 'Manage .newsrc files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 718,'pod' => 410,'pod_errors' => 0,'total' => 1128,'with_comments' => 8},'releases' => 9,'requires' => ['Set-IntSpan-1.07.tar.gz'],'requires_module' => {'Set::IntSpan' => '1.07'},'requires_recursive' => ['Set-IntSpan-1.07.tar.gz'],'size' => {'packed' => 10337,'unpacked' => 40496},'testers' => {'pass' => 11},'uses' => ['5.6.0','Set::IntSpan','integer','strict']},'News-Scan-0.53.tar.gz' => {'author' => 'GBACON','description' => 'gather and report Usenet newsgroup statistics','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1466,'pod' => 501,'pod_errors' => 1,'total' => 1967,'with_comments' => 25},'releases' => 3,'size' => {'packed' => 19598,'unpacked' => 95287},'testers' => {'pass' => 2},'uses' => ['5.004','Carp','Date::Parse','IO::File','IO::Seekable','Mail::Address','Mail::Internet','strict','vars']},'NewsClipper-1.32-OpenSource.tar.gz' => {'author' => 'DCOPPIT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4867,'pod' => 0,'pod_errors' => 0,'total' => 4867,'with_comments' => 789},'releases' => 3,'size' => {'packed' => 87482,'unpacked' => 328512},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['Carp','DBD::mysql','DBI','Exporter','File::Cache','File::Path','HTML::FormatText','HTML::Parser','HTML::TreeBuilder','LWP::UserAgent','Log::Agent','Log::Agent::Driver::File','Log::Agent::Rotate','Text::Wrap','Time::CTime','Time::ParseDate','URI','strict','vars']},'NewsTicker-0.02.tar.gz' => {'author' => 'RLZWART','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 553,'pod' => 45,'pod_errors' => 0,'total' => 598,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 8517,'unpacked' => 41826},'testers' => {'fail' => 3,'tests' => '1'},'uses' => ['5.006','Data::Dumper','Exporter','IO::File','LWP::Simple','Template','Term::ANSIScreen','Term::Size','Time::HiRes','XML::Parser::Lite','strict','warnings']},'Newt-1.08.tar.gz' => {'author' => 'AMEDINA','description' => 'Perl bindings for RedHat newt library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 940,'pod' => 517,'pod_errors' => 1,'total' => 1457,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 78346,'unpacked' => 286219},'testers' => {'pass' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'NexTrieve-0.39.tar.gz' => {'author' => 'ELIZABETH','description' => 'Convert message(s) to logical document(s)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 16699,'pod' => 4982,'pod_errors' => 0,'total' => 21681,'with_comments' => 7653},'releases' => 14,'requires' => ['IO-1.20.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Cwd' => 0,'Date::Parse' => 0,'File::Copy' => 0,'IO::File' => 0,'IO::Socket' => 0},'requires_recursive' => ['IO-1.20.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 221389,'unpacked' => 971464},'testers' => {'fail' => 5,'pass' => 1,'tests' => '383'},'uses' => ['Encode','File::Copy','Text::Iconv','strict']},'Nmap-Scanner-0.01.tar.gz' => {'author' => 'MAXSCHUBE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2958,'pod' => 924,'pod_errors' => 2,'total' => 3882,'with_comments' => 44},'releases' => 2,'size' => {'packed' => 24175,'unpacked' => 88666},'testers' => {'fail' => 1,'pass' => 1,'tests' => '6'},'uses' => ['File::Spec','IO::Socket','Nmap::Scanner','Nmap::Scanner::Backend::Processor','Nmap::Scanner::Backend::Results','Nmap::Scanner::Backend::XML','Nmap::Scanner::Host','Nmap::Scanner::HostList','Nmap::Scanner::Port','Nmap::Scanner::PortList','Nmap::Scanner::Scanner','Nmap::Scanner::Util','Nmap::Scanner::Util::BannerScanner','strict','vars']},'Nmap-Scanner-0.5.tar.gz' => {'author' => 'MAXSCHUBE','description' => 'Perform and manipulate nmap scans using perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2490,'pod' => 781,'pod_errors' => 1,'total' => 3271,'with_comments' => 16},'releases' => 2,'requires' => ['XML-SAX-0.12.tar.gz'],'requires_module' => {'XML::SAX' => 0,'XML::SAX::PurePerl' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 26690,'unpacked' => 96334},'testers' => {'pass' => 1},'uses' => ['File::Spec','IO::Socket','XML::SAX','XML::SAX::Base','XML::SAX::PurePerl','strict','vars']},'No-Die-0.02.tar.gz' => {'author' => 'KANE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 99,'pod' => 63,'pod_errors' => 0,'total' => 162,'with_comments' => 2},'releases' => 2,'requires' => ['Locale-Maketext-Simple-0.02.tar.gz','Params-Check-0.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Locale::Maketext::Simple' => 0,'Params::Check' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Locale-Maketext-Simple-0.02.tar.gz','Params-Check-0.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3134,'unpacked' => 6968},'testers' => {'pass' => 2},'uses' => ['Carp','Locale::Maketext::Simple','Params::Check','strict','vars']},'Norge-1.06.tar.gz' => {'author' => 'GAAS','description' => 'Norwegian stuff','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 740,'pod' => 251,'pod_errors' => 0,'total' => 991,'with_comments' => 63},'releases' => 10,'size' => {'packed' => 14947,'unpacked' => 39339},'testers' => {'pass' => 11},'uses' => ['5.002','Carp','Exporter','Time::Local','integer','strict','vars']},'Notes.zip' => {'author' => 'CCLOUTIER','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 1460,'pod' => 548,'pod_errors' => 0,'total' => 2008,'with_comments' => 242},'releases' => 1,'size' => {'packed' => 570122,'unpacked' => 2399292},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','Devel::Peek','DynaLoader','Exporter','LotusAPI::Name','LotusAPI::Object','strict','vars','warnings']},'Notify-0.0.1.tar.gz' => {'author' => 'MGILFIX','description' => 'Framework for asynchronously, remotely notifying users.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 674,'pod' => 488,'pod_errors' => 0,'total' => 1162,'with_comments' => 58},'releases' => 1,'requires' => ['Mail-Box-2.043.tar.gz','Mail-Sender-0.8.06.tar.gz','Tie-Persistent-1.00.tar.gz'],'requires_module' => {'Mail::Box' => '1.3','Mail::Sender' => '
','Tie::Persistent' => '0.9'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Errno-1.09.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Types-1.06.tar.gz','Mail-Box-2.043.tar.gz','Mail-Sender-0.8.06.tar.gz','MailTools-1.58.tar.gz','Object-Realize-Later-0.12.tar.gz','Scalar-List-Utils-1.11.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tie-Persistent-1.00.tar.gz','TimeDate-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9497,'unpacked' => 31195},'testers' => {'pass' => 4},'uses' => ['5.00503','Carp','Exporter','Mail::Box::Manager','Mail::Sender','Tie::Persistent','constant','strict']},'Number-Compare-0.01.tar.gz' => {'author' => 'RCLAMP','description' => 'numeric comparisons','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 52,'pod' => 48,'pod_errors' => 0,'total' => 100,'with_comments' => 4},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2123,'unpacked' => 4305},'testers' => {'pass' => 27},'uses' => ['Carp','strict','vars']},'Number-Encode-1.00.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Encode bit strings into digit strings','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 54,'pod_errors' => 0,'total' => 174,'with_comments' => 2},'releases' => 1,'requires' => ['Digest-MD5-2.26.tar.gz'],'requires_module' => {'Digest::MD5' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 2154,'unpacked' => 4472},'testers' => {'pass' => 14},'uses' => ['5.005_62','Digest::MD5','Exporter','strict','warnings']},'Number-Format-1.45.tar.gz' => {'author' => 'WRW','description' => 'Package for formatting numbers for display','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 575,'pod' => 205,'pod_errors' => 0,'total' => 780,'with_comments' => 84},'releases' => 8,'size' => {'packed' => 14084,'unpacked' => 49076},'testers' => {'fail' => 3,'pass' => 9,'tests' => '64'},'uses' => ['5.003','Carp','Exporter','POSIX','strict','vars']},'Number-Fraction-1.02.tar.gz' => {'author' => 'DAVECROSS','description' => 'Perl extension to model fractions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 221,'pod' => 91,'pod_errors' => 0,'total' => 312,'with_comments' => 22},'releases' => 2,'size' => {'packed' => 4057,'unpacked' => 13986},'testers' => {'pass' => 11},'uses' => ['5.006','Carp','overload','strict','warnings']},'Number-Latin-1.01.tar.gz' => {'author' => 'SBURKE','description' => '- convert to/from the number system "a,b,...z,aa,ab..."','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 69,'pod_errors' => 0,'total' => 245,'with_comments' => 30},'releases' => 1,'size' => {'packed' => 5176,'unpacked' => 13896},'testers' => {'pass' => 9},'uses' => ['5','Exporter','integer','strict']},'Number-Phone-Country-0.01.tar.gz' => {'author' => 'TJMATHER','description' => 'Lookup country of phone number','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 281,'pod' => 33,'pod_errors' => 0,'total' => 314,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 3323,'unpacked' => 6298},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Exporter','strict','warnings']},'Number-Phone-DE-Mobile-1_1.tgz' => {'author' => 'NETSRAK','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 110,'pod' => 71,'pod_errors' => 0,'total' => 181,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 2627,'unpacked' => 5705},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['Exporter']},'Number-Phone-JP-0.03.tar.gz' => {'author' => 'TANIGUCHI','description' => 'Validate Japanese phone numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 974,'pod' => 373,'pod_errors' => 0,'total' => 1347,'with_comments' => 23},'releases' => 3,'size' => {'packed' => 8713,'unpacked' => 39965},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','strict','vars']},'Number-Phone-US-1.5.tar.gz' => {'author' => 'KENNEDYH','description' => 'Validates several US phone number formats','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 61,'pod' => 108,'pod_errors' => 1,'total' => 169,'with_comments' => 11},'releases' => 3,'size' => {'packed' => 2702,'unpacked' => 5529},'testers' => {'pass' => 8},'uses' => ['5','Exporter','strict','vars']},'Number-Spell-0.04.tar.gz' => {'author' => 'LHOWARD','description' => 'Perl extension for spelling out numbers','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 206,'pod' => 83,'pod_errors' => 0,'total' => 289,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 3426,'unpacked' => 10969},'testers' => {'pass' => 10},'uses' => ['Exporter','strict','vars']},'Number-Spice-0.011.tar.gz' => {'author' => 'WIMV','description' => 'handling of Spice number strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 171,'pod' => 122,'pod_errors' => 0,'total' => 293,'with_comments' => 33},'releases' => 1,'size' => {'packed' => 4647,'unpacked' => 11759},'testers' => {'pass' => 11},'uses' => ['Exporter','strict','vars']},'Nums2Words-1.12.zip' => {'author' => 'HIGHTOWE','description' => 'compute English verbage from numerical values','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 500,'pod' => 42,'pod_errors' => 1,'total' => 542,'with_comments' => 79},'releases' => 5,'size' => {'packed' => 7823,'unpacked' => 23889},'testers' => {'pass' => 9},'uses' => ['5.000','Exporter']},'OAI-Harvester-0.2.tar.gz' => {'author' => 'ESUMMERS','description' => 'A package for harvesting metadata using OAI-PMH','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1309,'pod' => 589,'pod_errors' => 1,'total' => 1898,'with_comments' => 26},'releases' => 2,'requires' => ['URI-1.24.tar.gz','XML-SAX-0.12.tar.gz','YAML-0.35.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::UserAgent' => 0,'URI' => 0,'XML::SAX' => 0,'YAML' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','YAML-0.35.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13018,'unpacked' => 53641},'testers' => {'pass' => 2},'uses' => ['','Carp','File::Temp','LWP::UserAgent','URI','XML::SAX::Base','XML::SAX::ParserFactory','YAML','strict','warnings']},'OLE-Storage-0.386.tar.gz' => {'author' => 'MSCHWARTZ','description' => 'An Interface to B<Structured Storage> Documents. $Revision: 1.8 $ $Date: 1998/04/28 00:39:43 $','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3438,'pod' => 677,'pod_errors' => 0,'total' => 4115,'with_comments' => 1049},'releases' => 5,'size' => {'packed' => 83071,'unpacked' => 274428},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['Exporter','Symbol','strict','vars']},'OLE-Storage_Lite-0.11.tar.gz' => {'author' => 'KWITKNR','description' => 'Simple Class for OLE document interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1451,'pod' => 226,'pod_errors' => 0,'total' => 1677,'with_comments' => 354},'releases' => 11,'requires' => ['IO-stringy-2.108.tar.gz'],'requires_module' => {'IO::Scalar' => '2.101'},'requires_recursive' => ['IO-stringy-2.108.tar.gz'],'size' => {'packed' => 16592,'unpacked' => 83291},'testers' => {'pass' => 6},'uses' => ['Exporter','Fcntl','IO::File','IO::Handle','IO::Scalar','Math::BigInt','strict','vars']},'OODoc-0.06.tar.gz' => {'author' => 'MARKOV','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 7273,'pod' => 6270,'pod_errors' => 0,'total' => 13543,'with_comments' => 381},'releases' => 6,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.47'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 86369,'unpacked' => 317249},'testers' => {'pass' => 2},'uses' => ['Carp','File::Basename','File::Copy','File::Find','File::Spec','IO::File','IO::Scalar','List::Util','POSIX','Text::MagicTemplate','strict','vars','warnings']},'OS2-Attrib-1.00.tar.gz' => {'author' => 'CJM','description' => 'Get or set OS/2 file attributes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 111,'pod' => 45,'pod_errors' => 0,'total' => 156,'with_comments' => 28},'releases' => 2,'size' => {'packed' => 5211,'unpacked' => 14070},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'OS2-FTP-0_10.zip' => {'author' => 'ILYAZ','description' => 'Access to ftplib interface','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 66,'pod' => 0,'pod_errors' => 0,'total' => 66,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 3987,'unpacked' => 11671},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter']},'OS2-Focus-0.01.tar.gz' => {'author' => 'ILYAZ','description' => 'Perl extension to get and set focus on PM windows.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 80,'pod' => 42,'pod_errors' => 0,'total' => 122,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 3152,'unpacked' => 6189},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'OS2-Proc-0.02.tar.gz' => {'author' => 'ILYAZ','description' => 'Perl extension for get information about running processes and loaded modules.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 162,'pod' => 120,'pod_errors' => 0,'total' => 282,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 5345,'unpacked' => 13811},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'OS2-Process-0.2.tar.gz' => {'author' => 'ILYAZ','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 156,'pod_errors' => 0,'total' => 293,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 5165,'unpacked' => 14980},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter']},'OS2-SoftInstaller-0.07.tar.gz' => {'author' => 'ILYAZ','description' => 'Perl extension for generation of daughter packages for IBM\'s Software Installer.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 162,'pod' => 76,'pod_errors' => 0,'total' => 238,'with_comments' => 21},'releases' => 3,'size' => {'packed' => 12195,'unpacked' => 42175},'testers' => {'pass' => 2},'uses' => ['Config','Exporter','File::Find','strict','vars']},'OS2-UPM-0_10.zip' => {'author' => 'ILYAZ','description' => 'User Profile Management','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 98,'pod' => 0,'pod_errors' => 0,'total' => 98,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 4749,'unpacked' => 15609},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter']},'OS2-WinObject-0.02.tar.gz' => {'author' => 'ILYAZ','description' => 'Perl extension for access the subset of C<Win*> API for dealing with WPS objects.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 313,'pod' => 508,'pod_errors' => 0,'total' => 821,'with_comments' => 19},'releases' => 2,'size' => {'packed' => 12900,'unpacked' => 64261},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'OS390-Stdio-0.008.tar.gz' => {'author' => 'PVHP','description' => 'z/OS and OS/390 standard I/O functions with POSIX/XPG extensions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 398,'pod' => 1017,'pod_errors' => 0,'total' => 1415,'with_comments' => 13},'releases' => 6,'size' => {'packed' => 37269,'unpacked' => 144493},'testers' => {},'uses' => ['5.005','AutoLoader','Carp','IO::File','vars']},'Oak-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1307,'pod' => 816,'pod_errors' => 0,'total' => 2123,'with_comments' => 18},'releases' => 10,'requires' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'requires_module' => {'Error' => '0.15','IO' => '0','XML::Parser' => '0','XML::Writer' => '0'},'requires_recursive' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 11654,'unpacked' => 42229},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','Error','IO','Oak::AAS::Session','XML::Parser','XML::Writer','strict']},'Oak-AAS-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 209,'pod' => 153,'pod_errors' => 0,'total' => 362,'with_comments' => 0},'releases' => 1,'requires' => ['Error-0.15.tar.gz','Oak-1.7.tar.gz'],'requires_module' => {'Error' => '0.15','Oak::Object' => '0'},'requires_recursive' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 3275,'unpacked' => 8512},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Error','Oak::Object','strict']},'Oak-AAS-Service-DBI-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 206,'pod' => 66,'pod_errors' => 0,'total' => 272,'with_comments' => 1},'releases' => 1,'requires' => ['Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','Oak-AAS-1.7.tar.gz','Oak-IO-DBI-1.7.tar.gz'],'requires_module' => {'Digest::MD5' => '0','Error' => '0.15','Oak::AAS::Service' => '0','Oak::IO::DBI' => '0'},'requires_recursive' => ['DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','Oak-AAS-1.7.tar.gz','Oak-IO-DBI-1.7.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 2966,'unpacked' => 7612},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Digest::MD5','Error','Oak::AAS::Service','Oak::IO::DBI','strict']},'Oak-AAS-Service-DBI_N_PAM-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 253,'pod' => 95,'pod_errors' => 0,'total' => 348,'with_comments' => 1},'releases' => 1,'requires' => ['Authen-PAM-0.14.tar.gz','Oak-AAS-1.7.tar.gz','Oak-IO-DBI-1.7.tar.gz'],'requires_module' => {'Authen::PAM' => '0','Oak::AAS::Service' => '0','Oak::IO::DBI' => '0'},'requires_recursive' => ['Authen-PAM-0.14.tar.gz','DBI-1.37.tar.gz','Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','Oak-AAS-1.7.tar.gz','Oak-IO-DBI-1.7.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3467,'unpacked' => 9071},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Authen::PAM','Error','Oak::AAS::Service','Oak::IO::DBI','strict']},'Oak-Controller-EntityHelper-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 125,'pod_errors' => 0,'total' => 274,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2864,'unpacked' => 8745},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Exporter','strict']},'Oak-DBIEntity-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 563,'pod' => 221,'pod_errors' => 0,'total' => 784,'with_comments' => 3},'releases' => 1,'requires' => ['Error-0.15.tar.gz','Oak-1.7.tar.gz','Oak-Filer-DBI-1.7.tar.gz'],'requires_module' => {'Error' => '0.15','Oak::Filer::DBI' => '0','Oak::Persistent' => '0'},'requires_recursive' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','Oak-Filer-DBI-1.7.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 5929,'unpacked' => 20670},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Error','Oak::Filer::DBI','Oak::Persistent','strict']},'Oak-Filer-DBI-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 93,'pod_errors' => 0,'total' => 242,'with_comments' => 2},'releases' => 1,'requires' => ['Error-0.15.tar.gz','Oak-1.7.tar.gz'],'requires_module' => {'Error' => '0.15','Oak::Filer' => '0'},'requires_recursive' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 2250,'unpacked' => 5148},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Error','Oak::Filer','strict']},'Oak-Filer-XML-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 81,'pod_errors' => 0,'total' => 211,'with_comments' => 2},'releases' => 1,'requires' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'requires_module' => {'Error' => '0.15','IO' => '0','Oak::Filer' => '0','XML::Parser' => '0','XML::Writer' => '0'},'requires_recursive' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 3021,'unpacked' => 6319},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Error','IO','Oak::Filer','XML::Parser','XML::Writer']},'Oak-IO-Config-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 39,'pod_errors' => 0,'total' => 89,'with_comments' => 0},'releases' => 1,'requires' => ['Oak-1.7.tar.gz','Oak-Filer-XML-1.7.tar.gz'],'requires_module' => {'Oak::Component' => '0','Oak::Filer::XML' => '0'},'requires_recursive' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','Oak-Filer-XML-1.7.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 1999,'unpacked' => 3633},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Oak::Component','Oak::Filer::XML','strict']},'Oak-IO-DBI-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 187,'pod' => 113,'pod_errors' => 0,'total' => 300,'with_comments' => 3},'releases' => 1,'requires' => ['DBI-1.37.tar.gz','Error-0.15.tar.gz','Oak-1.7.tar.gz'],'requires_module' => {'DBI' => '1.35','Error' => '0.15','Oak::Component' => '0'},'requires_recursive' => ['DBI-1.37.tar.gz','Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 3001,'unpacked' => 6977},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['DBI','Error','Oak::Component','strict']},'Oak-IO-Log-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 25,'pod' => 35,'pod_errors' => 0,'total' => 60,'with_comments' => 0},'releases' => 1,'requires' => ['Oak-1.7.tar.gz'],'requires_module' => {'Oak::Component' => '0'},'requires_recursive' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 1870,'unpacked' => 3146},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Oak::Component','strict']},'Oak-IO-Log-Syslog-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 57,'pod_errors' => 0,'total' => 114,'with_comments' => 0},'releases' => 1,'requires' => ['Oak-IO-Log-1.7.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Oak::IO::Log' => '0','Sys::Syslog' => '0'},'requires_recursive' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','Oak-IO-Log-1.7.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2373,'unpacked' => 4373},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Oak::IO::Log','Sys::Syslog','strict']},'Oak-SOAP-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 103,'pod_errors' => 0,'total' => 263,'with_comments' => 0},'releases' => 1,'requires' => ['Error-0.15.tar.gz','Oak-1.7.tar.gz','SOAP-Lite-0.55.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Error' => '0.15','Oak::Application' => '0','Oak::Component' => '0','SOAP::Lite' => '0','SOAP::Transport::TCP' => '0','XML::Parser' => '0'},'requires_recursive' => ['Error-0.15.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','SOAP-Lite-0.55.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 3272,'unpacked' => 7257},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Error','Oak::Application','Oak::Component','SOAP::Lite','SOAP::Transport::TCP','strict']},'Oak-Web-1.7.tar.gz' => {'author' => 'DRUOSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4399,'pod' => 3937,'pod_errors' => 0,'total' => 8336,'with_comments' => 6},'releases' => 7,'requires' => ['CGI.pm-2.98.tar.gz','Oak-1.7.tar.gz','Time-Local-1.07.tar.gz'],'requires_module' => {'CGI' => '0','CGI::Cookie' => '0','Oak::Component' => '0','Oak::Object' => '0','Time::Local' => '0'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Oak-1.7.tar.gz','Time-Local-1.07.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 21891,'unpacked' => 146156},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['CGI::Cookie','Error','Oak::Application','Oak::Component','Oak::Object','Time::Local','strict']},'ObjStore-1.53.tar.gz' => {'author' => 'JPRIT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6014,'pod' => 1674,'pod_errors' => 1,'total' => 7688,'with_comments' => 446},'releases' => 49,'requires' => ['Test-1.24.tar.gz'],'requires_module' => {'Test' => '1.03'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 173782,'unpacked' => 518071},'testers' => {},'uses' => ['1','5.00404','5.00450','5.005','Carp','Config','Cwd','Devel::Symdump','DynaLoader','Event','Exporter','IO::File','IO::Handle','ObjStore','ObjStore::AV','ObjStore::AV::Set','ObjStore::Config','ObjStore::Database','ObjStore::HV','ObjStore::HV::Database','ObjStore::Job','ObjStore::Path::Ref','ObjStore::PathExam::Path','ObjStore::Peeker','ObjStore::Posh::Cursor','ObjStore::Process','ObjStore::REP','ObjStore::REP::FatTree','ObjStore::REP::ODI','ObjStore::REP::Splash','ObjStore::Serve','ObjStore::Serve::Notify','ObjStore::Set','ObjStore::SetEmulation','ObjStore::Table2','ObjStore::Table3','ObjStore::Table::Index','ObjStore::notify','Test','Time::Local','attrs','builtin','integer','strict','vars']},'ObjStore-1.59.tar.gz' => {'author' => 'JPRIT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6036,'pod' => 1674,'pod_errors' => 1,'total' => 7710,'with_comments' => 438},'releases' => 49,'requires' => ['Test-1.24.tar.gz'],'requires_module' => {'Test' => '1.03'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 169583,'unpacked' => 504017},'testers' => {},'uses' => ['5.00404','5.00450','5.005','Carp','Config','Cwd','Devel::Symdump','DynaLoader','Event','Exporter','IO::File','IO::Handle','List::Util','ObjStore::AV','ObjStore::Database','ObjStore::HV','ObjStore::REP::FatTree','ObjStore::SetEmulation','ObjStore::Table::Index','Test','Time::Local','attrs','integer','strict','vars']},'ObjStore-Lib-PDL-0.92.tar.gz' => {'author' => 'JPRIT','description' => 'Persistent PDL-compatible matrices','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 112,'pod' => 38,'pod_errors' => 0,'total' => 150,'with_comments' => 4},'releases' => 5,'requires' => ['ObjStore-1.59.tar.gz'],'requires_module' => {'ObjStore' => '1.52'},'requires_recursive' => ['File-Spec-0.82.tar.gz','ObjStore-1.59.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 10098,'unpacked' => 27009},'testers' => {'fail' => 1},'uses' => ['Carp','Config','DynaLoader','Exporter','ObjStore','ObjStore::Config','ObjStore::UNIVERSAL','PDL','PDL::Lite','strict','vars']},'ObjStore-REP-FatTree-1.01.tar.gz' => {'author' => 'JPRIT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 110,'pod' => 0,'pod_errors' => 0,'total' => 110,'with_comments' => 16},'releases' => 1,'requires' => ['ObjStore-1.59.tar.gz','Test-1.24.tar.gz','Tree-Fat-1.111.tar.gz'],'requires_module' => {'ObjStore' => '1.52','Test' => '1.03','Tree::Fat' => '1.1'},'requires_recursive' => ['File-Spec-0.82.tar.gz','ObjStore-1.59.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Tree-Fat-1.111.tar.gz'],'size' => {'packed' => 10152,'unpacked' => 40452},'testers' => {},'uses' => ['Carp','DynaLoader','ObjStore','ObjStore::AV','ObjStore::Config','ObjStore::PathExam::Path','ObjStore::REP','strict','vars']},'ObjStore-REP-HashRecord-0.96.tar.gz' => {'author' => 'JPRIT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 41,'pod' => 0,'pod_errors' => 0,'total' => 41,'with_comments' => 2},'releases' => 6,'requires' => ['ObjStore-1.59.tar.gz'],'requires_module' => {'ObjStore' => '1.52'},'requires_recursive' => ['File-Spec-0.82.tar.gz','ObjStore-1.59.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 9954,'unpacked' => 27742},'testers' => {},'uses' => ['Config','Exporter','ObjStore::MakeMaker','strict','vars']},'ObjStore-REP-Ring-0.02.tar.gz' => {'author' => 'JPRIT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 0,'pod_errors' => 0,'total' => 53,'with_comments' => 3},'releases' => 2,'requires' => ['ObjStore-1.59.tar.gz'],'requires_module' => {'ObjStore' => '1.47'},'requires_recursive' => ['File-Spec-0.82.tar.gz','ObjStore-1.59.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 9587,'unpacked' => 30141},'testers' => {},'uses' => ['Carp','DynaLoader','ObjStore','ObjStore::AV','strict','vars']},'Object-Interface-1.1.zip' => {'author' => 'GWELCH','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 169,'pod' => 35,'pod_errors' => 0,'total' => 204,'with_comments' => 49},'releases' => 2,'size' => {'packed' => 3501,'unpacked' => 7104},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['strict','vars','warnings']},'Object-Iterate-0.05.tar.gz' => {'author' => 'BDFOY','description' => 'iterators for objects that know the next element 	 =head1 SYNOPSIS 	use Object::Iterate qw(iterate igrep imap); 	 	iterate {...} $object; 	 	my @filtered = igrep {...} $object; 	 	my @transformed = imap {...} $object; 	 =head1 DESCRIPTION This module provides control structures to iterate through the elements of an object that cannot be represented as list of items all at once. Objects can represent a virtual collection that is beyond the reaches of foreach, map, and grep because they cannot turn themselves into a list. If the object can return the next object, it can use this module. Iterate assumes that the object responds to __next__ with the next element, and to __more__ with TRUE or FALSE if more elements remain to be processed. The __init__ method is called before the first iteration if it exists, and silently skipped otherwise. The control structure continues until the __more__ method returns FALSE (which does not mean that it visited all of the elements but that the object has decided to stop iterating). At the end of all iterations (when __more__ returns false), Object::Iterate calls __final__ if it exists, and skips it otherwise. Each control structure sets $_ to the current element, just like foreach, map, and grep. =head2 Mutable method names You do not really have to use the __next__, __more__, __init__, or __final__ names. They are just the defaults which Iterate stores in the package variables $Next, $More, $Init, and $Final respectively. This module does not export these variables, so you need to use the full package specification to change them (i.e. $Object::Iterate::$Next). If your object does not have the specified methods, the functions will die. You may want to wrap them in eval blocks. Since this module uses package variables to storethese methods names, the method names apply to every use of the functions no matter the object. You might want to local()-ise the variables for different objects. Before any control structure does its job, it checks the object to see if it can respond to these two methods, whatever you decide to call them, so your object must know that it can respond to these methods. AUTOLOADed methods cannot work since the module cannot know if they exist. =over 4 =item iterate BLOCK, OBJECT Applies BLOCK to each item returned by ODJECT->__next__. 	iterate { print "$_\\n" } $object; 	 This is the same thing as using a while loop, but iterate() stays out of your way. 	while( $object->__more__ ) 		{ 		local $_ = $object->__next__; 		 		...BLOCK... 		} =cut sub iterate (&$) 	{ 	my $sub = shift; 	my $object = shift; 	_check_object( $object ); 	 	while( $object->$More ) 		{ 		local $_; 		 		$_ = $object->$Next; 		 		$sub->(); 		} 	$object->$Final if $object->can( $Final ); 	} =item igrep BLOCK, OBJECT Applies BLOCK to each item returned by ODJECT->__next__, and returns all of the elements for which the BLOCK returns TRUE. 	my $output = igrep { print "$_\\n" } $object; 	 This is a grep for something that cannot be represented as a list at one time. 	while( $object->__more__ ) 		{ 		local $_ = $object->__next__; 		 		push @output, $_ if ...BLOCK...; 		} =item imap BLOCK, OBJECT Applies BLOCK to each item returned by ODJECT->__next__, and returns the combined lists that BLOCK returns for each of the elements. 	my $output = imap { print "$_\\n" } $object; 	 This is a map for something that cannot be represented as a list at one time. 	while( $object->$More ) 		{ 		local $_ = $object->__next__; 		 		push @output, ...BLOCK...; 		} =back','files' => ['Makefile.PL'],'lines' => {'nonpod' => 159,'pod' => 143,'pod_errors' => 0,'total' => 302,'with_comments' => 1},'releases' => 2,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Data-0.92.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','Test::Data' => '0','Test::Manifest' => '0.9','Test::More' => '0','Test::Pod' => '0','Test::Prereq' => '0.14'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Data-0.92.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4472,'unpacked' => 11685},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','strict','subs','vars']},'Object-Lexical-0.02.tar.gz' => {'author' => 'SWALTERS','description' => 'Syntactic Sugar for Easy Object Instance Data & More','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 241,'pod' => 173,'pod_errors' => 0,'total' => 414,'with_comments' => 40},'releases' => 2,'requires' => ['PadWalker-0.09.tar.gz'],'requires_module' => {'PadWalker' => '0.08'},'requires_recursive' => ['PadWalker-0.09.tar.gz'],'size' => {'packed' => 5972,'unpacked' => 15063},'testers' => {'pass' => 2},'uses' => ['5.008','PadWalker','strict','warnings']},'Object-MultiType-0.02.tar.gz' => {'author' => 'GMPASSOS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 318,'pod' => 403,'pod_errors' => 0,'total' => 721,'with_comments' => 45},'releases' => 2,'size' => {'packed' => 6368,'unpacked' => 21798},'testers' => {'pass' => 2},'uses' => ['5.006','strict']},'Object-PerlDesignPatterns-0.03.tar.gz' => {'author' => 'SWALTERS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14356,'pod' => 15559,'pod_errors' => 0,'total' => 29915,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 563497,'unpacked' => 2367791},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.006']},'Object-Persistence-0.92.tar.gz' => {'author' => 'VIPUL','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 452,'pod' => 175,'pod_errors' => 0,'total' => 627,'with_comments' => 56},'releases' => 9,'size' => {'packed' => 6635,'unpacked' => 18000},'testers' => {'pass' => 18},'uses' => ['Carp','Data::Dumper','Digest::MD5','Fcntl','vars']},'Object-Realize-Later-0.12.tar.gz' => {'author' => 'MARKOV','description' => 'Delay construction of real data until used','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 375,'pod' => 321,'pod_errors' => 2,'total' => 696,'with_comments' => 21},'releases' => 9,'requires' => ['Scalar-List-Utils-1.11.tar.gz'],'requires_module' => {'Scalar::Util' => 0},'requires_recursive' => ['Scalar-List-Utils-1.11.tar.gz'],'size' => {'packed' => 8685,'unpacked' => 24966},'testers' => {'pass' => 3},'uses' => ['Carp','Scalar::Util','strict','warnings']},'Object-Registrar-0.01.tar.gz' => {'author' => 'UARUN','description' => 'A global registry of objects that can be resolved by names','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 241,'pod' => 148,'pod_errors' => 0,'total' => 389,'with_comments' => 30},'releases' => 1,'requires' => ['Error-0.15.tar.gz'],'requires_module' => {'Error' => 0},'requires_recursive' => ['Error-0.15.tar.gz'],'size' => {'packed' => 4543,'unpacked' => 14374},'testers' => {'pass' => 8},'uses' => ['','Error','Error::Simple','strict','vars']},'Object-Transaction-1.01.tar.gz' => {'author' => 'MUIR','description' => 'Transactions on serialized HASH files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 809,'pod' => 390,'pod_errors' => 1,'total' => 1199,'with_comments' => 45},'releases' => 6,'requires' => ['File-Flock-101.060501.tar.gz','File-Sync-0.09.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'File::Flock' => '101.060501','File::Sync' => 0,'Storable' => 0},'requires_recursive' => ['File-Flock-101.060501.tar.gz','File-Spec-0.82.tar.gz','File-Sync-0.09.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 17919,'unpacked' => 62246},'testers' => {'pass' => 3},'uses' => ['$pkg','Carp','Exporter','File::Flock','File::Sync','ObjTransLclCnfg','POSIX','Storable','Time::HiRes','strict','vars']},'ObjectRowMap-0.11.tar.gz' => {'author' => 'CWELCH','description' => 'Simple perl object to DBI persistence engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 412,'pod' => 110,'pod_errors' => 2,'total' => 522,'with_comments' => 28},'releases' => 1,'size' => {'packed' => 8284,'unpacked' => 23640},'testers' => {'pass' => 1},'uses' => ['DBI','strict','vars','warnings']},'Ogg-Vorbis-Decoder-0.02.tar.gz' => {'author' => 'DBP','description' => 'An object-oriented Ogg Vorbis to decoder','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 417,'pod' => 108,'pod_errors' => 0,'total' => 525,'with_comments' => 14},'releases' => 2,'size' => {'packed' => 18453,'unpacked' => 40223},'testers' => {},'uses' => ['5.006','Carp','Inline','strict','warnings']},'Ogg-Vorbis-Header-0.03.tar.gz' => {'author' => 'DBP','description' => 'View Vorbis info & comments; edit comments','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 471,'pod' => 98,'pod_errors' => 0,'total' => 569,'with_comments' => 14},'releases' => 3,'size' => {'packed' => 32410,'unpacked' => 87647},'testers' => {},'uses' => ['5.006','Inline','strict','warnings']},'Ogg-Vorbis-Header-PurePerl-0.01.tar.gz' => {'author' => 'AMOLLOY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 547,'pod' => 90,'pod_errors' => 0,'total' => 637,'with_comments' => 73},'releases' => 1,'size' => {'packed' => 5529,'unpacked' => 17732},'testers' => {'pass' => 2},'uses' => ['5.005','strict','warnings']},'OpenCA-CRL-0.7.61.tar.gz' => {'author' => 'MADWOLF','description' => 'CRL Management module.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 303,'pod' => 130,'pod_errors' => 0,'total' => 433,'with_comments' => 55},'releases' => 2,'size' => {'packed' => 6070,'unpacked' => 18894},'testers' => {'pass' => 3},'uses' => ['strict']},'OpenCA-CRR-0.0.2.tar.gz' => {'author' => 'MADWOLF','description' => 'Perl extention to handle CRR objects.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 198,'pod' => 73,'pod_errors' => 0,'total' => 271,'with_comments' => 52},'releases' => 1,'size' => {'packed' => 3765,'unpacked' => 11502},'testers' => {'pass' => 6},'uses' => []},'OpenCA-Configuration-1.5.2a.tar.gz' => {'author' => 'MADWOLF','description' => 'Perl extention to deal with config files.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 265,'pod' => 21,'pod_errors' => 0,'total' => 286,'with_comments' => 81},'releases' => 1,'size' => {'packed' => 6739,'unpacked' => 18319},'testers' => {'pass' => 7},'uses' => []},'OpenCA-DB-1.02.tar.gz' => {'author' => 'MADWOLF','description' => 'Perl Certificates DB Extention.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1561,'pod' => 130,'pod_errors' => 0,'total' => 1691,'with_comments' => 278},'releases' => 3,'size' => {'packed' => 17798,'unpacked' => 64462},'testers' => {'fail' => 2},'uses' => ['AnyDBM_File','OpenCA::CRL','OpenCA::CRR','OpenCA::OpenSSL','OpenCA::REQ','OpenCA::Tools','OpenCA::X509','strict']},'OpenCA-DBIS-0.2.0.tar.gz' => {'author' => 'MADWOLF','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 723,'pod' => 84,'pod_errors' => 0,'total' => 807,'with_comments' => 166},'releases' => 1,'size' => {'packed' => 15140,'unpacked' => 47467},'testers' => {'fail' => 3},'uses' => ['DBI','English','IPC::SysV','OpenCA::CRL','OpenCA::CRR','OpenCA::OpenSSL','OpenCA::REQ','OpenCA::Tools','OpenCA::X509','POSIX','strict']},'OpenCA-OpenSSL-0.8.43.tar.gz' => {'author' => 'MADWOLF','description' => 'Perl Crypto Extention to OpenSSL','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1175,'pod' => 310,'pod_errors' => 0,'total' => 1485,'with_comments' => 187},'releases' => 3,'size' => {'packed' => 13214,'unpacked' => 53430},'testers' => {'fail' => 1,'pass' => 3},'uses' => []},'OpenCA-PKCS7-0.4.21a.tar.gz' => {'author' => 'MADWOLF','description' => 'Perl extension for basic handling PKCS#7 Signatures.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 328,'pod' => 84,'pod_errors' => 0,'total' => 412,'with_comments' => 58},'releases' => 2,'size' => {'packed' => 8342,'unpacked' => 24318},'testers' => {'fail' => 3},'uses' => ['strict']},'OpenCA-RBAC-0.2.0.tar.gz' => {'author' => 'MADWOLF','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 373,'pod' => 21,'pod_errors' => 0,'total' => 394,'with_comments' => 32},'releases' => 1,'size' => {'packed' => 4200,'unpacked' => 12017},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['OpenCA::DBI','OpenCA::DBIS','OpenCA::OpenSSL','OpenCA::Tools','OpenCA::X509','strict']},'OpenCA-REQ-0.7.35.tar.gz' => {'author' => 'MADWOLF','description' => 'Perl extension to easily manage Cert REQUESTs','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 522,'pod' => 33,'pod_errors' => 0,'total' => 555,'with_comments' => 70},'releases' => 2,'size' => {'packed' => 6772,'unpacked' => 21994},'testers' => {'pass' => 3},'uses' => ['strict']},'OpenCA-TRIStateCGI-1.5.4.tar.gz' => {'author' => 'MADWOLF','description' => 'Perl extension for implementing 3-state Input Objs.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 473,'pod' => 37,'pod_errors' => 0,'total' => 510,'with_comments' => 101},'releases' => 4,'size' => {'packed' => 6659,'unpacked' => 19370},'testers' => {'pass' => 3},'uses' => ['CGI']},'OpenCA-Tools-0.4.3a.tar.gz' => {'author' => 'MADWOLF','description' => 'Misc Utilities PERL Extention.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 314,'pod' => 149,'pod_errors' => 0,'total' => 463,'with_comments' => 63},'releases' => 2,'size' => {'packed' => 6017,'unpacked' => 17905},'testers' => {'pass' => 5},'uses' => ['strict']},'OpenCA-X509-0.9.8.tar.gz' => {'author' => 'MADWOLF','description' => 'Perl extension for basic handling x509 Certificates.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 292,'pod' => 138,'pod_errors' => 0,'total' => 430,'with_comments' => 63},'releases' => 2,'size' => {'packed' => 6022,'unpacked' => 17856},'testers' => {'fail' => 1},'uses' => ['strict']},'OpenFrame-2.12.tar.gz' => {'author' => 'JDUNCAN','description' => 'An Application Framework for Perl and the Web','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3660,'pod' => 1847,'pod_errors' => 0,'total' => 5507,'with_comments' => 108},'releases' => 15,'requires' => ['Cache-Cache-1.02.tar.gz','Chatbot-Eliza-1.04.tar.gz','Class-MethodMaker-1.10.tar.gz','Data-Denter-0.15.tar.gz','Data-Dumper-2.101.tar.gz','File-MMagic-1.19.tar.gz','File-Temp-0.12.tar.gz','Games-GuessWord-0.15.tar.gz','SOAP-Lite-0.55.tar.gz','Scalar-List-Utils-1.11.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Cache::Cache' => '0.01','Chatbot::Eliza' => '0.01','Class::MethodMaker' => '0.01','Data::Denter' => '0.01','Data::Dumper' => '0.01','File::MMagic' => '0.01','File::Temp' => '0.01','Games::GuessWord' => '0.15','LWP::UserAgent' => '0.01','SOAP::Lite' => '0.01','Scalar::Util' => '0.01','Template' => '0.01','Test::Simple' => '0.01','Time::HiRes' => '0.01','URI' => '0.01'},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','Chatbot-Eliza-1.04.tar.gz','Class-MethodMaker-1.10.tar.gz','Data-Denter-0.15.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Games-GuessWord-0.15.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','SOAP-Lite-0.55.tar.gz','Scalar-List-Utils-1.11.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','YAML-0.35.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 93604,'unpacked' => 296183},'testers' => {'fail' => 1,'pass' => 1,'tests' => '242'},'uses' => ['','Apache','Apache::Constants','Apache::Cookie','Apache::Request','CGI','CGI::Cookie','CGI::Fast','Cache::FileCache','Cache::MemoryCache','Carp','Chatbot::Eliza','Data::Denter','Data::Dumper','Digest::MD5','Exporter','Fcntl','File::MMagic','File::Spec','File::Temp','FileHandle','Games::GuessWord','HTTP::Daemon','HTTP::Status','IO::File','OpenFrame','OpenFrame::Request','OpenFrame::Response','OpenFrame::SlotStore','SOAP::Lite','SOAP::Transport::HTTP','Scalar::Util','Storable','Template','URI','XML::LibXML','XML::LibXSLT','constant','lib','strict','warnings::register']},'OpenFrame-3.02.tar.gz' => {'author' => 'JDUNCAN','description' => 'a framework for network enabled applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 870,'pod' => 407,'pod_errors' => 0,'total' => 1277,'with_comments' => 34},'releases' => 15,'requires' => ['CGI.pm-2.98.tar.gz','File-MMagic-1.19.tar.gz','IO-Null-0.02.tar.gz','Pipeline-3.04.tar.gz','Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'CGI::Cookie' => '0.01','File::MMagic' => '0.01','HTTP::Request' => '0.01','IO::Null' => '0.01','Pipeline' => '2.00','Test::More' => '0.01','Test::Simple' => '0.01'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Class-ISA-0.32.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-Null-0.02.tar.gz','MIME-Base64-2.20.tar.gz','Pipeline-3.04.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11197,'unpacked' => 37924},'testers' => {'pass' => 4},'uses' => ['','CGI','CGI::Cookie','Data::Dumper','Exporter','File::MMagic','File::Spec','File::Temp','FileHandle','HTTP::Headers','HTTP::Response','HTTP::Status','IO::Null','OpenFrame','OpenFrame::Argument::Blob','OpenFrame::Cookie','OpenFrame::Cookies','OpenFrame::Object','OpenFrame::Request','OpenFrame::Response','OpenFrame::Segment::HTTP::Response','Pipeline','Pipeline::Production','Pipeline::Segment','constant','strict','warnings::register']},'OpenFrame-3.03.tar.gz' => {'author' => 'JDUNCAN','description' => 'a framework for network enabled applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 869,'pod' => 407,'pod_errors' => 0,'total' => 1276,'with_comments' => 34},'releases' => 15,'requires' => ['CGI.pm-2.98.tar.gz','File-MMagic-1.19.tar.gz','File-Temp-0.12.tar.gz','IO-Null-0.02.tar.gz','Pipeline-3.04.tar.gz','Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'CGI::Cookie' => '0.01','File::MMagic' => '0.01','File::Temp' => '0.01','HTTP::Request' => '0.01','IO::Null' => '0.01','Pipeline' => '2.00','Test::More' => '0.01','Test::Simple' => '0.01'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Class-ISA-0.32.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-Null-0.02.tar.gz','MIME-Base64-2.20.tar.gz','Pipeline-3.04.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11104,'unpacked' => 37972},'testers' => {'pass' => 1},'uses' => ['','CGI','CGI::Cookie','Exporter','File::MMagic','File::Spec','File::Temp','FileHandle','HTTP::Headers','HTTP::Response','HTTP::Status','IO::Null','Pipeline','Pipeline::Production','Pipeline::Segment','constant','strict','warnings::register']},'OpenFrame-AppKit-3.03.tar.gz' => {'author' => 'JDUNCAN','description' => 'The OpenFrame AppKit','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 867,'pod' => 409,'pod_errors' => 0,'total' => 1276,'with_comments' => 51},'releases' => 5,'requires' => ['Cache-Cache-1.02.tar.gz','Games-GuessWord-0.15.tar.gz','OpenFrame-3.03.tar.gz','Pipeline-3.04.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Cache::Cache' => '0.01','Games::GuessWord' => '0.01','OpenFrame' => '3.00','Pipeline' => '3.01','Template' => '0.01','Test::More' => '0.01','Test::Simple' => '0.01'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Cache-Cache-1.02.tar.gz','Class-ISA-0.32.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Games-GuessWord-0.15.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-Null-0.02.tar.gz','MIME-Base64-2.20.tar.gz','OpenFrame-3.03.tar.gz','Pipeline-3.04.tar.gz','Scalar-List-Utils-1.11.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 29578,'unpacked' => 60985},'testers' => {'pass' => 1},'uses' => ['','Cache::FileCache','Digest::MD5','File::MMagic','File::Spec','Games::GuessWord','IO::File','OpenFrame::Cookie','OpenFrame::Cookies','OpenFrame::Response','Pipeline::Segment','Storable','Template','strict','warnings::register']},'OpenFrame-Segment-Apache-1.05.tar.gz' => {'author' => 'LBROCARD','description' => 'Apache segments for OpenFrame 3','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 432,'pod' => 160,'pod_errors' => 0,'total' => 592,'with_comments' => 13},'releases' => 6,'requires' => ['OpenFrame-AppKit-3.03.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '1.27','HTTP::Cookies' => '1.25','LWP::UserAgent' => '2.001','OpenFrame::AppKit' => '1.00','URI' => '1.21'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Cache-Cache-1.02.tar.gz','Class-ISA-0.32.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Games-GuessWord-0.15.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-Null-0.02.tar.gz','MIME-Base64-2.20.tar.gz','OpenFrame-3.03.tar.gz','OpenFrame-AppKit-3.03.tar.gz','Pipeline-3.04.tar.gz','Scalar-List-Utils-1.11.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 28192,'unpacked' => 71263},'testers' => {},'uses' => ['','Apache','Apache::Constants','Apache::Cookie','Apache::Request','Apache::URI','CGI::Cookie','File::MMagic','File::Spec','File::Spec::Functions','HTTP::Headers','HTTP::Response','HTTP::Status','IO::File','OpenFrame::Argument::Blob','OpenFrame::Cookies','OpenFrame::Object','OpenFrame::Request','OpenFrame::Response','OpenFrame::Segment::ContentLoader','OpenFrame::Segment::HTTP::Response','Pipeline','Pipeline::Segment','Scalar::Util','URI','strict','warnings']},'OpenFrame-Segment-Apache2-1.00.tar.gz' => {'author' => 'LBROCARD','description' => 'Apache2 segments for OpenFrame 3','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 365,'pod' => 134,'pod_errors' => 0,'total' => 499,'with_comments' => 40},'releases' => 1,'requires' => ['OpenFrame-AppKit-3.03.tar.gz','Template-Toolkit-2.10.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'HTTP::Cookies' => '1.25','LWP::UserAgent' => '2.001','OpenFrame::AppKit' => '1.00','Template' => '2.08','URI' => '1.21','mod_perl' => '1.9908'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Cache-Cache-1.02.tar.gz','Class-ISA-0.32.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Games-GuessWord-0.15.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-Null-0.02.tar.gz','MIME-Base64-2.20.tar.gz','OpenFrame-3.03.tar.gz','OpenFrame-AppKit-3.03.tar.gz','Pipeline-3.04.tar.gz','Scalar-List-Utils-1.11.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 34830,'unpacked' => 92086},'testers' => {'fail' => 1},'uses' => ['Apache2','Apache::Const','Apache::Response','Apache::URI','CGI::Cookie','File::MMagic','File::Spec::Functions','HTTP::Response','OpenFrame::AppKit','OpenFrame::Argument::Blob','OpenFrame::Cookies','OpenFrame::Example::Redirector','OpenFrame::Object','OpenFrame::Request','OpenFrame::Response','OpenFrame::Segment::ContentLoader','OpenFrame::Segment::HTTP::Response','Pipeline','Pipeline::Segment','Scalar::Util','URI','strict','warnings']},'OpenFrame-WebApp-0.02.tar.gz' => {'author' => 'SPURKIS','description' => 'OpenFrame tools for web applications.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1665,'pod' => 1515,'pod_errors' => 1,'total' => 3180,'with_comments' => 36},'releases' => 2,'requires' => ['Cache-Cache-1.02.tar.gz','OpenFrame-3.03.tar.gz','Pipeline-3.04.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz'],'requires_module' => {'Cache::Cache' => '1.01','OpenFrame' => '3.00','Pipeline' => '3.04','Test::More' => '0.01','Time::ParseDate' => '2003.0'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Cache-Cache-1.02.tar.gz','Class-ISA-0.32.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-Null-0.02.tar.gz','MIME-Base64-2.20.tar.gz','OpenFrame-3.03.tar.gz','Pipeline-3.04.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21498,'unpacked' => 103576},'testers' => {'pass' => 1},'uses' => ['','	','Cache::FileCache','Cache::MemoryCache','Digest::MD5','Error','Exporter','OpenFrame::Cookie','OpenFrame::Cookies','OpenFrame::Object','OpenFrame::Response','OpenFrame::WebApp::Error','OpenFrame::WebApp::Error::Abstract','OpenFrame::WebApp::Factory','OpenFrame::WebApp::Segment::Decline','OpenFrame::WebApp::Segment::Decline::SessionInStore','OpenFrame::WebApp::Segment::Decline::TemplateInStore','OpenFrame::WebApp::Segment::Decline::UserInSession','OpenFrame::WebApp::Segment::Decline::UserInStore','OpenFrame::WebApp::Segment::Session','OpenFrame::WebApp::Segment::Session::CookieLoader','OpenFrame::WebApp::Segment::Session::Loader','OpenFrame::WebApp::Segment::Session::Saver','OpenFrame::WebApp::Segment::Template','OpenFrame::WebApp::Segment::Template::Loader','OpenFrame::WebApp::Segment::User','OpenFrame::WebApp::Segment::User::EnvLoader','OpenFrame::WebApp::Segment::User::Loader','OpenFrame::WebApp::Segment::User::RequestLoader','OpenFrame::WebApp::Segment::User::SaveInSession','OpenFrame::WebApp::Session','OpenFrame::WebApp::Session::CacheBase','OpenFrame::WebApp::Session::Factory','OpenFrame::WebApp::Template','OpenFrame::WebApp::Template::Error','OpenFrame::WebApp::Template::Factory','OpenFrame::WebApp::User','OpenFrame::WebApp::User::Factory','Petal','Pipeline::Production','Pipeline::Segment','Template','Time::ParseDate','constant','strict','utf','warnings::register']},'OpenFrame-WebApp-0.03.tar.gz' => {'author' => 'SPURKIS','description' => 'OpenFrame tools for web applications.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1805,'pod' => 1635,'pod_errors' => 1,'total' => 3440,'with_comments' => 38},'releases' => 2,'requires' => ['Cache-Cache-1.02.tar.gz','OpenFrame-3.03.tar.gz','Pipeline-3.04.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz'],'requires_module' => {'Cache::Cache' => '1.01','OpenFrame' => '3.00','Pipeline' => '3.04','Test::More' => '0.01','Time::ParseDate' => '2003.0'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Cache-Cache-1.02.tar.gz','Class-ISA-0.32.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-Null-0.02.tar.gz','MIME-Base64-2.20.tar.gz','OpenFrame-3.03.tar.gz','Pipeline-3.04.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 23247,'unpacked' => 111693},'testers' => {'pass' => 1},'uses' => ['','	','Cache::FileCache','Cache::MemoryCache','Digest::MD5','Error','Exporter','MIME::Types','OpenFrame::Cookie','OpenFrame::Cookies','OpenFrame::Object','OpenFrame::Response','Petal','Pipeline::Production','Pipeline::Segment','Template','Time::ParseDate','constant','strict','utf','warnings::register']},'OpenGL-0.5.tar.gz' => {'author' => 'KJALB','description' => 'Interface to OpenGL drawing/imaging library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3373,'pod' => 97,'pod_errors' => 1,'total' => 3470,'with_comments' => 18},'releases' => 6,'size' => {'packed' => 237209,'unpacked' => 1412029},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter']},'OpenGuides-0.21.tar.gz' => {'author' => 'KAKE','description' => 'A complete web application for managing a collaboratively-written guide to a city or town.','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 877,'pod' => 532,'pod_errors' => 2,'total' => 1409,'with_comments' => 33},'releases' => 18,'requires' => ['Algorithm-Diff-1.15.tar.gz','CGI-Wiki-0.44.tar.gz','CGI-Wiki-Formatter-UseMod-0.05.tar.gz','CGI-Wiki-Plugin-Categoriser-0.02.tar.gz','CGI-Wiki-Plugin-GeoCache-0.11.tar.gz','CGI-Wiki-Plugin-Locator-UK-0.06.tar.gz','CGI-Wiki-Plugin-RSS-ModWiki-0.03.tar.gz','CGI.pm-2.98.tar.gz','Config-Tiny-1.tar.gz','DBD-Pg-1.22.tar.gz','Data-Dumper-2.101.tar.gz','Geography-NationalGrid-1.6.tar.gz','Module-Build-0.19.tar.gz','Parse-RecDescent-1.94.tar.gz','Search-InvertedIndex-1.12.tar.gz','Template-Toolkit-2.10.tar.gz','Test-MockObject-0.12.tar.gz','Time-Piece-1.08.tar.gz','URI-1.24.tar.gz','VCS-Lite-0.04.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Algorithm::Diff' => '0.13','CGI' => '2.76','CGI::Carp' => '0','CGI::Cookie' => '0','CGI::Wiki' => '0.44','CGI::Wiki::Formatter::UseMod' => '0.04','CGI::Wiki::Plugin::Categoriser' => '0','CGI::Wiki::Plugin::GeoCache' => '0','CGI::Wiki::Plugin::Locator::UK' => '0.06','CGI::Wiki::Plugin::RSS::ModWiki' => '0.02','Config::Tiny' => '0','DBD::Pg' => '0','Data::Dumper' => '0','File::Spec::Functions' => '0','Geography::NationalGrid' => '0','Module::Build' => '0.18','Parse::RecDescent' => '0','Search::InvertedIndex' => '0','Template' => '0','Test::MockObject' => '0.07','Time::Piece' => '0','URI::Escape' => '0','VCS::Lite' => '0.04'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','CGI-Wiki-0.44.tar.gz','CGI-Wiki-Formatter-UseMod-0.05.tar.gz','CGI-Wiki-Plugin-Categoriser-0.02.tar.gz','CGI-Wiki-Plugin-GeoCache-0.11.tar.gz','CGI-Wiki-Plugin-Locator-UK-0.06.tar.gz','CGI-Wiki-Plugin-RSS-ModWiki-0.03.tar.gz','CGI.pm-2.98.tar.gz','Class-Delegation-1.06.tar.gz','Class-NamedParms-1.04.tar.gz','Class-ParmList-1.03.tar.gz','Config-Tiny-1.tar.gz','DBD-Pg-1.22.tar.gz','DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','Geography-NationalGrid-1.6.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Module-Build-0.19.tar.gz','Parse-RecDescent-1.94.tar.gz','Search-InvertedIndex-1.12.tar.gz','Storable-2.07.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-MockObject-0.12.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-WikiFormat-0.6.tar.gz','Tie-DB_File-SplitHash-1.01.tar.gz','Tie-FileLRUCache-1.01.tar.gz','Time-Piece-1.08.tar.gz','URI-1.24.tar.gz','URI-Find-0.13.tar.gz','URI-Find-Delimited-0.02.tar.gz','VCS-Lite-0.04.tar.gz','XML-Parser-2.31.tar.gz','XML-RSS-1.02.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 43669,'unpacked' => 158907},'testers' => {},'uses' => ['Algorithm::Diff','CGI','CGI::Cookie','CGI::Wiki','CGI::Wiki::Formatter::UseMod','CGI::Wiki::Plugin','CGI::Wiki::Plugin::Locator::UK','CGI::Wiki::Plugin::RSS::ModWiki','CGI::Wiki::Search::SII','Carp','Geography::NationalGrid','Geography::NationalGrid::GB','Module::Build','Search::InvertedIndex::DB::DB_File_SplitHash','Template','Time::Piece','URI::Escape','VCS::Lite','strict','vars','warnings']},'OpenIndex-1.05.tar.gz' => {'author' => 'SANDERSON','description' => 'Apache modperl module to manage site files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3128,'pod' => 735,'pod_errors' => 0,'total' => 3863,'with_comments' => 204},'releases' => 6,'requires' => ['Apache-Icon-0.02.tar.gz','Apache-Language-0.14.tar.gz','File-NCopy0.32.tar.gz','HTML-Parser-3.28.tar.gz','Storable-2.07.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => 0,'Apache::Icon' => '0.02','Apache::Language' => 0,'Apache::Status' => 0,'File::NCopy' => 0,'HTML::HeadParser' => 0,'Storable' => 0},'requires_recursive' => ['Apache-Icon-0.02.tar.gz','Apache-Language-0.14.tar.gz','File-NCopy0.32.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','I18N-LangTags-0.28.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 49349,'unpacked' => 172593},'testers' => {'fail' => 4,'tests' => '2'},'uses' => ['Apache::Constants','Apache::Icon','Apache::Language','Apache::Log','Apache::ModuleConfig','Apache::Request','Apache::Util','Archive::Zip','Archive::Zip::Tree','Data::Dumper','Digest::MD5','Fcntl','File::Copy','File::NCopy','File::Path','HTML::HeadParser','Storable','constant','strict','subs','vars']},'OpenInteract-1.58.tar.gz' => {'author' => 'CWINTERS','description' => 'mod_perl handler to process all OpenInteract requests','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 12380,'pod' => 6548,'pod_errors' => 1,'total' => 18928,'with_comments' => 1399},'releases' => 23,'requires' => ['Apache-Session-1.54.tar.gz','Archive-Tar-1.03.tar.gz','Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Date-1.1.6.tar.gz','Class-Fields-0.16.tar.gz','Class-Singleton-1.03.tar.gz','Compress-Zlib-1.22.tar.gz','Digest-MD5-2.26.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Summary-0.017.tar.gz','Lingua-Stem-0.60.tar.gz','MIME-Lite-3.01.tar.gz','Mail-RFC822-Address-0.3.tar.gz','Mail-Sendmail-0.79.tar.gz','Pod-POM-0.15.tar.gz','PodParser-1.23.tar.gz','SPOPS-0.78.tar.gz','Template-Toolkit-2.10.tar.gz','libapreq-1.2.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache::Request' => '0.31','Apache::Session' => '1.5','Archive::Tar' => 0,'Carp::Assert' => 0,'Class::Accessor' => 0,'Class::Date' => 1,'Class::Fields' => 0,'Class::Singleton' => '1.03','Compress::Zlib' => '1.08','Digest::MD5' => 0,'File::Basename' => 0,'File::Copy' => 0,'File::MMagic' => 0,'File::Path' => 0,'File::Spec' => 0,'HTML::Entities' => '1.13','HTTP::Request' => 0,'Lingua::Stem' => 0,'MIME::Lite' => 2,'Mail::RFC822::Address' => '0.3','Mail::Sendmail' => '0.77','Pod::POM' => 0,'Pod::Usage' => '1.12','SPOPS' => '0.6','Template' => '2.04','Text::Sentence' => 0},'requires_recursive' => ['Apache-Session-1.54.tar.gz','Archive-Tar-1.03.tar.gz','Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Date-1.1.6.tar.gz','Class-Factory-1.00.tar.gz','Class-Fields-0.16.tar.gz','Class-ISA-0.32.tar.gz','Class-Singleton-1.03.tar.gz','Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','Devel-StackTrace-1.03.tar.gz','Digest-MD5-2.26.tar.gz','File-MMagic-1.19.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Summary-0.017.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','Mail-RFC822-Address-0.3.tar.gz','Mail-Sendmail-0.79.tar.gz','Pod-POM-0.15.tar.gz','PodParser-1.23.tar.gz','SPOPS-0.78.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Storable-2.07.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-German-0.03.tar.gz','Time-Piece-1.08.tar.gz','URI-1.24.tar.gz','libapreq-1.2.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 650419,'unpacked' => 1574012},'testers' => {},'uses' => ['','Apache','Apache::Constants','Apache::Cookie','Apache::DBI','Apache::Request','Apache::Session::File','Apache::Session::SQLite','Authen::SASL','CGI::Cookie','Cache::FileCache','Carp','Class::Date','Class::Singleton','Config','Cwd','Data::Dumper','Digest::MD5','Exporter','File::Basename','File::Copy','File::Path','File::Spec','Getopt::Long','HTML::Entities','Net::LDAP','OpenInteract::ResultsManage','SPOPS::ClassFactory','SPOPS::HashFile','SPOPS::SQLInterface','SPOPS::Secure','SPOPS::Utility','Template','Template::Context','Template::Plugin','Template::Provider','Text::Sentence','constant','strict','vars']},'OpenMosix-HA-0.542.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 798,'pod' => 260,'pod_errors' => 0,'total' => 1058,'with_comments' => 60},'releases' => 9,'requires' => ['Cluster-Init-0.213.tar.gz','Data-Dump-0.04.tar.gz','Event-0.87.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'Cluster::Init' => '0.203','Data::Dump' => 0,'Event' => 0,'Time::HiRes' => 0},'requires_recursive' => ['Cluster-Init-0.213.tar.gz','Data-Dump-0.04.tar.gz','Event-0.87.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Time-HiRes-1.49.tar.gz'],'testers' => {},'uses' => ['Cluster::Init','Data::Dump','Event','Time::HiRes','strict','vars']},'OpenOffice-Parse-SXC-0.03.tar.gz' => {'author' => 'DCLEE','description' => 'Perl extension for parsing OpenOffice SXC files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 473,'pod' => 176,'pod_errors' => 1,'total' => 649,'with_comments' => 98},'releases' => 3,'size' => {'packed' => 20215,'unpacked' => 47821},'testers' => {'fail' => 2,'pass' => 6,'tests' => '67'},'uses' => ['5.006','Exporter','IO::File','XML::Parser','strict','warnings']},'OpenPlugin-0.10.tar.gz' => {'author' => 'ERIC','description' => 'Plugin manager for web applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5913,'pod' => 3799,'pod_errors' => 0,'total' => 9712,'with_comments' => 569},'releases' => 2,'size' => {'packed' => 78463,'unpacked' => 313623},'testers' => {},'uses' => ['','5.004','Authen::PAM','Authen::Smb','CGI','CGI::Application','CGI::Cookie','CPAN','CPANPLUS::Backend','Carp','Class::Factory','Cwd','DBI','Data::Dumper','Exporter','ExtUtils::Manifest','File::Basename','File::Spec','Log::Log4perl','Net::LDAP','constant','strict','vars']},'OpenThought-0.64.tar.gz' => {'author' => 'ERIC','description' => 'Web Application Engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2447,'pod' => 1375,'pod_errors' => 0,'total' => 3822,'with_comments' => 233},'releases' => 2,'size' => {'packed' => 68200,'unpacked' => 213706},'testers' => {},'uses' => ['5.004','CPAN','CPANPLUS::Backend','Carp','Cwd','ExtUtils::Manifest','File::Basename','File::Spec','OpenPlugin::Application','lib','strict','vars']},'OpenThought-XML2Hash-0.56.tar.gz' => {'author' => 'ERIC','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 256,'pod' => 61,'pod_errors' => 0,'total' => 317,'with_comments' => 67},'releases' => 1,'size' => {'packed' => 11701,'unpacked' => 30708},'testers' => {'pass' => 2},'uses' => ['Exporter','strict']},'Openview-Message-0.02.tar.gz' => {'author' => 'LBAXTER','description' => 'OO interface to sending HP OpenView messages.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 180,'pod_errors' => 0,'total' => 418,'with_comments' => 19},'releases' => 2,'size' => {'packed' => 6497,'unpacked' => 19043},'testers' => {},'uses' => ['5.6.0','AutoLoader','Carp','DynaLoader','Exporter','constant','strict','warnings']},'Orac-1.1.11.tar.gz' => {'author' => 'ANDYDUNC','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 4394,'pod' => 196,'pod_errors' => 0,'total' => 4590,'with_comments' => 436},'releases' => 21,'size' => {'packed' => 105060,'unpacked' => 417063},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['DBI::Format','Data::Dumper','Exporter','Shell::Do','Shell::Grid','Tk','Tk::Pretty','Tk::Table','orac_Base','pretty','strict']},'Orac-alpha-1.2.6.tar.gz' => {'author' => 'ANDYDUNC','description' => 'the base class for all database modules of the Orac tool','files' => ['README'],'lines' => {'nonpod' => 21221,'pod' => 906,'pod_errors' => 0,'total' => 22127,'with_comments' => 1831},'releases' => 3,'size' => {'packed' => 364014,'unpacked' => 1477255},'testers' => {'pass' => 3},'uses' => ['5.004','Carp','DBD::Chart','DBI::Format','DDL::Oracle','Data::Dumper','Exporter','File::Basename','FileHandle','FindBin','Pod::Text','Text::Abbrev','Tk','Tk::Adjuster','Tk::Balloon','Tk::Derived','Tk::Dialog','Tk::FileSelect','Tk::IconList','Tk::JPEG','Tk::LabFrame','Tk::Listbox','Tk::Photo','Tk::Pretty','Tk::ProgressBar','Tk::Scale','Tk::Tiler','pretty','strict','vars']},'Oracle-Debug-1.45.tar.gz' => {'author' => 'RFOLEY','description' => 'perldb like interface to Oracle DBMS_DEBUG','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1451,'pod' => 465,'pod_errors' => 5,'total' => 1916,'with_comments' => 86},'releases' => 4,'size' => {'packed' => 1108599,'unpacked' => 1200271},'testers' => {'fail' => 1,'tests' => '12'},'uses' => ['5.008','Carp','DBI','Data::Dumper','Term::ReadKey','strict','vars','warnings']},'OurNet-1.60.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Interface to BBS-based groupware platforms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 132,'pod' => 186,'pod_errors' => 0,'total' => 318,'with_comments' => 4},'releases' => 4,'requires' => ['ExtUtils-AutoInstall-0.52.tar.gz','OurNet-BBS-1.65.tar.gz','OurNet-BBSAgent-1.61.tar.gz','OurNet-FuzzyIndex-1.60.tar.gz','OurNet-Query-1.56.tar.gz','ebx-0.87.tar.gz'],'requires_module' => {'ExtUtils::AutoInstall' => '0.01','OurNet::BBS' => '1.62','OurNet::BBSAgent' => '1.58','OurNet::BBSApp::Sync' => '0.87','OurNet::ChatBot' => '0.01','OurNet::FuzzyIndex' => '0.01','OurNet::Query' => '0.01','OurNet::Site' => '0.01','OurNet::Template' => '0.01'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Crypt-Rijndael-0.05.tar.gz','DB_File-1.806.tar.gz','Digest-MD5-2.26.tar.gz','ExtUtils-AutoInstall-0.52.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-Telnet-3.03.tar.gz','OurNet-BBS-1.65.tar.gz','OurNet-BBSAgent-1.61.tar.gz','OurNet-FuzzyIndex-1.60.tar.gz','OurNet-Query-1.56.tar.gz','ParallelUserAgent-2.56.tar.gz','Storable-2.07.tar.gz','Template-Toolkit-2.10.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','ebx-0.87.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5659,'unpacked' => 12197},'testers' => {'pass' => 1},'uses' => ['5.005','strict']},'OurNet-BBS-1.65.tar.gz' => {'author' => 'AUTRIJUS','description' => undef,'files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 9888,'pod' => 427,'pod_errors' => 0,'total' => 10315,'with_comments' => 780},'releases' => 14,'size' => {'packed' => 106321,'unpacked' => 420378},'testers' => {'pass' => 2},'uses' => ['$file','$self->{path}::$self->{dispatch}','$self::$_[1]::$_[2]','5.006','5.006001','B::Deparse','CPAN','CPANPLUS','CPANPLUS::Backend','Carp','Config','Cwd','Date::Format','Date::Parse','Digest::MD5','Encode','ExtUtils::MM_Unix','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Basename','File::Find','File::Path','File::Spec','FileHandle','Hook::LexWrap','IO::Socket::INET','LWP::Simple','Mail::Box::Manager','Module::Install','Module::Install::Base','Net::Daemon::Log','Net::FTP','Net::NNTP','OurNet::BBS::$backend::$mod','OurNet::BBSAgent','POSIX','RPC::PlClient','RPC::PlServer','RPC::PlServer::Comm','Safe','Socket','Sys::Hostname','YAML','bytes','constant','enum','fields','inc::Module::Install','open','overload','strict','subs','vars','warnings']},'OurNet-BBSAgent-1.61.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Scriptable telnet-based virtual users','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 537,'pod' => 246,'pod_errors' => 0,'total' => 783,'with_comments' => 28},'releases' => 11,'requires' => ['Net-Telnet-3.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Net::Telnet' => '3.02','Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Net-Telnet-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 21220,'unpacked' => 71871},'testers' => {'pass' => 2},'uses' => ['5.005','Carp','Net::Telnet','fields','strict','vars']},'OurNet-BBSApp-0.03.tar.gz' => {'author' => 'AUTRIJUS','description' => 'BBS Application Interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1087,'pod' => 65,'pod_errors' => 0,'total' => 1152,'with_comments' => 82},'releases' => 3,'requires' => ['HTML-FromText-1.005.tar.gz','OurNet-BBS-1.65.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'HTML::FromText' => '1.005','OurNet::BBS' => '1.5','XML::Simple' => '1.04'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-FromText-1.005.tar.gz','OurNet-BBS-1.65.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz'],'size' => {'packed' => 10902,'unpacked' => 37284},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['$handler','5.006','HTML::FromText','OurNet::BBS','OurNet::Template','Text::Wrap','XML::Simple','bytes','constant','fields','strict','vars']},'OurNet-FuzzyIndex-1.60.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Inverted search for double-byte characters','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 784,'pod' => 257,'pod_errors' => 0,'total' => 1041,'with_comments' => 28},'releases' => 7,'requires' => ['DB_File-1.806.tar.gz'],'requires_module' => {'DB_File' => '1.54'},'requires_recursive' => ['DB_File-1.806.tar.gz'],'size' => {'packed' => 58081,'unpacked' => 159136},'testers' => {'pass' => 3},'uses' => ['5.004','5.005','DB_File','DynaLoader','Exporter','constant','fields','integer','strict','vars']},'OurNet-Query-1.56.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Scriptable queries with template extraction','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1088,'pod' => 379,'pod_errors' => 0,'total' => 1467,'with_comments' => 92},'releases' => 3,'requires' => ['ParallelUserAgent-2.56.tar.gz','Template-Toolkit-2.10.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request::Common' => '1.16','LWP::Parallel' => '2.49','Template' => '2.00'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','ParallelUserAgent-2.56.tar.gz','Template-Toolkit-2.10.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 64309,'unpacked' => 251149},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['5.005','5.006','CGI','CGI::Cookie','Data::Dumper','HTML::Template','HTTP::Request::Common','LWP::Parallel::UserAgent','Safe','Template','Template::Parser','constant','fields','re','strict','vars','warnings']},'OutlineNumber-1.00.tar.gz' => {'author' => 'WILSONPM','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 95,'pod' => 34,'pod_errors' => 0,'total' => 129,'with_comments' => 11},'releases' => 2,'size' => {'packed' => 1798,'unpacked' => 3892},'testers' => {'fail' => 1},'uses' => ['5.000','strict','vars','warnings']},'Output-Buffer-0.1.tar.gz' => {'author' => 'ROBWALKER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 25,'pod_errors' => 0,'total' => 114,'with_comments' => 24},'releases' => 1,'requires' => ['Tie-FileHandle-Buffer-0.11.tar.gz'],'requires_module' => {'Tie::FileHandle::Buffer' => '0.11'},'requires_recursive' => ['Tie-FileHandle-Base-0.1.tar.gz','Tie-FileHandle-Buffer-0.11.tar.gz'],'size' => {'packed' => 2323,'unpacked' => 4524},'testers' => {'pass' => 3},'uses' => ['Carp','Symbol','Tie::FileHandle::Buffer','constant','strict','vars']},'Oxford-Calendar-1.5.tar.gz' => {'author' => 'SIMON','description' => 'Oxford calendar conversion routines','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 201,'pod' => 39,'pod_errors' => 0,'total' => 240,'with_comments' => 12},'releases' => 4,'requires' => ['Date-Calc-5.3.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Date::Calc' => 0,'LWP::Simple' => 0,'Text::Abbrev' => 0},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Date-Calc-5.3.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4635,'unpacked' => 10669},'testers' => {'pass' => 3},'uses' => ['Date::Calc','Text::Abbrev','strict']},'P2P-pDonkey-0.04.tar.gz' => {'author' => 'KLIMKIN','description' => 'Perl extension for handling *.met files of eDonkey peer2peer protocol.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3068,'pod' => 445,'pod_errors' => 0,'total' => 3513,'with_comments' => 293},'releases' => 4,'requires' => ['Data-Hexdumper-1.0.1.tar.gz','Digest-MD4-1.1.tar.gz','Tie-IxHash-1.21.tar.gz','Video-Info-0.993.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Hexdumper' => 1,'Digest::MD4' => '1.1','Tie::IxHash' => '1.21','Tie::RefHash' => '1.3','Video::Info' => 0},'requires_recursive' => ['Class-MakeMethods-1.006.tar.gz','Data-Dumper-2.101.tar.gz','Data-Hexdumper-1.0.1.tar.gz','Digest-MD4-1.1.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','MP3-Info-1.02.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Tie-IxHash-1.21.tar.gz','Video-Info-0.993.tar.gz','Video-OpenQuicktime-1.02.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 48930,'unpacked' => 180551},'testers' => {},'uses' => ['5.006','Carp','Data::Hexdumper','Digest::MD4','Exporter','File::Basename','File::Find','File::Glob','IO::Select','IO::Socket','P2P::pDonkey','POSIX','Socket','Tie::IxHash','Video::Info','constant','strict','vars','warnings']},'P4-1.2587.tar.gz' => {'author' => 'SMEE','description' => 'OO interface to the Perforce SCM System.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 380,'pod' => 210,'pod_errors' => 0,'total' => 590,'with_comments' => 86},'releases' => 5,'requires' => ['P4-Client-2.2596.tar.gz'],'requires_module' => {'P4::Client' => '1.1084'},'requires_recursive' => ['P4-Client-2.2596.tar.gz'],'size' => {'packed' => 7756,'unpacked' => 21407},'testers' => {},'uses' => ['AutoLoader','P4::Client','P4::UI','strict','vars']},'P4-C4-2.010.tar.gz' => {'author' => 'WSNYDER','description' => 'CVS Like wrapper for Perforce','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2026,'pod' => 543,'pod_errors' => 0,'total' => 2569,'with_comments' => 580},'releases' => 2,'requires' => ['P4-Client-2.2596.tar.gz'],'requires_module' => {'P4::Client' => '2.2279'},'requires_recursive' => ['P4-Client-2.2596.tar.gz'],'size' => {'packed' => 25306,'unpacked' => 104244},'testers' => {},'uses' => ['5.6.0','Carp','Cwd','Data::Dumper','DirHandle','Exporter','Fcntl','File::Find','IO::File','P4::Client','P4::UI','strict','vars']},'P4-Client-2.2596.tar.gz' => {'author' => 'SMEE','description' => 'Perl extension for the Perforce API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 375,'pod' => 310,'pod_errors' => 0,'total' => 685,'with_comments' => 73},'releases' => 10,'size' => {'packed' => 23878,'unpacked' => 84359},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'PAR-0.69.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Perl Archive Toolkit','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 2451,'pod' => 845,'pod_errors' => 0,'total' => 3296,'with_comments' => 145},'releases' => 38,'size' => {'packed' => 67141,'unpacked' => 248879},'testers' => {'fail' => 1,'pass' => 3,'tests' => '9'},'uses' => ['$self->{path}::$self->{dispatch}','5.006','Archive::Zip','CPAN','CPANPLUS','CPANPLUS::Backend','Carp','Compress::Zlib','Config','Cwd','DynaLoader','ExtUtils::MM_Unix','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Basename','File::Find','File::Glob','File::Path','File::Spec','File::Temp','FileHandle','LWP::Simple','Module::Install','Module::Install::Base','Net::FTP','Socket','YAML','inc::Module::Install','strict','vars','warnings']},'PAR-Dist-0.01.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Create and manipulate PAR distributions','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 906,'pod' => 89,'pod_errors' => 0,'total' => 995,'with_comments' => 48},'releases' => 1,'size' => {'packed' => 12304,'unpacked' => 35137},'testers' => {'pass' => 4},'uses' => ['$self->{path}::$self->{dispatch}','Archive::Zip','Config','Cwd','Exporter','ExtUtils::Install','ExtUtils::MM_Unix','File::Find','File::Path','File::Spec','File::Temp','LWP::Simple','Module::Install','Module::Install::Base','Module::Signature','YAML','inc::Module::Install','strict','vars']},'PApp-0.2.tar.gz' => {'author' => 'MLEHMANN','description' => 'multi-page-state-preserving web applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11887,'pod' => 3623,'pod_errors' => 2,'total' => 15510,'with_comments' => 696},'releases' => 13,'requires' => ['Compress-LZF-0.1045.tar.gz','Convert-Scalar-0.1e.tar.gz','Crypt-Twofish2-0.06.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Digest-SHA1-2.04.tar.gz','PApp-SQL-0.142.tar.gz','Storable-2.07.tar.gz','String-Similarity-0.02.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','XML-Sablotron-0.98.tar.gz'],'requires_module' => {'Compress::LZF' => '0.1045','Convert::Scalar' => '0.09','Crypt::Twofish2' => '0.01','DBD::mysql' => '2.04','DBI' => '1.3','Digest::SHA1' => '1.01','PApp::SQL' => '0.142','Storable' => '2.05','String::Similarity' => '0.02','URI' => '1.22','XML::Parser' => '2.31','XML::Sablotron' => '0.6'},'requires_recursive' => ['Compress-LZF-0.1045.tar.gz','Convert-Scalar-0.1e.tar.gz','Crypt-Twofish2-0.06.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','PApp-SQL-0.142.tar.gz','Storable-2.07.tar.gz','String-Similarity-0.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','XML-Sablotron-0.98.tar.gz'],'size' => {'packed' => 376554,'unpacked' => 1328470},'testers' => {},'uses' => ['5.006','Apache::Debug','AutoLoader','CGI::SpeedyCGI','Carp','Compress::LZF','Config','Convert::Scalar','Crypt::Twofish2','Data::Dumper','Digest::SHA1','Dumpvalue','DynaLoader','Errno','Exporter','Fcntl','File::Basename','File::Glob','HTML::Parser','LWP::Simple','List::Util','PApp::Config','PApp::SQL','POSIX','Socket','String::Similarity','Time::HiRes','URI','XML::LibXML','XML::LibXSLT','XML::Parser::Expat','XML::Sablotron','XSLoader','bytes','integer','strict','utf','vars']},'PApp-Hinduism-0.09.tar.gz' => {'author' => 'TBONE','description' => 'database driven Hindu course database.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 315,'pod' => 25,'pod_errors' => 0,'total' => 340,'with_comments' => 14},'releases' => 8,'requires' => ['DBIx-AnyDBD-2.01.tar.gz','DBIx-Connect-1.9.tar.gz','DBIx-Recordset-0.24.tar.gz','PApp-SQL-0.142.tar.gz','Text-Template-1.44.tar.gz'],'requires_module' => {'DBIx::AnyDBD' => 2,'DBIx::Connect' => '1.7','DBIx::Recordset' => '0.24','PApp::SQL' => '0.131','Text::Template' => '1.43'},'requires_recursive' => ['AppConfig-1.55.tar.gz','AppConfig-Std-1.07.tar.gz','DBI-1.37.tar.gz','DBIx-AnyDBD-2.01.tar.gz','DBIx-Connect-1.9.tar.gz','DBIx-Recordset-0.24.tar.gz','File-Spec-0.82.tar.gz','PApp-SQL-0.142.tar.gz','PodParser-1.23.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Template-1.44.tar.gz'],'size' => {'packed' => 10835,'unpacked' => 71118},'testers' => {},'uses' => ['5.005_62','DBIx::Recordset','Data::Dumper','Exporter','PApp::SQL','strict','warnings']},'PApp-Recipe-0.04.tar.gz' => {'author' => 'TBONE','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 38,'pod' => 28,'pod_errors' => 0,'total' => 66,'with_comments' => 8},'releases' => 3,'requires' => ['DBIx-AnyDBD-2.01.tar.gz','DBIx-Connect-1.9.tar.gz','DBIx-Recordset-0.24.tar.gz','PApp-SQL-0.142.tar.gz','Text-Template-1.44.tar.gz'],'requires_module' => {'DBIx::AnyDBD' => 2,'DBIx::Connect' => '1.7','DBIx::Recordset' => '0.24','PApp::SQL' => '0.131','Text::Template' => '1.43'},'requires_recursive' => ['AppConfig-1.55.tar.gz','AppConfig-Std-1.07.tar.gz','DBI-1.37.tar.gz','DBIx-AnyDBD-2.01.tar.gz','DBIx-Connect-1.9.tar.gz','DBIx-Recordset-0.24.tar.gz','File-Spec-0.82.tar.gz','PApp-SQL-0.142.tar.gz','PodParser-1.23.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Template-1.44.tar.gz'],'size' => {'packed' => 1765,'unpacked' => 2654},'testers' => {},'uses' => ['5.005_62','Exporter','strict','warnings']},'PApp-SQL-0.142.tar.gz' => {'author' => 'MLEHMANN','description' => 'easy yet fast and powerful dbi sql wrapper','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 226,'pod' => 230,'pod_errors' => 0,'total' => 456,'with_comments' => 9},'releases' => 9,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.13'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 11090,'unpacked' => 40087},'testers' => {'pass' => 5},'uses' => ['DynaLoader','Exporter']},'PBJ-JNI-0.1.tar.gz' => {'author' => 'PING','description' => 'Full access to and from Java virtual machine from Perl.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 264,'pod' => 124,'pod_errors' => 0,'total' => 388,'with_comments' => 48},'releases' => 1,'size' => {'packed' => 14749,'unpacked' => 85067},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'PCL-Simple-1.01.tar.gz' => {'author' => 'PRL','description' => 'Create PCL for printing plain text files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 326,'pod' => 86,'pod_errors' => 1,'total' => 412,'with_comments' => 29},'releases' => 2,'size' => {'packed' => 4862,'unpacked' => 19178},'testers' => {'pass' => 11},'uses' => ['Exporter','vars']},'PCX-Loader-0.50.zip' => {'author' => 'JBRYAN','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 82,'pod_errors' => 1,'total' => 249,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 3985,'unpacked' => 7865},'testers' => {'pass' => 3},'uses' => ['strict']},'PDF-110.tgz' => {'author' => 'ANTRO','description' => 'Library for PDF access and manipulation in Perl','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 655,'pod' => 386,'pod_errors' => 5,'total' => 1041,'with_comments' => 65},'releases' => 12,'size' => {'packed' => 14094,'unpacked' => 50962},'testers' => {'pass' => 4,'tests' => '0','unknown' => 6},'uses' => ['5.004','Carp','PDF::Core','PDF::Parse','vars']},'PDF-111.tgz' => {'author' => 'ANTRO','description' => 'parsing functions for PDF library','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1163,'pod' => 391,'pod_errors' => 2,'total' => 1554,'with_comments' => 227},'releases' => 12,'size' => {'packed' => 13222,'unpacked' => 44052},'testers' => {'pass' => 2,'tests' => '0','unknown' => 9},'uses' => ['5.005','Carp','strict','vars']},'PDF-API2-0.3r74.tar.gz' => {'author' => 'AREIBENS','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 93418,'pod' => 7189,'pod_errors' => 42,'total' => 100607,'with_comments' => 63981},'releases' => 1,'requires' => ['Compress-Zlib-1.22.tar.gz'],'requires_module' => {'Compress::Zlib' => '1.03'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz'],'size' => {'packed' => 965018,'unpacked' => 5330900},'testers' => {'pass' => 2},'uses' => ['$t','5.006','Compress::Zlib','Data::Dumper','Exporter','File::Find','File::Spec','FileHandle','IO::File','IO::Handle','Math::Trig','PDF::API2::CoreFont::defaultencodings','POSIX','WeakRef','Win32','Win32::Registry','XML::Parser::Expat','strict','vars']},'PDF-Create-0.01.tar.gz' => {'author' => 'FTASSIN','description' => 'create PDF files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1450,'pod' => 286,'pod_errors' => 0,'total' => 1736,'with_comments' => 117},'releases' => 1,'size' => {'packed' => 12561,'unpacked' => 64362},'testers' => {'pass' => 10},'uses' => ['Carp','Data::Dumper','Exporter','FileHandle','strict','vars']},'PDF-Extract-2.05.tar.gz' => {'author' => 'NSHARROCK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 479,'pod' => 288,'pod_errors' => 0,'total' => 767,'with_comments' => 25},'releases' => 6,'size' => {'packed' => 8777,'unpacked' => 28901},'testers' => {'pass' => 2},'uses' => ['strict','vars','warnings']},'PDF-Labels-0.01.tar.gz' => {'author' => 'JLAWRENC','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 531,'pod' => 14,'pod_errors' => 1,'total' => 545,'with_comments' => 3},'releases' => 2,'requires' => ['PDF-API2-0.3r74.tar.gz','Paper-Specs-0.05.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'PDF::API2' => 0,'Paper::Specs' => '0.03','Test::More' => 0},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','File-Spec-0.82.tar.gz','PDF-API2-0.3r74.tar.gz','Paper-Specs-0.05.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5584,'unpacked' => 23471},'testers' => {'pass' => 1},'uses' => ['PDF::API2','Paper::Specs','strict','vars']},'PDF-Labels-1.8.tar.gz' => {'author' => 'OWEN','description' => 'Produce sheets of mailing labels in PDF','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 184,'pod' => 118,'pod_errors' => 0,'total' => 302,'with_comments' => 28},'releases' => 2,'size' => {'packed' => 4058,'unpacked' => 14562},'testers' => {'fail' => 3,'pass' => 6},'uses' => ['Exporter','PDF::Create','strict','vars']},'PDF-Report-1.10.tar.gz' => {'author' => 'AORR','description' => 'Simple PDF document creation.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 809,'pod' => 194,'pod_errors' => 1,'total' => 1003,'with_comments' => 85},'releases' => 2,'requires' => ['PDF-API2-0.3r74.tar.gz','Text-Roman-3.01.tar.gz'],'requires_module' => {'PDF::API2' => '0.3a9','Text::Roman' => '3.01'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','PDF-API2-0.3r74.tar.gz','Text-Roman-3.01.tar.gz'],'size' => {'packed' => 13388,'unpacked' => 39944},'testers' => {'pass' => 3},'uses' => ['PDF::API2','Text::Roman','strict']},'PDF-Reuse-0.09.tar.gz' => {'author' => 'LARSLUND','description' => 'Reuse and mass produce PDF documents','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4286,'pod' => 626,'pod_errors' => 0,'total' => 4912,'with_comments' => 287},'releases' => 8,'requires' => ['Compress-Zlib-1.22.tar.gz','Digest-MD5-2.26.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'AutoLoader' => 0,'Carp' => 0,'Compress::Zlib' => 0,'Digest::MD5' => 0,'Exporter' => 0},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Digest-MD5-2.26.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 162513,'unpacked' => 322115},'testers' => {'pass' => 2},'uses' => ['5.006','AutoLoader','Digest::MD5','Exporter','autouse','constant','strict','warnings']},'PDF-Reuse-Barcode-0.02.tar.gz' => {'author' => 'LARSLUND','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 623,'pod' => 278,'pod_errors' => 0,'total' => 901,'with_comments' => 2},'releases' => 2,'requires' => ['Barcode-Code128-2.00.tar.gz','GD-Barcode-1.14.tar.gz','PDF-Reuse-0.09.tar.gz'],'requires_module' => {'Barcode::Code128' => 0,'GD::Barcode' => 0,'GD::Barcode::COOP2of5' => 0,'GD::Barcode::Code39' => 0,'GD::Barcode::EAN13' => 0,'GD::Barcode::EAN8' => 0,'GD::Barcode::IATA2of5' => 0,'GD::Barcode::ITF' => 0,'GD::Barcode::Industrial2of5' => 0,'GD::Barcode::Matrix2of5' => 0,'GD::Barcode::NW7' => 0,'GD::Barcode::UPCA' => 0,'GD::Barcode::UPCE' => 0,'PDF::Reuse' => 0},'requires_recursive' => ['Barcode-Code128-2.00.tar.gz','Compress-Zlib-1.22.tar.gz','Digest-MD5-2.26.tar.gz','GD-Barcode-1.14.tar.gz','PDF-Reuse-0.09.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6332,'unpacked' => 26753},'testers' => {'pass' => 2},'uses' => ['5.006','PDF::Reuse','strict','warnings']},'PDF-Reuse-Tutorial-0.04.tar.gz' => {'author' => 'LARSLUND','description' => 'How to produce documents with PDF::Reuse','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 330,'pod' => 1437,'pod_errors' => 0,'total' => 1767,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 22683,'unpacked' => 68018},'testers' => {'pass' => 2},'uses' => ['strict']},'PDF-Template-0.05.tar.gz' => {'author' => 'FERRANCE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1922,'pod' => 446,'pod_errors' => 7,'total' => 2368,'with_comments' => 231},'releases' => 5,'size' => {'packed' => 104445,'unpacked' => 210615},'testers' => {},'uses' => ['Data::Dumper','Exporter','Unicode::MapUTF8','XML::Parser','pdflib','strict','vars']},'PDFLib-0.12.tar.gz' => {'author' => 'MSERGEANT','description' => 'More OO interface to pdflib_pl.pm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1295,'pod' => 700,'pod_errors' => 0,'total' => 1995,'with_comments' => 40},'releases' => 12,'size' => {'packed' => 26909,'unpacked' => 61321},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['Carp','strict','vars']},'PDFREP-1.01.tar.gz' => {'author' => 'TWIBBLER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1401,'pod' => 0,'pod_errors' => 0,'total' => 1401,'with_comments' => 341},'releases' => 2,'size' => {'packed' => 14892,'unpacked' => 64185},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['CGI','English','Exporter','GD','strict','vars']},'PDL-1.99989.tar.gz' => {'author' => 'LUKKA','description' => '- support for PDL online documentation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 23160,'pod' => 6883,'pod_errors' => 3,'total' => 30043,'with_comments' => 2538},'releases' => 29,'requires' => ['ExtUtils-F77-1.14.tar.gz'],'requires_module' => {'ExtUtils::F77' => '1.03'},'requires_recursive' => ['ExtUtils-F77-1.14.tar.gz'],'size' => {'packed' => 662720,'unpacked' => 2137965},'testers' => {'fail' => 1},'uses' => ['$mod','5.002','AutoLoader','Benchmark','Carp','Config','Cwd','Data::Dumper','DynaLoader','English','Exporter','File::Basename','File::Find','FileHandle','Getopt::Long','IO::File','PDL','PDL::Basic','PDL::Core','PDL::Core::Dev','PDL::Dbg','PDL::Doc','PDL::Doc::Config','PDL::Doc::Perldl','PDL::Exporter','PDL::Graphics::OpenGL','PDL::Graphics::OpenGLQ','PDL::Graphics::PGPLOT','PDL::Graphics::TriD','PDL::Graphics::TriD::ArcBall','PDL::Graphics::TriD::Control3D','PDL::Graphics::TriD::Graph','PDL::Graphics::TriD::Image','PDL::Graphics::TriD::Logo','PDL::Graphics::TriD::Objects','PDL::Graphics::TriD::Quaternion','PDL::Graphics::TriD::Rout','PDL::Graphics::TriD::SimpleScaler','PDL::Graphics::TriD::TextObjects','PDL::Graphics::VRML','PDL::IO::Misc','PDL::IO::Pic','PDL::IO::Pnm','PDL::Image2D','PDL::ImageRGB','PDL::Lib::LLSQRout','PDL::Lite','PDL::LiteF','PDL::Ops','PDL::PP::CType','PDL::PP::Dims','PDL::PP::PDLCode','PDL::PP::PdlParObj','PDL::PP::Signature','PDL::PP::SymTab','PDL::PP::XS','PDL::Pod::Parser','PDL::Primitive','PDL::Quaternion','PDL::Slatec','PDL::Slices','PDL::Types','PGPLOT','POSIX','Pod::Functions','Pod::Text','SelfLoader','Tk','Tk::Dialog','Tk::Entry','UNIVERSAL','diagnostics','release','strict','vars','~.whereami_any().q~::Core::Dev']},'PDL-2.004.tar.gz' => {'author' => 'KGB','description' => '- support for PDL online documentation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 22518,'pod' => 7261,'pod_errors' => 3,'total' => 29779,'with_comments' => 2244},'releases' => 29,'requires' => ['ExtUtils-F77-1.14.tar.gz','File-Spec-0.82.tar.gz'],'requires_module' => {'ExtUtils::F77' => '1.1','File::Spec' => '0.6'},'requires_recursive' => ['ExtUtils-F77-1.14.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 752479,'unpacked' => 2758230},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['$mod','5.002','AutoLoader','Benchmark','Carp','Config','Data::Dumper','DynaLoader','English','Exporter','File::Basename','File::Find','File::Spec','FileHandle','IO::File','PDL','PDL::Basic','PDL::Complex','PDL::Core','PDL::Core::Dev','PDL::Dbg','PDL::Doc','PDL::Doc::Config','PDL::Doc::Perldl','PDL::Exporter','PDL::Graphics::LUT','PDL::Graphics::OpenGLQ','PDL::Graphics::PGPLOT','PDL::Graphics::TriD','PDL::Graphics::TriD::ArcBall','PDL::Graphics::TriD::Control3D','PDL::Graphics::TriD::Graph','PDL::Graphics::TriD::Objects','PDL::Graphics::TriD::Quaternion','PDL::Graphics::TriD::Rout','PDL::Graphics::TriD::SimpleScaler','PDL::Graphics::TriD::TextObjects','PDL::Graphics::VRML','PDL::IO::Misc','PDL::IO::Pic','PDL::IO::Pnm','PDL::Image2D','PDL::ImageRGB','PDL::Lib::LLSQRout','PDL::Lite','PDL::LiteF','PDL::Ops','PDL::Options','PDL::PP::CType','PDL::PP::Dims','PDL::PP::PDLCode','PDL::PP::PdlParObj','PDL::PP::Signature','PDL::PP::SymTab','PDL::PP::XS','PDL::Pod::Parser','PDL::Primitive','PDL::Quaternion','PDL::Slatec','PDL::Slices','PDL::Types','PDL::Version','PGPLOT','POSIX','Pod::Text','SelfLoader','Tk','Tk::Dialog','Tk::Entry','UNIVERSAL','diagnostics','release','strict','vars','~.whereami_any().q~::Core::Dev']},'PDL-2.1.1.tar.gz' => {'author' => 'KGB','description' => 'support for PDL online documentation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 25332,'pod' => 8291,'pod_errors' => 0,'total' => 33623,'with_comments' => 2682},'releases' => 29,'requires' => ['ExtUtils-F77-1.14.tar.gz','File-Spec-0.82.tar.gz'],'requires_module' => {'ExtUtils::F77' => '1.1','File::Spec' => '0.6'},'requires_recursive' => ['ExtUtils-F77-1.14.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 890419,'unpacked' => 3312893},'testers' => {'pass' => 1},'uses' => ['$mod','5.002','AutoLoader','Benchmark','Carp','Config','Data::Dumper','DynaLoader','English','Exporter','File::Basename','File::Find','File::Spec','FileHandle','IO::File','PDL','PDL::Basic','PDL::Complex','PDL::Core::Dev','PDL::Dbg','PDL::Doc','PDL::Doc::Config','PDL::Doc::Perldl','PDL::Exporter','PDL::Graphics::LUT','PDL::Graphics::OpenGL','PDL::Graphics::OpenGLQ','PDL::Graphics::PGPLOT','PDL::Graphics::TriD','PDL::Graphics::TriD::ArcBall','PDL::Graphics::TriD::Control3D','PDL::Graphics::TriD::Graph','PDL::Graphics::TriD::Image','PDL::Graphics::TriD::Logo','PDL::Graphics::TriD::Objects','PDL::Graphics::TriD::Quaternion','PDL::Graphics::TriD::Rout','PDL::Graphics::TriD::SimpleScaler','PDL::Graphics::TriD::TextObjects','PDL::Graphics::VRML','PDL::IO::Misc','PDL::IO::Pic','PDL::IO::Pnm','PDL::Image2D','PDL::ImageRGB','PDL::Interpolate','PDL::Lib::LLSQRout','PDL::Lite','PDL::LiteF','PDL::Ops','PDL::Options','PDL::PP::CType','PDL::PP::Dims','PDL::PP::PDLCode','PDL::PP::PdlParObj','PDL::PP::Signature','PDL::PP::SymTab','PDL::PP::XS','PDL::Pod::Parser','PDL::Primitive','PDL::Quaternion','PDL::Slatec','PDL::Slices','PDL::Types','PDL::Version','PGPLOT','POSIX','Pod::Text','SelfLoader','Tk','Tk::Dialog','Tk::Entry','UNIVERSAL','diagnostics','release','strict','vars','~.whereami_any().q~::Core::Dev']},'PDL-2.3.2.tar.gz' => {'author' => 'KGB','description' => 'support for PDL online documentation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 29774,'pod' => 10995,'pod_errors' => 4,'total' => 40769,'with_comments' => 3573},'releases' => 29,'size' => {'packed' => 1104107,'unpacked' => 3832199},'testers' => {'fail' => 3,'pass' => 1,'tests' => '580'},'uses' => ['$mod','5.002','AutoLoader','Benchmark','Carp','Config','Cwd','Data::Dumper','DynaLoader','English','Exporter','ExtUtils::Liblist','ExtUtils::MakeMaker','File::Basename','File::Find','File::Spec','FileHandle','Filter::Util::Call','FindBin','IO::File','Inline','PDL','PDL::Bad','PDL::Complex','PDL::Config','PDL::Core','PDL::Doc::Config','PDL::Graphics::OpenGL','PDL::Graphics::OpenGLQ','PDL::Graphics::State','PDL::Graphics::TriD','PDL::Graphics::TriD::GL','PDL::Graphics::TriD::GObject','PDL::Graphics::TriD::GObject_Lattice','PDL::Graphics::TriD::Image','PDL::Graphics::TriD::Logo','PDL::Graphics::TriD::Objects','PDL::Graphics::TriD::OneTransformation','PDL::Graphics::TriD::QuaterController','PDL::Graphics::TriD::Rout','PDL::Graphics::TriD::ScaleController','PDL::Graphics::TriD::TextObjects','PDL::Graphics::TriD::ViewPort','PDL::IO::Misc','PDL::IO::Pnm','PDL::Image2D','PDL::ImageRGB','PDL::Lib::LLSQRout','PDL::Lite','PDL::LiteF','PDL::NiceSlice','PDL::Ops','PDL::PP::CType','PDL::PP::Dims','PDL::PP::PDLCode','PDL::PP::SymTab','PDL::PP::XS','PDL::Primitive','PDL::Slatec','PDL::Slices','PDL::Types','PDL::Ufunc','PDL::Version','PGPLOT','POSIX','Pod::Text','SelfLoader','Text::Balanced','Tk','diagnostics','fields','release','strict','vars','~.whereami_any().q~::Core::Dev']},'PDL-2.3.4.tar.gz' => {'author' => 'CSOE','description' => 'support for PDL online documentation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 32043,'pod' => 11896,'pod_errors' => 2,'total' => 43939,'with_comments' => 3928},'releases' => 29,'size' => {'packed' => 1172903,'unpacked' => 4093701},'testers' => {'pass' => 2},'uses' => ['$mod','5.002','AutoLoader','Benchmark','Carp','Config','Cwd','Data::Dumper','DynaLoader','English','Exporter','ExtUtils::Liblist','ExtUtils::MakeMaker','File::Basename','File::Find','File::Spec','FileHandle','Filter::Util::Call','FindBin','IO::File','Inline','Inline::MakePdlppInstallable','PDL','PDL::Bad','PDL::Basic','PDL::Complex','PDL::Config','PDL::Core','PDL::Core::Dev','PDL::Dbg','PDL::Doc','PDL::Doc::Config','PDL::Exporter','PDL::Graphics::LUT','PDL::Graphics::OpenGL','PDL::Graphics::OpenGLQ','PDL::Graphics::PGPLOT','PDL::Graphics::PGPLOT::Window','PDL::Graphics::PGPLOTOptions','PDL::Graphics::State','PDL::Graphics::TriD','PDL::Graphics::TriD::ArcBall','PDL::Graphics::TriD::ButtonControl','PDL::Graphics::TriD::Contours','PDL::Graphics::TriD::Control3D','PDL::Graphics::TriD::GL','PDL::Graphics::TriD::GObject','PDL::Graphics::TriD::GObject_Lattice','PDL::Graphics::TriD::Graph','PDL::Graphics::TriD::Image','PDL::Graphics::TriD::Labels','PDL::Graphics::TriD::Logo','PDL::Graphics::TriD::Object','PDL::Graphics::TriD::Objects','PDL::Graphics::TriD::OneTransformation','PDL::Graphics::TriD::QuaterController','PDL::Graphics::TriD::Quaternion','PDL::Graphics::TriD::Rout','PDL::Graphics::TriD::ScaleController','PDL::Graphics::TriD::SimpleScaler','PDL::Graphics::TriD::TextObjects','PDL::Graphics::TriD::Tk','PDL::Graphics::TriD::ViewPort','PDL::Graphics::TriD::Window','PDL::Graphics::VRML','PDL::IO::Misc','PDL::IO::Pic','PDL::IO::Pnm','PDL::Image2D','PDL::ImageRGB','PDL::Interpolate','PDL::Lib::LLSQRout','PDL::Lite','PDL::LiteF','PDL::Lvalue','PDL::Math','PDL::NiceSlice','PDL::Ops','PDL::Options','PDL::PP::CType','PDL::PP::Dims','PDL::PP::PDLCode','PDL::PP::PdlParObj','PDL::PP::SymTab','PDL::PP::XS','PDL::Pod::Parser','PDL::Primitive','PDL::Slatec','PDL::Slices','PDL::Types','PDL::Ufunc','PDL::Version','PGPLOT','POSIX','Pod::Text','SelfLoader','Text::Balanced','Tk','diagnostics','fields','release','strict','vars','~.whereami_any().q~::Core::Dev']},'PDL-2.4.0.tar.gz' => {'author' => 'CSOE','description' => 'support for PDL online documentation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 37559,'pod' => 13251,'pod_errors' => 1,'total' => 50810,'with_comments' => 4555},'releases' => 29,'size' => {'packed' => 1758829,'unpacked' => 5389363},'testers' => {'pass' => 1},'uses' => ['$mod','5.002','AutoLoader','Benchmark','Carp','Config','Convert::UU','Cwd','Data::Dumper','DynaLoader','English','Exporter','ExtUtils::Liblist','ExtUtils::MakeMaker','File::Basename','File::Find','File::Spec','FileHandle','Filter::Util::Call','FindBin','IO::File','Inline','PDL::Bad','PDL::Basic','PDL::Complex','PDL::Config','PDL::Core','PDL::Core::Dev','PDL::Dbg','PDL::Doc','PDL::Doc::Config','PDL::Exporter','PDL::Graphics::LUT','PDL::Graphics::OpenGL','PDL::Graphics::OpenGLQ','PDL::Graphics::PGPLOT','PDL::Graphics::PGPLOT::Window','PDL::Graphics::PGPLOTOptions','PDL::Graphics::TriD','PDL::Graphics::TriD::ArcBall','PDL::Graphics::TriD::ButtonControl','PDL::Graphics::TriD::Contours','PDL::Graphics::TriD::Control3D','PDL::Graphics::TriD::GL','PDL::Graphics::TriD::GObject','PDL::Graphics::TriD::GObject_Lattice','PDL::Graphics::TriD::Graph','PDL::Graphics::TriD::Image','PDL::Graphics::TriD::Labels','PDL::Graphics::TriD::Logo','PDL::Graphics::TriD::Object','PDL::Graphics::TriD::Objects','PDL::Graphics::TriD::OneTransformation','PDL::Graphics::TriD::QuaterController','PDL::Graphics::TriD::Quaternion','PDL::Graphics::TriD::Rout','PDL::Graphics::TriD::ScaleController','PDL::Graphics::TriD::SimpleScaler','PDL::Graphics::TriD::TextObjects','PDL::Graphics::TriD::Tk','PDL::Graphics::TriD::ViewPort','PDL::Graphics::TriD::Window','PDL::Graphics::VRML','PDL::IO::Misc','PDL::IO::Pic','PDL::IO::Pnm','PDL::Image2D','PDL::ImageRGB','PDL::Interpolate','PDL::Lib::LLSQRout','PDL::Lite','PDL::LiteF','PDL::Lvalue','PDL::Math','PDL::MatrixOps','PDL::NiceSlice','PDL::Ops','PDL::Options','PDL::PP::CType','PDL::PP::Dims','PDL::PP::PDLCode','PDL::PP::PdlParObj','PDL::PP::SymTab','PDL::PP::XS','PDL::Pod::Parser','PDL::Primitive','PDL::Slatec','PDL::Slices','PDL::Types','PDL::Ufunc','PDL::Version','PGPLOT','POSIX','Pod::Text','SelfLoader','Text::Balanced','Tk','diagnostics','fields','release','strict','vars','~.whereami_any().q~::Core::Dev']},'PDL-Audio-0.4.tar.gz' => {'author' => 'MLEHMANN','description' => 'Over 1200 musical scales in PDL format.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2372,'pod' => 118,'pod_errors' => 0,'total' => 2490,'with_comments' => 1149},'releases' => 1,'size' => {'packed' => 238167,'unpacked' => 971707},'testers' => {'fail' => 1},'uses' => ['Exporter','PDL::Lite']},'PDL-Graphics-PLplot-0.18.tar.gz' => {'author' => 'DHUNT','description' => 'Object-oriented interface from perl/PDL to the PLPLOT plotting library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 807,'pod' => 417,'pod_errors' => 0,'total' => 1224,'with_comments' => 132},'releases' => 4,'size' => {'packed' => 18678,'unpacked' => 61774},'testers' => {},'uses' => ['PDL::Graphics::PLplot','vars']},'PDL-IO-Grib-2.0.tar.gz' => {'author' => 'JEDWARDS','description' => 'Grib file utilities for perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1322,'pod' => 165,'pod_errors' => 0,'total' => 1487,'with_comments' => 103},'releases' => 5,'size' => {'packed' => 19457,'unpacked' => 60198},'testers' => {'fail' => 1},'uses' => ['Config','Data::Dumper','FileHandle','PDL','PDL::IO::FlexRaw','PDL::IO::Grib::Gribtables','PDL::IO::Grib::Wgrib','PDL::IO::Misc','fields','strict','vars','warnings']},'PDL-IO-HDF5-0.3.tar.gz' => {'author' => 'CERNEY','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1535,'pod' => 429,'pod_errors' => 0,'total' => 1964,'with_comments' => 230},'releases' => 3,'size' => {'packed' => 28886,'unpacked' => 129557},'testers' => {},'uses' => ['Carp','IO::File','Tk','Tk::Tree']},'PDL-NamedArgs-0.12.tar.gz' => {'author' => 'CAVANAUGH','description' => 'Perl extension for named & unamed arguments with optional default values','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 100,'pod' => 88,'pod_errors' => 0,'total' => 188,'with_comments' => 21},'releases' => 2,'size' => {'packed' => 3740,'unpacked' => 8718},'testers' => {'pass' => 3},'uses' => ['5.006','Exporter','strict','warnings']},'PDL-NetCDF-0.81.tar.gz' => {'author' => 'DHUNT','description' => 'Reads/Writes NetCDF files from/to PDL objs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1085,'pod' => 332,'pod_errors' => 0,'total' => 1417,'with_comments' => 205},'releases' => 20,'size' => {'packed' => 25314,'unpacked' => 112687},'testers' => {'fail' => 1},'uses' => ['DynaLoader','PDL::Core','PDL::Exporter']},'PDL-NiceSlice-0.991.tar.gz' => {'author' => 'CSOE','description' => 'a nicer slicing syntax for PDL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 569,'pod' => 509,'pod_errors' => 0,'total' => 1078,'with_comments' => 108},'releases' => 7,'requires' => ['Filter-1.29.tar.gz','PDL-2.4.0.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Filter::Util::Call' => 0,'PDL' => '2.3','Text::Balanced' => 0},'requires_recursive' => ['Filter-1.29.tar.gz','PDL-2.4.0.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 23312,'unpacked' => 64173},'testers' => {'fail' => 3,'pass' => 3},'uses' => ['Filter::Util::Call','PDL::Version','Text::Balanced']},'PDL-Parallel-MPI-0.02.tar.gz' => {'author' => 'DARIN','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 790,'pod' => 362,'pod_errors' => 0,'total' => 1152,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 132903,'unpacked' => 440519},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','PDL','PDL::Slatec','strict','vars']},'PDL_IO_HDF-1.0.tar.gz' => {'author' => 'OARCHER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 188,'pod' => 50,'pod_errors' => 0,'total' => 238,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 80356,'unpacked' => 659315},'testers' => {},'uses' => ['PDL::Basic','PDL::IO::HDF::SD','PDL::IO::HDF::VS','PDL::Primitive']},'PException-2.4.tar.gz' => {'author' => 'MOUNS','description' => 'Exception manager','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 308,'pod' => 159,'pod_errors' => 0,'total' => 467,'with_comments' => 56},'releases' => 3,'size' => {'packed' => 10856,'unpacked' => 31929},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'PGForth1.0.tar.gz' => {'author' => 'PETERGAL','description' => undef,'files' => [],'lines' => {'nonpod' => 418,'pod' => 0,'pod_errors' => 0,'total' => 418,'with_comments' => 118},'releases' => 1,'size' => {'packed' => 3446,'unpacked' => 10059},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['5','strict']},'PGP-0.3a.tar.gz' => {'author' => 'GEHIC','description' => 'perl module to work with PGP messages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 845,'pod' => 273,'pod_errors' => 1,'total' => 1118,'with_comments' => 71},'releases' => 1,'size' => {'packed' => 10910,'unpacked' => 29796},'testers' => {'fail' => 2},'uses' => ['5.000','Carp','Data::Dumper','Dumper','English','File::Basename','IPC::Open3','Time::Local']},'PGP-FindKey-0.02.tar.gz' => {'author' => 'CHRIS','description' => 'Perl interface to finding PGP keyids from e-mail addresses.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 47,'pod_errors' => 0,'total' => 132,'with_comments' => 17},'releases' => 2,'requires' => ['URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request' => 0,'LWP::UserAgent' => 0,'URI::Escape' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3069,'unpacked' => 5615},'testers' => {'pass' => 3},'uses' => ['HTTP::Request','LWP::UserAgent','URI::Escape','strict','vars']},'PGP-Mail-1.5.tar.gz' => {'author' => 'MATTBM','description' => 'Signature checking for PGP-signed mail messages','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 259,'pod' => 47,'pod_errors' => 0,'total' => 306,'with_comments' => 2},'releases' => 3,'requires' => ['GnuPG-Interface-0.33.tar.gz','MIME-tools-5.411a.tar.gz'],'requires_module' => {'GnuPG::Interface' => 0,'MIME::Tools' => 0},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','File-Spec-0.82.tar.gz','GnuPG-Interface-0.33.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','MailTools-1.58.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7444,'unpacked' => 14320},'testers' => {'fail' => 1,'pass' => 1,'tests' => '14'},'uses' => ['Fcntl','GnuPG::Interface','IO::Handle','MIME::Parser','strict','vars']},'PGP-Sign-0.17.tar.gz' => {'author' => 'RRA','description' => 'Create/verify PGP/GnuPG signatures, securely','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2,'pod' => 0,'pod_errors' => 0,'total' => 2,'with_comments' => 0},'releases' => 11,'size' => {'packed' => 29219,'unpacked' => 77846},'testers' => {'pass' => 3},'uses' => []},'PGPLOT-2.18.tar.gz' => {'author' => 'KGB','description' => 'PGPLOT plotting library - scientific graphs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 88,'pod' => 151,'pod_errors' => 0,'total' => 239,'with_comments' => 6},'releases' => 18,'requires' => ['ExtUtils-F77-1.14.tar.gz'],'requires_module' => {'ExtUtils::F77' => '1.13'},'requires_recursive' => ['ExtUtils-F77-1.14.tar.gz'],'size' => {'packed' => 48632,'unpacked' => 124513},'testers' => {'pass' => 3},'uses' => ['DynaLoader','Exporter']},'PHP-Include-0.05.tar.gz' => {'author' => 'ESUMMERS','description' => 'Include PHP files from Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 156,'pod' => 124,'pod_errors' => 0,'total' => 280,'with_comments' => 4},'releases' => 3,'requires' => ['Filter-Simple-0.78.tar.gz','Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Filter::Simple' => '0.78','Parse::RecDescent' => 1},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 4349,'unpacked' => 10394},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Dumper','Filter::Simple','Parse::RecDescent','strict','warnings']},'PHP-Session-0.20.tar.gz' => {'author' => 'MIYAGAWA','description' => 'read / write PHP session files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 520,'pod' => 137,'pod_errors' => 0,'total' => 657,'with_comments' => 33},'releases' => 20,'requires' => ['Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'requires_module' => {'Test::More' => '0.32','UNIVERSAL::require' => '0.03'},'requires_recursive' => ['Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'size' => {'packed' => 7955,'unpacked' => 26407},'testers' => {'pass' => 3},'uses' => ['Carp','Fcntl','File::Spec','FileHandle','UNIVERSAL::require','strict','vars']},'PLP-3.18.tar.gz' => {'author' => 'JUERD','description' => 'Perl in HTML pages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 947,'pod' => 506,'pod_errors' => 0,'total' => 1453,'with_comments' => 120},'releases' => 8,'size' => {'packed' => 18788,'unpacked' => 53108},'testers' => {'pass' => 3},'uses' => ['5.006','Apache::Constants','Carp','Exporter','Fcntl','File::Spec','Safe','strict','vars']},'PML-0.4.1.tar.gz' => {'author' => 'PJONES','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4024,'pod' => 365,'pod_errors' => 0,'total' => 4389,'with_comments' => 1744},'releases' => 2,'size' => {'packed' => 52942,'unpacked' => 213547},'testers' => {'pass' => 7},'uses' => ['Apache::Constants','CGI','Carp','Cwd','File::Basename','LWP','LWP::UserAgent','Storable','Text::Wrap','constant','strict','vars']},'PNGgraph-1.11.tar.gz' => {'author' => 'SBONDS','description' => 'Graph Plotting Module for Perl 5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3230,'pod' => 518,'pod_errors' => 0,'total' => 3748,'with_comments' => 552},'releases' => 4,'requires' => ['GD-2.07.tar.gz'],'requires_module' => {'GD' => '1.20'},'requires_recursive' => ['GD-2.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 106095,'unpacked' => 228402},'testers' => {'pass' => 2},'uses' => ['5.004','Exporter','GD','strict','vars']},'POE-0.26.tar.gz' => {'author' => 'RCAPUTO','description' => 'multitasking and networking framework for perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 20909,'pod' => 6967,'pod_errors' => 0,'total' => 27876,'with_comments' => 3080},'releases' => 27,'size' => {'packed' => 326790,'unpacked' => 1286229},'testers' => {'pass' => 6},'uses' => ['$p','$q','5.004','Benchmark','CPAN','CPANPLUS::Backend','Carp','Compress::Zlib','Config','Curses','Cwd','Devel::CoreStack','Exporter','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Path','File::Spec','Filter::Util::Call','HTTP::Date','HTTP::Request','HTTP::Response','HTTP::Status','IO::Handle','IO::Poll','IO::Pty','IO::Socket','POSIX','Socket','Symbol','Sys::Hostname','Term::Cap','Term::ReadKey','Test::Harness::Assert','Test::Harness::Iterator','Test::Harness::Straps','Time::HiRes','URI','lib','protocols','strict','vars','vmsish']},'POE-Component-CD-Detect-1.1.tar.gz' => {'author' => 'ECALDER','description' => 'Detects CD insertions and provides TOC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 265,'pod' => 74,'pod_errors' => 1,'total' => 339,'with_comments' => 45},'releases' => 1,'requires' => ['POE-0.26.tar.gz'],'requires_module' => {'POE' => '0.22'},'requires_recursive' => ['POE-0.26.tar.gz'],'size' => {'packed' => 5166,'unpacked' => 11361},'testers' => {'fail' => 2},'uses' => ['Carp','Fcntl','IO::Socket','POE','strict','vars','warnings']},'POE-Component-CD-Rip-1.2.tar.gz' => {'author' => 'ECALDER','description' => 'POE Component for running cdparanoia, a CD ripper.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 92,'pod_errors' => 1,'total' => 211,'with_comments' => 13},'releases' => 1,'requires' => ['POE-0.26.tar.gz'],'requires_module' => {'POE' => '0.22'},'requires_recursive' => ['POE-0.26.tar.gz'],'size' => {'packed' => 3603,'unpacked' => 7390},'testers' => {'pass' => 2},'uses' => ['Carp','POE','strict','vars','warnings']},'POE-Component-Child-1.31.tar.gz' => {'author' => 'ECALDER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 323,'pod' => 181,'pod_errors' => 1,'total' => 504,'with_comments' => 42},'releases' => 3,'requires' => ['POE-0.26.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'POE' => '0.23','Test::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','POE-0.26.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 16807,'unpacked' => 45307},'testers' => {'fail' => 1},'uses' => ['Carp','Cwd','POE','strict','vars','warnings']},'POE-Component-Client-DNS-0.95.tar.gz' => {'author' => 'RCAPUTO','description' => 'a DNS client component','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 198,'pod' => 128,'pod_errors' => 0,'total' => 326,'with_comments' => 32},'releases' => 4,'requires' => ['Net-DNS-0.38.tar.gz','POE-0.26.tar.gz'],'requires_module' => {'Net::DNS' => '0.12','POE' => '0.11'},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','POE-0.26.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7807,'unpacked' => 21250},'testers' => {},'uses' => ['Carp','Net::DNS','POE::Session','Socket','strict','vars']},'POE-Component-Client-Dashboard-0.02.tar.gz' => {'author' => 'MARTIJN','description' => '- Dashboard cluepacket component','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 366,'pod' => 76,'pod_errors' => 0,'total' => 442,'with_comments' => 47},'releases' => 1,'requires' => ['POE-0.26.tar.gz','POE-Component-Client-DNS-0.95.tar.gz'],'requires_module' => {'POE' => '0.25','POE::Component::Client::DNS' => 0},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','POE-0.26.tar.gz','POE-Component-Client-DNS-0.95.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 11275,'unpacked' => 30858},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['POE','XML::Simple','strict','warnings']},'POE-Component-Client-FTP-0.07.tar.gz' => {'author' => 'MCHING','description' => 'POE FTP client','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 939,'pod' => 198,'pod_errors' => 1,'total' => 1137,'with_comments' => 88},'releases' => 6,'requires' => ['POE-0.26.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'POE' => 0,'Socket' => 0},'requires_recursive' => ['POE-0.26.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12984,'unpacked' => 44938},'testers' => {'pass' => 3},'uses' => ['Carp','Data::Dumper','Exporter','POE','Socket','strict','vars','warnings']},'POE-Component-Client-HTTP-0.54.tar.gz' => {'author' => 'RCAPUTO','description' => 'non-blocking/parallel web requests engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1811,'pod' => 449,'pod_errors' => 0,'total' => 2260,'with_comments' => 192},'releases' => 18,'requires' => ['POE-0.26.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request' => '1.27','HTTP::Response' => '1.33','POE' => '0.1106','URI' => '1.11'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','POE-0.26.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 29456,'unpacked' => 91635},'testers' => {'pass' => 2},'uses' => ['CPAN','CPANPLUS::Backend','Carp','Config','Cwd','ExtUtils::Manifest','File::Spec','HTTP::Response','Net::SSLeay::Handle','POE','POE::Component::Client::DNS','POSIX','Symbol','strict','vars']},'POE-Component-Client-POP3-0.02.tar.gz' => {'author' => 'SABECK','description' => 'Impliment a POP3 client POE component','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 842,'pod' => 437,'pod_errors' => 0,'total' => 1279,'with_comments' => 47},'releases' => 2,'requires' => ['POE-0.26.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'POE' => '0.17','Socket' => 0},'requires_recursive' => ['POE-0.26.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14045,'unpacked' => 57644},'testers' => {},'uses' => ['Carp','Digest::MD5','POE','Socket','strict','vars']},'POE-Component-Client-Ping-0.98.tar.gz' => {'author' => 'RCAPUTO','description' => 'concurrent ICMP ping without fork or threads','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 459,'pod' => 153,'pod_errors' => 0,'total' => 612,'with_comments' => 81},'releases' => 7,'requires' => ['POE-0.26.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'POE' => '0.11','Time::HiRes' => '1.2'},'requires_recursive' => ['POE-0.26.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 10128,'unpacked' => 28809},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','POE::Session','Socket','Symbol','Time::HiRes','strict','vars']},'POE-Component-Client-Rcon-0.22.tar.gz' => {'author' => 'ACHEN','description' => '- an implementation of the Rcon remote console protocol.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 373,'pod' => 174,'pod_errors' => 1,'total' => 547,'with_comments' => 27},'releases' => 2,'requires' => ['POE-0.26.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'POE' => '0.15','Socket' => 0,'Time::HiRes' => 0},'requires_recursive' => ['POE-0.26.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6277,'unpacked' => 20130},'testers' => {'pass' => 3},'uses' => ['Carp','POE','Socket','Time::HiRes','strict','vars']},'POE-Component-Client-UserAgent-0.05.tar.gz' => {'author' => 'RCAPUTO','description' => 'LWP and LWP::Parallel based POE web client','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 453,'pod' => 245,'pod_errors' => 0,'total' => 698,'with_comments' => 24},'releases' => 3,'requires' => ['POE-0.26.tar.gz','ParallelUserAgent-2.56.tar.gz'],'requires_module' => {'LWP::Parallel' => '2.51','POE' => '0.1402'},'requires_recursive' => ['POE-0.26.tar.gz','ParallelUserAgent-2.56.tar.gz'],'size' => {'packed' => 8632,'unpacked' => 31127},'testers' => {'pass' => 1},'uses' => ['LWP::Parallel','POE','strict']},'POE-Component-DBIAgent-0.12.tar.gz' => {'author' => 'RDB','description' => 'POE Component for running asynchronous DBI calls.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 588,'pod' => 291,'pod_errors' => 0,'total' => 879,'with_comments' => 71},'releases' => 2,'requires' => ['Class-MethodMaker-1.10.tar.gz','DBI-1.37.tar.gz','POE-0.26.tar.gz','Storable-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Class::MethodMaker' => 0,'DBI' => 0,'POE' => '0.17','Socket' => 0,'Storable' => 0},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','POE-0.26.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9009,'unpacked' => 23441},'testers' => {'pass' => 3},'uses' => ['Carp','DBI','Daemon','Data::Dumper','POE','Socket','Storable','constant','strict','vars']},'POE-Component-DirWatch-0.01.tar.gz' => {'author' => 'CHOLET','description' => 'POE directory watcher','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 153,'pod' => 69,'pod_errors' => 0,'total' => 222,'with_comments' => 30},'releases' => 1,'requires' => ['POE-0.26.tar.gz'],'requires_module' => {'POE' => '0.12'},'requires_recursive' => ['POE-0.26.tar.gz'],'size' => {'packed' => 3835,'unpacked' => 9583},'testers' => {'pass' => 2},'uses' => ['Carp','DirHandle','File::Spec','POE','constant','strict','vars']},'POE-Component-Enc-Mp3-1.2.tar.gz' => {'author' => 'ECALDER','description' => 'mp3 encoder wrapper','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 104,'pod' => 84,'pod_errors' => 1,'total' => 188,'with_comments' => 12},'releases' => 1,'requires' => ['POE-0.26.tar.gz'],'requires_module' => {'POE' => '0.22'},'requires_recursive' => ['POE-0.26.tar.gz'],'size' => {'packed' => 3321,'unpacked' => 6763},'testers' => {'fail' => 2},'uses' => ['Carp','POE','strict','vars','warnings']},'POE-Component-IKC-0.14.tar.gz' => {'author' => 'GWYN','description' => 'POE Inter-Kernel Communication client','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4126,'pod' => 1076,'pod_errors' => 5,'total' => 5202,'with_comments' => 669},'releases' => 4,'requires' => ['POE-0.26.tar.gz'],'requires_module' => {'POE' => '0.1701'},'requires_recursive' => ['POE-0.26.tar.gz'],'size' => {'packed' => 51675,'unpacked' => 207188},'testers' => {'fail' => 1,'pass' => 2,'tests' => '44'},'uses' => ['$q','Carp','Data::Dumper','Exporter','IO::Select','IO::Socket','POE','POE::Session','POSIX','Proc::ProcessTable','Socket','strict','vars']},'POE-Component-IRC-2.9.tar.gz' => {'author' => 'FIMM','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1682,'pod' => 462,'pod_errors' => 0,'total' => 2144,'with_comments' => 219},'releases' => 20,'requires' => ['POE-0.26.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'POE' => '0.0607','Socket' => 0},'requires_recursive' => ['POE-0.26.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 34797,'unpacked' => 111944},'testers' => {'pass' => 1},'uses' => ['Carp','POE','Socket','Symbol','Sys::Hostname','constant','strict','vars']},'POE-Component-IRC-Object-0.02.tar.gz' => {'author' => 'MSERGEANT','description' => 'A slightly simpler OO interface to PoCoIRC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 127,'pod' => 79,'pod_errors' => 0,'total' => 206,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 2972,'unpacked' => 7039},'testers' => {'fail' => 7,'pass' => 5,'tests' => '1'},'uses' => ['POE','POE::Component::IRC','strict','vars']},'POE-Component-IRC-Onjoin-1.12.tar.gz' => {'author' => 'FOX','description' => 'Provides IRC moved message & onjoin services','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 338,'pod' => 70,'pod_errors' => 0,'total' => 408,'with_comments' => 46},'releases' => 3,'requires' => ['POE-0.26.tar.gz','POE-Component-IRC-2.9.tar.gz'],'requires_module' => {'POE' => '0.12','POE::Component::IRC' => '1.0b'},'requires_recursive' => ['POE-0.26.tar.gz','POE-Component-IRC-2.9.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11688,'unpacked' => 31612},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['5.005','Carp','POE::Component::IRC','POE::Kernel','POE::Session','strict','vars']},'POE-Component-Jabber-0.2.tar.gz' => {'author' => 'MAHEX','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 580,'pod' => 103,'pod_errors' => 0,'total' => 683,'with_comments' => 25},'releases' => 2,'requires' => ['Digest-SHA1-2.04.tar.gz','Jabber-Connection-0.03.tar.gz','POE-0.26.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Digest::SHA1' => '1.03','Jabber::Connection' => '0.02','POE' => 0,'XML::Parser' => '2.29'},'requires_recursive' => ['Digest-SHA1-2.04.tar.gz','Jabber-Connection-0.03.tar.gz','POE-0.26.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 6569,'unpacked' => 21273},'testers' => {'pass' => 2},'uses' => ['Carp','Digest::SHA1','Jabber::NS','Jabber::NodeFactory','POE','Socket','XML::Parser','constant','strict','vars']},'POE-Component-JobQueue-0.53.tar.gz' => {'author' => 'RCAPUTO','description' => 'a component to manage queues and worker pools','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 373,'pod' => 201,'pod_errors' => 0,'total' => 574,'with_comments' => 56},'releases' => 3,'requires' => ['POE-0.26.tar.gz'],'requires_module' => {'POE' => '0.11'},'requires_recursive' => ['POE-0.26.tar.gz'],'size' => {'packed' => 9207,'unpacked' => 27998},'testers' => {'pass' => 2},'uses' => ['Carp','POE::Session','strict','vars']},'POE-Component-LaDBI-1.0.3.tar.gz' => {'author' => 'SEGAN','description' => 'POE Component that spawns a perl subprocess to handle non-blocking access to the DBI API.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1992,'pod' => 727,'pod_errors' => 0,'total' => 2719,'with_comments' => 103},'releases' => 4,'requires' => ['DBI-1.37.tar.gz','POE-0.26.tar.gz'],'requires_module' => {'DBI' => '1.20','POE' => '0.18'},'requires_recursive' => ['DBI-1.37.tar.gz','POE-0.26.tar.gz'],'size' => {'packed' => 21800,'unpacked' => 150732},'testers' => {'fail' => 1,'tests' => '23'},'uses' => ['DBI','Data::Dumper','Exporter','IO::File','IO::Handle','POE','strict','warnings']},'POE-Component-Logger-1.00.tar.gz' => {'author' => 'MSERGEANT','description' => 'A POE logging class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 91,'pod_errors' => 0,'total' => 210,'with_comments' => 5},'releases' => 1,'requires' => ['Log-Dispatch-Config-1.01.tar.gz','POE-0.26.tar.gz'],'requires_module' => {'Log::Dispatch::Config' => '0.10','POE' => '0.11'},'requires_recursive' => ['AppConfig-1.55.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Log-Dispatch-2.06.tar.gz','Log-Dispatch-Config-1.01.tar.gz','POE-0.26.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2910,'unpacked' => 6053},'testers' => {'pass' => 3},'uses' => ['Log::Dispatch::Config','POE','strict','vars']},'POE-Component-Pcap-0.04.tar.gz' => {'author' => 'FLETCH','description' => 'POE Interface to Net::Pcap','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 466,'pod' => 111,'pod_errors' => 0,'total' => 577,'with_comments' => 77},'releases' => 3,'requires' => ['Net-Pcap-0.04.tar.gz','NetPacket-0.03.tar.gz','POE-0.26.tar.gz'],'requires_module' => {'Net::Pcap' => '0.04','NetPacket::Ethernet' => '0.01','POE' => '0.26'},'requires_recursive' => ['Net-Pcap-0.04.tar.gz','NetPacket-0.03.tar.gz','POE-0.26.tar.gz'],'size' => {'packed' => 6940,'unpacked' => 21594},'testers' => {},'uses' => ['Carp','Fcntl','IO::Handle','Net::Pcap','NetPacket::ARP','NetPacket::Ethernet','POE','Pcap','Symbol','strict']},'POE-Component-Player-Mpg123-1.2.tar.gz' => {'author' => 'ECALDER','description' => 'a wrapper for the C<mpg123> player','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 216,'pod' => 157,'pod_errors' => 1,'total' => 373,'with_comments' => 33},'releases' => 1,'requires' => ['POE-Component-Child-1.31.tar.gz'],'requires_module' => {'POE::Component::Child' => '1.16'},'requires_recursive' => ['File-Spec-0.82.tar.gz','POE-0.26.tar.gz','POE-Component-Child-1.31.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6637,'unpacked' => 15690},'testers' => {'fail' => 1},'uses' => ['Carp','POE','POE::Component::Child','strict','vars','warnings']},'POE-Component-Player-Slideshow-1.4.tar.gz' => {'author' => 'ECALDER','description' => 'a wrapper for the C<qiv> application','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 129,'pod_errors' => 1,'total' => 306,'with_comments' => 10},'releases' => 1,'requires' => ['POE-Component-Child-1.31.tar.gz','X11-SendEvent-1.3.tar.gz'],'requires_module' => {'POE::Component::Child' => '1.22','X11::SendEvent' => '1.4'},'requires_recursive' => ['File-Spec-0.82.tar.gz','POE-0.26.tar.gz','POE-Component-Child-1.31.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','X11-Protocol-0.51.tar.gz','X11-SendEvent-1.3.tar.gz'],'size' => {'packed' => 21307,'unpacked' => 28026},'testers' => {'pass' => 1},'uses' => ['POE','POE::Component::Child','X11::SendEvent','strict','vars','warnings']},'POE-Component-RRDTool-0.14.tar.gz' => {'author' => 'TCAINE','description' => 'POE interface to Tobias Oetiker\'s RRDTool','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 264,'pod' => 248,'pod_errors' => 1,'total' => 512,'with_comments' => 27},'releases' => 4,'requires' => ['POE-0.26.tar.gz'],'requires_module' => {'POE' => '0.22'},'requires_recursive' => ['POE-0.26.tar.gz'],'size' => {'packed' => 8749,'unpacked' => 31826},'testers' => {},'uses' => ['Data::Dumper','Exporter','File::Basename','POE::Driver::SysRW','POE::Filter::Line','POE::Filter::Stream','POE::Session','POE::Wheel::Run','POSIX','strict','vars']},'POE-Component-RSS-0.07.tar.gz' => {'author' => 'SUNGO','description' => 'Event based RSS interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 164,'pod' => 97,'pod_errors' => 0,'total' => 261,'with_comments' => 11},'releases' => 3,'requires' => ['POE-0.26.tar.gz','Test-Simple-0.47.tar.gz','XML-RSS-1.02.tar.gz'],'requires_module' => {'POE' => '0.11','Test::More' => '0.08','XML::RSS' => '0.9'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','POE-0.26.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Simple-0.47.tar.gz','XML-Parser-2.31.tar.gz','XML-RSS-1.02.tar.gz'],'size' => {'packed' => 4791,'unpacked' => 13512},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','POE','XML::RSS','strict','vars']},'POE-Component-RSSAggregator-0.02.tgz' => {'author' => 'JBISBEE','description' => 'A Simple POE RSS Aggregator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 100,'pod' => 73,'pod_errors' => 0,'total' => 173,'with_comments' => 1},'releases' => 2,'requires' => ['POE-Component-Client-HTTP-0.54.tar.gz','XML-RSS-Feed-0.02.tgz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request' => '1.3','POE::Component::Client::HTTP' => '0.51','XML::RSS::Feed' => '0.01'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','POE-0.26.tar.gz','POE-Component-Client-HTTP-0.54.tar.gz','URI-1.24.tar.gz','XML-RSS-Feed-0.02.tgz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10066,'unpacked' => 25765},'testers' => {'pass' => 1},'uses' => ['Carp','HTTP::Request','POE','POE::Component::Client::HTTP','XML::RSS::Feed','strict','vars']},'POE-Component-SMTP-1.4.tar.gz' => {'author' => 'CWEST','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 338,'pod' => 182,'pod_errors' => 0,'total' => 520,'with_comments' => 18},'releases' => 4,'requires' => ['POE-0.26.tar.gz','POE-Session-MultiDispatch-1.3.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'POE' => 0,'POE::Session::MultiDispatch' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','POE-0.26.tar.gz','POE-Session-MultiDispatch-1.3.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5478,'unpacked' => 17968},'testers' => {'pass' => 3},'uses' => ['Exporter','Mail::Internet','POE','POE::Filter::Line','Sys::Hostname','constant','strict','vars']},'POE-Component-SNMP-0.01.tar.gz' => {'author' => 'TCAINE','description' => 'event-driven SNMP interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 190,'pod' => 133,'pod_errors' => 0,'total' => 323,'with_comments' => 15},'releases' => 1,'requires' => ['Net-SNMP-4.1.0.tar.gz'],'requires_module' => {'Net::SNMP' => 0},'requires_recursive' => ['Crypt-DES-2.03.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','Net-SNMP-4.1.0.tar.gz'],'size' => {'packed' => 4017,'unpacked' => 17667},'testers' => {'pass' => 1},'uses' => ['Net::SNMP','POE::Session','strict']},'POE-Component-Server-HTTP-0.03.tar.gz' => {'author' => 'ABERGMAN','description' => 'Foundation of a POE HTTP Daemon','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 441,'pod' => 120,'pod_errors' => 0,'total' => 561,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 7183,'unpacked' => 18134},'testers' => {'fail' => 4,'pass' => 1},'uses' => ['Carp','File::Spec','HTTP::Date','HTTP::Request','HTTP::Response','HTTP::Status','POE','POE::Component::Server::TCP','Socket','Sys::Hostname','strict','vars']},'POE-Component-Server-IRC-0.0001.tar.gz' => {'author' => 'HACHI','description' => 'Perl extension for making a subclassable POE session set that comes as close as I can to being an IRC daemon.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 509,'pod' => 118,'pod_errors' => 0,'total' => 627,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 5736,'unpacked' => 17150},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Data::Dumper','POE','Socket','strict','vars','warnings']},'POE-Component-Server-PreforkTCP-0.11.tar.gz' => {'author' => 'WANG','description' => 'Perl TCP server , which can fork processes before request and each process can do with requestion corcurrently as same as Apache.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 895,'pod' => 214,'pod_errors' => 1,'total' => 1109,'with_comments' => 155},'releases' => 1,'requires' => ['POE-0.26.tar.gz'],'requires_module' => {'POE' => '0.22'},'requires_recursive' => ['POE-0.26.tar.gz'],'size' => {'packed' => 10111,'unpacked' => 33908},'testers' => {'pass' => 3},'uses' => ['Carp','POE','POE::Component::Server::TCP','POE::Session','POE::Wheel::Run','strict','vars']},'POE-Component-Server-SOAP-0.03.tar.gz' => {'author' => 'RCAPUTO','description' => 'publish POE event handlers via SOAP over HTTP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 263,'pod' => 100,'pod_errors' => 0,'total' => 363,'with_comments' => 12},'releases' => 3,'requires' => ['POE-0.26.tar.gz','POE-Component-Server-HTTP-0.03.tar.gz','SOAP-0.28.tar.gz'],'requires_module' => {'POE' => '0.22','POE::Component::Server::HTTP' => '0.02','SOAP::EnvelopeMaker' => '0.28'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','POE-0.26.tar.gz','POE-Component-Server-HTTP-0.03.tar.gz','SOAP-0.28.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5084,'unpacked' => 14870},'testers' => {},'uses' => ['Carp','POE','POE::Component::Server::HTTP','SOAP::Defs','SOAP::EnvelopeMaker','SOAP::Parser','strict','vars','warnings']},'POE-Component-Server-Syslog-0.02.tar.gz' => {'author' => 'SUNGO','description' => 'Syslog server ability for POE','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 166,'pod' => 115,'pod_errors' => 0,'total' => 281,'with_comments' => 20},'releases' => 3,'requires' => ['IO-1.20.tar.gz','POE-0.26.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'IO::Socket' => 0,'POE' => '0.24','Test::More' => 0,'Time::ParseDate' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-1.20.tar.gz','POE-0.26.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7210,'unpacked' => 20084},'testers' => {'pass' => 2},'uses' => ['5.006001','Carp','IO::Socket','POE','Time::ParseDate','strict','warnings']},'POE-Component-Server-XMLRPC-0.05.tar.gz' => {'author' => 'MAHEX','description' => 'publish POE event handlers via XMLRPC over HTTP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 228,'pod' => 105,'pod_errors' => 0,'total' => 333,'with_comments' => 4},'releases' => 3,'requires' => ['POE-0.26.tar.gz','POE-Component-Server-HTTP-0.03.tar.gz','SOAP-Lite-0.55.tar.gz'],'requires_module' => {'POE' => '0.22','POE::Component::Server::HTTP' => '0.02','XMLRPC::Lite' => '0.28'},'requires_recursive' => ['POE-0.26.tar.gz','POE-Component-Server-HTTP-0.03.tar.gz','SOAP-Lite-0.55.tar.gz'],'size' => {'packed' => 5291,'unpacked' => 13702},'testers' => {'pass' => 1},'uses' => ['Carp','POE','POE::Component::Server::HTTP','XMLRPC::Lite','strict','vars','warnings']},'POE-Component-SubWrapper-0.08.tar.gz' => {'author' => 'SUNGO','description' => 'Event based Module interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 72,'pod_errors' => 0,'total' => 224,'with_comments' => 13},'releases' => 4,'requires' => ['Devel-Symdump-2.03.tar.gz','POE-0.26.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Devel::Symdump' => '2.01','POE' => '0.23','Test::More' => '0.08'},'requires_recursive' => ['Devel-Symdump-2.03.tar.gz','File-Spec-0.82.tar.gz','POE-0.26.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5329,'unpacked' => 13156},'testers' => {'pass' => 4},'uses' => ['Carp','Data::Dumper','Devel::Symdump','Exporter','POE','strict','vars']},'POE-Component-TSTP-0.02.tar.gz' => {'author' => 'MSERGEANT','description' => 'A POE Component to handle Ctrl-Z','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 48,'pod' => 40,'pod_errors' => 0,'total' => 88,'with_comments' => 1},'releases' => 2,'requires' => ['POE-0.26.tar.gz'],'requires_module' => {'POE' => '0.2'},'requires_recursive' => ['POE-0.26.tar.gz'],'size' => {'packed' => 1685,'unpacked' => 2597},'testers' => {'pass' => 2},'uses' => ['POE','strict','vars']},'POE-Component-UserBase-0.09.tar.gz' => {'author' => 'JGOFF','description' => 'A component to manage user authentication','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 667,'pod' => 211,'pod_errors' => 0,'total' => 878,'with_comments' => 23},'releases' => 2,'requires' => ['POE-0.26.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'POE' => '0.11','Storable' => 1},'requires_recursive' => ['File-Spec-0.82.tar.gz','POE-0.26.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 17247,'unpacked' => 59389},'testers' => {'pass' => 7},'uses' => ['Carp','POE::Session','Storable','strict','vars']},'POE-Component-YahooMessenger-0.05.tar.gz' => {'author' => 'MIYAGAWA','description' => 'POE component for Yahoo! Messenger','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 544,'pod' => 76,'pod_errors' => 0,'total' => 620,'with_comments' => 17},'releases' => 5,'requires' => ['Net-YahooMessenger-0.13.tar.gz','POE-0.26.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Net::YahooMessenger' => '0.13','POE' => '0.22','Test::More' => '0.32'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Net-YahooMessenger-0.13.tar.gz','POE-0.26.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5948,'unpacked' => 18897},'testers' => {'pass' => 3},'uses' => ['Data::Dumper','Exporter','Net::YahooMessenger::CRAM','POE','Socket','constant','strict','vars']},'POE-Exceptions-0.02.tar.gz' => {'author' => 'SUNGO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 104,'pod_errors' => 0,'total' => 241,'with_comments' => 0},'releases' => 2,'requires' => ['POE-0.26.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '0','POE' => '0.25','Test::More' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','POE-0.26.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4256,'unpacked' => 14444},'testers' => {'pass' => 2},'uses' => ['POE','POE::Kernel','POE::Session','strict','vars','warnings']},'POE-Filter-Ls-0.01.tar.gz' => {'author' => 'MCHING','description' => 'translates common ls formats into a hashref','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 49,'pod' => 5,'pod_errors' => 0,'total' => 54,'with_comments' => 0},'releases' => 1,'requires' => ['POE-0.26.tar.gz'],'requires_module' => {'POE::Filter::Line' => 0},'requires_recursive' => ['POE-0.26.tar.gz'],'size' => {'packed' => 7836,'unpacked' => 21531},'testers' => {'pass' => 2},'uses' => ['POE::Filter::Line']},'POE-Framework-MIDI-0.1.tar.gz' => {'author' => 'SMCNABB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1352,'pod' => 494,'pod_errors' => 0,'total' => 1846,'with_comments' => 184},'releases' => 1,'size' => {'packed' => 22591,'unpacked' => 71782},'testers' => {'fail' => 1},'uses' => ['Carp','Exporter','MIDI::Simple','POE','String::Similarity','constant','strict','vars','warnings']},'POE-Session-GladeXML-0.1.3.tar.gz' => {'author' => 'MARTIJN','description' => 'connects Gtk::GladeXML and POE::Session','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 93,'pod' => 52,'pod_errors' => 0,'total' => 145,'with_comments' => 3},'releases' => 1,'requires' => ['Gtk-Perl-0.7009.tar.gz','POE-0.26.tar.gz'],'requires_module' => {'Gtk::GladeXML' => '0.7008','POE' => '0.23'},'requires_recursive' => ['Gtk-Perl-0.7009.tar.gz','POE-0.26.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 9571,'unpacked' => 23732},'testers' => {},'uses' => ['Carp','Gtk','Gtk::GladeXML','POE','POE::Session','strict','warnings']},'POE-Session-MessageBased-0.01.tar.gz' => {'author' => 'RCAPUTO','description' => 'a message-based (not @_ based) POE::Session','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 77,'pod_errors' => 0,'total' => 237,'with_comments' => 41},'releases' => 1,'requires' => ['POE-0.26.tar.gz'],'requires_module' => {'POE' => '0.25'},'requires_recursive' => ['POE-0.26.tar.gz'],'size' => {'packed' => 4157,'unpacked' => 13551},'testers' => {'pass' => 3},'uses' => ['POE','POE::Session','POSIX','strict','vars','warnings']},'POE-Session-MultiDispatch-1.3.tar.gz' => {'author' => 'CWEST','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 366,'pod' => 113,'pod_errors' => 0,'total' => 479,'with_comments' => 20},'releases' => 3,'requires' => ['POE-0.26.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'POE' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','POE-0.26.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6001,'unpacked' => 22409},'testers' => {'pass' => 10},'uses' => ['Carp','POE::Session','strict','vars']},'POE-Sugar-Args-1.2.tar.gz' => {'author' => 'CWEST','description' => 'Get "pretty", OO representation of args.','files' => ['README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 40,'pod' => 100,'pod_errors' => 1,'total' => 140,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 2857,'unpacked' => 6546},'testers' => {'pass' => 2},'uses' => ['Devel::Caller::Perl','Exporter::Lite','POE::Session','strict','vars']},'POSIX-RT-MQ-0.03.tar.gz' => {'author' => 'ILJATABAC','description' => 'Perl interface for POSIX Message Queues','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 184,'pod' => 225,'pod_errors' => 0,'total' => 409,'with_comments' => 3},'releases' => 3,'size' => {'packed' => 8751,'unpacked' => 30081},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','DynaLoader','Fcntl','strict','warnings']},'PPI-0.4.tar.gz' => {'author' => 'ADAMK','description' => 'Parsing an manipulating Perl code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5349,'pod' => 33,'pod_errors' => 0,'total' => 5382,'with_comments' => 1048},'releases' => 7,'requires' => ['Class-Handle-0.4.tar.gz','File-Find-Rule-0.10.tar.gz','File-Flat-0.8.tar.gz','File-Spec-0.82.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Handle' => '0.2','File::Find::Rule' => 0,'File::Flat' => '0.6','File::Spec' => '0.82','Test::More' => 0},'requires_recursive' => ['Class-Autouse-0.7.tar.gz','Class-Handle-0.4.tar.gz','Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','File-Find-Rule-0.10.tar.gz','File-Flat-0.8.tar.gz','File-NCopy0.32.tar.gz','File-Remove0.20.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 46565,'unpacked' => 166822},'testers' => {'fail' => 1},'uses' => ['Carp','Class::Autouse','Exporter','PPI','PPI::Common','PPI::Tokenizer::Classes','PPI::Tokenizer::Quote::Full','PPI::Tokenizer::Quote::Simple','PPI::Tokenizer::Token::Bareword','UNIVERSAL','diagnostics','strict','vars','warnings']},'PPI-0.7.tar.gz' => {'author' => 'ADAMK','description' => 'Parse and manipulate Perl code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6209,'pod' => 420,'pod_errors' => 0,'total' => 6629,'with_comments' => 1346},'releases' => 7,'requires' => ['CGI.pm-2.98.tar.gz','Class-Autouse-0.7.tar.gz','Class-Handle-0.4.tar.gz','File-Find-Rule-0.10.tar.gz','File-Flat-0.8.tar.gz','File-Spec-0.82.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'CGI' => 0,'CGI::Carp' => 0,'Class::Autouse' => 0,'Class::Handle' => '0.2','File::Find::Rule' => 0,'File::Flat' => '0.6','File::Spec' => '0.82','Test::More' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Class-Autouse-0.7.tar.gz','Class-Handle-0.4.tar.gz','Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','File-Find-Rule-0.10.tar.gz','File-Flat-0.8.tar.gz','File-NCopy0.32.tar.gz','File-Remove0.20.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 58326,'unpacked' => 209552},'testers' => {},'uses' => ['5.005','CGI','Class::Autouse','Class::Default','Exporter','File::Spec','PPI::Token::Bareword','PPI::Tokenizer::Quote','UNIVERSAL','diagnostics','strict','vars','warnings']},'PPM-2.1.1.tar.gz' => {'author' => 'MURRAY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3443,'pod' => 1004,'pod_errors' => 0,'total' => 4447,'with_comments' => 786},'releases' => 5,'requires' => ['Archive-Tar-1.03.tar.gz','Compress-Zlib-1.22.tar.gz','SOAP-0.28.tar.gz','XML-Parser-2.31.tar.gz','XML-TreeBuilder-3.08.tar.gz'],'requires_module' => {'Archive::Tar' => 0,'Compress::Zlib' => 0,'SOAP::Parser' => '0.23','XML::Element' => '0.1','XML::Parser' => '2.09'},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','Compress-Zlib-1.22.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','SOAP-0.28.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','XML-TreeBuilder-3.08.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 53988,'unpacked' => 246551},'testers' => {},'uses' => ['5.004','Archive::Tar','Config','Cwd','Exporter','ExtUtils::Install','File::Basename','File::Copy','File::Find','File::Path','LWP::Simple','LWP::UserAgent','PPM::RelocPerl','SOAP::EnvelopeMaker','SOAP::Parser','SOAP::Transport::HTTP::Client','XML::PPD','XML::PPMConfig','XML::Parser','XML::RepositorySummary','XML::ValidatingElement','strict','vars']},'PPM-2.1.3.tar.gz' => {'author' => 'MURRAY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2649,'pod' => 838,'pod_errors' => 0,'total' => 3487,'with_comments' => 343},'releases' => 5,'requires' => ['Archive-Tar-1.03.tar.gz','Compress-Zlib-1.22.tar.gz','XML-Parser-2.31.tar.gz','XML-TreeBuilder-3.08.tar.gz'],'requires_module' => {'Archive::Tar' => 0,'Compress::Zlib' => 0,'XML::Element' => '0.1','XML::Parser' => '2.09'},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','Compress-Zlib-1.22.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Parser-2.31.tar.gz','XML-TreeBuilder-3.08.tar.gz'],'size' => {'packed' => 48526,'unpacked' => 204562},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.004','Archive::Tar','Config','Cwd','Exporter','ExtUtils::Install','File::Basename','File::Copy','File::Find','File::Path','LWP::Simple','LWP::UserAgent','PPM::RelocPerl','SOAP::Lite','XML::Parser','XML::ValidatingElement','strict']},'PPM-2.1.6.tar.gz' => {'author' => 'MURRAY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3084,'pod' => 986,'pod_errors' => 0,'total' => 4070,'with_comments' => 442},'releases' => 5,'requires' => ['Archive-Tar-1.03.tar.gz','Compress-Zlib-1.22.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Archive::Tar' => 0,'Compress::Zlib' => 0,'XML::Parser' => '2.09'},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','Compress-Zlib-1.22.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 53251,'unpacked' => 225420},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['5.004','Archive::Tar','Config','Cwd','Exporter','ExtUtils::Install','File::Basename','File::Copy','File::Find','File::Path','File::Spec','HTML::Entities','LWP::Simple','LWP::UserAgent','SOAP::Lite','XML::Parser','XML::RepositorySummary','strict','vars']},'PPM-Make-0.52.tar.gz' => {'author' => 'RKOBES','description' => 'Make a PPM package from a CPAN distribution','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1447,'pod' => 208,'pod_errors' => 0,'total' => 1655,'with_comments' => 27},'releases' => 7,'size' => {'packed' => 22268,'unpacked' => 74018},'testers' => {'pass' => 1},'uses' => ['Archive::Tar','Archive::Zip','CPAN','CPAN::Config','Config','Config::IniFiles','Cwd','File::Basename','File::Copy','File::Find','File::Path','File::Spec','LWP::Simple','Net::FTP','PPM','Pod::Find','Pod::Html','XML::Parser','strict','vars','warnings']},'PPM-Repositories-0.04.tar.gz' => {'author' => 'PODMASTER','description' => undef,'files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 204,'pod' => 75,'pod_errors' => 0,'total' => 279,'with_comments' => 2},'releases' => 3,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Exporter' => undef},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 4043,'unpacked' => 13356},'testers' => {'pass' => 2},'uses' => ['Exporter','vars']},'PPerl-0.23.tar.gz' => {'author' => 'MSERGEANT','description' => 'Make perl scripts persistent in memory','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 61,'pod_errors' => 0,'total' => 93,'with_comments' => 0},'releases' => 19,'size' => {'packed' => 20900,'unpacked' => 57707},'testers' => {'pass' => 2},'uses' => ['DynaLoader','Exporter','strict','vars']},'PPresenter-1.17.tar.gz' => {'author' => 'MARKOV','description' => 'Slide shows written in Perl (or XML)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 8312,'pod' => 23,'pod_errors' => 0,'total' => 8335,'with_comments' => 574},'releases' => 5,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '800.012'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 329594,'unpacked' => 777140},'testers' => {'fail' => 2,'tests' => '0','unknown' => 6},'uses' => ['','Carp','Exporter','File::Basename','Image::Magick','MIME::Base64','PPresenter::Export::Images::Tk','PPresenter::Viewport::Phases::Box','PPresenter::Viewport::Phases::Circle','Tk','Tk::Balloon','Tk::Derived','Tk::Dialog','Tk::LabFrame','Tk::Label','Tk::Photo','Tk::Table','overload','strict','vars']},'PPrint-0.1.tar.gz' => {'author' => 'SEGV','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 278,'pod' => 143,'pod_errors' => 0,'total' => 421,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 4421,'unpacked' => 11944},'testers' => {'pass' => 2},'uses' => ['5.005_62','Carp','Data::Dumper','strict','warnings']},'PQEdit-1.7.tar.gz' => {'author' => 'BRIAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 99,'pod' => 364,'pod_errors' => 0,'total' => 463,'with_comments' => 0},'releases' => 8,'requires' => ['CGI.pm-2.98.tar.gz','RDBAL-1.2.tar.gz'],'requires_module' => {'CGI' => 2,'RDBAL::Schema' => 1},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','RDBAL-1.2.tar.gz'],'size' => {'packed' => 85978,'unpacked' => 170218},'testers' => {'pass' => 2},'uses' => ['SQL::Password']},'Package-Alias-0.04.tar.gz' => {'author' => 'JOSHUA','description' => 'alias one namespace into another','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 38,'pod_errors' => 0,'total' => 95,'with_comments' => 11},'releases' => 4,'size' => {'packed' => 10585,'unpacked' => 28300},'testers' => {'pass' => 1},'uses' => ['Carp','strict','vars']},'Packed-Array-0.01.tar.gz' => {'author' => 'DSUGAL','description' => 'Packed integer array','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 27,'pod_errors' => 0,'total' => 69,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 2480,'unpacked' => 4907},'testers' => {'pass' => 8},'uses' => ['5.005_62','DynaLoader','Exporter','strict','warnings']},'PadWalker-0.09.tar.gz' => {'author' => 'ROBIN','description' => 'play with other peoples\' lexical variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 51,'pod_errors' => 0,'total' => 83,'with_comments' => 0},'releases' => 6,'size' => {'packed' => 5574,'unpacked' => 13626},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['5.00502','DynaLoader','Exporter','strict','vars']},'Palm-ListDB-0.25.tar.gz' => {'author' => 'RPQS','description' => 'Handler for ListDB databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 243,'pod' => 94,'pod_errors' => 0,'total' => 337,'with_comments' => 47},'releases' => 3,'size' => {'packed' => 6558,'unpacked' => 16075},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars']},'Palm-PalmDoc-0.12.tar.gz' => {'author' => 'BEATNIK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 515,'pod' => 225,'pod_errors' => 0,'total' => 740,'with_comments' => 70},'releases' => 8,'size' => {'packed' => 7649,'unpacked' => 27589},'testers' => {'pass' => 1},'uses' => ['Exporter','strict','vars']},'Palm-Progect-2.0.1.tar.gz' => {'author' => 'MGRAHAM','description' => 'Handler for Palm Progect databases.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3497,'pod' => 1321,'pod_errors' => 0,'total' => 4818,'with_comments' => 491},'releases' => 3,'requires' => ['CLASS-0.91.tar.gz','Class-Accessor-0.18.tar.gz','Class-Constructor-1.0.0.tar.gz'],'requires_module' => {'CLASS' => '0','Class::Accessor' => '0','Class::Constructor' => '0'},'requires_recursive' => ['CLASS-0.91.tar.gz','Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Constructor-1.0.0.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 50245,'unpacked' => 190482},'testers' => {'fail' => 1,'tests' => '47'},'uses' => ['5.004','CLASS','Carp','Class::Accessor','Class::Constructor','Exporter','File::Spec','IO::File','Palm::PDB','Palm::Raw','Palm::StdAppInfo','Test::Simple','Text::CSV_XS','Text::Tabs','Text::Wrap','Time::Local','constant','strict','vars']},'Palm-PunchClock-1.2.tar.gz' => {'author' => 'PEDERST','description' => 'Perl extension for parsing PunchClock pdb files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 31,'pod_errors' => 0,'total' => 125,'with_comments' => 20},'releases' => 2,'size' => {'packed' => 2191,'unpacked' => 3812},'testers' => {'pass' => 2},'uses' => ['Palm::PDB','Palm::StdAppInfo','strict','vars']},'Palm-ThinkDB-0.02.tar.gz' => {'author' => 'EARNESON','description' => 'Manipulate ThinkDB TinyBytes for PalmOS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 484,'pod' => 0,'pod_errors' => 0,'total' => 484,'with_comments' => 68},'releases' => 1,'size' => {'packed' => 7042,'unpacked' => 22031},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['strict']},'Palm-Timesheet-0.1.tar.gz' => {'author' => 'JOHANVDB','description' => 'Handler for Timesheet1.5.3 databases.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 824,'pod' => 422,'pod_errors' => 0,'total' => 1246,'with_comments' => 23},'releases' => 1,'size' => {'packed' => 7717,'unpacked' => 29774},'testers' => {'fail' => 2},'uses' => ['','Carp','Exporter','Palm::PDB','Palm::Raw','constant','strict','vars']},'Palm-Zetetic-Strip-1.01.tar.gz' => {'author' => 'DDRIBIN','description' => 'Manipulate Zetetic Strip Palm database files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1312,'pod' => 175,'pod_errors' => 0,'total' => 1487,'with_comments' => 28},'releases' => 2,'size' => {'packed' => 11566,'unpacked' => 49182},'testers' => {'pass' => 2},'uses' => ['Carp','Crypt::IDEA','Crypt::Rijndael','Digest::MD5','Digest::SHA256','Exporter','Palm::PDB','Palm::Raw','strict','vars']},'Paper-Specs-0.03.tar.gz' => {'author' => 'JLAWRENC','description' => 'Size and layout information for paper stock, forms, and labels.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 438,'pod' => 234,'pod_errors' => 1,'total' => 672,'with_comments' => 4},'releases' => 5,'size' => {'packed' => 6589,'unpacked' => 16424},'testers' => {'pass' => 2},'uses' => ['Paper::Specs::base::brand','Paper::Specs::base::label','Paper::Specs::base::sheet','strict','vars']},'Paper-Specs-0.05.tar.gz' => {'author' => 'JLAWRENC','description' => 'Size and layout information for paper stock, forms, and labels.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7626,'pod' => 232,'pod_errors' => 1,'total' => 7858,'with_comments' => 4},'releases' => 5,'size' => {'packed' => 16899,'unpacked' => 145778},'testers' => {'pass' => 2},'uses' => ['Paper::Specs::Axxxx','strict','vars']},'Parallel-ForkManager-0.7.5.tar.gz' => {'author' => 'DLUX','description' => 'A simple parallel processing fork manager','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 194,'pod' => 222,'pod_errors' => 0,'total' => 416,'with_comments' => 15},'releases' => 7,'size' => {'packed' => 5935,'unpacked' => 15262},'testers' => {'pass' => 10},'uses' => ['POSIX','strict','vars']},'Parallel-Jobs-0.04.tar.gz' => {'author' => 'JIK','description' => 'run jobs in parallel with access to their stdout and stderr','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 64,'pod_errors' => 0,'total' => 501,'with_comments' => 34},'releases' => 4,'size' => {'packed' => 5964,'unpacked' => 16666},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','File::Spec','IPC::Open3','POSIX','strict','vars','warnings']},'Parallel-MPI-0.03.tar.gz' => {'author' => 'JOSH','description' => 'Perl interface to the MPI message passing system','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 143,'pod' => 132,'pod_errors' => 0,'total' => 275,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 28047,'unpacked' => 130424},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Parallel-MPI-Simple-0.03.tar.gz' => {'author' => 'AJGOUGH','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 522,'pod' => 220,'pod_errors' => 0,'total' => 742,'with_comments' => 19},'releases' => 2,'requires' => ['Storable-2.07.tar.gz'],'requires_module' => {'Storable' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10282,'unpacked' => 33778},'testers' => {},'uses' => ['DynaLoader','Storable','strict','vars']},'Parallel-Pvm-1.3.0.tgz' => {'author' => 'DLECONTE','description' => 'Interface to the PVM messaging service','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 333,'pod' => 622,'pod_errors' => 0,'total' => 955,'with_comments' => 11},'releases' => 6,'size' => {'packed' => 17792,'unpacked' => 55589},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'ParallelUserAgent-2.54.tar.gz' => {'author' => 'MARCLANG','description' => 'Extension for LWP to allow parallel HTTP and FTP access','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3190,'pod' => 719,'pod_errors' => 2,'total' => 3909,'with_comments' => 742},'releases' => 18,'size' => {'packed' => 50395,'unpacked' => 178822},'testers' => {'fail' => 3,'pass' => 12,'tests' => '51'},'uses' => ['5.004','HTML::HeadParser','HTTP::Date','HTTP::Headers::Util','HTTP::Request','HTTP::Response','HTTP::Status','IO::Select','IO::Socket','IO::Socket::SSL','LWP::Debug','LWP::Parallel::Protocol','LWP::Parallel::Protocol::http','LWP::Parallel::RobotUA','LWP::Parallel::UserAgent','LWP::Protocol','LWP::Protocol::ftp','LWP::Protocol::http10','LWP::Protocol::https10','LWP::RobotUA','LWP::UserAgent','Net::SSL','UNIVERSAL','strict','vars']},'ParallelUserAgent-2.56.tar.gz' => {'author' => 'MARCLANG','description' => 'Extension for LWP to allow parallel HTTP and FTP access','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3638,'pod' => 710,'pod_errors' => 2,'total' => 4348,'with_comments' => 817},'releases' => 18,'size' => {'packed' => 55290,'unpacked' => 197270},'testers' => {'pass' => 2},'uses' => ['5.004','HTML::HeadParser','HTTP::Date','HTTP::Headers::Util','HTTP::Request','HTTP::Response','HTTP::Status','IO::Select','IO::Socket','IO::Socket::SSL','LWP::Debug','LWP::Protocol','LWP::Protocol::file','LWP::Protocol::ftp','LWP::Protocol::http10','LWP::Protocol::https10','LWP::RobotUA','LWP::UserAgent','Net::FTP','Net::HTTP','Net::SSL','UNIVERSAL','strict','vars']},'Params-Check-0.03.tar.gz' => {'author' => 'KANE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 421,'pod' => 215,'pod_errors' => 0,'total' => 636,'with_comments' => 38},'releases' => 2,'requires' => ['Locale-Maketext-Simple-0.02.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Locale::Maketext::Simple' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Locale-Maketext-Simple-0.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8096,'unpacked' => 26685},'testers' => {'pass' => 2},'uses' => ['Carp','Locale::Maketext::Simple','strict','vars']},'Params-Style-0.02.tar.gz' => {'author' => 'MIROD','description' => undef,'files' => ['README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 163,'pod' => 91,'pod_errors' => 0,'total' => 254,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 4664,'unpacked' => 14161},'testers' => {},'uses' => ['Exporter','Tie::Hash','strict','vars','warnings']},'Params-Validate-0.64.tar.gz' => {'author' => 'DROLSKY','description' => 'Validate method/function parameters','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 1019,'pod' => 510,'pod_errors' => 0,'total' => 1529,'with_comments' => 74},'releases' => 38,'requires' => ['Attribute-Handlers-0.78.tar.gz'],'requires_module' => {'Attribute::Handlers' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz'],'size' => {'packed' => 42907,'unpacked' => 151414},'testers' => {'pass' => 3},'uses' => ['Attribute::Handlers','Carp','DynaLoader','Exporter','Params::ValidatePP','XSLoader','strict','vars','warnings']},'Parrot-AssemblyTokenizer-0.01.tar.gz' => {'author' => 'SARGIE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 127,'pod' => 45,'pod_errors' => 1,'total' => 172,'with_comments' => 21},'releases' => 1,'size' => {'packed' => 2537,'unpacked' => 5700},'testers' => {'pass' => 3},'uses' => ['strict']},'Parse-AccessLogEntry-0.05.tar.gz' => {'author' => 'MSLAGLE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 44,'pod_errors' => 0,'total' => 107,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2763,'unpacked' => 6460},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','warnings']},'Parse-CVSEntries-0.02.tar.gz' => {'author' => 'RCLAMP','description' => undef,'files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 58,'pod_errors' => 0,'total' => 111,'with_comments' => 1},'releases' => 2,'requires' => ['Class-Accessor-0.18.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Accessor::Fast' => '0','Test::More' => '0'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2600,'unpacked' => 5287},'testers' => {'pass' => 2},'uses' => ['Class::Accessor::Fast','Date::Parse','strict']},'Parse-DebControl-1.8.tar.gz' => {'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 405,'pod' => 211,'pod_errors' => 0,'total' => 616,'with_comments' => 13},'releases' => 11,'requires' => ['IO-stringy-2.108.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'IO::Scalar' => '2.104','Test::More' => '0.45'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'testers' => {'pass' => 1},'uses' => ['IO::Scalar','strict','vars']},'Parse-Earley-0.15.tar.gz' => {'author' => 'LPALMER','description' => 'Parse I<any> Context-Free Grammar','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 563,'pod' => 245,'pod_errors' => 0,'total' => 808,'with_comments' => 34},'releases' => 1,'requires' => ['Text-Balanced-1.95.tar.gz'],'requires_module' => {'Text::Balanced' => 0},'requires_recursive' => ['Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 9980,'unpacked' => 30490},'testers' => {'pass' => 7},'uses' => ['Carp','strict']},'Parse-FixedLength-5.26.tar.gz' => {'author' => 'DOUGW','description' => 'Parse strings containing fixed length fields','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 400,'pod' => 315,'pod_errors' => 1,'total' => 715,'with_comments' => 38},'releases' => 29,'size' => {'packed' => 12803,'unpacked' => 50439},'testers' => {'pass' => 7},'uses' => ['Carp','strict','vars']},'Parse-Nessus-ENX-.01.tar.gz' => {'author' => 'DKYGER','description' => 'extract data from nessusWX export files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 94,'pod_errors' => 0,'total' => 243,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 2816,'unpacked' => 7169},'testers' => {'pass' => 2},'uses' => ['Exporter','constant','strict','vars']},'Parse-Nessus-NBE-.01.tar.gz' => {'author' => 'DKYGER','description' => 'extract data from nessus nbe files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 146,'pod' => 94,'pod_errors' => 0,'total' => 240,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 2847,'unpacked' => 7236},'testers' => {'pass' => 2},'uses' => ['Exporter','constant','strict','vars']},'Parse-Nibbler-1.10.tar.gz' => {'author' => 'GSLONDON','description' => 'Parse huge files using grammars written in pure perl.','files' => [],'lines' => {'nonpod' => 2068,'pod' => 431,'pod_errors' => 4,'total' => 2499,'with_comments' => 444},'releases' => 14,'size' => {'packed' => 33827,'unpacked' => 885107},'testers' => {'pass' => 3},'uses' => ['5.005_62','Carp','Data::Dumper','Exporter','Time::HiRes','strict','warnings']},'Parse-Nmap-XML-0.6.tar.gz' => {'author' => 'APERSAUD','description' => 'frontend to parse the Nmap scan data from the XML output (-oX).','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 468,'pod' => 412,'pod_errors' => 6,'total' => 880,'with_comments' => 26},'releases' => 2,'requires' => ['XML-Twig-3.10.tar.gz'],'requires_module' => {'XML::Twig' => 3},'requires_recursive' => ['XML-Parser-2.31.tar.gz','XML-Twig-3.10.tar.gz'],'size' => {'packed' => 15729,'unpacked' => 51381},'testers' => {'pass' => 2},'uses' => ['Exporter','XML::Twig','lib','strict','vars']},'Parse-Passwd-1.4.tar.gz' => {'author' => 'TBONE','description' => 'parse Unix passwd files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 56,'pod' => 84,'pod_errors' => 0,'total' => 140,'with_comments' => 6},'releases' => 4,'size' => {'packed' => 2281,'unpacked' => 4498},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'Parse-PerlConfig-0.05.tar.gz' => {'author' => 'MFOWLER','description' => 'parse a configuration file written in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1105,'pod' => 267,'pod_errors' => 0,'total' => 1372,'with_comments' => 82},'releases' => 3,'size' => {'packed' => 17014,'unpacked' => 55547},'testers' => {'pass' => 6},'uses' => ['Data::Dumper','Exporter','Fcntl','IO::Handle','strict']},'Parse-PhoneNumber-1.1.tar.gz' => {'author' => 'CWEST','description' => 'Parse Phone Numbers','files' => ['README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 140,'pod' => 72,'pod_errors' => 0,'total' => 212,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 4732,'unpacked' => 11703},'testers' => {'pass' => 4},'uses' => ['Carp','strict','vars']},'Parse-Pyapp-0.01.tar.gz' => {'author' => 'XERN','description' => 'PCFG Parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 229,'pod' => 94,'pod_errors' => 0,'total' => 323,'with_comments' => 26},'releases' => 1,'size' => {'packed' => 3747,'unpacked' => 9626},'testers' => {'pass' => 3},'uses' => ['5.006','B::Deparse','Data::Dumper','strict']},'Parse-RecDescent-1.94.tar.gz' => {'author' => 'DCONWAY','description' => 'Recursive descent parser generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3967,'pod' => 1901,'pod_errors' => 0,'total' => 5868,'with_comments' => 65},'releases' => 23,'requires' => ['Text-Balanced-1.95.tar.gz'],'requires_module' => {'Text::Balanced' => 0},'requires_recursive' => ['Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 126584,'unpacked' => 360123},'testers' => {'pass' => 7},'uses' => ['5.005','Carp','Data::Dumper','Text::Balanced','strict','vars']},'Parse-RecDescent-Consumer-1.03.tar.gz' => {'author' => 'TBONE','description' => 'reveal text matched through n token transitions.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 45,'pod_errors' => 0,'total' => 108,'with_comments' => 8},'releases' => 3,'size' => {'packed' => 2201,'unpacked' => 4067},'testers' => {'pass' => 6},'uses' => ['5.005_62','Exporter','strict','warnings']},'Parse-RecDescent-Deparse-1.00.tar.gz' => {'author' => 'SIMON','description' => 'Turn a Parse::RecDescent object back into its grammar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 36,'pod_errors' => 0,'total' => 212,'with_comments' => 35},'releases' => 1,'requires' => ['Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Parse::RecDescent' => 1},'requires_recursive' => ['Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 4192,'unpacked' => 11249},'testers' => {'pass' => 4},'uses' => ['5.006','Parse::RecDescent','strict','warnings']},'Parse-RecDescent-FAQ-2.37.tar.gz' => {'author' => 'TBONE','description' => 'the official, authorized FAQ for Parse::RecDescent.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 472,'pod' => 1745,'pod_errors' => 7,'total' => 2217,'with_comments' => 0},'releases' => 28,'size' => {'packed' => 42203,'unpacked' => 113104},'testers' => {'pass' => 4},'uses' => ['vars']},'Parse-Syslog-1.02.tar.gz' => {'author' => 'DSCHWEI','description' => 'Parse Unix syslog files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 264,'pod' => 142,'pod_errors' => 0,'total' => 406,'with_comments' => 27},'releases' => 8,'size' => {'packed' => 8036,'unpacked' => 40713},'testers' => {'pass' => 6},'uses' => ['Carp','Symbol','Time::Local','strict','vars']},'Parse-Text-0.02.tar.gz' => {'author' => 'CTWETEN','description' => 'Perl module for parsing plain text files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 37,'pod' => 25,'pod_errors' => 0,'total' => 62,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 2040,'unpacked' => 3340},'testers' => {'pass' => 8},'uses' => ['5.006','Exporter','strict','warnings']},'Parse-Tokens-0.27.tar.gz' => {'author' => 'MCKAY','description' => 'Base class for parsing tokens from text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 361,'pod' => 175,'pod_errors' => 1,'total' => 536,'with_comments' => 23},'releases' => 8,'size' => {'packed' => 5795,'unpacked' => 16343},'testers' => {'pass' => 11},'uses' => ['strict','vars']},'Parse-Vipar-0.01.tar.gz' => {'author' => 'SFINK','description' => 'Visual LALR parser debugger','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3248,'pod' => 29,'pod_errors' => 0,'total' => 3277,'with_comments' => 213},'releases' => 1,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 24391,'unpacked' => 93092},'testers' => {'fail' => 2,'pass' => 3},'uses' => ['Carp','POSIX','Parse::YALALR::Build','Parse::YALALR::Common','Parse::YALALR::Run','Tk','Tk::English','Tk::FBox','Tk::Font','Tk::Menu','Tk::Menubutton','Tk::Text','Tk::Tree','constant','lib','strict','vars']},'Parse-YALALR-0.02.tar.gz' => {'author' => 'SFINK','description' => 'Yet Another LALR parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2784,'pod' => 43,'pod_errors' => 0,'total' => 2827,'with_comments' => 564},'releases' => 2,'size' => {'packed' => 33366,'unpacked' => 121189},'testers' => {'pass' => 5},'uses' => ['Carp','fields','integer','lib','strict','vars']},'Parse-Yapp-1.05.tar.gz' => {'author' => 'FDESAR','description' => 'Perl extension for generating and using LALR parsers.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3288,'pod' => 386,'pod_errors' => 0,'total' => 3674,'with_comments' => 497},'releases' => 12,'size' => {'packed' => 47776,'unpacked' => 175465},'testers' => {'pass' => 19},'uses' => ['5.004','Carp','strict','vars']},'ParseLex-2.15.tar.gz' => {'author' => 'PVERD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3763,'pod' => 2298,'pod_errors' => 0,'total' => 6061,'with_comments' => 487},'releases' => 18,'size' => {'packed' => 51560,'unpacked' => 190843},'testers' => {'fail' => 15,'pass' => 4,'tests' => '7'},'uses' => ['${file}-t','5.000','5.003','5.004','5.005','Carp','FileHandle','Parse::Template','constant','integer','strict','vars']},'ParsePlainConfig-1.7a.tar.gz' => {'author' => 'CORLISS','description' => 'Human-readable config file parser/generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 558,'pod' => 201,'pod_errors' => 0,'total' => 759,'with_comments' => 105},'releases' => 1,'size' => {'packed' => 16116,'unpacked' => 47358},'testers' => {'pass' => 7},'uses' => ['Carp','Fcntl','Text::ParseWords','strict','vars']},'ParseTemplate-0.37.zip' => {'author' => 'PVERD','description' => 'Processeur de templates contenant des expressions Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 578,'pod' => 520,'pod_errors' => 0,'total' => 1098,'with_comments' => 59},'releases' => 6,'size' => {'packed' => 22670,'unpacked' => 45219},'testers' => {'fail' => 5,'tests' => '5'},'uses' => ['5.004','5.6.0','Carp','Symbol','constant','strict','vars','warnings']},'Passwd-DB-1.01.tar.gz' => {'author' => 'EESTABROO','description' => 'Perl module for manipulating a password file stored in a BerkeleyDB hash','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 254,'pod' => 70,'pod_errors' => 0,'total' => 324,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 3551,'unpacked' => 10831},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','DB_File','Exporter','strict','vars']},'Passwd-Linux-0.70.tar.gz' => {'author' => 'EESTABROO','description' => 'Perl module for manipulating the passwd and shadow files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 51,'pod_errors' => 0,'total' => 148,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 6391,'unpacked' => 18495},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Passwd-Solaris-0.65.tar.gz' => {'author' => 'EESTABROO','description' => 'Perl module for manipulating the passwd and shadow files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 51,'pod_errors' => 0,'total' => 148,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 6248,'unpacked' => 18129},'testers' => {'pass' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Patch-SREZIC-Tk-800_023.010.tar.gz' => {'author' => 'SREZIC','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4148,'pod' => 1366,'pod_errors' => 1,'total' => 5514,'with_comments' => 577},'releases' => 1,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => undef},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 134875,'unpacked' => 358613},'testers' => {},'uses' => ['5.004','Config','Cwd','File::Basename','File::Spec','Patch::SREZIC::Tk::DialogBox','Patch::SREZIC::Tk::DragDrop','Patch::SREZIC::Tk::DragDrop::XDNDSite','Patch::SREZIC::Tk::Entry','Patch::SREZIC::Tk::FBox','Patch::SREZIC::Tk::FileSelect','Patch::SREZIC::Tk::HList','Patch::SREZIC::Tk::IconList','Patch::SREZIC::Tk::LabFrame','Patch::SREZIC::Tk::Listbox','Patch::SREZIC::Tk::Menu','Patch::SREZIC::Tk::Scrollbar','Patch::SREZIC::Tk::Text','Patch::SREZIC::Tk::Widget','Tk','Tk::Derived','Tk::DialogBox','Tk::DragDrop','Tk::DragDrop::XDNDSite','Tk::DropSite','Tk::Entry','Tk::FBox','Tk::FileSelect','Tk::Frame','Tk::IconList','Tk::Listbox','Tk::Menu','Tk::Pane','Tk::Pixmap','Tk::Scrollbar','Tk::Text','Tk::Widget','Tk::Wm','strict','vars']},'Patch-SREZIC-Tk-800_024.004.tar.gz' => {'author' => 'SREZIC','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3634,'pod' => 1046,'pod_errors' => 0,'total' => 4680,'with_comments' => 482},'releases' => 1,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '800.024'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 133042,'unpacked' => 346138},'testers' => {},'uses' => ['Cwd','File::Basename','File::Spec','Tk','Tk::Derived','Tk::DialogBox','Tk::DragDrop','Tk::DragDrop::XDNDSite','Tk::DropSite','Tk::Entry','Tk::FBox','Tk::FileSelect','Tk::Frame','Tk::IconList','Tk::Listbox','Tk::Menu','Tk::Pane','Tk::Pixmap','Tk::Scrollbar','Tk::Text','Tk::Widget','Tk::Wm','strict','vars']},'Path-Class-0.03.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Cross-platform path specification manipulation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 318,'pod' => 360,'pod_errors' => 0,'total' => 678,'with_comments' => 4},'releases' => 3,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Spec' => 0,'File::Spec::Mac' => '1.3','overload' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7521,'unpacked' => 26931},'testers' => {'pass' => 3},'uses' => ['Exporter','File::Spec','strict']},'Paw-0.52.tar.gz' => {'author' => 'UGANSERT','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2732,'pod' => 2153,'pod_errors' => 0,'total' => 4885,'with_comments' => 238},'releases' => 8,'size' => {'packed' => 54319,'unpacked' => 217641},'testers' => {'fail' => 1,'pass' => 2,'tests' => '46'},'uses' => ['Carp','Curses','Exporter','Paw::Textbox','strict']},'Paw-0.54.tar.gz' => {'author' => 'UGANSERT','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2712,'pod' => 2153,'pod_errors' => 0,'total' => 4865,'with_comments' => 238},'releases' => 8,'size' => {'packed' => 52796,'unpacked' => 217582},'testers' => {'fail' => 2,'tests' => '46'},'uses' => ['Carp','Curses','Exporter','Paw::Box','Paw::Button','Paw::Container','Paw::Label','Paw::Line','Paw::Listbox','Paw::Scrollbar','Paw::Statusbar','Paw::Text_entry','Paw::Window','strict']},'PeekPoke-0.01.tar.gz' => {'author' => 'MJD','description' => 'Perl extension for reading and writing memory','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 23,'pod' => 31,'pod_errors' => 0,'total' => 54,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 1704,'unpacked' => 2658},'testers' => {'pass' => 3},'uses' => ['5.005_62','DynaLoader','Exporter','strict','warnings']},'Penguin-3.00.tar.gz' => {'author' => 'FSG','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 622,'pod' => 0,'pod_errors' => 0,'total' => 622,'with_comments' => 28},'releases' => 2,'size' => {'packed' => 19165,'unpacked' => 50378},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['IO::Socket','IPC::Open3','Safe']},'Penguin-Easy-1.1.tar.gz' => {'author' => 'JDUNCAN','description' => 'Provides quick, easy access to Penguin API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 23,'pod_errors' => 0,'total' => 95,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 4305,'unpacked' => 9015},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Penguin','Penguin::Channel::TCP::Client','Penguin::Compartment','Penguin::Frame::Code','Penguin::Frame::Data','Penguin::Rights','Penguin::Wrapper::PGP','Penguin::Wrapper::Transparent']},'PeopleSoft-1.05.tar.gz' => {'author' => 'GOEDICKE','description' => 'Procedural interface for working with PeopleSoft applications.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1154,'pod' => 207,'pod_errors' => 0,'total' => 1361,'with_comments' => 73},'releases' => 6,'requires' => ['DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Graph-0.20101.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'DBI' => 0,'Data::Dumper' => 0,'Getopt::Std' => 0,'Graph' => 0,'Time::Local' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Graph-0.20101.tar.gz','Heap-0.50.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 450849,'unpacked' => 913421},'testers' => {'pass' => 3},'uses' => ['DBI','Data::Dumper','Exporter','Getopt::Std','Graph','Time::Local','strict','vars']},'Perf-ARM-0.04.tar.gz' => {'author' => 'BBACKER','description' => 'Application Response Measurement','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 107,'pod_errors' => 0,'total' => 176,'with_comments' => 13},'releases' => 2,'size' => {'packed' => 6914,'unpacked' => 20588},'testers' => {},'uses' => ['5.005','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Period-1.20.tar.gz' => {'author' => 'PRYAN','description' => 'Code to deal with time periods','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 633,'pod' => 169,'pod_errors' => 0,'total' => 802,'with_comments' => 92},'releases' => 4,'size' => {'packed' => 10711,'unpacked' => 43130},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.001','Exporter']},'Perl-RPM-0.40.tar.gz' => {'author' => 'RJRAY','description' => 'Perl interface to the API for the RPM Package Manager','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1029,'pod' => 1325,'pod_errors' => 1,'total' => 2354,'with_comments' => 172},'releases' => 13,'size' => {'packed' => 54668,'unpacked' => 195214},'testers' => {'pass' => 1},'uses' => ['5.005','DynaLoader','Exporter','strict','subs','vars']},'Perl-Repository-APC-1.081.tar.gz' => {'author' => 'ANDK','description' => 'Class modelling "All Perl Changes" repository','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 637,'pod' => 143,'pod_errors' => 0,'total' => 780,'with_comments' => 45},'releases' => 20,'size' => {'packed' => 132487,'unpacked' => 505313},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','File::Basename','File::Spec','List::Util','strict','warnings']},'Perl-Tidy-20021130.tar.gz' => {'author' => 'SHANCOCK','description' => 'main module for the perltidy utility','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 23996,'pod' => 914,'pod_errors' => 0,'total' => 24910,'with_comments' => 5449},'releases' => 1,'size' => {'packed' => 305237,'unpacked' => 1202885},'testers' => {'pass' => 3},'uses' => ['5.004','Carp','Exporter','File::Basename','Getopt::Long','IO::File','constant','strict','vars','warnings']},'Perl-Visualize-1.02.tar.gz' => {'author' => 'JNAGRA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 343,'pod' => 341,'pod_errors' => 0,'total' => 684,'with_comments' => 3},'releases' => 3,'size' => {'packed' => 367158,'unpacked' => 527864},'testers' => {'pass' => 2},'uses' => ['5.008','Exporter','strict','warnings']},'Perl-WhichPhase-0.01.tar.gz' => {'author' => 'JSMITH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 38,'pod' => 70,'pod_errors' => 1,'total' => 108,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1926,'unpacked' => 4761},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'Perl6-Binding-0.4.tar.gz' => {'author' => 'KVAIL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 906,'pod' => 99,'pod_errors' => 0,'total' => 1005,'with_comments' => 90},'releases' => 4,'requires' => ['Filter-1.29.tar.gz','PadWalker-0.09.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Filter::Util::Call' => '1.06','PadWalker' => '0.09','Text::Balanced' => '1.89'},'requires_recursive' => ['Filter-1.29.tar.gz','PadWalker-0.09.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 15551,'unpacked' => 49106},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','Filter::Util::Call','PadWalker','Text::Balanced','XSLoader','strict','vars','warnings']},'Perl6-Classes-0.22.tar.gz' => {'author' => 'LPALMER','description' => 'Perl 6 class syntax for Perl 5','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 433,'pod' => 178,'pod_errors' => 0,'total' => 611,'with_comments' => 13},'releases' => 1,'requires' => ['Filter-Simple-0.78.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Filter::Simple' => 0,'Test::Simple' => 0,'Text::Balanced' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 7319,'unpacked' => 22200},'testers' => {'pass' => 4},'uses' => ['$_','$name','${name}__class','Carp','Filter::Simple','Text::Balanced']},'Perl6-Currying-0.05.tar.gz' => {'author' => 'DCONWAY','description' => 'Perl 6 subroutine currying for Perl 5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 207,'pod_errors' => 0,'total' => 344,'with_comments' => 6},'releases' => 3,'requires' => ['Filter-Simple-0.78.tar.gz'],'requires_module' => {'Filter::Simple' => '0.78'},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 5065,'unpacked' => 13564},'testers' => {'pass' => 5},'uses' => ['Carp','Filter::Simple']},'Perl6-Interpolators-0.03.zip' => {'author' => 'BRENTDAX','description' => 'Use Perl 6 function-interpolation syntax','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 48,'pod' => 50,'pod_errors' => 0,'total' => 98,'with_comments' => 0},'releases' => 3,'requires' => ['Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Filter::Simple' => '0.60','Text::Balanced' => '1.85'},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3515,'unpacked' => 4734},'testers' => {'pass' => 3},'uses' => ['5.6.0','Text::Balanced','strict','warnings']},'Perl6-Parameters-0.03.tar.gz' => {'author' => 'BRENTDAX','description' => 'Use Perl 6-style named parameters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 218,'pod' => 93,'pod_errors' => 0,'total' => 311,'with_comments' => 23},'releases' => 3,'requires' => ['Filter-Simple-0.78.tar.gz','Switch-2.09.tar.gz'],'requires_module' => {'Filter::Simple' => '0.78','Switch' => '2.09'},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Switch-2.09.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 4414,'unpacked' => 10320},'testers' => {'pass' => 5},'uses' => ['5.006','Filter::Simple','Switch','strict','warnings']},'Perl6-Placeholders-0.05.tar.gz' => {'author' => 'DCONWAY','description' => 'Perl 6 implicitly declared parameters for Perl 5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 56,'pod' => 131,'pod_errors' => 0,'total' => 187,'with_comments' => 0},'releases' => 1,'requires' => ['Filter-Simple-0.78.tar.gz'],'requires_module' => {'Filter::Simple' => '0.78'},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3669,'unpacked' => 8945},'testers' => {'pass' => 5},'uses' => ['Filter::Simple','re']},'Perl6-Tokener-0.01.tar.gz' => {'author' => 'SIMON','description' => 'It\'s a Perl 6 tokener. It tokenises Perl 6.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 615,'pod' => 31,'pod_errors' => 0,'total' => 646,'with_comments' => 31},'releases' => 1,'size' => {'packed' => 6405,'unpacked' => 22532},'testers' => {'pass' => 4},'uses' => ['Text::Balanced']},'Perl6-Variables-0.01.tar.gz' => {'author' => 'DCONWAY','description' => 'Perl 6 variable syntax for Perl 5','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 44,'pod' => 83,'pod_errors' => 0,'total' => 127,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2879,'unpacked' => 6477},'testers' => {'fail' => 4,'pass' => 6},'uses' => ['Filter::Simple']},'PerlBean-0.8.tar.gz' => {'author' => 'ZOCCAV','description' => 'Package to generate bean like Perl modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9611,'pod' => 4957,'pod_errors' => 0,'total' => 14568,'with_comments' => 922},'releases' => 6,'requires' => ['Error-0.15.tar.gz'],'requires_module' => {'Error' => 0},'requires_recursive' => ['Error-0.15.tar.gz'],'size' => {'packed' => 67061,'unpacked' => 513976},'testers' => {'pass' => 3},'uses' => ['','5.005','AutoLoader','Error','Exporter','IO::File','strict','warnings']},'PerlIO-gzip-0.15.tar.gz' => {'author' => 'NWCLARK','description' => 'provide a PerlIO layer to gzip/gunzip','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 72,'pod_errors' => 0,'total' => 115,'with_comments' => 0},'releases' => 13,'size' => {'packed' => 17714,'unpacked' => 59701},'testers' => {'pass' => 1},'uses' => ['5.008','strict','warnings']},'PerlIO-subfile-0.07.tar.gz' => {'author' => 'NWCLARK','description' => 'Perl extension to provide a PerlIO layer to pretend a subsection of a file is a whole regular file.','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 59,'pod_errors' => 0,'total' => 104,'with_comments' => 0},'releases' => 7,'size' => {'packed' => 8448,'unpacked' => 24054},'testers' => {'pass' => 2},'uses' => ['5.008','XSLoader','strict','warnings']},'PerlIO-via-Base64-0.05.tar.gz' => {'author' => 'ELIZABETH','description' => 'PerlIO layer for base64 (MIME) encoded strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 56,'pod_errors' => 0,'total' => 189,'with_comments' => 54},'releases' => 3,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::Base64' => 0},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 4363,'unpacked' => 9805},'testers' => {'pass' => 2},'uses' => ['strict']},'PerlIO-via-Bastardize-0.01.tar.gz' => {'author' => 'XERN','description' => 'PerlIO layer for bastardizing text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 56,'pod' => 22,'pod_errors' => 0,'total' => 78,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 1436,'unpacked' => 2381},'testers' => {'pass' => 8},'uses' => ['5.006','Text::Bastardize','strict']},'PerlIO-via-Include-0.01.tar.gz' => {'author' => 'ELIZABETH','description' => 'PerlIO layer for including other files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 217,'pod' => 79,'pod_errors' => 0,'total' => 296,'with_comments' => 85},'releases' => 1,'size' => {'packed' => 4181,'unpacked' => 11812},'testers' => {'pass' => 1},'uses' => ['strict']},'PerlIO-via-LineNumber-0.01.tar.gz' => {'author' => 'ELIZABETH','description' => 'PerlIO layer for prefixing line numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 164,'pod' => 113,'pod_errors' => 0,'total' => 277,'with_comments' => 66},'releases' => 1,'size' => {'packed' => 4033,'unpacked' => 11297},'testers' => {'pass' => 1},'uses' => ['strict']},'PerlIO-via-MD5-0.04.tar.gz' => {'author' => 'ELIZABETH','description' => 'PerlIO layer for creating an MD5 digest of a file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 112,'pod' => 44,'pod_errors' => 0,'total' => 156,'with_comments' => 44},'releases' => 2,'requires' => ['Digest-MD5-2.26.tar.gz'],'requires_module' => {'Digest::MD5' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 3473,'unpacked' => 7373},'testers' => {'pass' => 1},'uses' => ['strict']},'PerlIO-via-Pod-0.02.tar.gz' => {'author' => 'ELIZABETH','description' => 'PerlIO layer for extracting plain old documentation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 42,'pod_errors' => 0,'total' => 134,'with_comments' => 39},'releases' => 2,'size' => {'packed' => 2929,'unpacked' => 6005},'testers' => {'pass' => 2},'uses' => ['strict']},'PerlIO-via-QuotedPrint-0.04.tar.gz' => {'author' => 'ELIZABETH','description' => 'PerlIO layer for quoted-printable strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 58,'pod' => 29,'pod_errors' => 0,'total' => 87,'with_comments' => 25},'releases' => 2,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::QuotedPrint' => 0},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 2867,'unpacked' => 5540},'testers' => {'pass' => 1},'uses' => ['strict']},'PerlIO-via-Rotate-0.04.tar.gz' => {'author' => 'ELIZABETH','description' => 'PerlIO layer for encoding using rotational deviation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 164,'pod' => 39,'pod_errors' => 0,'total' => 203,'with_comments' => 45},'releases' => 2,'size' => {'packed' => 4592,'unpacked' => 13981},'testers' => {'pass' => 1},'uses' => ['bytes','strict']},'PerlIO-via-StripHTML-0.04.tar.gz' => {'author' => 'RGARCIA','description' => 'PerlIO layer to strip HTML tags from an input file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 61,'pod' => 29,'pod_errors' => 0,'total' => 90,'with_comments' => 2},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz'],'requires_module' => {'HTML::Parser' => 3},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 2385,'unpacked' => 4312},'testers' => {'pass' => 1},'uses' => ['5.008','HTML::Parser','strict','warnings']},'PerlIO-via-UnComment-0.01.tar.gz' => {'author' => 'ELIZABETH','description' => 'PerlIO layer for removing comments','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 52,'pod_errors' => 0,'total' => 129,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 2715,'unpacked' => 5603},'testers' => {'pass' => 2},'uses' => ['strict']},'PerlIO-via-UnPod-0.02.tar.gz' => {'author' => 'ELIZABETH','description' => 'PerlIO layer for removing plain old documentation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 42,'pod_errors' => 0,'total' => 131,'with_comments' => 38},'releases' => 2,'size' => {'packed' => 2892,'unpacked' => 5856},'testers' => {'pass' => 2},'uses' => ['strict']},'PerlIO-via-chop-0.01.tar.gz' => {'author' => 'AUTRIJUS','description' => 'PerlIO layer to chop the last byte outputted','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 38,'pod' => 32,'pod_errors' => 0,'total' => 70,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 2454,'unpacked' => 4401},'testers' => {'pass' => 2},'uses' => ['strict']},'PerlIO-via-trap-0.09.tar.gz' => {'author' => 'CLKAO','description' => 'PerlIO layer to trap write','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 58,'pod' => 40,'pod_errors' => 0,'total' => 98,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 2063,'unpacked' => 3435},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','IO::Handle','strict']},'PerlInterp-0.02.tar.gz' => {'author' => 'GSAR','description' => 'Create Perl interpreters from within Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14,'pod' => 0,'pod_errors' => 0,'total' => 14,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 2901,'unpacked' => 6762},'testers' => {'fail' => 1},'uses' => ['5.005','DynaLoader']},'PerlKDE-0.004.tar.gz' => {'author' => 'AWIN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2748,'pod' => 0,'pod_errors' => 0,'total' => 2748,'with_comments' => 406},'releases' => 4,'requires' => ['PerlQt-3.006.tar.gz'],'requires_module' => {'Qt' => '2.104'},'requires_recursive' => ['PerlQt-3.006.tar.gz'],'size' => {'packed' => 94114,'unpacked' => 402474},'testers' => {},'uses' => ['Carp','Cwd','DynaLoader','ExtUtils::MakeMaker','Qt','perlqt.conf','strict']},'PerlMagick-5.56.tar.gz' => {'author' => 'JCRISTY','description' => 'Read, query, transform, and write images','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 36,'pod_errors' => 0,'total' => 180,'with_comments' => 14},'releases' => 72,'size' => {'packed' => 989704,'unpacked' => 2576617},'testers' => {'fail' => 1},'uses' => ['5.002','AutoLoader','Carp','DynaLoader','Exporter','vars']},'PerlPoint-Converters-1.01.tar.gz' => {'author' => 'LDOMKE','description' => 'README and common functions for PerlPoint converters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 509,'pod' => 484,'pod_errors' => 0,'total' => 993,'with_comments' => 32},'releases' => 7,'requires' => ['Getopt-ArgvFile-1.06.tgz','PerlPoint-Package-0.38.tgz'],'requires_module' => {'Getopt::ArgvFile' => '1.01','PerlPoint::Parser' => '0.36'},'requires_recursive' => ['Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getopt-ArgvFile-1.06.tgz','IO-1.20.tar.gz','PerlPoint-Package-0.38.tgz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 162701,'unpacked' => 466624},'testers' => {'pass' => 4},'uses' => ['Carp','Cwd','Exporter','File::Copy','PerlPoint::Constants','PerlPoint::Tags','strict','vars']},'PerlPoint-Package-0.38.tgz' => {'author' => 'JSTENZEL','description' => 'processes PerlPoint tag declarations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10582,'pod' => 2889,'pod_errors' => 0,'total' => 13471,'with_comments' => 2816},'releases' => 12,'requires' => ['Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Digest::SHA1' => 1,'File::Spec' => '0.8','File::Temp' => '0.12','IO::File' => 1,'Storable' => 1,'Test::Harness' => '1.25','Test::More' => '0.11'},'requires_recursive' => ['Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 322109,'unpacked' => 1458143},'testers' => {'pass' => 3},'uses' => ['5.004','5.00503','Carp','Cwd','Data::Dumper','Digest::SHA1','Exporter','File::Basename','File::Spec::Functions','File::Temp','IO::File','PerlPoint::Tags::HTML','Storable','constant','fields','strict','vars']},'PerlQt-1.05.tar.gz' => {'author' => 'AWIN','description' => 'A Perl module interface to Qt','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5500,'pod' => 2161,'pod_errors' => 0,'total' => 7661,'with_comments' => 201},'releases' => 24,'size' => {'packed' => 162054,'unpacked' => 766933},'testers' => {},'uses' => ['5.004','CannonField','Carp','DynaLoader','Exporter','LCDRange','POSIX','QAccel','QApplication','QBitmap','QBrush','QButton','QButtonGroup','QClipboard','QColor','QCursor','QDialog','QEvent','QFileDialog','QFont','QFontInfo','QFontMetrics','QFrame','QGlobal','QGroupBox','QImage','QLCDNumber','QLabel','QLayout','QMenuBar','QMenuData','QMultiLineEdit','QObject','QPaintDevice','QPainter','QPalette','QPen','QPicture','QPixmap','QPoint','QPointArray','QPopupMenu','QPushButton','QRadioButton','QRangeControl','QRect','QRegion','QScrollBar','QSize','QSlider','QTabDialog','QTableView','QTimer','QToolTip','QWMatrix','QWidget','Qt','signals','slots','strict','vars']},'PerlQt-1.06.tar.gz' => {'author' => 'AWIN','description' => 'A Perl module interface to Qt','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5495,'pod' => 2161,'pod_errors' => 0,'total' => 7656,'with_comments' => 201},'releases' => 24,'size' => {'packed' => 162346,'unpacked' => 767417},'testers' => {},'uses' => ['5.004','CannonField','Carp','DynaLoader','Exporter','LCDRange','POSIX','Qt','signals','slots','strict','vars']},'PerlQt-2.105.tar.gz' => {'author' => 'AWIN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9768,'pod' => 355,'pod_errors' => 0,'total' => 10123,'with_comments' => 770},'releases' => 24,'size' => {'packed' => 211952,'unpacked' => 970310},'testers' => {'pass' => 1},'uses' => ['CannonField','Carp','Cwd','DynaLoader','Exporter','ExtUtils::MakeMaker','LCDRange','POSIX','Qt','Qt::signals','Qt::slots','perlqt.conf','strict','vars']},'PerlQt-3.006.tar.gz' => {'author' => 'GGARAND','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 12395,'pod' => 1913,'pod_errors' => 0,'total' => 14308,'with_comments' => 855},'releases' => 24,'size' => {'packed' => 839542,'unpacked' => 3363618},'testers' => {},'uses' => ['5.006','Ast','CannonField','Carp','DesignerMimeSourceFactory_richedit','Exporter','File::Basename','File::Path','LCDRange','OpenGL','POSIX','Term::ReadLine','XSLoader','kalyptus','kdoc','overload','strict','vars','warnings']},'PerlVision-1.5.tar.gz' => {'author' => 'AGUL','description' => 'Text-mode user interface widgets','files' => ['MANIFEST'],'lines' => {'nonpod' => 1965,'pod' => 389,'pod_errors' => 1,'total' => 2354,'with_comments' => 170},'releases' => 2,'size' => {'packed' => 19538,'unpacked' => 77855},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.000','Curses','vars']},'Perlbug-2.93.tar.gz' => {'author' => 'RFOLEY','description' => 'PerlBug DataBase specification','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 16965,'pod' => 5512,'pod_errors' => 16,'total' => 22477,'with_comments' => 1455},'releases' => 8,'requires' => ['CGI.pm-2.98.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','IO-1.20.tar.gz','MailTools-1.58.tar.gz','Test-1.24.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CGI' => 0,'Carp' => 0,'DBI' => 0,'Data::Dumper' => 0,'Email::Valid' => '0.13','Exporter' => 0,'File::Spec' => 0,'FileHandle' => 0,'Getopt::Std' => 0,'HTML::Entities' => 0,'IO::File' => 0,'Mail::Address' => 0,'Mail::Header' => 0,'Mail::Internet' => 0,'Mail::Send' => 0,'Mysql' => 0,'Shell' => 0,'Sys::Hostname' => 0,'Test' => 0,'URI::Escape' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MailTools-1.58.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 505899,'unpacked' => 1882028},'testers' => {'fail' => 5,'tests' => '127'},'uses' => ['$file','Apache::Constants','AutoLoader','Benchmark','CGI','CGI::Carp','Carp','DBI','Data::Dumper','Devel::Trace','Email::Valid','Exporter','File::Spec','FileHandle','GD::Graph::pie','Getopt::Std','HTML::Entities','IO::File','Mail::Address','Mail::Header','Mail::Internet','Mail::Send','Perlbug::Template','Shell','Sys::Hostname','Test','Text::Wrap','UNIVERSAL','URI::Escape','lib','strict','vars']},'Persistence-Database-SQL-1.9.tar.gz' => {'author' => 'AGUL','description' => 'Object Persistence in SQL Databases.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 127,'pod' => 165,'pod_errors' => 0,'total' => 292,'with_comments' => 10},'releases' => 4,'requires' => ['Persistence-Object-Postgres-1.24.tar.gz'],'requires_module' => {'Persistence::Object::Postgres' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Persistence-Object-Postgres-1.24.tar.gz'],'size' => {'packed' => 3556,'unpacked' => 8646},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','strict','vars']},'Persistence-Object-Postgres-1.24.tar.gz' => {'author' => 'AGUL','description' => 'Object Persistence with PostgreSQL.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 357,'pod' => 112,'pod_errors' => 0,'total' => 469,'with_comments' => 12},'releases' => 6,'requires' => ['DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz'],'requires_module' => {'DBI' => 0,'Data::Dumper' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 4942,'unpacked' => 13731},'testers' => {'pass' => 1,'tests' => '0','unknown' => 6},'uses' => ['Carp','DBI','Data::Dumper','IO::Handle','IO::Wrap','vars']},'Persistent-Base-0.52.tar.gz' => {'author' => 'DWINTERS','description' => 'Persistent base classes (& DBM/File classes)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4042,'pod' => 2727,'pod_errors' => 0,'total' => 6769,'with_comments' => 1190},'releases' => 3,'size' => {'packed' => 39240,'unpacked' => 225098},'testers' => {'pass' => 12},'uses' => ['5.004','Carp','English','Fcntl','strict','vars']},'Persistent-DBI-0.50.tar.gz' => {'author' => 'DWINTERS','description' => 'Persistent abstract class for DBI databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 576,'pod' => 436,'pod_errors' => 0,'total' => 1012,'with_comments' => 135},'releases' => 1,'size' => {'packed' => 9771,'unpacked' => 36021},'testers' => {'pass' => 4},'uses' => ['5.004','Carp','DBI','English','Persistent::Base','strict','vars']},'Persistent-Hash-0.5.tar.gz' => {'author' => 'BBEAUSEJ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1097,'pod' => 876,'pod_errors' => 0,'total' => 1973,'with_comments' => 24},'releases' => 2,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '0'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 28264,'unpacked' => 129435},'testers' => {'pass' => 3},'uses' => ['Carp','DBI','Data::Dumper','constant','strict','vars']},'Persistent-LDAP-0.50.tar.gz' => {'author' => 'DWINTERS','description' => 'Persistent class for LDAP directories','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 688,'pod' => 438,'pod_errors' => 0,'total' => 1126,'with_comments' => 184},'releases' => 1,'size' => {'packed' => 14938,'unpacked' => 72620},'testers' => {'fail' => 1,'tests' => '2'},'uses' => ['5.004','Carp','English','Net::LDAP','Persistent::Base','strict','vars']},'Persistent-MySQL-0.50.tar.gz' => {'author' => 'DWINTERS','description' => 'Persistent class for MySQL databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 247,'pod' => 180,'pod_errors' => 0,'total' => 427,'with_comments' => 90},'releases' => 1,'size' => {'packed' => 10727,'unpacked' => 49221},'testers' => {'pass' => 1},'uses' => ['5.004','Carp','English','Persistent::DBI','strict','vars']},'Persistent-Oracle-0.50.tar.gz' => {'author' => 'DWINTERS','description' => 'Persistent class for Oracle databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 248,'pod' => 182,'pod_errors' => 0,'total' => 430,'with_comments' => 91},'releases' => 1,'size' => {'packed' => 10976,'unpacked' => 51355},'testers' => {},'uses' => ['5.004','Carp','English','Persistent::DBI','strict','vars']},'Persistent-Sybase-0.50.tar.gz' => {'author' => 'DWINTERS','description' => 'Persistent class for Sybase databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 255,'pod' => 180,'pod_errors' => 0,'total' => 435,'with_comments' => 92},'releases' => 1,'size' => {'packed' => 10837,'unpacked' => 49691},'testers' => {},'uses' => ['5.004','Carp','English','Persistent::DBI','strict','vars']},'Persistent-mSQL-0.50.tar.gz' => {'author' => 'DWINTERS','description' => 'Persistent class for mSQL databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 261,'pod' => 182,'pod_errors' => 0,'total' => 443,'with_comments' => 90},'releases' => 1,'size' => {'packed' => 10801,'unpacked' => 48740},'testers' => {},'uses' => ['5.004','Carp','English','Persistent::DBI','strict','vars']},'PersistentPerl-2.21.tar.gz' => {'author' => 'HORROCKS','description' => 'Speed up perl scripts by running them persistently.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 591,'pod' => 610,'pod_errors' => 0,'total' => 1201,'with_comments' => 53},'releases' => 2,'size' => {'packed' => 142839,'unpacked' => 478103},'testers' => {'pass' => 3},'uses' => ['AutoLoader','Cwd','DynaLoader','Exporter','Socket','strict','vars']},'Petal-0.3.tgz' => {'author' => 'JHIVER','description' => 'Perl Template Attribute Language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1652,'pod' => 820,'pod_errors' => 0,'total' => 2472,'with_comments' => 160},'releases' => 36,'requires' => ['HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'HTML::TreeBuilder' => '3.11','XML::Parser' => '2.31'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 22422,'unpacked' => 79499},'testers' => {'pass' => 3},'uses' => ['Carp','Digest::MD5','File::Spec','HTML::TreeBuilder','Petal::Cache::Disk','Petal::Cache::Memory','Petal::CodeGenerator','Petal::Hash','Petal::Hash::Encode_XML','Petal::Hash::FALSE','Petal::Hash::SET','Petal::Hash::TRUE','Petal::Hash::VAR','Petal::Parser::HTMLWrapper','Petal::Parser::XMLWrapper','Safe','XML::Parser','strict','vars','warnings']},'Petal-0.64.tgz' => {'author' => 'JHIVER','description' => 'Perl Template Attribute Language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2337,'pod' => 987,'pod_errors' => 0,'total' => 3324,'with_comments' => 208},'releases' => 36,'requires' => ['HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'HTML::TreeBuilder' => '3.12','XML::Parser' => '2.31'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 33594,'unpacked' => 120143},'testers' => {'fail' => 2,'pass' => 2,'tests' => '44'},'uses' => ['Carp','Digest::MD5','File::Spec','HTML::Parser','HTML::TreeBuilder','Petal::Cache::Disk','Petal::Cache::Memory','Petal::Canonicalizer::XHTML','Petal::Canonicalizer::XML','Petal::CodeGenerator','Petal::Hash','Petal::Hash::String','Petal::Parser::HTMLWrapper','Petal::Parser::XMLWrapper','Safe','XML::Parser','strict','vars','warnings']},'Petal-0.80.tar.gz' => {'author' => 'JHIVER','description' => 'Perl Template Attribute Language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2466,'pod' => 1469,'pod_errors' => 0,'total' => 3935,'with_comments' => 214},'releases' => 36,'requires' => ['HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'HTML::TreeBuilder' => '3.12','XML::Parser' => '2.31'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 39457,'unpacked' => 147790},'testers' => {'pass' => 2},'uses' => ['Carp','Digest::MD5','File::Spec','HTML::Parser','HTML::TreeBuilder','Petal::Cache::Disk','Petal::Cache::Memory','Petal::Canonicalizer::XHTML','Petal::Canonicalizer::XML','Petal::CodeGenerator','Petal::Hash','Petal::Hash::String','Petal::Hash::Var','Petal::Parser::HTMLWrapper','Petal::Parser::XMLWrapper','Petal::XML_Encode_Decode','Safe','XML::Parser','strict','vars','warnings']},'Petal-0.90.tar.gz' => {'author' => 'JHIVER','description' => 'Perl Template Attribute Language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2715,'pod' => 1592,'pod_errors' => 0,'total' => 4307,'with_comments' => 230},'releases' => 36,'requires' => ['HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'HTML::TreeBuilder' => '3.12','XML::Parser' => '2.31'},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 45741,'unpacked' => 178093},'testers' => {'pass' => 2},'uses' => ['Carp','Digest::MD5','File::Spec','HTML::Parser','HTML::TreeBuilder','Petal::Cache::Disk','Petal::Cache::Memory','Petal::Canonicalizer::XHTML','Petal::Canonicalizer::XML','Petal::CodeGenerator','Petal::Hash','Petal::Hash::String','Petal::Parser::HTMLWrapper','Petal::Parser::XMLWrapper','Petal::XML_Encode_Decode','Safe','XML::Parser','strict','vars','warnings']},'Petal-1.00.tar.gz' => {'author' => 'JHIVER','description' => 'Perl Template Attribute Language - TAL for Perl!','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3194,'pod' => 1020,'pod_errors' => 0,'total' => 4214,'with_comments' => 550},'releases' => 36,'requires' => ['CGI.pm-2.98.tar.gz','HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'CGI' => '2.97','HTML::TreeBuilder' => '3.12','XML::Parser' => '2.31'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 51971,'unpacked' => 204153},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Dumper','Digest::MD5','Encode','File::Spec','HTML::Parser','HTML::TreeBuilder','Safe','Scalar::Util','UNIVERSAL','XML::Parser','bytes','strict','vars','warnings']},'Petal-CodePerl-0.05.tar.gz' => {'author' => 'FDALY','description' => 'Make Petal go faster by compiling the expressions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10603,'pod' => 266,'pod_errors' => 0,'total' => 10869,'with_comments' => 181},'releases' => 4,'requires' => ['Code-Perl-0.03.tar.gz','Parse-RecDescent-1.94.tar.gz','Petal-1.00.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Deep-0.06.tar.gz','Test-NoWarnings-0.05.tar.gz'],'requires_module' => {'Code::Perl' => '0.01','Parse::RecDescent' => '1.80','Petal' => '0.95','Scalar::Util' => '1.09','Test::Deep' => '0.02','Test::NoWarnings' => '0.03'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Class-MethodMaker-1.10.tar.gz','Code-Perl-0.03.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','Parse-RecDescent-1.94.tar.gz','Petal-1.00.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Deep-0.06.tar.gz','Test-NoWarnings-0.05.tar.gz','Test-Tester-0.06.tar.gz','Text-Balanced-1.95.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 42904,'unpacked' => 491181},'testers' => {},'uses' => ['','Carp','Code::Perl::Expr','Code::Perl::Expr::Base','Data::Dumper','Exporter','Parse::RecDescent','Petal','Petal::CodeGenerator','Petal::CodePerl::GrammarLoader','Scalar::Util','strict','vars','warnings']},'Pg-Simple-1.0.tar.gz' => {'author' => 'DJERIUS','description' => 'simple OO interface to PostgreSQL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 432,'pod' => 181,'pod_errors' => 0,'total' => 613,'with_comments' => 30},'releases' => 1,'requires' => ['pgsql_perl5-1.9.0.tar.gz'],'requires_module' => {'Pg' => 0},'requires_recursive' => ['pgsql_perl5-1.9.0.tar.gz'],'size' => {'packed' => 11139,'unpacked' => 32879},'testers' => {'pass' => 1},'uses' => ['Carp','Pg','strict','vars']},'PgSQL-0.51.tar.gz' => {'author' => 'GTHYNI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 586,'pod' => 0,'pod_errors' => 0,'total' => 586,'with_comments' => 36},'releases' => 2,'size' => {'packed' => 8073,'unpacked' => 22603},'testers' => {'fail' => 4},'uses' => ['IO::Select','IO::Socket::UNIX','integer','strict','vars']},'Ph-2.01.tar.gz' => {'author' => 'GDAMORE','description' => '- provide a perl API for talking to CSO ph servers.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 597,'pod' => 124,'pod_errors' => 0,'total' => 721,'with_comments' => 71},'releases' => 1,'size' => {'packed' => 8798,'unpacked' => 23601},'testers' => {'pass' => 2},'uses' => ['5.003','Carp','IO::Socket','strict','vars']},'PhotoIndex-1.20.tar.gz' => {'author' => 'MYNEID','description' => 'Perl extension for creating a Photo Gallery with mod_perl creating everything on the fly','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 591,'pod' => 71,'pod_errors' => 0,'total' => 662,'with_comments' => 50},'releases' => 3,'size' => {'packed' => 8006,'unpacked' => 33586},'testers' => {'fail' => 1},'uses' => ['Apache','Apache::Constants','AutoLoader','CGI::Carp','Carp','DynaLoader','Exporter','Image::Magick','Imager','strict','vars']},'Physics-Particles-1.00.tar.gz' => {'author' => 'SMUELLER','description' => 'Simulate particle dynamics','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 334,'pod' => 126,'pod_errors' => 0,'total' => 460,'with_comments' => 57},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Data::Dumper' => 2,'Test::More' => '0.44'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 134756,'unpacked' => 164985},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Data::Dumper','constant','strict','vars','warnings']},'Physics-Springs-1.00.tar.gz' => {'author' => 'SMUELLER','description' => 'Simulate particle dynamics with springs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 127,'pod' => 73,'pod_errors' => 0,'total' => 200,'with_comments' => 2},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz','Physics-Particles-1.00.tar.gz','Sub-Assert-1.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Physics::Particles' => 1,'Sub::Assert' => 0,'Test::More' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Physics-Particles-1.00.tar.gz','Sub-Assert-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 58623,'unpacked' => 73329},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Physics::Particles','Sub::Assert','strict','warnings']},'Physics-Springs-Friction-1.00.tar.gz' => {'author' => 'SMUELLER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 192,'pod' => 107,'pod_errors' => 0,'total' => 299,'with_comments' => 7},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz','Physics-Particles-1.00.tar.gz','Physics-Springs-1.00.tar.gz','Sub-Assert-1.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Physics::Particles' => 1,'Physics::Springs' => 1,'Sub::Assert' => 0,'Test::More' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Physics-Particles-1.00.tar.gz','Physics-Springs-1.00.tar.gz','Sub-Assert-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19532,'unpacked' => 34438},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Data::Dumper','Physics::Springs','Sub::Assert','constant','strict','warnings']},'Physics-Unit-0.04.tar.gz' => {'author' => 'KLORTHO','description' => 'Manipulate physics units and dimensions.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2198,'pod' => 1024,'pod_errors' => 0,'total' => 3222,'with_comments' => 172},'releases' => 4,'size' => {'packed' => 48257,'unpacked' => 261067},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','strict','vars']},'Piet-Interpreter-0.03.tar.gz' => {'author' => 'MAJCHER','description' => 'Interpreter for the Piet programming language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1087,'pod' => 251,'pod_errors' => 0,'total' => 1338,'with_comments' => 129},'releases' => 2,'requires' => ['PerlMagick-5.56.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Image::Magick' => '5.39','POSIX' => '1.03'},'requires_recursive' => ['PerlMagick-5.56.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17164,'unpacked' => 78749},'testers' => {},'uses' => ['5.6.0','Carp','Image::Magick','POSIX','strict']},'Pilot-0.4.tar.gz' => {'author' => 'JWIEGLEY','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 1451,'pod' => 0,'pod_errors' => 0,'total' => 1451,'with_comments' => 75},'releases' => 1,'size' => {'packed' => 10473,'unpacked' => 45548},'testers' => {},'uses' => ['5.001']},'Pipeline-3.04.tar.gz' => {'author' => 'JDUNCAN','description' => 'Generic pipeline interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 754,'pod' => 620,'pod_errors' => 0,'total' => 1374,'with_comments' => 6},'releases' => 11,'requires' => ['Class-ISA-0.32.tar.gz','Error-0.15.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::ISA' => '0.01','Error' => '0.01','Scalar::Util' => '0.01','Test::More' => '0.01'},'requires_recursive' => ['Class-ISA-0.32.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10631,'unpacked' => 39392},'testers' => {'pass' => 1},'uses' => ['','Class::ISA','Error','Scalar::Util','strict','warnings::register']},'Pipeline-Config-0.02.tar.gz' => {'author' => 'SPURKIS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 358,'pod' => 149,'pod_errors' => 0,'total' => 507,'with_comments' => 5},'releases' => 2,'requires' => ['Pipeline-3.04.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Pipeline' => '3.01','Test::More' => '0.01'},'requires_recursive' => ['Class-ISA-0.32.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','Pipeline-3.04.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5254,'unpacked' => 17068},'testers' => {'pass' => 1},'uses' => ['','Error','Pipeline','Pipeline::Base','Scalar::Util','YAML','strict','warnings::register']},'Pixie-2.05.tar.gz' => {'author' => 'JDUNCAN','description' => 'The magic data pixie','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2708,'pod' => 277,'pod_errors' => 0,'total' => 2985,'with_comments' => 18},'releases' => 7,'requires' => ['DBIx-AnyDBD-2.01.tar.gz','Data-UUID-0.10.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Class-0.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DBIx::AnyDBD' => '2.01','Data::UUID' => '0.01','Scalar::Util' => '0.01','Test::Class' => '0.03','Test::Simple' => '0.01'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Attribute-Handlers-0.78.tar.gz','Class-ISA-0.32.tar.gz','DBIx-AnyDBD-2.01.tar.gz','Data-UUID-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Scalar-List-Utils-1.11.tar.gz','Storable-2.07.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Class-0.03.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz'],'size' => {'packed' => 33802,'unpacked' => 122096},'testers' => {'fail' => 1,'pass' => 2,'tests' => '390'},'uses' => ['','AutoLoader','BerkeleyDB','Carp','CorporatePerson','DBI','DBIx::AnyDBD','Data::Dumper','Data::UUID','DynaLoader','Exporter','File::Spec','IndividualPerson','MIME::Base64','Person','Pixie::Complicity','Pixie::FinalMethods','Pixie::Info','Pixie::LiveObjectManager','Pixie::LockStrat','Pixie::LockStrat::Null','Pixie::Name','Pixie::Object','Pixie::ObjectGraph','Pixie::ObjectInfo','Pixie::Proxy','Pixie::Store','Pixie::Store::DBI::Default','Scalar::Util','SpringfieldObject','Storable','SunnydaleObject','Test::More','bytes','overload','strict','vars','warnings','warnings::register']},'Pixie-2.06.tar.gz' => {'author' => 'JDUNCAN','description' => 'The magic data pixie','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2944,'pod' => 279,'pod_errors' => 0,'total' => 3223,'with_comments' => 29},'releases' => 7,'requires' => ['DBIx-AnyDBD-2.01.tar.gz','Data-UUID-0.10.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Class-0.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DBIx::AnyDBD' => '2.01','Data::UUID' => '0.01','Scalar::Util' => '0.01','Test::Class' => '0.03','Test::Simple' => '0.01'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Attribute-Handlers-0.78.tar.gz','Class-ISA-0.32.tar.gz','DBIx-AnyDBD-2.01.tar.gz','Data-UUID-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Scalar-List-Utils-1.11.tar.gz','Storable-2.07.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Class-0.03.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz'],'size' => {'packed' => 34470,'unpacked' => 128237},'testers' => {},'uses' => ['','AutoLoader','BerkeleyDB','Carp','CorporatePerson','DBI','DBIx::AnyDBD','Data::Dumper','Data::UUID','DynaLoader','Exporter','File::Spec','IndividualPerson','MIME::Base64','Person','Scalar::Util','SpringfieldObject','Storable','SunnydaleObject','Test::More','bytes','overload','strict','vars','warnings','warnings::register']},'PlRPC-0.2017.tar.gz' => {'author' => 'JWIED','description' => 'Interface for building Perl Servers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 871,'pod' => 520,'pod_errors' => 0,'total' => 1391,'with_comments' => 216},'releases' => 11,'size' => {'packed' => 19433,'unpacked' => 63755},'testers' => {'pass' => 4},'uses' => ['5.004','Compress::Zlib','Net::Daemon::Test','Storable','strict','vars']},'PlotCalendar-1.1.tar.gz' => {'author' => 'AJACKSON','description' => 'Generate ascii or html for a single day in a calendar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1210,'pod' => 415,'pod_errors' => 0,'total' => 1625,'with_comments' => 207},'releases' => 1,'size' => {'packed' => 20977,'unpacked' => 101163},'testers' => {'fail' => 2,'tests' => '34'},'uses' => ['Carp','Exporter','Time::DaysInMonth','Time::JulianDay','strict','vars']},'Plotter-1.0.1.tar.gz' => {'author' => 'MAKLER','description' => 'Binding for C++ libplotter plotting library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 413,'pod' => 516,'pod_errors' => 0,'total' => 929,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 24938,'unpacked' => 81825},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'PlugIn-0.01.tar.gz' => {'author' => 'BSTURNER','description' => undef,'files' => [],'lines' => {'nonpod' => 188,'pod' => 132,'pod_errors' => 0,'total' => 320,'with_comments' => 28},'releases' => 1,'size' => {'packed' => 3482,'unpacked' => 16352},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Archive::Tar']},'PlusPlus-1.23.tar.gz' => {'author' => 'DMOW','description' => '[Delphi|VB|Java]-like Perl preprocessor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 228,'pod' => 281,'pod_errors' => 0,'total' => 509,'with_comments' => 1},'releases' => 2,'requires' => ['Filter-1.29.tar.gz'],'requires_module' => {'Filter::Util::Call' => '1.04'},'requires_recursive' => ['Filter-1.29.tar.gz'],'size' => {'packed' => 7488,'unpacked' => 21506},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Exporter','Filter::Util::Call','Tie::Hash','strict','vars']},'Pod-Compiler-0.10.tar.gz' => {'author' => 'MAREKR','description' => 'compile POD into an object tree','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2749,'pod' => 780,'pod_errors' => 6,'total' => 3529,'with_comments' => 328},'releases' => 1,'size' => {'packed' => 29941,'unpacked' => 98777},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','Pod::Parser','Storable','Tree::DAG_Node','strict']},'Pod-Constants-0.15.tar.gz' => {'author' => 'SAMV','description' => 'Include constants from POD','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 317,'pod' => 230,'pod_errors' => 0,'total' => 547,'with_comments' => 25},'releases' => 7,'requires' => ['PodParser-1.23.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Pod::Parser' => '1.13','Test::Simple' => '0.18'},'requires_recursive' => ['File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10097,'unpacked' => 24971},'testers' => {'pass' => 19},'uses' => ['5.004','Carp','Data::Dumper','Exporter','IO::Handle','Pod::Parser','strict','vars']},'Pod-Coverage-0.11.tar.gz' => {'author' => 'RCLAMP','description' => 'Checks if the documentation of a module is comprehensive','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 459,'pod' => 411,'pod_errors' => 3,'total' => 870,'with_comments' => 20},'releases' => 10,'requires' => ['Devel-Symdump-2.03.tar.gz','PodParser-1.23.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Devel::Symdump' => '2.01','Pod::Find' => '0.21','Pod::Parser' => '1.13','Test::More' => '0.11'},'requires_recursive' => ['Devel-Symdump-2.03.tar.gz','File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10694,'unpacked' => 32977},'testers' => {'pass' => 17},'uses' => ['Data::Dumper','Devel::Symdump','DynaLoader','Pod::Find','Pod::Parser','strict','vars']},'Pod-DocBook-0.05.tar.gz' => {'author' => 'ADESC','description' => 'convert POD to and from DocBook','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1210,'pod' => 151,'pod_errors' => 0,'total' => 1361,'with_comments' => 366},'releases' => 6,'size' => {'packed' => 16282,'unpacked' => 48866},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','Cwd','Exporter','Getopt::Long','Pod::Functions','strict']},'Pod-Escapes-1.03.tar.gz' => {'author' => 'SBURKE','description' => '- for resolving Pod EE<lt>...E<gt> sequences','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 632,'pod' => 89,'pod_errors' => 0,'total' => 721,'with_comments' => 55},'releases' => 3,'size' => {'packed' => 9162,'unpacked' => 27987},'testers' => {'pass' => 31},'uses' => ['5','Exporter','strict','vars']},'Pod-GroveBuilder-0.01.tar.gz' => {'author' => 'KMACLEOD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 60,'pod' => 39,'pod_errors' => 0,'total' => 99,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 3485,'unpacked' => 8341},'testers' => {'fail' => 2},'uses' => ['SGML::SPGrove','strict','vars']},'Pod-HTML2Pod-4.04.tar.gz' => {'author' => 'SBURKE','description' => 'Translate HTML into POD','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1435,'pod' => 216,'pod_errors' => 0,'total' => 1651,'with_comments' => 294},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'HTML::Element' => '3.05','HTML::Entities' => 0,'HTML::Tagset' => '3.02','HTML::TreeBuilder' => '3.05','UNIVERSAL' => 0,'integer' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18056,'unpacked' => 51690},'testers' => {'pass' => 7},'uses' => ['5','integer','strict']},'Pod-HtmlHelp-1.1.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Interface with Microsoft\'s HtmlHelp system','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 3233,'pod' => 134,'pod_errors' => 0,'total' => 3367,'with_comments' => 770},'releases' => 1,'size' => {'packed' => 27263,'unpacked' => 101696},'testers' => {'pass' => 2},'uses' => ['Carp','Config','Cwd','Exporter','File::Basename','File::Copy','File::Path','Getopt::Long','Pod::Functions','locale','strict','subs','vars']},'Pod-HtmlPsPdf-0.04.tar.gz' => {'author' => 'STAS','description' => 'documentation projects builder in HTML, PS and PDF formats','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3125,'pod' => 427,'pod_errors' => 1,'total' => 3552,'with_comments' => 784},'releases' => 4,'size' => {'packed' => 121219,'unpacked' => 356272},'testers' => {'pass' => 2,'tests' => '0','unknown' => 15},'uses' => ['Carp','Config','Cwd','Exporter','File::Copy','Getopt::Long','Pod::Functions','Storable','strict','vars']},'Pod-HtmlTree-0.96.tar.gz' => {'author' => 'MSCHILLI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 306,'pod' => 147,'pod_errors' => 0,'total' => 453,'with_comments' => 38},'releases' => 2,'requires' => ['File-Spec-0.82.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Cwd' => 0,'Exporter' => 0,'File::Basename' => 0,'File::Find' => 0,'File::Path' => 0,'File::Spec' => 0,'Pod::Html' => 0,'Text::Wrap' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6345,'unpacked' => 22031},'testers' => {'pass' => 1},'uses' => ['Cwd','Exporter','File::Basename','File::Find','File::Path','File::Spec','File::Temp','Pod::Html','Text::Wrap','strict','warnings']},'Pod-LaTeX-0.55.tar.gz' => {'author' => 'TJENNESS','description' => 'Converts pod to latex with Pod::Parser','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1651,'pod' => 217,'pod_errors' => 0,'total' => 1868,'with_comments' => 514},'releases' => 6,'requires' => ['PodParser-1.23.tar.gz'],'requires_module' => {'Pod::Find' => 0,'Pod::ParseUtils' => 0,'Pod::Parser' => 0,'Pod::Select' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 25346,'unpacked' => 82960},'testers' => {'pass' => 8},'uses' => ['','Carp','Data::Dumper','Pod::ParseUtils','Pod::Select','strict','vars']},'Pod-LaTeX-TPR-1.04.tar.gz' => {'author' => 'BDFOY','description' => 'Translate POD for The Perl Review','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 175,'pod' => 50,'pod_errors' => 0,'total' => 225,'with_comments' => 3},'releases' => 3,'requires' => ['Pod-LaTeX-0.55.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Pod::LaTeX' => '0.54','Test::Manifest' => '0.9','Test::More' => '0','Test::Pod' => '0.90','Test::Prereq' => '0.18'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-LaTeX-0.55.tar.gz','Pod-Simple-0.96.tar.gz','PodParser-1.23.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 2961,'unpacked' => 6491},'testers' => {'pass' => 1},'uses' => ['Pod::LaTeX','vars']},'Pod-POM-0.15.tar.gz' => {'author' => 'ABW','description' => 'POD Object Model','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2417,'pod' => 1137,'pod_errors' => 2,'total' => 3554,'with_comments' => 414},'releases' => 9,'size' => {'packed' => 34314,'unpacked' => 128255},'testers' => {'pass' => 26},'uses' => ['','5.004','Carp','Exporter','Text::Wrap','constant','overload','strict','vars']},'Pod-PP-0.1.2.tar.gz' => {'author' => 'RAM','description' => 'POD pre-processor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1561,'pod' => 273,'pod_errors' => 0,'total' => 1834,'with_comments' => 538},'releases' => 3,'requires' => ['Carp-Datum-0.1.3.tar.gz','Clone-0.13.tar.gz','Getargs-Long-0.1.3.tar.gz','Log-Agent-0.304.tar.gz','PodParser-1.23.tar.gz'],'requires_module' => {'Carp::Datum' => '0.100','Clone' => '0.09','Getargs::Long' => '0.103','Log::Agent' => '0.207','Pod::Parser' => '1.13'},'requires_recursive' => ['Carp-Datum-0.1.3.tar.gz','Clone-0.13.tar.gz','File-Spec-0.82.tar.gz','Getargs-Long-0.1.3.tar.gz','Log-Agent-0.304.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 17672,'unpacked' => 62843},'testers' => {'pass' => 3},'uses' => ['Carp::Datum','Clone','Cwd','Exporter','File::Basename','File::Spec','Getargs::Long','Log::Agent','Pod::Parser','Safe','constant','strict','vars']},'Pod-PXML-0.1001.tar.gz' => {'author' => 'SBURKE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 699,'pod' => 236,'pod_errors' => 1,'total' => 935,'with_comments' => 175},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz','Pod-Tree-1.10.tar.gz','XML-Parser-2.31.tar.gz','podlators-1.27.tar.gz'],'requires_module' => {'HTML::Entities' => 1,'Pod::Text' => '2.09','Pod::Tree' => '1.06','XML::Parser' => 2},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Stream-1.54.tar.gz','HTML-Tagset-3.03.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Tree-1.10.tar.gz','PodParser-1.23.tar.gz','XML-Parser-2.31.tar.gz','podlators-1.27.tar.gz'],'size' => {'packed' => 11398,'unpacked' => 32459},'testers' => {'pass' => 1},'uses' => ['Carp','Data::Dumper','Pod::Tree','XML::Parser','strict','utf','vars']},'Pod-PalmDoc-0.0.2.tar.gz' => {'author' => 'BEATNIK','description' => 'Convert POD Data to PalmDoc','files' => [],'lines' => {'nonpod' => 69,'pod' => 62,'pod_errors' => 0,'total' => 131,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2304,'unpacked' => 6128},'testers' => {'fail' => 2},'uses' => ['Exporter','Palm::PalmDoc','Pod::Parser','strict','vars']},'Pod-Pdf-1.2.tar.gz' => {'author' => 'AJFRY','description' => 'Converter to PDF','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1915,'pod' => 175,'pod_errors' => 1,'total' => 2090,'with_comments' => 184},'releases' => 1,'size' => {'packed' => 24637,'unpacked' => 89856},'testers' => {'pass' => 8},'uses' => ['Exporter','File::Basename','Getopt::Long','strict','vars']},'Pod-Peapod-0.42.tar.gz' => {'author' => 'GSLONDON','description' => 'Perl module to provide an easy interface to parsing POD','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2679,'pod' => 1135,'pod_errors' => 0,'total' => 3814,'with_comments' => 320},'releases' => 3,'requires' => ['Pod-Simple-0.96.tar.gz','Tk-800.024.tar.gz'],'requires_module' => {'Pod::Simple' => '0.96','Tk' => '800.015'},'requires_recursive' => ['Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Tk-800.024.tar.gz'],'size' => {'packed' => 31537,'unpacked' => 124613},'testers' => {'pass' => 1},'uses' => ['5.005_62','5.008','Carp','Data::Dumper','Pod::Simple::Methody','Text::Wrap','Tk','Tk::Adjuster','Tk::Frame','Tk::ROText','strict','warnings']},'Pod-PerlPoint-0.03.tgz' => {'author' => 'JSTENZEL','description' => 'a POD to PerlPoint converter class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 355,'pod' => 129,'pod_errors' => 0,'total' => 484,'with_comments' => 87},'releases' => 2,'requires' => ['Getopt-ArgvFile-1.06.tgz','Getopt-Long-2.33.tar.gz','Pod-Simple-0.96.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Getopt::ArgvFile' => '1.06','Getopt::Long' => '2.32','Pod::Simple' => '0.96','Pod::Usage' => '1.14','Test::Harness' => '1.25','Test::More' => '0.11'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-ArgvFile-1.06.tgz','Getopt-Long-2.33.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8292,'unpacked' => 26838},'testers' => {'pass' => 3},'uses' => ['5','strict']},'Pod-Perldoc-3.08.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2426,'pod' => 425,'pod_errors' => 0,'total' => 2851,'with_comments' => 418},'releases' => 6,'requires' => ['File-Temp-0.12.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Fcntl' => 0,'File::Spec::Functions' => 0,'File::Temp' => 0,'Symbol' => 0,'Text::ParseWords' => 0,'strict' => 0,'warnings' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','perl-5.8.0.tar.gz'],'testers' => {'pass' => 5},'uses' => ['','5','Config','Fcntl','File::Spec::Functions','File::Temp','Pod::Checker','Pod::Simple::RTF','Pod::Simple::XMLOutStream','Symbol','Text::ParseWords','Tk','Tk::ErrorDialog','Tk::FcyEntry','Tk::Pod','blib','lib','strict','vars','vmsish','warnings']},'Pod-SAX-0.14.tar.gz' => {'author' => 'MSERGEANT','description' => 'a SAX parser for Pod','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 709,'pod' => 193,'pod_errors' => 0,'total' => 902,'with_comments' => 111},'releases' => 12,'requires' => ['PodParser-1.23.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'Pod::Parser' => 0,'XML::SAX' => '0.1','XML::SAX::Writer' => '0.39'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14081,'unpacked' => 45838},'testers' => {'pass' => 4},'uses' => ['Data::Dumper','Pod::Parser','XML::SAX::Base','XML::SAX::DocumentLocator','strict','vars']},'Pod-Simple-0.96.tar.gz' => {'author' => 'SBURKE','description' => 'the framework for parsing Pod','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7795,'pod' => 5000,'pod_errors' => 7,'total' => 12795,'with_comments' => 985},'releases' => 7,'requires' => ['Pod-Escapes-1.03.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'requires_module' => {'Pod::Escapes' => '1.03','Text::Wrap' => '98.112902'},'requires_recursive' => ['Pod-Escapes-1.03.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 179205,'unpacked' => 624517},'testers' => {'pass' => 28},'uses' => ['5','Carp','Data::Dumper','Symbol','integer','strict','utf','vars']},'Pod-Simple-31337-0.02.tar.gz' => {'author' => 'CWEST','description' => 'Convert POD to Cool Talk','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 132,'pod' => 30,'pod_errors' => 0,'total' => 162,'with_comments' => 6},'releases' => 1,'requires' => ['Lingua-31337-0.02.tar.gz','Pod-Simple-0.96.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'requires_module' => {'Lingua::31337' => '0.01','Pod::Simple' => '0.01','Text::Wrap' => '98.112902'},'requires_recursive' => ['Lingua-31337-0.02.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 2352,'unpacked' => 5287},'testers' => {'fail' => 1},'uses' => ['5','Exporter','Lingua::31337','Pod::Find','strict','vars']},'Pod-Simple-Wiki-0.03.tar.gz' => {'author' => 'JMCNAMARA','description' => 'A class for creating Pod to Wiki filters.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 505,'pod' => 102,'pod_errors' => 0,'total' => 607,'with_comments' => 134},'releases' => 1,'requires' => ['Pod-Simple-0.96.tar.gz'],'requires_module' => {'Pod::Simple' => 0},'requires_recursive' => ['Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 4906,'unpacked' => 19422},'testers' => {'pass' => 1},'uses' => ['Pod::Simple','Pod::Simple::Debug','strict','vars']},'Pod-Spell-1.01.tar.gz' => {'author' => 'SBURKE','description' => '- a formatter for spellchecking Pod','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1336,'pod' => 133,'pod_errors' => 0,'total' => 1469,'with_comments' => 37},'releases' => 1,'requires' => ['Pod-Escapes-1.03.tar.gz','PodParser-1.23.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'requires_module' => {'Pod::Escapes' => '1.01','Pod::Parser' => 1,'Text::Wrap' => 1},'requires_recursive' => ['File-Spec-0.82.tar.gz','Pod-Escapes-1.03.tar.gz','PodParser-1.23.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 12846,'unpacked' => 35539},'testers' => {'pass' => 8},'uses' => ['5','Carp','Pod::Escapes','Text::Wrap','constant','integer','locale','strict','vars']},'Pod-Stripper-0.22.tar.gz' => {'author' => 'PODMASTER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 96,'pod_errors' => 0,'total' => 256,'with_comments' => 12},'releases' => 2,'requires' => ['PodParser-1.23.tar.gz','Test-1.24.tar.gz'],'requires_module' => {'Pod::Parser' => '1.13','Test' => '1.15'},'requires_recursive' => ['File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 4238,'unpacked' => 11213},'testers' => {'pass' => 6},'uses' => ['Pod::Parser','strict','vars']},'Pod-Tree-1.10.tar.gz' => {'author' => 'SWMCD','description' => 'Create a static syntax tree for a POD','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4989,'pod' => 3722,'pod_errors' => 13,'total' => 8711,'with_comments' => 81},'releases' => 11,'requires' => ['HTML-Stream-1.54.tar.gz','Pod-Escapes-1.03.tar.gz'],'requires_module' => {'HTML::Stream' => '1.49','Pod::Escapes' => '1.02'},'requires_recursive' => ['HTML-Stream-1.54.tar.gz','Pod-Escapes-1.03.tar.gz'],'size' => {'packed' => 53955,'unpacked' => 250920},'testers' => {'fail' => 1,'pass' => 9,'tests' => '76'},'uses' => ['5.004','5.005','5.6.0','Exporter','File::Find','HTML::Stream','IO::File','strict','vars']},'Pod-XML-0.93.tar.gz' => {'author' => 'MSERGEANT','description' => 'Generate XML from POD','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 378,'pod' => 83,'pod_errors' => 0,'total' => 461,'with_comments' => 99},'releases' => 4,'requires' => ['PodParser-1.23.tar.gz'],'requires_module' => {'Pod::Parser' => 1},'requires_recursive' => ['File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 5487,'unpacked' => 18921},'testers' => {'pass' => 8},'uses' => ['Pod::Parser','strict','vars']},'Pod2VMSHlp-1.02.tar.gz' => {'author' => 'PVHP','description' => 'Convert POD to formatted VMS Help text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2342,'pod' => 317,'pod_errors' => 1,'total' => 2659,'with_comments' => 520},'releases' => 2,'size' => {'packed' => 102081,'unpacked' => 278375},'testers' => {'pass' => 5},'uses' => ['5.004','Carp','Exporter','File::Basename','strict','subs','vars']},'Pod2WinHlp-0.02.tar.gz' => {'author' => 'PVHP','description' => 'Converter from POD to Rich Text Format','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 295,'pod' => 96,'pod_errors' => 1,'total' => 391,'with_comments' => 48},'releases' => 1,'requires' => ['PodParser-1.23.tar.gz'],'requires_module' => {'Pod::Parser' => ''},'requires_recursive' => ['File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 7227,'unpacked' => 28724},'testers' => {'fail' => 6,'tests' => '2'},'uses' => ['Pod::Parser','Pod::PlainText','strict','vars']},'PodParser-1.23.tar.gz' => {'author' => 'MAREKR','description' => 'Check pod documents for syntax errors','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5391,'pod' => 1956,'pod_errors' => 1,'total' => 7347,'with_comments' => 1016},'releases' => 30,'requires' => ['File-Spec-0.82.tar.gz'],'requires_module' => {'File::Spec' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz'],'size' => {'packed' => 89611,'unpacked' => 330610},'testers' => {'pass' => 4},'uses' => ['5.005','Carp','Config','Cwd','Exporter','File::Find','File::Spec','Pod::Text','Symbol','diagnostics','happy','strict','vars']},'PodSimplify-0.04.tar.gz' => {'author' => 'KJALB','description' => 'converter to RTF','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2458,'pod' => 1470,'pod_errors' => 23,'total' => 3928,'with_comments' => 172},'releases' => 1,'size' => {'packed' => 61056,'unpacked' => 193828},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Exporter','HTML::AsSubs','HTML::Element','HTML::Entities']},'PodToHTML-0.04.tar.gz' => {'author' => 'NI-S','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 757,'pod' => 99,'pod_errors' => 1,'total' => 856,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 9199,'unpacked' => 27422},'testers' => {'fail' => 3,'tests' => '3'},'uses' => ['Carp','Data::Dumper','Exporter','File::Basename','File::Find','HTML::AsSubs','HTML::Element','HTML::Entities','HTML::FormatPS','Pod::Parser','URI::URL','strict','vars']},'Poetry-Aum-1.1.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 25,'pod' => 50,'pod_errors' => 1,'total' => 75,'with_comments' => 3},'releases' => 3,'size' => {'packed' => 1547,'unpacked' => 2399},'testers' => {'pass' => 2},'uses' => ['strict','warnings']},'Pogo-0.08.tar.gz' => {'author' => 'SEYN','description' => 'Interface for GOODS object database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1022,'pod' => 1268,'pod_errors' => 2,'total' => 2290,'with_comments' => 30},'releases' => 2,'size' => {'packed' => 39266,'unpacked' => 150305},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','overload','strict','vars']},'Pollute-0.07.tar.gz' => {'author' => 'DAVIDNICO','description' => 'build include files that use modules indirectly','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 110,'pod' => 117,'pod_errors' => 0,'total' => 227,'with_comments' => 10},'releases' => 5,'size' => {'packed' => 4448,'unpacked' => 10771},'testers' => {'pass' => 5},'uses' => ['5.005','Carp','strict','vars','warnings']},'Polyglot-0.07.tar.gz' => {'author' => 'BDFOY','description' => 'a little language interpreter','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 275,'pod' => 135,'pod_errors' => 0,'total' => 410,'with_comments' => 2},'releases' => 1,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','Test::Manifest' => '0.91','Test::More' => '0','Test::Pod' => '0.90'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 4623,'unpacked' => 10276},'testers' => {},'uses' => ['Carp','Mac::iTunes','Text::ParseWords','autouse','strict','vars']},'PostScript-0.06.tar.gz' => {'author' => 'SHAWNPW','description' => 'Objects for shapes, lines, images','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1128,'pod' => 215,'pod_errors' => 1,'total' => 1343,'with_comments' => 256},'releases' => 4,'size' => {'packed' => 19506,'unpacked' => 93595},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['strict','vars']},'PostScript-Columns-1.23.tar.gz' => {'author' => 'FIVE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 165,'pod' => 101,'pod_errors' => 0,'total' => 266,'with_comments' => 7},'releases' => 4,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'POSIX' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 17892,'unpacked' => 52190},'testers' => {'fail' => 4,'pass' => 2},'uses' => ['Exporter','strict','vars']},'PostScript-EPSF-0.01.tar.gz' => {'author' => 'GAAS','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 227,'pod' => 0,'pod_errors' => 0,'total' => 227,'with_comments' => 14},'releases' => 1,'size' => {'packed' => 4489,'unpacked' => 10964},'testers' => {},'uses' => ['Data::Dumper','Exporter','strict','vars']},'PostScript-File-1.tar.gz' => {'author' => 'CPWILLMOT','description' => 'PostScript File creation with debug support','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1485,'pod' => 864,'pod_errors' => 0,'total' => 2349,'with_comments' => 38},'releases' => 11,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Spec' => 0,'Sys::Hostname' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 22488,'unpacked' => 70914},'testers' => {'pass' => 2},'uses' => ['Exporter','File::Spec','Sys::Hostname','strict','warnings']},'PostScript-Font-1.08.tar.gz' => {'author' => 'JV','description' => 'ISO Latin1 Encoding vector','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3910,'pod' => 1304,'pod_errors' => 0,'total' => 5214,'with_comments' => 482},'releases' => 10,'requires' => ['Getopt-Long-2.33.tar.gz','IO-1.20.tar.gz'],'requires_module' => {'Getopt::Long' => 2,'IO' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','IO-1.20.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 150643,'unpacked' => 368743},'testers' => {'pass' => 6,'tests' => '0','unknown' => 3},'uses' => ['5.005','5.006','Carp','Data::Dumper','File::Basename','File::Spec','Font::TTF::Font','IO','constant','integer','strict','vars','warnings']},'PostScript-Graph-1.00.tar.gz' => {'author' => 'CPWILLMOT','description' => 'Draw point or line graphs from CSV files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3498,'pod' => 2351,'pod_errors' => 0,'total' => 5849,'with_comments' => 305},'releases' => 8,'requires' => ['PostScript-File-1.tar.gz','Test-Simple-0.47.tar.gz','Text-CSV_XS-0.23.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Exporter' => 0,'PostScript::File' => '0.13','Test::More' => 0,'Text::CSV_XS' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','PostScript-File-1.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-CSV_XS-0.23.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 54766,'unpacked' => 218699},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','PostScript::File','Text::CSV_XS','strict','warnings']},'PostScript-MailLabels-2.03.tar.gz' => {'author' => 'AJACKSON','description' => 'Modules for creating PostScript(tm) files of mailing address labels.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2350,'pod' => 580,'pod_errors' => 0,'total' => 2930,'with_comments' => 233},'releases' => 6,'size' => {'packed' => 34935,'unpacked' => 137268},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','strict','vars']},'PostScript-Simple-0.05.tar.gz' => {'author' => 'MCNEWTON','description' => 'Produce PostScript files from Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2053,'pod' => 912,'pod_errors' => 0,'total' => 2965,'with_comments' => 212},'releases' => 4,'size' => {'packed' => 34774,'unpacked' => 106494},'testers' => {'pass' => 1},'uses' => ['Exporter','strict','vars']},'Postgres-1.4.tar.gz' => {'author' => 'VKHERA','description' => 'PostgreSQL interface with Perl5 coding style','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 62,'pod' => 99,'pod_errors' => 0,'total' => 161,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 9389,'unpacked' => 27036},'testers' => {},'uses' => ['5.002','DynaLoader','Exporter','strict','vars']},'Pquota-1.1.tar.gz' => {'author' => 'DBONNER','description' => 'a UNIX print quota module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1048,'pod' => 216,'pod_errors' => 0,'total' => 1264,'with_comments' => 206},'releases' => 2,'requires' => ['MLDBM-2.01.tar.gz'],'requires_module' => {'MLDBM' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','MLDBM-2.01.tar.gz'],'size' => {'packed' => 13393,'unpacked' => 51817},'testers' => {'pass' => 5},'uses' => ['Carp','Fcntl','MLDBM','strict']},'Pragmatic-1.6.tar.gz' => {'author' => 'BINKLEY','description' => 'Adds pragmata to Exporter','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 172,'pod_errors' => 0,'total' => 288,'with_comments' => 12},'releases' => 5,'size' => {'packed' => 5235,'unpacked' => 17102},'testers' => {'fail' => 5,'pass' => 2,'tests' => '31'},'uses' => ['5.001','Carp','Exporter','strict','vars']},'PrayMind-1.01.tar.gz' => {'author' => 'TASMIN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 874,'pod' => 232,'pod_errors' => 0,'total' => 1106,'with_comments' => 221},'releases' => 1,'size' => {'packed' => 12132,'unpacked' => 52847},'testers' => {'pass' => 4},'uses' => ['5.006','Exporter','IO::Socket','XML::Parser','constant','strict','warnings']},'Prim-0.01.tar.gz' => {'author' => 'PHILCROW','description' => 'Perl Remote Invocation of Methods (RMI and EJB\'s for Perl, sort of)','files' => ['README'],'lines' => {'nonpod' => 1680,'pod' => 552,'pod_errors' => 0,'total' => 2232,'with_comments' => 215},'releases' => 1,'size' => {'packed' => 36726,'unpacked' => 125599},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Data::Dumper','IO::Socket','strict','vars']},'Prima-1.11.tar.gz' => {'author' => 'KARASIK','description' => 'a perl graphic toolkit','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 54299,'pod' => 16611,'pod_errors' => 14,'total' => 70910,'with_comments' => 3655},'releases' => 10,'size' => {'packed' => 1218127,'unpacked' => 5090336},'testers' => {'pass' => 1},'uses' => ['Benchmark','Carp','Config','Cwd','Data::Dumper','DynaLoader','Exporter','File::Basename','File::Copy','File::Find','File::Path','POSIX','Prima::Buttons','Prima::Classes','Prima::Notebooks','Prima::Outlines','Prima::Sliders','Prima::StdDlg','Tie::RefHash','constant','strict','vars']},'Printer-0.97d.tar.gz' => {'author' => 'SRPATT','description' => 'a low-level, platform independent printing interface (curently Linux and MS Win32. other UNIXES should also work.) This version includes working support for Windows 95 and some changes to make it work with windows 2000 and XP.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 618,'pod' => 283,'pod_errors' => 0,'total' => 901,'with_comments' => 149},'releases' => 1,'size' => {'packed' => 15802,'unpacked' => 45954},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['Carp','English','Env','Printer::Unix','Printer::Win32','Win32','Win32::Registry','strict','vars']},'ProLite-0.01.tar.gz' => {'author' => 'MSPENCER','description' => 'Perl extension to control Pro-Lite LED Message Signs','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 540,'pod' => 242,'pod_errors' => 1,'total' => 782,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 9310,'unpacked' => 29135},'testers' => {},'uses' => ['5.005_62','AutoLoader','Device::SerialPort','Exporter','Time::HiRes','strict','warnings']},'Proc-Application-0.01.tar.gz' => {'author' => 'MKUL','description' => 'base class for all applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 963,'pod' => 315,'pod_errors' => 0,'total' => 1278,'with_comments' => 15},'releases' => 1,'requires' => ['IO-Socket-SSL-0.94.tar.gz'],'requires_module' => {'IO::Socket::SSL' => '0.73'},'requires_recursive' => ['IO-Socket-SSL-0.94.tar.gz','Net_SSLeay.pm-1.23.tar.gz'],'size' => {'packed' => 7644,'unpacked' => 27809},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['Errno','Fcntl','Getopt::ArgvFile','Getopt::Long','HTTP::Daemon','HTTP::Status','IO::Dir','IO::File','IO::Handle','Log::Dispatch','Log::Dispatch::File','Log::Dispatch::Screen','Log::Dispatch::Syslog','POSIX','Proc::PID_File','constant','strict']},'Proc-Background-1.08.tar.gz' => {'author' => 'BZAJAC','description' => 'Generic interface to Unix and Win32 background process management','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 576,'pod' => 196,'pod_errors' => 0,'total' => 772,'with_comments' => 97},'releases' => 12,'size' => {'packed' => 14687,'unpacked' => 45776},'testers' => {'fail' => 1,'pass' => 1,'tests' => '47'},'uses' => ['5.004_04','Carp','Cwd','Exporter','POSIX','strict','vars']},'Proc-Command-0.03.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 761,'pod' => 428,'pod_errors' => 1,'total' => 1189,'with_comments' => 60},'releases' => 3,'requires' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz'],'requires_module' => {'File::Package' => '0','File::SmartNL' => '0','File::TestPath' => '0','Test::Tech' => '1.08'},'requires_recursive' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz'],'size' => {'packed' => 9610,'unpacked' => 46208},'testers' => {'pass' => 1},'uses' => ['5.001','Exporter','strict','vars','warnings','warnings::register']},'Proc-Daemon-0.03.tar.gz' => {'author' => 'EHOOD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 156,'pod' => 76,'pod_errors' => 0,'total' => 232,'with_comments' => 40},'releases' => 3,'size' => {'packed' => 3784,'unpacked' => 8569},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','POSIX','strict','vars']},'Proc-Fork-0.05.tar.gz' => {'author' => 'ROODE','description' => 'Simple interface to fork() system call.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 150,'pod' => 216,'pod_errors' => 0,'total' => 366,'with_comments' => 47},'releases' => 1,'size' => {'packed' => 4779,'unpacked' => 12188},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','strict','vars']},'Proc-Forkfunc-96.042201.tar.gz' => {'author' => 'MUIR','description' => 'Simple lwall-style fork wrapper','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 46,'pod' => 21,'pod_errors' => 0,'total' => 67,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 1314,'unpacked' => 1768},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','POSIX','strict','vars']},'Proc-InvokeEditor-0.02.tar.gz' => {'author' => 'MSTEVENS','description' => 'Perl extension for starting a text editor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 243,'pod' => 92,'pod_errors' => 0,'total' => 335,'with_comments' => 14},'releases' => 1,'requires' => ['Carp-Assert-0.17.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Carp::Assert' => '0.11','File::Spec' => '0.82','File::Temp' => '0.12','Test::More' => '0.08'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5397,'unpacked' => 13381},'testers' => {'pass' => 3},'uses' => ['Carp::Assert','Exporter','Fcntl','File::Spec','File::Temp','strict','vars']},'Proc-NiceSleep-0.57.tar.gz' => {'author' => 'JOSHR','description' => 'yield system in a quasi-intelligent fashion','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 386,'pod' => 101,'pod_errors' => 0,'total' => 487,'with_comments' => 137},'releases' => 11,'size' => {'packed' => 12687,'unpacked' => 40831},'testers' => {'pass' => 7},'uses' => ['5.004','AutoLoader','Exporter','Time::HiRes','strict','vars','warnings']},'Proc-PID-File-1.22.tar.gz' => {'author' => 'ECALDER','description' => 'a module to manage process id files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 217,'pod' => 148,'pod_errors' => 0,'total' => 365,'with_comments' => 8},'releases' => 4,'size' => {'packed' => 13307,'unpacked' => 33974},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Exporter','Fcntl','strict','vars']},'Proc-PID_File-0.05.tar.gz' => {'author' => 'SHARYANTO','description' => 'check whether a self process is already running','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 92,'pod_errors' => 0,'total' => 187,'with_comments' => 3},'releases' => 7,'size' => {'packed' => 4071,'unpacked' => 10871},'testers' => {'pass' => 3},'uses' => ['Exporter','Fcntl','strict','vars']},'Proc-ParallelLoop-0.5.tgz' => {'author' => 'BDARRAH','description' => 'Execute loops in parallel','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 487,'pod' => 205,'pod_errors' => 0,'total' => 692,'with_comments' => 139},'releases' => 1,'size' => {'packed' => 17445,'unpacked' => 54865},'testers' => {'pass' => 2},'uses' => ['Fcntl','POSIX','strict','vars']},'Proc-ProcessTable-0.38.tar.gz' => {'author' => 'DURIST','description' => 'Perl extension to access the unix process table','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 387,'pod' => 220,'pod_errors' => 0,'total' => 607,'with_comments' => 44},'releases' => 36,'requires' => ['Storable-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Find' => 0,'Storable' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 48137,'unpacked' => 154623},'testers' => {'pass' => 8},'uses' => ['5.004','AutoLoader','Carp','Config','DynaLoader','Exporter','File::Basename','File::Find','Storable','strict','subs','vars']},'Proc-Queue-1.13.tar.gz' => {'author' => 'SALVA','description' => 'limits number of concurrent forked processes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 422,'pod' => 180,'pod_errors' => 0,'total' => 602,'with_comments' => 22},'releases' => 9,'size' => {'packed' => 6944,'unpacked' => 20473},'testers' => {'pass' => 1},'uses' => ['5.005','Carp','Exporter','POSIX','strict','warnings']},'Proc-Reliable-1.13.tar.gz' => {'author' => 'DGOLD','description' => 'Easy, reliable managed process execution','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 649,'pod' => 219,'pod_errors' => 0,'total' => 868,'with_comments' => 130},'releases' => 4,'size' => {'packed' => 10876,'unpacked' => 31916},'testers' => {'pass' => 3},'uses' => ['5.003','Carp','Exporter','FileHandle','POSIX','strict','vars']},'Proc-SafePipe-0.01.tar.gz' => {'author' => 'ROSCH','description' => 'popen() and `` without calling the shell','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 35,'pod_errors' => 0,'total' => 108,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 2678,'unpacked' => 5674},'testers' => {'pass' => 8},'uses' => ['5.003_98','Carp','Symbol','strict','vars']},'Proc-Short-0.01.tar.gz' => {'author' => 'JHKIM','description' => 'System calls with timeout option','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 336,'pod' => 129,'pod_errors' => 0,'total' => 465,'with_comments' => 88},'releases' => 1,'size' => {'packed' => 5569,'unpacked' => 15317},'testers' => {'pass' => 12},'uses' => ['5.003','Carp','Exporter','POSIX','strict','vars']},'Proc-Simple-1.19.tar.gz' => {'author' => 'MSCHILLI','description' => 'Fork wrapper with objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 396,'pod' => 213,'pod_errors' => 0,'total' => 609,'with_comments' => 130},'releases' => 9,'size' => {'packed' => 9080,'unpacked' => 29958},'testers' => {'pass' => 8},'uses' => ['5.003','Exporter','POSIX','strict','vars']},'Proc-Spawn-1.03.tar.gz' => {'author' => 'GARROW','description' => 'Run external programs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 39,'pod_errors' => 0,'total' => 191,'with_comments' => 39},'releases' => 2,'requires' => ['IO-1.20.tar.gz','IO-Tty-1.02.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Exporter' => 0,'IO' => 0,'IO::Handle' => 0,'IO::Pty' => 0,'POSIX' => 0},'requires_recursive' => ['IO-1.20.tar.gz','IO-Tty-1.02.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2834,'unpacked' => 6743},'testers' => {'pass' => 4},'uses' => ['5.6.0','Exporter','IO','IO::Pty','POSIX','strict']},'Proc-Swarm-0.5.tar.gz' => {'author' => 'DIEDERICH','description' => 'intelligently handle massive multi-processing on one machine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 78,'pod_errors' => 0,'total' => 515,'with_comments' => 40},'releases' => 1,'size' => {'packed' => 6714,'unpacked' => 21252},'testers' => {'pass' => 7},'uses' => ['IPC::Msg','IPC::SysV','Storable']},'Proc-SyncExec-1.00.tar.gz' => {'author' => 'ROSCH','description' => 'Spawn processes but report exec() errors','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 199,'pod' => 87,'pod_errors' => 0,'total' => 286,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 4672,'unpacked' => 10963},'testers' => {'pass' => 7},'uses' => ['Carp','Fcntl','POSIX','Symbol','strict','vars']},'Proc-WaitStat-1.00.tar.gz' => {'author' => 'ROSCH','description' => 'Interpret and act on wait() status values','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 103,'pod' => 75,'pod_errors' => 0,'total' => 178,'with_comments' => 8},'releases' => 2,'requires' => ['IPC-Signal-1.00.tar.gz'],'requires_module' => {'IPC::Signal' => 0},'requires_recursive' => ['IPC-Signal-1.00.tar.gz'],'size' => {'packed' => 3223,'unpacked' => 7274},'testers' => {'fail' => 1,'pass' => 6},'uses' => ['5.003_98','Carp','IPC::Signal','POSIX','Symbol','strict','vars']},'Proc-Watchdog-1.01.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Perl extension to implement (more) reliable watchdog of processes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 99,'pod' => 62,'pod_errors' => 0,'total' => 161,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 3453,'unpacked' => 6485},'testers' => {'pass' => 5},'uses' => ['5.005_62','Carp','IO::File','strict','warnings']},'Project-Tree-0.02.tar.gz' => {'author' => 'JRED','description' => 'graphical filesystem / project tree for software developers and webmasters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 618,'pod' => 147,'pod_errors' => 0,'total' => 765,'with_comments' => 63},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz','Gtk-Perl-0.7009.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Gtk' => '0.5'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Gtk-Perl-0.7009.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 8272,'unpacked' => 28319},'testers' => {},'uses' => ['Data::Dumper','Exporter','File::Basename','Gtk','strict','vars']},'Prolog-alpha.tar.gz' => {'author' => 'JACKS','description' => undef,'files' => [],'lines' => {'nonpod' => 1006,'pod' => 0,'pod_errors' => 0,'total' => 1006,'with_comments' => 165},'releases' => 1,'size' => {'packed' => 7547,'unpacked' => 26689},'testers' => {'tests' => '0','unknown' => 30},'uses' => ['Language::Prolog::Interpreter']},'Protect-1.00a.tar.gz' => {'author' => 'JDUNCAN','description' => 'allows the declaration of protected subs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 110,'pod_errors' => 1,'total' => 187,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2473,'unpacked' => 5336},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','Exporter']},'PsionToGnomecard-0.01.tar.gz' => {'author' => 'NAKISA','description' => 'Perl extension for converting files exported from the Psion Contacts application to vcard format suitable for Gnomecard.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 347,'pod' => 21,'pod_errors' => 0,'total' => 368,'with_comments' => 38},'releases' => 1,'size' => {'packed' => 3994,'unpacked' => 12415},'testers' => {'pass' => 2},'uses' => ['5.005_62','AutoLoader','Exporter','strict','warnings']},'Ptml0140.tgz' => {'author' => 'MDEWJONES','description' => 'Perl Template Merge Language (aka `HTML with a P\')','files' => ['README'],'lines' => {'nonpod' => 403,'pod' => 287,'pod_errors' => 1,'total' => 690,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 23547,'unpacked' => 72997},'testers' => {'pass' => 2},'uses' => []},'Ptml0150.tgz' => {'author' => 'MDEWJONES','description' => 'Perl Template Merge Language (aka `HTML with a P\')','files' => ['README'],'lines' => {'nonpod' => 439,'pod' => 374,'pod_errors' => 1,'total' => 813,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 20645,'unpacked' => 62001},'testers' => {'pass' => 1},'uses' => []},'Ptml0160.tgz' => {'author' => 'MDEWJONES','description' => 'Procedural Template Merge Language','files' => ['README'],'lines' => {'nonpod' => 620,'pod' => 557,'pod_errors' => 1,'total' => 1177,'with_comments' => 75},'releases' => 1,'size' => {'packed' => 24272,'unpacked' => 73944},'testers' => {'pass' => 3},'uses' => []},'Ptty-0.01.tar.gz' => {'author' => 'NI-S','description' => 'Pseudo terminal interface functions','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 0,'pod_errors' => 0,'total' => 53,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 15339,'unpacked' => 44243},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','DynaLoader','Tk::Pretty']},'Puppet-Any-0.04.tar.gz' => {'author' => 'DDUMONT','description' => 'Base class for an optionnal GUI','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 436,'pod' => 188,'pod_errors' => 0,'total' => 624,'with_comments' => 53},'releases' => 4,'requires' => ['DB_File-1.806.tar.gz','MLDBM-2.01.tar.gz','Puppet-Log-1.011.tar.gz','Tk-800.024.tar.gz','Tk-Multi-1.004.tar.gz','Tk-ObjScanner-2.004.tar.gz','Tk-Pod-0.9919.tar.gz'],'requires_module' => {'DB_File' => 0,'MLDBM' => 0,'Puppet::Log' => '0.4','Tk' => 0,'Tk::Multi::Text' => '2.001','Tk::ObjScanner' => '0.5','Tk::Pod' => 0},'requires_recursive' => ['DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','MLDBM-2.01.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Puppet-Log-1.011.tar.gz','Puppet-LogBody-1.002.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Tie-IxHash-1.21.tar.gz','Tk-800.024.tar.gz','Tk-GBARR-1.0401.tar.gz','Tk-HistEntry-0.40.tar.gz','Tk-Multi-1.004.tar.gz','Tk-ObjScanner-2.004.tar.gz','Tk-Pod-0.9919.tar.gz','WeakRef-0.01.tar.gz','perlindex-1.301.tar.gz'],'size' => {'packed' => 8198,'unpacked' => 25311},'testers' => {},'uses' => ['AutoLoader','Carp','Puppet::Log','Tk::Multi::Manager','Tk::Multi::Text','Tk::ObjScanner','Tk::Pod','Tk::Pod::Text','strict','vars']},'Puppet-Body-1.018.tar.gz' => {'author' => 'DDUMONT','description' => 'Utility class to handle has-a relations and logs','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 442,'pod' => 263,'pod_errors' => 0,'total' => 705,'with_comments' => 35},'releases' => 6,'requires' => ['DB_File-1.806.tar.gz','MLDBM-2.01.tar.gz','Puppet-LogBody-1.002.tar.gz'],'requires_module' => {'DB_File' => 0,'MLDBM' => 0,'Puppet::LogBody' => '1.001'},'requires_recursive' => ['DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','MLDBM-2.01.tar.gz','Puppet-LogBody-1.002.tar.gz'],'size' => {'packed' => 7552,'unpacked' => 24187},'testers' => {'fail' => 6,'pass' => 3,'tests' => '29'},'uses' => ['AutoLoader','Carp','Puppet::LogBody','strict','vars']},'Puppet-Log-1.011.tar.gz' => {'author' => 'DDUMONT','description' => 'Logging facility based on Tk','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 217,'pod' => 109,'pod_errors' => 0,'total' => 326,'with_comments' => 21},'releases' => 7,'requires' => ['Puppet-LogBody-1.002.tar.gz','Tk-800.024.tar.gz','Tk-Multi-1.004.tar.gz'],'requires_module' => {'Puppet::LogBody' => 0,'Tk' => 0,'Tk::Multi::Manager' => '2.001','Tk::Multi::Text' => '2.001','Tk::Multi::Toplevel' => '0'},'requires_recursive' => ['Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Puppet-LogBody-1.002.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Tie-IxHash-1.21.tar.gz','Tk-800.024.tar.gz','Tk-GBARR-1.0401.tar.gz','Tk-HistEntry-0.40.tar.gz','Tk-Multi-1.004.tar.gz','Tk-ObjScanner-2.004.tar.gz','Tk-Pod-0.9919.tar.gz','WeakRef-0.01.tar.gz','perlindex-1.301.tar.gz'],'size' => {'packed' => 5439,'unpacked' => 15220},'testers' => {'pass' => 1},'uses' => ['Carp','Puppet::LogBody','Tk::Multi::Manager','Tk::Multi::Text','Tk::Multi::Toplevel','strict','vars']},'Puppet-LogBody-1.002.tar.gz' => {'author' => 'DDUMONT','description' => 'Log facility','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 98,'pod' => 79,'pod_errors' => 0,'total' => 177,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 3360,'unpacked' => 7796},'testers' => {'fail' => 1,'pass' => 6,'tests' => '8'},'uses' => ['Carp','strict','vars']},'Puppet-Show-1.007.tar.gz' => {'author' => 'DDUMONT','description' => 'Optional Tk Gui for Puppet::Body','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 340,'pod' => 147,'pod_errors' => 0,'total' => 487,'with_comments' => 26},'releases' => 4,'requires' => ['DB_File-1.806.tar.gz','MLDBM-2.01.tar.gz','Puppet-Body-1.018.tar.gz','Puppet-Log-1.011.tar.gz','Tk-800.024.tar.gz','Tk-Multi-1.004.tar.gz','Tk-ObjScanner-2.004.tar.gz','Tk-Pod-0.9919.tar.gz'],'requires_module' => {'DB_File' => 0,'MLDBM' => 0,'Puppet::Body' => '1.013','Puppet::Log' => '1.010','Tk' => 0,'Tk::Multi::Text' => '2.001','Tk::Multi::Toplevel' => '1.002','Tk::ObjScanner' => '0.5','Tk::Pod' => 0},'requires_recursive' => ['DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','MLDBM-2.01.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Puppet-Body-1.018.tar.gz','Puppet-Log-1.011.tar.gz','Puppet-LogBody-1.002.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Tie-IxHash-1.21.tar.gz','Tk-800.024.tar.gz','Tk-GBARR-1.0401.tar.gz','Tk-HistEntry-0.40.tar.gz','Tk-Multi-1.004.tar.gz','Tk-ObjScanner-2.004.tar.gz','Tk-Pod-0.9919.tar.gz','WeakRef-0.01.tar.gz','perlindex-1.301.tar.gz'],'size' => {'packed' => 6283,'unpacked' => 18831},'testers' => {},'uses' => ['AutoLoader','Carp','Puppet::Log','Tk::Multi::Manager','Tk::Multi::Text','Tk::Multi::Toplevel','strict','vars']},'Puppet-VcsTools-File-1.003.tar.gz' => {'author' => 'DDUMONT','description' => 'VCS (RCS HMS) file manager','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1255,'pod' => 249,'pod_errors' => 0,'total' => 1504,'with_comments' => 70},'releases' => 3,'requires' => ['DB_File-1.806.tar.gz','MLDBM-2.01.tar.gz','Puppet-Show-1.007.tar.gz','Puppet-VcsTools-History-1.004.tar.gz','String-ShellQuote-1.00.tar.gz','Tk-800.024.tar.gz','VcsTools-File-1.004.tar.gz'],'requires_module' => {'DB_File' => 0,'MLDBM' => 0,'Puppet::Show' => '1.003','Puppet::VcsTools::History' => '1.005','String::ShellQuote' => 0,'Tk' => 0,'Tk::ROText' => 0,'VcsTools::File' => '1.005'},'requires_recursive' => ['DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','File-chmod-0.31.tar.gz','Getopt-Long-2.33.tar.gz','MLDBM-2.01.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','PodParser-1.23.tar.gz','Puppet-Body-1.018.tar.gz','Puppet-Log-1.011.tar.gz','Puppet-LogBody-1.002.tar.gz','Puppet-Show-1.007.tar.gz','Puppet-VcsTools-History-1.004.tar.gz','Sort-Versions-1.4.tar.gz','Storable-2.07.tar.gz','String-ShellQuote-1.00.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Tie-IxHash-1.21.tar.gz','Time-Local-1.07.tar.gz','Tk-800.024.tar.gz','Tk-GBARR-1.0401.tar.gz','Tk-HistEntry-0.40.tar.gz','Tk-Multi-1.004.tar.gz','Tk-ObjScanner-2.004.tar.gz','Tk-Pod-0.9919.tar.gz','VcsTools-File-1.004.tar.gz','VcsTools-History-1.004.tar.gz','WeakRef-0.01.tar.gz','perlindex-1.301.tar.gz'],'size' => {'packed' => 15391,'unpacked' => 57254},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['AutoLoader','Carp','Puppet::Show','Puppet::VcsTools::History','Tk::Checkbutton','Tk::Derived','Tk::Multi::Frame','Tk::Multi::Text','Tk::Pod','Tk::ROText','Tk::Toplevel','VcsTools::File','strict','vars']},'Puppet-VcsTools-History-1.004.tar.gz' => {'author' => 'DDUMONT','description' => 'VCS (RCS HMS) history viewer based on Canvas','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 872,'pod' => 369,'pod_errors' => 0,'total' => 1241,'with_comments' => 70},'releases' => 4,'requires' => ['DB_File-1.806.tar.gz','MLDBM-2.01.tar.gz','Puppet-Show-1.007.tar.gz','Sort-Versions-1.4.tar.gz','Tk-800.024.tar.gz','Tk-Multi-1.004.tar.gz','VcsTools-History-1.004.tar.gz'],'requires_module' => {'DB_File' => 0,'MLDBM' => 0,'Puppet::Show' => '0.04','Sort::Versions' => 0,'Tk' => 0,'Tk::Multi::Manager' => '2.001','Tk::Multi::Text' => '2.001','VcsTools::History' => '1.007','VcsTools::Version' => '1.006'},'requires_recursive' => ['DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','MLDBM-2.01.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Puppet-Body-1.018.tar.gz','Puppet-Log-1.011.tar.gz','Puppet-LogBody-1.002.tar.gz','Puppet-Show-1.007.tar.gz','Sort-Versions-1.4.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Tie-IxHash-1.21.tar.gz','Time-Local-1.07.tar.gz','Tk-800.024.tar.gz','Tk-GBARR-1.0401.tar.gz','Tk-HistEntry-0.40.tar.gz','Tk-Multi-1.004.tar.gz','Tk-ObjScanner-2.004.tar.gz','Tk-Pod-0.9919.tar.gz','VcsTools-History-1.004.tar.gz','WeakRef-0.01.tar.gz','perlindex-1.301.tar.gz'],'size' => {'packed' => 16174,'unpacked' => 55483},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['AutoLoader','Carp','Puppet::Show','Sort::Versions','Tk::Derived','Tk::Frame','Tk::Label','Tk::Menubutton','Tk::ROText','Tk::TreeGraph','VcsTools::HistSqlStorage','VcsTools::History','VcsTools::VerSqlStorage','VcsTools::Version','strict','vars']},'Pvm-0.9.tar.gz' => {'author' => 'EWALKER','description' => 'Perl extension for the Parallel Virtual Machine (PVM) Message Passing System','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 552,'pod' => 1198,'pod_errors' => 2,'total' => 1750,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 139756,'unpacked' => 502682},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Python-Bytecode-2.0.tar.gz' => {'author' => 'SIMON','description' => 'Disassemble and investigate Python bytecode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 692,'pod' => 52,'pod_errors' => 0,'total' => 744,'with_comments' => 126},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6618,'unpacked' => 24458},'testers' => {'pass' => 8},'uses' => ['5.6.0','Carp','strict']},'Python-Bytecode-SAX-0.1.tar.gz' => {'author' => 'GREGOR','description' => 'Process Python bytecode, generating SAX events.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 696,'pod' => 55,'pod_errors' => 0,'total' => 751,'with_comments' => 123},'releases' => 1,'requires' => ['Python-Bytecode-2.0.tar.gz'],'requires_module' => {'Python::Bytecode' => '2.0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Python-Bytecode-2.0.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6452,'unpacked' => 20888},'testers' => {'pass' => 6},'uses' => ['5.6.0','Carp','Data::Dumper','Python::Bytecode::v21','Python::Bytecode::v22','strict']},'Python-Serialise-Marshal-0.02.tar.gz' => {'author' => 'SIMONW','description' => 'a module for reading and writing marshalled Python files','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 338,'pod' => 107,'pod_errors' => 0,'total' => 445,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 8881,'unpacked' => 30229},'testers' => {'pass' => 2},'uses' => ['File::Binary','IO::File','Math::Complex','strict','vars']},'Python-Serialise-Pickle-0.01.tar.gz' => {'author' => 'SIMONW','description' => 'a file for reading and writing pickled Python files','files' => ['Makefile.PL','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 510,'pod' => 107,'pod_errors' => 0,'total' => 617,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 6614,'unpacked' => 19661},'testers' => {'pass' => 2},'uses' => ['Data::Dumper','IO::File','strict','vars']},'QNA_0.5.tar.gz' => {'author' => 'RFOLEY','description' => 'Questions wrapper.','files' => ['README'],'lines' => {'nonpod' => 372,'pod' => 243,'pod_errors' => 4,'total' => 615,'with_comments' => 54},'releases' => 1,'size' => {'packed' => 4234,'unpacked' => 12775},'testers' => {'fail' => 3},'uses' => ['strict','vars']},'Qmail-Control-0.01.tar.gz' => {'author' => 'TECH','description' => undef,'files' => [],'lines' => {'nonpod' => 315,'pod' => 225,'pod_errors' => 2,'total' => 540,'with_comments' => 71},'releases' => 1,'size' => {'packed' => 5663,'unpacked' => 21590},'testers' => {'pass' => 2},'uses' => ['5.006','Exporter','Fcntl','strict','warnings']},'Qt-0.03.tar.gz' => {'author' => 'AWIN','description' => 'A Perl module interface to Qt','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4418,'pod' => 1887,'pod_errors' => 0,'total' => 6305,'with_comments' => 75},'releases' => 3,'size' => {'packed' => 105612,'unpacked' => 429890},'testers' => {'fail' => 1},'uses' => ['Carp','DynaLoader','Exporter','POSIX','QAccel','QApplication','QBitmap','QBrush','QButton','QButtonGroup','QClipboard','QColor','QCursor','QDialog','QEvent','QFont','QFontInfo','QFontMetrics','QFrame','QGlobal','QGroupBox','QImage','QLCDNumber','QLabel','QLayout','QMenuBar','QMenuData','QMultiLineEdit','QObject','QPaintDevice','QPainter','QPalette','QPen','QPicture','QPixmap','QPoint','QPointArray','QPopupMenu','QPushButton','QRadioButton','QRangeControl','QRect','QRegion','QScrollBar','QSize','QSlider','QTabDialog','QTableView','QTimer','QWMatrix','QWidget','Qt','signals','slots','strict','vars']},'Qt-OpenGL-0.02.tar.gz' => {'author' => 'AWIN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2748,'pod' => 0,'pod_errors' => 0,'total' => 2748,'with_comments' => 406},'releases' => 2,'requires' => ['PerlQt-3.006.tar.gz'],'requires_module' => {'Qt' => '2.104'},'requires_recursive' => ['PerlQt-3.006.tar.gz'],'size' => {'packed' => 36562,'unpacked' => 156266},'testers' => {},'uses' => ['Carp','Cwd','DynaLoader','ExtUtils::MakeMaker','Qt','perlqt.conf','strict']},'Qtk-QuickTk-0.89.tar.gz' => {'author' => 'JNK','description' => 'A Simpler Syntax for Perl-Tk GUI Building','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 841,'pod' => 588,'pod_errors' => 0,'total' => 1429,'with_comments' => 24},'releases' => 2,'size' => {'packed' => 18411,'unpacked' => 58746},'testers' => {'fail' => 1,'pass' => 5,'tests' => '1'},'uses' => ['5.002','AutoLoader','Carp','English','Exporter','FileHandle','Text::TreeFile','Tk','strict','vars']},'Quantum-Entanglement-0.32.tar.gz' => {'author' => 'AJGOUGH','description' => 'QM entanglement of variables in perl','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 927,'pod' => 402,'pod_errors' => 0,'total' => 1329,'with_comments' => 89},'releases' => 8,'size' => {'packed' => 20276,'unpacked' => 58412},'testers' => {'pass' => 9},'uses' => ['Carp','Math::Complex','strict','warnings']},'Quantum-Superpositions-2.02.tar.gz' => {'author' => 'LEMBARK','description' => 'QM-like superpositions in Perl','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 837,'pod' => 364,'pod_errors' => 0,'total' => 1201,'with_comments' => 48},'releases' => 9,'requires' => ['Class-Multimethods-1.70.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Class::Multimethods' => 0,'strict' => 0},'requires_recursive' => ['Class-Multimethods-1.70.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13742,'unpacked' => 41250},'testers' => {'pass' => 3},'uses' => ['Carp','Class::Multimethods','Quantum::Superpositions::Conj','subs']},'Quantum-Usrn-1.00.tar.gz' => {'author' => 'KASEI','description' => 'Square root of not.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 45,'pod_errors' => 0,'total' => 120,'with_comments' => 11},'releases' => 1,'requires' => ['Crypt-Blowfish-2.09.tar.gz'],'requires_module' => {'Crypt::Blowfish' => '2.06'},'requires_recursive' => ['Crypt-Blowfish-2.09.tar.gz'],'size' => {'packed' => 2231,'unpacked' => 4173},'testers' => {'pass' => 4},'uses' => ['Crypt::Blowfish','strict']},'Queue-Base-1.1.tar.gz' => {'author' => 'ARPADF','description' => 'Simple OO style queue implementation.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 180,'pod' => 82,'pod_errors' => 0,'total' => 262,'with_comments' => 8},'releases' => 3,'size' => {'packed' => 3187,'unpacked' => 8176},'testers' => {'pass' => 2},'uses' => ['Exporter']},'Queue-Dir-0.01.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Manage queue directories where each object is a file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 557,'pod' => 134,'pod_errors' => 0,'total' => 691,'with_comments' => 31},'releases' => 1,'requires' => ['File-Spec-0.82.tar.gz','Params-Validate-0.64.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Path' => 0,'File::Spec' => 0,'Params::Validate' => 0,'Sys::Hostname' => 0,'Test::More' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','File-Spec-0.82.tar.gz','Params-Validate-0.64.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10255,'unpacked' => 31458},'testers' => {'fail' => 1,'pass' => 2,'tests' => '137'},'uses' => ['5.005_62','Fcntl','IO::Dir','IO::File','Params::Validate','Sys::Hostname','Time::HiRes','strict','vars','warnings']},'Quilt-0.08.tar.gz' => {'author' => 'KMACLEOD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1452,'pod' => 0,'pod_errors' => 0,'total' => 1452,'with_comments' => 215},'releases' => 4,'size' => {'packed' => 27029,'unpacked' => 113757},'testers' => {'fail' => 2},'uses' => ['Class::Visitor','FileHandle','Quilt::HTML','Text::EntityMap','strict','vars']},'Quine-1.01.tar.gz' => {'author' => 'PINYAN','description' => 'extension for creating quines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 19,'pod' => 24,'pod_errors' => 0,'total' => 43,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 1268,'unpacked' => 1919},'testers' => {'pass' => 5},'uses' => []},'Quizzer-0.08.tar.gz' => {'author' => 'IPPO','description' => 'Quizzer Base Class','files' => ['README'],'lines' => {'nonpod' => 3679,'pod' => 964,'pod_errors' => 0,'total' => 4643,'with_comments' => 408},'releases' => 1,'size' => {'packed' => 1418713,'unpacked' => 3551127},'testers' => {'fail' => 1,'tests' => '0','unknown' => 3},'uses' => ['CGI','Exporter','Gtk','Gtk::Atoms','IO::Select','IO::Socket','IPC::Open3','POSIX','Quizzer::ConfigDb','Term::ReadLine','Text::Wrap','UNIVERSAL','strict','vars']},'Quota-1.4.8.tar.gz' => {'author' => 'TOMZO','description' => 'Disk quota system functions, local & remote','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 209,'pod' => 129,'pod_errors' => 0,'total' => 338,'with_comments' => 25},'releases' => 18,'size' => {'packed' => 41290,'unpacked' => 130847},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','POSIX','strict']},'R3-0.31.tar.gz' => {'author' => 'SCHOEN','description' => 'Perl object oriented client interface to SAP R/3 using RFCSDK','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 549,'pod' => 152,'pod_errors' => 0,'total' => 701,'with_comments' => 18},'releases' => 3,'size' => {'packed' => 6549,'unpacked' => 20420},'testers' => {'fail' => 5},'uses' => ['AutoLoader','Carp','Exporter','R3::rfcapi','strict','vars']},'R3-rfcapi-0.32.tar.gz' => {'author' => 'SCHOEN','description' => 'Perl extension for SAP\'s rfcsdk','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 23,'pod_errors' => 0,'total' => 73,'with_comments' => 7},'releases' => 5,'size' => {'packed' => 12600,'unpacked' => 58954},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'RADIUS-1.0.tar.gz' => {'author' => 'CHRMASTO','description' => 'Object interface to RADIUS (rfc2138) packets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 273,'pod' => 266,'pod_errors' => 0,'total' => 539,'with_comments' => 20},'releases' => 3,'size' => {'packed' => 43413,'unpacked' => 196167},'testers' => {'fail' => 3,'pass' => 2},'uses' => ['Exporter','MD5','Socket','strict','vars']},'RADIUS-UserFile-1.01.tar.gz' => {'author' => 'OEVANS','description' => 'Manipulate a RADIUS users file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 610,'pod' => 136,'pod_errors' => 0,'total' => 746,'with_comments' => 91},'releases' => 4,'size' => {'packed' => 14862,'unpacked' => 47137},'testers' => {'fail' => 3,'pass' => 3},'uses' => ['5.004','Carp','Exporter','Fcntl','File::Copy','IO::File','Tie::IxHash','strict','vars']},'RAPNAP-client-0.02.tar.gz' => {'author' => 'DAVIDNICO','description' => 'perform a check against the RAPNAP database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 104,'pod' => 131,'pod_errors' => 1,'total' => 235,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 4103,'unpacked' => 8674},'testers' => {'pass' => 3},'uses' => ['Socket','strict','vars']},'RAS-AS5200-1.04.tar.gz' => {'author' => 'STIGMATA','description' => 'Interface to Cisco AS5200 dialup server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 265,'pod' => 252,'pod_errors' => 0,'total' => 517,'with_comments' => 44},'releases' => 5,'requires' => ['Net-Telnet-3.03.tar.gz'],'requires_module' => {'Net::Telnet' => 0},'requires_recursive' => ['Net-Telnet-3.03.tar.gz'],'size' => {'packed' => 8499,'unpacked' => 25026},'testers' => {'fail' => 1},'uses' => ['strict']},'RAS-HiPerARC-1.03.tar.gz' => {'author' => 'STIGMATA','description' => 'Interface to 3Com TotalControl HiPerARC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 212,'pod' => 187,'pod_errors' => 0,'total' => 399,'with_comments' => 30},'releases' => 4,'requires' => ['Net-Telnet-3.03.tar.gz'],'requires_module' => {'Net::Telnet' => 0},'requires_recursive' => ['Net-Telnet-3.03.tar.gz'],'size' => {'packed' => 6446,'unpacked' => 17774},'testers' => {'pass' => 1},'uses' => ['strict']},'RAS-PortMaster-1.16.tar.gz' => {'author' => 'STIGMATA','description' => 'Interface to Livingston PortMaster','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 173,'pod' => 186,'pod_errors' => 0,'total' => 359,'with_comments' => 28},'releases' => 7,'requires' => ['Net-Telnet-3.03.tar.gz'],'requires_module' => {'Net::Telnet' => 0},'requires_recursive' => ['Net-Telnet-3.03.tar.gz'],'size' => {'packed' => 5940,'unpacked' => 15703},'testers' => {'pass' => 2},'uses' => ['strict']},'RCGI-1.20.tar.gz' => {'author' => 'BRIAN','description' => 'Remote CGI distributed processing','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1289,'pod' => 639,'pod_errors' => 0,'total' => 1928,'with_comments' => 141},'releases' => 1,'size' => {'packed' => 24072,'unpacked' => 89131},'testers' => {'pass' => 3},'uses' => ['5.000','CGI','Carp','Data::Dumper','Exporter','HTTP::Request::Common','IO::Pipe','LWP::Simple','LWP::UserAgent','MIME::Base64','Safe','URI::URL','lib','module','strict','vars']},'RCU-0.01.tar.gz' => {'author' => 'MLEHMANN','description' => 'Remote Control Unit Interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 652,'pod' => 360,'pod_errors' => 0,'total' => 1012,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 17289,'unpacked' => 46615},'testers' => {'pass' => 2},'uses' => ['Carp','DynaLoader','Event','Fcntl','RCU::Interface']},'RDBAL-1.2.tar.gz' => {'author' => 'BRIAN','description' => 'Relational DataBase Abstraction Layer class (ReDBALl)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2427,'pod' => 868,'pod_errors' => 0,'total' => 3295,'with_comments' => 272},'releases' => 6,'size' => {'packed' => 21910,'unpacked' => 95526},'testers' => {'pass' => 3},'uses' => ['$RDBAL::Config::middle_module{$_}','.','5.000','Apache::Sybase::DBlib','DBI','Exporter','RDBAL::Layer::','Sybase::DBlib','Win32::ODBC','strict','vars']},'RDBMS.pm-0.93.tar.gz' => {'author' => 'BJEPS','description' => 'Relational Database Management System for Msql','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1277,'pod' => 73,'pod_errors' => 0,'total' => 1350,'with_comments' => 169},'releases' => 1,'size' => {'packed' => 32070,'unpacked' => 135407},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.002','CGI','CGI::Carp','Date::Format','Date::Parse','Msql','strict','vars']},'RDF-Core-0.11.tar.gz' => {'author' => 'PAVELH','description' => 'An object oriented Perl modules for handling tasks related to RDF.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5059,'pod' => 1282,'pod_errors' => 0,'total' => 6341,'with_comments' => 1017},'releases' => 9,'size' => {'packed' => 47977,'unpacked' => 241932},'testers' => {'pass' => 3},'uses' => ['Carp','DBI','Data::Dumper','Exporter','RDF::Core::Enumerator::Memory','RDF::Core::Enumerator::Postgres','RDF::Core::Function','RDF::Core::Literal','RDF::Core::Node','RDF::Core::NodeFactory','RDF::Core::Parser','RDF::Core::Query','RDF::Core::Resource','RDF::Core::Serializer','RDF::Core::Statement','URI','XML::Parser','constant','strict']},'RDF-Core-0.16.tar.gz' => {'author' => 'PAVELH','description' => 'An object oriented Perl modules for handling tasks related to RDF.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6527,'pod' => 1531,'pod_errors' => 1,'total' => 8058,'with_comments' => 1272},'releases' => 9,'size' => {'packed' => 71753,'unpacked' => 372602},'testers' => {'pass' => 4},'uses' => ['Carp','DBI','DB_File','Data::Dumper','Exporter','RDF::Core::Constants','RDF::Core::Enumerator','RDF::Core::Enumerator::DB_File','RDF::Core::Enumerator::Postgres','RDF::Core::Function','RDF::Core::Literal','RDF::Core::Node','RDF::Core::NodeFactory','RDF::Core::Parser','RDF::Core::Query','RDF::Core::Resource','RDF::Core::Serializer','RDF::Core::Statement','RDF::Core::Storage','URI','XML::Parser','constant','strict','vars']},'RDF-Core-0.30.tar.gz' => {'author' => 'DPOKORNY','description' => 'An object oriented Perl modules for handling tasks related to RDF.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6727,'pod' => 1550,'pod_errors' => 1,'total' => 8277,'with_comments' => 1270},'releases' => 9,'size' => {'packed' => 74897,'unpacked' => 382427},'testers' => {'pass' => 3},'uses' => ['Carp','DBI','DB_File','Data::Dumper','Exporter','RDF::Core::Enumerator::Memory','URI','XML::Parser','constant','strict','vars']},'RDF-Notation3-0.83.tar.gz' => {'author' => 'PCIMPRICH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2328,'pod' => 524,'pod_errors' => 0,'total' => 2852,'with_comments' => 233},'releases' => 10,'size' => {'packed' => 18290,'unpacked' => 73384},'testers' => {'pass' => 2},'uses' => ['5.005_62','Carp','RDF::Core::Literal','RDF::Core::Model','RDF::Core::Resource','RDF::Core::Statement','RDFStore::Model','RDFStore::NodeFactory','XML::SAX::Base','strict','vars','warnings']},'RDF-Service-0.02.tar.gz' => {'author' => 'JONAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4221,'pod' => 0,'pod_errors' => 0,'total' => 4221,'with_comments' => 948},'releases' => 4,'requires' => ['CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','Template-Toolkit-2.10.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'CGI' => 0,'DBI' => 0,'Template' => 2,'Time::HiRes' => 0,'URI' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','Template-Toolkit-2.10.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz'],'size' => {'packed' => 56195,'unpacked' => 207599},'testers' => {'fail' => 1},'uses' => ['$file','5.006','Carp','DBI','Data::Dumper','Date::Parse','Exporter','POSIX','RDF::Service::Cache','RDF::Service::Constants','RDF::Service::Context','RDF::Service::Dispatcher','RDF::Service::Resource','Time::HiRes','Time::Object','URI','constant','strict','vars']},'RDF-Service-0.04.tar.gz' => {'author' => 'JONAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5923,'pod' => 0,'pod_errors' => 0,'total' => 5923,'with_comments' => 1157},'releases' => 4,'requires' => ['CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','FreezeThaw-0.43.tar.gz','IO-1.20.tar.gz','Template-Toolkit-2.10.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'CGI' => 0,'DBI' => 0,'Data::Dumper' => 0,'FreezeThaw' => 0,'IO::Socket' => '1.18','Template' => 2,'Time::HiRes' => 0,'URI' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','FreezeThaw-0.43.tar.gz','IO-1.20.tar.gz','Template-Toolkit-2.10.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz'],'size' => {'packed' => 63179,'unpacked' => 235973},'testers' => {'fail' => 1,'tests' => '0','unknown' => 3},'uses' => ['$file','5.006','Carp','DBI','Data::Dumper','Exporter','POSIX','Time::HiRes','URI','constant','strict','vars']},'RDFStore-0.31.tar.gz' => {'author' => 'AREGGIORI','description' => 'This is a set of Perl modules that implement an object-oriented API to manipulate RDF models','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 6983,'pod' => 1424,'pod_errors' => 3,'total' => 8407,'with_comments' => 1412},'releases' => 4,'size' => {'packed' => 166220,'unpacked' => 824687},'testers' => {'fail' => 2,'tests' => '37'},'uses' => ['5.6.0','AutoLoader','BerkeleyDB','Carp','DBMS','DB_File','Data::MagicTie','Digest','DynaLoader','Exporter','Fcntl','RDFStore::Literal','RDFStore::Model','RDFStore::NodeFactory','RDFStore::Parser::OpenHealth','RDFStore::Parser::SiRPAC','RDFStore::Parser::Styles::MagicTie','RDFStore::RDFNode','RDFStore::Resource','RDFStore::SchemaModel','RDFStore::SetModel','RDFStore::Stanford::Digest','RDFStore::Stanford::Digest::Abstract','RDFStore::Stanford::Digest::Generic','RDFStore::Stanford::Digest::MD5','RDFStore::Stanford::Digest::SHA1','RDFStore::Stanford::Digest::Util','RDFStore::Stanford::Literal','RDFStore::Stanford::Model','RDFStore::Stanford::NodeFactory','RDFStore::Stanford::RDFNode','RDFStore::Stanford::Resource','RDFStore::Stanford::SetModel','RDFStore::Stanford::Statement','RDFStore::Stanford::VirtualModel','RDFStore::Statement','RDFStore::VirtualModel','RDFStore::Vocabulary::DAML','RDFStore::Vocabulary::DC','RDFStore::Vocabulary::RDF','RDFStore::Vocabulary::RDFS','Socket','Storable','Symbol','Tie::Hash','URI','URI::Escape','XML::Parser::Expat','strict','vars']},'RDFStore-0.42.tar.gz' => {'author' => 'AREGGIORI','description' => 'This is a set of Perl modules that implement an object-oriented API to manipulate RDF models','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 8974,'pod' => 1543,'pod_errors' => 4,'total' => 10517,'with_comments' => 1918},'releases' => 4,'size' => {'packed' => 193825,'unpacked' => 943483},'testers' => {'fail' => 1,'pass' => 2,'tests' => '178'},'uses' => ['5.6.0','AutoLoader','BerkeleyDB','Carp','DB_File','Digest','DynaLoader','Exporter','File::Path','RDFStore::Vocabulary::DAML','RDFStore::Vocabulary::DC','RDFStore::Vocabulary::RDF','RDFStore::Vocabulary::RDFS','SDBM_File','Socket','Storable','Symbol','Tie::Hash','URI','URI::Escape','XML::Parser::Expat','integer','strict','vars']},'RFC_RFC822_Address-1.5.tgz' => {'author' => 'ABIGAIL','description' => '- RFC 822 style address validation.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 175,'pod' => 75,'pod_errors' => 0,'total' => 250,'with_comments' => 77},'releases' => 2,'requires' => ['Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'Parse::RecDescent' => '1.52'},'requires_recursive' => ['Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 5108,'unpacked' => 13276},'testers' => {'pass' => 4},'uses' => ['Exporter','Parse::RecDescent','vars']},'RIFF-Info-1.03.tar.gz' => {'author' => 'ALLENDAY','description' => 'Probe DivX, AVI, and ASF files for attributes like: -video codec -audio codec -frame height -frame width -frame count and more!','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 219,'pod' => 105,'pod_errors' => 0,'total' => 324,'with_comments' => 8},'releases' => 8,'size' => {'packed' => 2210763,'unpacked' => 2466692},'testers' => {'fail' => 2,'pass' => 3,'tests' => '17'},'uses' => ['5.005_62','constant','strict','vars','warnings']},'RIFF-Info-1.07.tar.gz' => {'author' => 'ALLENDAY','description' => 'Probe DivX and AVI files for attributes like: -video codec -audio codec -frame height -frame width -frame count and more!','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 216,'pod' => 100,'pod_errors' => 0,'total' => 316,'with_comments' => 26},'releases' => 8,'requires' => ['Video-Info-0.993.tar.gz'],'requires_module' => {'Video::Info' => '0.06'},'requires_recursive' => ['Class-MakeMethods-1.006.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','MP3-Info-1.02.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Video-Info-0.993.tar.gz','Video-OpenQuicktime-1.02.tar.gz'],'size' => {'packed' => 176618,'unpacked' => 202885},'testers' => {'fail' => 1,'pass' => 1,'tests' => '23'},'uses' => ['5.005_62','Video::Info','constant','strict','vars','warnings']},'RIPEMD160-0.02.tar.gz' => {'author' => 'CHGEUER','description' => 'Perl extension for the RIPEMD-160 Hash function','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 257,'pod' => 180,'pod_errors' => 0,'total' => 437,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 48599,'unpacked' => 195096},'testers' => {'pass' => 2},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'RPC-Simple-0.5.tar.gz' => {'author' => 'DDUMONT','description' => 'Simple OO async remote procedure calls','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1313,'pod' => 650,'pod_errors' => 0,'total' => 1963,'with_comments' => 172},'releases' => 5,'requires' => ['Data-Dumper-2.101.tar.gz','Tk-800.024.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Tk' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Tk-800.024.tar.gz'],'size' => {'packed' => 16702,'unpacked' => 58161},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['AutoLoader','Data::Dumper','Exporter','Fcntl','IO::Select','IO::Socket','Tk','strict','vars']},'RPC-XML-0.53.tar.gz' => {'author' => 'RJRAY','description' => 'A set of classes for core data, message and XML handling','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6664,'pod' => 1482,'pod_errors' => 0,'total' => 8146,'with_comments' => 1931},'releases' => 20,'requires' => ['File-Spec-0.82.tar.gz','XML-Parser-2.31.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'File::Spec' => '0.8','LWP' => 0,'XML::Parser' => '2.25'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 111557,'unpacked' => 400977},'testers' => {'pass' => 8},'uses' => ['5.005','Apache','Apache::Constants','Apache::File','AutoLoader','CGI','Carp','Exporter','File::Spec','HTTP::Daemon','HTTP::Request','HTTP::Response','HTTP::Status','LWP::UserAgent','MIME::Base64','Net::Server::MultiType','Symbol','URI','XML::Parser','bytes','constant','strict','subs','vars']},'RPM-Info-1.03.tar.gz' => {'author' => 'MAHNKONG','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 254,'pod' => 75,'pod_errors' => 0,'total' => 329,'with_comments' => 6},'releases' => 2,'requires' => ['Test-1.24.tar.gz'],'requires_module' => {'Test' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 2222,'unpacked' => 6387},'testers' => {'pass' => 2},'uses' => ['strict']},'RPM-Perlonly-1.0.1.tar.gz' => {'author' => 'TLBDK','description' => 'a perl only implementaion of a RPM header reader.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 954,'pod' => 21,'pod_errors' => 0,'total' => 975,'with_comments' => 67},'releases' => 2,'size' => {'packed' => 6370,'unpacked' => 23200},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'RPM-Specfile-1.13.tar.gz' => {'author' => 'CHIPT','description' => 'Perl extension for creating RPM Specfiles','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 204,'pod' => 25,'pod_errors' => 0,'total' => 229,'with_comments' => 11},'releases' => 11,'requires' => ['Archive-Tar-1.03.tar.gz','Getopt-Long-2.33.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Archive::Tar' => 0,'File::Basename' => 0,'File::Copy' => 0,'Getopt::Long' => 0,'URI::Escape' => 0},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8274,'unpacked' => 21948},'testers' => {'pass' => 1},'uses' => ['POSIX','strict','vars']},'RPM-Tools-0.8.tar.gz' => {'author' => 'SHARRISON','description' => 'cleanly generate an RPM','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1235,'pod' => 460,'pod_errors' => 0,'total' => 1695,'with_comments' => 137},'releases' => 8,'size' => {'packed' => 16558,'unpacked' => 53297},'testers' => {'pass' => 2},'uses' => ['Getopt::Long','strict','vars']},'RPM-VersionSort-1.00.tar.gz' => {'author' => 'HAG','description' => 'RPM version sorting algorithm, in perl XS','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 30,'pod' => 22,'pod_errors' => 0,'total' => 52,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 3209,'unpacked' => 6305},'testers' => {'pass' => 8},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'RPM2-0.63.tar.gz' => {'author' => 'CHIPT','description' => 'Perl bindings for the RPM Package Manager API','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 476,'pod' => 229,'pod_errors' => 1,'total' => 705,'with_comments' => 18},'releases' => 5,'size' => {'packed' => 13821,'unpacked' => 39503},'testers' => {},'uses' => ['5.00503','Cwd','Data::Dumper','DynaLoader','File::Basename','File::Spec','strict','vars']},'RTF-Document-0.64.tar.gz' => {'author' => 'RRWO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 934,'pod' => 262,'pod_errors' => 0,'total' => 1196,'with_comments' => 61},'releases' => 6,'requires' => ['Convert-Units-0.43.tar.gz'],'requires_module' => {'Convert::Units::Type' => '0.33'},'requires_recursive' => ['Convert-Units-0.43.tar.gz'],'size' => {'packed' => 12539,'unpacked' => 40959},'testers' => {'pass' => 9},'uses' => ['5.005','Carp','Convert::Units::Type','Exporter','POSIX','vars']},'RTF-Generator-1.00.tar.gz' => {'author' => 'RRWO','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1569,'pod' => 561,'pod_errors' => 0,'total' => 2130,'with_comments' => 152},'releases' => 1,'requires' => ['Convert-Units-0.43.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Convert::Units::Type' => 0,'warnings::register' => 0},'requires_recursive' => ['Convert-Units-0.43.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14398,'unpacked' => 53678},'testers' => {'pass' => 6},'uses' => ['5.005_62','Carp','Convert::Units::Type','Exporter','strict','warnings','warnings::register']},'RTF-Parser-1.05.tar.gz' => {'author' => 'PVERD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2085,'pod' => 0,'pod_errors' => 0,'total' => 2085,'with_comments' => 440},'releases' => 7,'size' => {'packed' => 19726,'unpacked' => 62970},'testers' => {},'uses' => ['5.003','5.004','Carp','Config','Exporter','File::Basename','RTF::Charsets','RTF::Config','RTF::Control','RTF::Parser','constant','strict','vars']},'RTF-Parser-1.07.tar.gz' => {'author' => 'PVERD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2270,'pod' => 0,'pod_errors' => 0,'total' => 2270,'with_comments' => 520},'releases' => 7,'size' => {'packed' => 26427,'unpacked' => 92999},'testers' => {'pass' => 6},'uses' => ['5.003','5.004','Carp','Config','Exporter','File::Basename','constant','strict','vars']},'RTF-Tokenizer-1.01.tar.gz' => {'author' => 'SARGIE','description' => 'Module for Tokenizing RTF','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 318,'pod' => 102,'pod_errors' => 0,'total' => 420,'with_comments' => 35},'releases' => 6,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.01'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 17765,'unpacked' => 151764},'testers' => {'pass' => 3},'uses' => ['5','Carp','IO::File','strict','vars']},'RTF-Writer-1.07.tar.gz' => {'author' => 'SBURKE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1214,'pod' => 916,'pod_errors' => 0,'total' => 2130,'with_comments' => 236},'releases' => 7,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Exporter' => 0,'UNIVERSAL' => 0,'strict' => 0,'utf8' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 30244,'unpacked' => 85558},'testers' => {'pass' => 2},'uses' => ['5','5.005','Exporter','strict','utf','vars']},'Radioactive-Decay-0.02.tar.gz' => {'author' => 'TMTM','description' => 'allow scalar values to decay over time','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 22,'pod' => 35,'pod_errors' => 0,'total' => 57,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1673,'unpacked' => 2750},'testers' => {'pass' => 7},'uses' => ['strict','vars']},'RadiusPerl-0.09.tar.gz' => {'author' => 'MANOWAR','description' => 'provide simple Radius client facilities','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 433,'pod' => 82,'pod_errors' => 0,'total' => 515,'with_comments' => 30},'releases' => 5,'requires' => ['Data-Dumper-2.101.tar.gz','Data-HexDump-0.02.tar.gz','Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz'],'requires_module' => {'Data::Dumper' => 1,'Data::HexDump' => '0.02','Digest::MD5' => '2.2','IO' => '1.12'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Data-HexDump-0.02.tar.gz','Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz'],'size' => {'packed' => 8187,'unpacked' => 21947},'testers' => {'fail' => 1},'uses' => ['Data::Dumper','Data::HexDump','Digest::MD5','Exporter','FileHandle','IO::Select','IO::Socket','strict','vars']},'Randomize-1.10.tar.gz' => {'author' => 'BHILTON','description' => 'Perl extension for randomizing things.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 792,'pod' => 222,'pod_errors' => 0,'total' => 1014,'with_comments' => 129},'releases' => 4,'size' => {'packed' => 10795,'unpacked' => 66921},'testers' => {'pass' => 1},'uses' => ['Data::Dumper','strict','warnings']},'Rc-0.03.tar.gz' => {'author' => 'JPRIT','description' => 'parser and backends for \'rc\' shell','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 767,'pod' => 31,'pod_errors' => 0,'total' => 798,'with_comments' => 25},'releases' => 3,'size' => {'packed' => 43396,'unpacked' => 153103},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','DynaLoader','Exporter','IO::Handle','strict','vars']},'RcReader-0.5.9b.tar.gz' => {'author' => 'SAMSK','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 304,'pod' => 0,'pod_errors' => 0,'total' => 304,'with_comments' => 82},'releases' => 1,'size' => {'packed' => 18854,'unpacked' => 51058},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['Exporter','integer','strict','vars']},'Rcs-1.04.tar.gz' => {'author' => 'CFRETER','description' => 'Alternate RCS interface (see VCS::RCS)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1936,'pod' => 853,'pod_errors' => 0,'total' => 2789,'with_comments' => 468},'releases' => 12,'size' => {'packed' => 38451,'unpacked' => 184056},'testers' => {'pass' => 17},'uses' => ['5.001','5.002','Carp','Exporter','Time::Local','strict','subs','vars']},'Rcs-Agent-1.03.tar.gz' => {'author' => 'NICKH','description' => 'an RCS archive manipulation method library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1162,'pod' => 195,'pod_errors' => 0,'total' => 1357,'with_comments' => 172},'releases' => 4,'requires' => ['File-Temp-0.12.tar.gz','String-ShellQuote-1.00.tar.gz'],'requires_module' => {'File::Temp' => '','String::ShellQuote' => '1.00'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','String-ShellQuote-1.00.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15667,'unpacked' => 50315},'testers' => {'pass' => 3},'uses' => ['Carp','Cwd','File::Basename','File::Temp','File::stat','String::ShellQuote','strict','vars']},'ReadDir-0.01.tar.gz' => {'author' => 'SAMV','description' => 'Get the inode numbers in your readdir call.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 33,'pod' => 36,'pod_errors' => 0,'total' => 69,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2788,'unpacked' => 4833},'testers' => {'pass' => 1},'uses' => ['5.005','DynaLoader','Exporter','strict','vars']},'Readonly-1.02.tar.gz' => {'author' => 'ROODE','description' => 'Create read-only scalars, arrays, hashes.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 497,'pod' => 282,'pod_errors' => 0,'total' => 779,'with_comments' => 53},'releases' => 5,'size' => {'packed' => 12955,'unpacked' => 44663},'testers' => {'pass' => 2},'uses' => ['5.000','Carp','Exporter','strict','vars','warnings']},'Readonly-XS-1.02.tar.gz' => {'author' => 'ROODE','description' => 'Companion module for Readonly.pm, to speed up read-only scalar variables.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 47,'pod_errors' => 0,'total' => 132,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 8698,'unpacked' => 21896},'testers' => {'pass' => 2},'uses' => ['XSLoader','strict','vars','warnings']},'RedHat-Kickstart-0.3.tar.gz' => {'author' => 'PATRICK','description' => 'generate RedHat Kickstart files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 767,'pod' => 500,'pod_errors' => 3,'total' => 1267,'with_comments' => 104},'releases' => 1,'size' => {'packed' => 8649,'unpacked' => 36009},'testers' => {'pass' => 3},'uses' => ['5.005','Carp','strict','warnings']},'RedirectDBI-0.02.tar.gz' => {'author' => 'SANDERSON','description' => 'Redirect to different directories by DBI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 179,'pod' => 121,'pod_errors' => 0,'total' => 300,'with_comments' => 47},'releases' => 1,'size' => {'packed' => 4518,'unpacked' => 15411},'testers' => {'pass' => 4},'uses' => ['Apache::Constants','strict']},'Regex-PreSuf-1.15.tar.gz' => {'author' => 'JHI','description' => 'create regular expressions from word lists','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 313,'pod' => 71,'pod_errors' => 0,'total' => 384,'with_comments' => 13},'releases' => 14,'size' => {'packed' => 7123,'unpacked' => 21394},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'Regexp-0.004.tar.gz' => {'author' => 'GBARR','description' => 'Object Oriented interface to perl\'s regular expression code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 58,'pod' => 138,'pod_errors' => 0,'total' => 196,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 4428,'unpacked' => 11191},'testers' => {},'uses' => ['DynaLoader','Exporter','overload','vars']},'Regexp-Cherokee-0.02.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 331,'pod' => 124,'pod_errors' => 0,'total' => 455,'with_comments' => 43},'releases' => 2,'size' => {'packed' => 6057,'unpacked' => 15655},'testers' => {'pass' => 2},'uses' => ['Exporter','overload','strict','utf','vars']},'Regexp-Common-2.113.tar.gz' => {'author' => 'ABIGAIL','description' => 'Provide commonly requested regular expressions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3223,'pod' => 4115,'pod_errors' => 1,'total' => 7338,'with_comments' => 219},'releases' => 21,'size' => {'packed' => 136055,'unpacked' => 485310},'testers' => {'pass' => 5},'uses' => ['5.00473','Carp','constant','lib','re','strict','vars']},'Regexp-Copy-0.06.tar.gz' => {'author' => 'JDUNCAN','description' => 'copy Regexp objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 44,'pod_errors' => 0,'total' => 108,'with_comments' => 0},'releases' => 5,'size' => {'packed' => 3104,'unpacked' => 5399},'testers' => {'pass' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Regexp-English-0.21.tar.gz' => {'author' => 'CHROMATIC','description' => 'Perl module to create regular expressions more verbosely','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 436,'pod' => 312,'pod_errors' => 0,'total' => 748,'with_comments' => 22},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.30'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 11021,'unpacked' => 35947},'testers' => {'pass' => 4},'uses' => ['','Carp','Exporter','constant','strict','vars']},'Regexp-Ethiopic-0.12.tar.gz' => {'author' => 'DYACOB','description' => 'Regular Expressions Support for Ethiopic Script.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 881,'pod' => 302,'pod_errors' => 0,'total' => 1183,'with_comments' => 79},'releases' => 12,'size' => {'packed' => 15176,'unpacked' => 60651},'testers' => {'pass' => 1},'uses' => ['Exporter','overload','strict','utf','vars']},'Regexp-Ignore-0.03.tar.gz' => {'author' => 'RANI','description' => 'Let us ignore unwanted parts, while parsing text.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 919,'pod' => 551,'pod_errors' => 0,'total' => 1470,'with_comments' => 258},'releases' => 3,'size' => {'packed' => 71233,'unpacked' => 779804},'testers' => {'pass' => 3},'uses' => ['5.006','strict','warnings']},'Regexp-Log-0.01.tar.gz' => {'author' => 'BOOK','description' => 'A base class for log files regexp builders','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 229,'pod_errors' => 0,'total' => 467,'with_comments' => 30},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 6817,'unpacked' => 18009},'testers' => {'fail' => 1,'tests' => '44'},'uses' => ['','Carp','re','strict','vars']},'Regexp-Log-BlueCoat-0.02.tar.gz' => {'author' => 'BOOK','description' => 'A regexp builder to parse BlueCoat log files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 353,'pod' => 326,'pod_errors' => 0,'total' => 679,'with_comments' => 89},'releases' => 2,'requires' => ['Regexp-Log-0.01.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Regexp::Log' => '0.01','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Regexp-Log-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 11738,'unpacked' => 43753},'testers' => {},'uses' => ['','Carp','Regexp::Log','strict','vars']},'Regexp-Optimizer-0.10.tar.gz' => {'author' => 'DANKOGAI','description' => 'optimizes regular expressions','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 741,'pod' => 349,'pod_errors' => 0,'total' => 1090,'with_comments' => 92},'releases' => 2,'size' => {'packed' => 17668,'unpacked' => 48946},'testers' => {'pass' => 3},'uses' => ['5.006','Data::Dumper','Exporter','strict','utf','warnings']},'Regexp-Shellish-0.93.tar.gz' => {'author' => 'RBS','description' => 'Shell-like regular expressions','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 124,'pod' => 89,'pod_errors' => 0,'total' => 213,'with_comments' => 6},'releases' => 3,'size' => {'packed' => 3343,'unpacked' => 8745},'testers' => {'pass' => 11},'uses' => ['Carp','Exporter','strict','vars']},'Regexp-Subst-Parallel-0.10.tar.gz' => {'author' => 'LPALMER','description' => 'Safely perform multiple substitutions on a string in parallel. =head1 VERSION Regexp::Subst::Parallel version 0.10, Feb 9, 2003.','files' => ['Makefile.PL'],'lines' => {'nonpod' => 70,'pod' => 78,'pod_errors' => 0,'total' => 148,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2548,'unpacked' => 6273},'testers' => {'pass' => 10},'uses' => ['Carp','Exporter']},'Regexp-Tr-0.05.tar.gz' => {'author' => 'CHIA','description' => 'Lightweight run-time tr/// operations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 124,'pod' => 68,'pod_errors' => 0,'total' => 192,'with_comments' => 24},'releases' => 4,'size' => {'packed' => 3686,'unpacked' => 7434},'testers' => {'pass' => 2},'uses' => ['5.008','Carp','strict','warnings']},'Register-0.0.2.tar.gz' => {'author' => 'FABRVEC','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 413,'pod' => 197,'pod_errors' => 0,'total' => 610,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3229,'unpacked' => 12248},'testers' => {'pass' => 5},'uses' => ['DBI','Exporter','vars']},'Relations-0.95.tar.gz' => {'author' => 'GAFFER','description' => 'Database, CGI, and Graph Interfunctionality','files' => ['Makefile.PL'],'lines' => {'nonpod' => 1021,'pod' => 465,'pod_errors' => 0,'total' => 1486,'with_comments' => 260},'releases' => 3,'size' => {'packed' => 18463,'unpacked' => 75460},'testers' => {'pass' => 11},'uses' => ['5.004','Exporter','strict']},'Relations-Abstract-0.94.tar.gz' => {'author' => 'GAFFER','description' => 'DBI/DBD::mysql Functions to Save Development Time and Code Space','files' => ['Makefile.PL'],'lines' => {'nonpod' => 746,'pod' => 399,'pod_errors' => 0,'total' => 1145,'with_comments' => 166},'releases' => 2,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Relations-0.95.tar.gz','Relations-Query-0.93.tar.gz'],'requires_module' => {'DBD::mysql' => '1.18','DBI' => '1.13','Relations' => '0.94','Relations::Query' => '0.93'},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Relations-0.95.tar.gz','Relations-Query-0.93.tar.gz'],'size' => {'packed' => 11302,'unpacked' => 60329},'testers' => {'fail' => 4},'uses' => ['5.004','DBI','Exporter','Relations','Relations::Query','strict']},'Relations-Display-0.92.tar.gz' => {'author' => 'GAFFER','description' => 'DBI/DBD::mysql Query Graphing Module','files' => ['Makefile.PL'],'lines' => {'nonpod' => 1496,'pod' => 475,'pod_errors' => 0,'total' => 1971,'with_comments' => 355},'releases' => 3,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','GDGraph-1.43.tar.gz','Relations-0.95.tar.gz','Relations-Abstract-0.94.tar.gz','Relations-Query-0.93.tar.gz'],'requires_module' => {'DBD::mysql' => '1.18','DBI' => '1.13','GD::Graph' => '1.3','Relations' => '0.95','Relations::Abstract' => '0.94','Relations::Query' => '0.93'},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','Relations-0.95.tar.gz','Relations-Abstract-0.94.tar.gz','Relations-Query-0.93.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 25014,'unpacked' => 138135},'testers' => {},'uses' => ['5.004','DBI','Exporter','GD::Graph','Relations','Relations::Abstract','Relations::Query','strict']},'Relations-Family-0.94.tar.gz' => {'author' => 'GAFFER','description' => 'DBI/DBD::mysql Relational Query Engine module.','files' => ['Makefile.PL'],'lines' => {'nonpod' => 3568,'pod' => 943,'pod_errors' => 0,'total' => 4511,'with_comments' => 685},'releases' => 4,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Relations-0.95.tar.gz','Relations-Abstract-0.94.tar.gz','Relations-Query-0.93.tar.gz'],'requires_module' => {'DBD::mysql' => '1.18','DBI' => '1.13','Relations' => '0.94','Relations::Abstract' => '0.94','Relations::Query' => '0.93'},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Relations-0.95.tar.gz','Relations-Abstract-0.94.tar.gz','Relations-Query-0.93.tar.gz'],'size' => {'packed' => 49915,'unpacked' => 263086},'testers' => {},'uses' => ['5.004','DBI','Exporter','Relations','Relations::Abstract','Relations::Query','strict']},'Relations-Query-0.93.tar.gz' => {'author' => 'GAFFER','description' => 'Object for building queries with DBI/DBD::mysql','files' => ['Makefile.PL'],'lines' => {'nonpod' => 447,'pod' => 389,'pod_errors' => 0,'total' => 836,'with_comments' => 78},'releases' => 2,'requires' => ['Relations-0.95.tar.gz'],'requires_module' => {'Relations' => '0.94'},'requires_recursive' => ['Relations-0.95.tar.gz'],'size' => {'packed' => 10518,'unpacked' => 53422},'testers' => {'pass' => 7},'uses' => ['Exporter','Relations','strict']},'ReleaseAction-0.03.tar.gz' => {'author' => 'TILLY','description' => 'Trigger actions on destruction of a handle','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 111,'pod_errors' => 1,'total' => 156,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2972,'unpacked' => 5642},'testers' => {'pass' => 6},'uses' => ['Exporter','strict']},'Religion-1.03.tar.gz' => {'author' => 'KJALB','description' => 'Control where you go when you die()/warn()','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 273,'pod' => 144,'pod_errors' => 1,'total' => 417,'with_comments' => 44},'releases' => 2,'size' => {'packed' => 4467,'unpacked' => 12131},'testers' => {'fail' => 5},'uses' => []},'Remedy-ARSTools-0.7.tar.gz' => {'author' => 'AHICOX','description' => 'Alternative object interface to ARSperl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 991,'pod' => 464,'pod_errors' => 0,'total' => 1455,'with_comments' => 193},'releases' => 3,'requires' => ['ARSperl-1.74.tgz','Data-DumpXML-1.05.tar.gz'],'requires_module' => {'ARS' => '1.72','Data::DumpXML' => '1.03'},'requires_recursive' => ['ARSperl-1.74.tgz','Array-RefElem-0.02.tar.gz','Data-DumpXML-1.05.tar.gz','MIME-Base64-2.20.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 14231,'unpacked' => 50158},'testers' => {},'uses' => ['5.6.0','ARS','AutoLoader','Carp','Data::DumpXML','Data::DumpXML::Parser','Data::DumpXML::dump_xml','Exporter','warnings']},'RenderMan-0.04.tar.gz' => {'author' => 'GMLEWIS','description' => 'A RenderMan binding as a Perl 5.6 module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 794,'pod' => 68,'pod_errors' => 0,'total' => 862,'with_comments' => 63},'releases' => 4,'size' => {'packed' => 82671,'unpacked' => 266414},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Replication-Recall-1.6.tar.gz' => {'author' => 'AGUL','description' => 'Recall replication library server interface','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 0,'pod_errors' => 0,'total' => 20,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 2775,'unpacked' => 6739},'testers' => {},'uses' => ['DynaLoader','Exporter']},'Replication-Recall-DBServer-1.14.tar.gz' => {'author' => 'AGUL','description' => 'Database replication server using Recall','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 320,'pod' => 113,'pod_errors' => 0,'total' => 433,'with_comments' => 10},'releases' => 5,'requires' => ['DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','File-Rsync-0.30.tar.gz','Replication-Recall-1.6.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'DBI' => 0,'Data::Dumper' => 0,'File::Rsync' => 0,'POSIX' => 0,'Replication::Recall::Client' => 0,'Replication::Recall::Server' => 0,'Time::HiRes' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','File-Rsync-0.30.tar.gz','Replication-Recall-1.6.tar.gz','Time-HiRes-1.49.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5959,'unpacked' => 21245},'testers' => {},'uses' => ['Carp','DBI','Data::Dumper','File::Rsync','POSIX','Replication::Recall::Client','Replication::Recall::Server','Time::HiRes','strict','vars']},'Resource-Loader-0.03.tar.gz' => {'author' => 'JOSHUA','description' => 'Load different resources depending...','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 284,'pod' => 304,'pod_errors' => 0,'total' => 588,'with_comments' => 50},'releases' => 3,'requires' => ['Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Exception' => '0.15','Test::More' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8285,'unpacked' => 35059},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars','warnings']},'ResourcePool-0.9904.tar.gz' => {'author' => 'MWS','description' => 'A connection caching and pooling class.','files' => ['Makefile.PL'],'lines' => {'nonpod' => 1326,'pod' => 743,'pod_errors' => 0,'total' => 2069,'with_comments' => 105},'releases' => 13,'size' => {'packed' => 15096,'unpacked' => 57478},'testers' => {'pass' => 5},'uses' => ['DBI','Data::Dumper','Net::LDAP','Net::LDAP::Constant','ResourcePool::Factory','ResourcePool::Resource','ResourcePool::Resource::DBI','ResourcePool::Resource::Net::LDAP','strict','vars']},'ResourcePool-1.0103.tar.gz' => {'author' => 'MWS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1275,'pod' => 1365,'pod_errors' => 3,'total' => 2640,'with_comments' => 129},'releases' => 13,'size' => {'packed' => 33018,'unpacked' => 133438},'testers' => {'pass' => 2},'uses' => ['Data::Dumper','overload','strict','vars']},'ResourcePool-Resource-DBI-1.0100.tar.gz' => {'author' => 'MWS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 500,'pod' => 374,'pod_errors' => 0,'total' => 874,'with_comments' => 42},'releases' => 2,'size' => {'packed' => 9843,'unpacked' => 39496},'testers' => {'fail' => 1,'pass' => 8},'uses' => ['DBI','ResourcePool::Command','ResourcePool::Command::NoFailoverException','ResourcePool::Factory','ResourcePool::Resource','strict','vars']},'ResourcePool-Resource-Net-LDAP-1.0001.tar.gz' => {'author' => 'MWS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 220,'pod' => 117,'pod_errors' => 0,'total' => 337,'with_comments' => 24},'releases' => 2,'size' => {'packed' => 5866,'unpacked' => 23823},'testers' => {'pass' => 4},'uses' => ['Data::Dumper','Net::LDAP','Net::LDAP::Constant','ResourcePool::Factory','ResourcePool::Resource','strict','vars']},'ResourcePool-Resource-SOAP-Lite-1.0101.tar.gz' => {'author' => 'MWS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 153,'pod' => 153,'pod_errors' => 0,'total' => 306,'with_comments' => 17},'releases' => 2,'size' => {'packed' => 5326,'unpacked' => 16254},'testers' => {'pass' => 2},'uses' => ['ResourcePool::Command','ResourcePool::Command::NoFailoverException','ResourcePool::Factory','ResourcePool::Resource','SOAP::Lite','strict','vars']},'Resources-1.04.tar.gz' => {'author' => 'FRANCOC','description' => 'Application defaults management in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1259,'pod' => 537,'pod_errors' => 0,'total' => 1796,'with_comments' => 134},'releases' => 3,'size' => {'packed' => 18627,'unpacked' => 57190},'testers' => {'fail' => 2},'uses' => ['5.001','Carp','FileHandle','Safe','strict','vars']},'Reuters-SSL-0.52.tar.gz' => {'author' => 'CBARKEY','description' => 'Perl extension for Reuters SSL Source Sink Library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 148,'pod' => 87,'pod_errors' => 0,'total' => 235,'with_comments' => 6},'releases' => 3,'size' => {'packed' => 7730,'unpacked' => 21496},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Rodney-XML-QuickStruct-1.1.tar.gz' => {'author' => 'RBROOM','description' => 'Quick Perl data structures from XML.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1139,'pod' => 571,'pod_errors' => 1,'total' => 1710,'with_comments' => 178},'releases' => 1,'requires' => ['HTML-SimpleParse-0.12.tar.gz'],'requires_module' => {'HTML::SimpleParse' => '0.10'},'requires_recursive' => ['HTML-SimpleParse-0.12.tar.gz'],'size' => {'packed' => 16726,'unpacked' => 58516},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['HTML::SimpleParse','strict']},'Roman-1.1.tar.gz' => {'author' => 'OZAWA','description' => 'Convert Roman numbers to and from Arabic','files' => ['README'],'lines' => {'nonpod' => 73,'pod' => 33,'pod_errors' => 0,'total' => 106,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 1452,'unpacked' => 3648},'testers' => {'tests' => '0','unknown' => 33},'uses' => ['Exporter']},'Rosetta-0.12.tar.gz' => {'author' => 'DUNCAND','description' => 'Framework for RDBMS-generic apps and schemas','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1546,'pod' => 3466,'pod_errors' => 31,'total' => 5012,'with_comments' => 68},'releases' => 20,'size' => {'packed' => 82203,'unpacked' => 314944},'testers' => {'pass' => 2},'uses' => ['5.004','Rosetta::Engine','strict','vars','warnings']},'Rosetta-0.152.tar.gz' => {'author' => 'DUNCAND','description' => 'Framework for RDBMS-generic apps and schemas','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2156,'pod' => 3429,'pod_errors' => 19,'total' => 5585,'with_comments' => 145},'releases' => 20,'size' => {'packed' => 97915,'unpacked' => 388281},'testers' => {'fail' => 2,'pass' => 1,'tests' => '4'},'uses' => ['5.004','Carp','strict','vars','warnings']},'Rstat-Client-1.02.tar.gz' => {'author' => 'SCHWENKE','description' => 'Perl extension for client access to rstatd','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 118,'pod_errors' => 0,'total' => 161,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 7386,'unpacked' => 24534},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['DynaLoader','strict','vars']},'Run-0.03.tar.gz' => {'author' => 'ILYAZ','description' => 'Perl extension for to start programs in background','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 560,'pod' => 42,'pod_errors' => 0,'total' => 602,'with_comments' => 69},'releases' => 2,'size' => {'packed' => 7846,'unpacked' => 26042},'testers' => {'fail' => 1,'tests' => '74'},'uses' => ['Exporter','Fcntl','IO::File','IO::Handle','strict','vars']},'Runescape-Stats-0.03.tar.gz' => {'author' => 'MADCODER','description' => 'A persistent, cached, and object-oriented interface to Runescape Hiscores.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 249,'pod' => 156,'pod_errors' => 0,'total' => 405,'with_comments' => 45},'releases' => 2,'requires' => ['Storable-2.07.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::Simple' => 0,'Storable' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6053,'unpacked' => 21251},'testers' => {'pass' => 1},'uses' => ['LWP::Simple','Storable','strict','vars']},'Rx-0.53.tar.gz' => {'author' => 'MJD','description' => 'Regex debugger module','files' => ['Makefile.PL'],'lines' => {'nonpod' => 434,'pod' => 22,'pod_errors' => 0,'total' => 456,'with_comments' => 90},'releases' => 1,'size' => {'packed' => 20694,'unpacked' => 64363},'testers' => {'fail' => 1},'uses' => ['Carp','Data::Dumper','DynaLoader','Exporter','strict','vars']},'RxLaser-0.15.tar.gz' => {'author' => 'MARTINDT','description' => 'Perl extension for printing medical forms on HP LaserJet printers with the RxLaser simm. RxLaser, Inc. Laser Printing Solutions 3350 East Birch St. Suite 205 Brea, CA 92821 Tel: 714 986-1559 Fax: 714 986-1568 email: mail@rxlaser.com','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 181,'pod' => 44,'pod_errors' => 0,'total' => 225,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 2655,'unpacked' => 7710},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'SAP-BC-XMLRFC-0.06.tar.gz' => {'author' => 'PIERS','description' => 'Interface to SAP\'s Business Connector','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1229,'pod' => 258,'pod_errors' => 1,'total' => 1487,'with_comments' => 150},'releases' => 3,'requires' => ['XML-Parser-2.31.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request' => '1.26','LWP::Simple' => '1.32','LWP::UserAgent' => '1.68','XML::Parser' => '2.27'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12443,'unpacked' => 41971},'testers' => {'pass' => 3},'uses' => ['AutoLoader','Data::Dumper','Exporter','HTTP::Cookies','HTTP::Request','LWP::Simple','LWP::UserAgent','XML::Parser','strict','vars']},'SAP-Rfc-1.00.tar.gz' => {'author' => 'PIERS','description' => 'Perl extension for performing RFC Function calls against an SAP R/3 System. Please refer to the README file found with this distribution.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2179,'pod' => 343,'pod_errors' => 0,'total' => 2522,'with_comments' => 239},'releases' => 18,'size' => {'packed' => 28533,'unpacked' => 99714},'testers' => {},'uses' => ['AutoLoader','Data::Dumper','DynaLoader','Exporter','SAP::Iface','SAP::Rfc','SOAP::Lite','XML::Parser','constant','strict','vars']},'SAP-Rfc-1.16.tar.gz' => {'author' => 'PIERS','description' => 'Perl extension for performing RFC Function calls against an SAP R/3 System. Please refer to the README file found with this distribution. This Distribution also allows the creation of registered RFCs so that an SAP system can call arbitrary Perl code created in assigned callbacks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2583,'pod' => 399,'pod_errors' => 0,'total' => 2982,'with_comments' => 295},'releases' => 18,'size' => {'packed' => 37862,'unpacked' => 134578},'testers' => {},'uses' => ['5.005','Apache::Constants','Apache::Reload','AutoLoader','Data::Dumper','DynaLoader','Exporter','SOAP::Lite','SOAP::Transport::HTTP','XML::Parser','constant','lib','strict','vars']},'SAP-WAS-SOAP-0.01.tar.gz' => {'author' => 'PIERS','description' => 'Perl extension for performing RFC Function calls against an SAP R/3 using the Business Connector System. Please refer to the README file found with this distribution.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 971,'pod' => 170,'pod_errors' => 0,'total' => 1141,'with_comments' => 143},'releases' => 1,'requires' => ['SOAP-Lite-0.55.tar.gz'],'requires_module' => {'SOAP::Lite' => '0.5'},'requires_recursive' => ['SOAP-Lite-0.55.tar.gz'],'size' => {'packed' => 8200,'unpacked' => 29316},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Data::Dumper','SOAP::Lite','strict','vars']},'SAVI-Perl-0.10.tar.gz' => {'author' => 'PHENSON','description' => 'Perl module interface to Sophos Anti-Virus Engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 109,'pod_errors' => 0,'total' => 242,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 27753,'unpacked' => 154860},'testers' => {'fail' => 1,'tests' => '1'},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'SDL-App-FPS-0.20.tar.gz' => {'author' => 'TELS','description' => 'a parent class for FPS (framerate/s centric) SDL applications','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 6215,'pod' => 1428,'pod_errors' => 0,'total' => 7643,'with_comments' => 817},'releases' => 19,'requires' => ['Config-Simple-4.55.tar.gz','Games-Console-0.03.tar.gz','Games-OpenGL-Font-2D-0.06.tar.gz','SDL_perl-1.19.2.tar.gz'],'requires_module' => {'Config::Simple' => '4.48','Games::Console' => '0.02','Games::OpenGL::Font::2D' => '0.05','SDL' => 'v1.20.3'},'requires_recursive' => ['Config-Simple-4.55.tar.gz','Games-Console-0.03.tar.gz','Games-OpenGL-Font-2D-0.06.tar.gz','SDL_perl-1.19.2.tar.gz'],'size' => {'packed' => 81785,'unpacked' => 470583},'testers' => {},'uses' => ['Carp','Config::Simple','DynaLoader','Exporter','File::Spec','Games::OpenGL::Font::2D','Getopt::Long','Math::Fractal::Mandelbrot','SDL','SDL::App','SDL::Color','SDL::Constants','SDL::Event','SDL::OpenGL','SDL::OpenGL::Cube','Storable','strict','vars']},'SDL-sdlpl-1.08.tar.gz' => {'author' => 'WKEENAN','description' => 'Perl bindings for the SDL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3355,'pod' => 887,'pod_errors' => 0,'total' => 4242,'with_comments' => 401},'releases' => 1,'size' => {'packed' => 179335,'unpacked' => 359890},'testers' => {},'uses' => ['AutoLoader','Carp','Data::Dumper','DynaLoader','Exporter','Getopt::Long','IO::File','OpenGL','strict','vars']},'SDL_perl-1.19.2.tar.gz' => {'author' => 'DGOEHRIG','description' => 'Simple DirectMedia Layer Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2521,'pod' => 2063,'pod_errors' => 1,'total' => 4584,'with_comments' => 135},'releases' => 3,'size' => {'packed' => 680136,'unpacked' => 1299691},'testers' => {'fail' => 1},'uses' => ['AutoLoader','DynaLoader','Exporter','IO::File','SDL::Event','SDL::Font','SDL::Music','SDL::OpenGL','SDL::Palette','SDL::Rect','SDL::Sound','SDL::Surface','strict','vars']},'SETI-Stats-1.06.tar.gz' => {'author' => 'MHAMILTON','description' => 'gather local and remote SETI@home stats and manipulate them','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 379,'pod' => 177,'pod_errors' => 0,'total' => 556,'with_comments' => 21},'releases' => 4,'size' => {'packed' => 6430,'unpacked' => 19759},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['strict','vars']},'SETI-WebStats-1.02.tar.gz' => {'author' => 'KSPENCER','description' => 'Gather SETI@home statistics from the SETI@home web server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 213,'pod' => 135,'pod_errors' => 0,'total' => 348,'with_comments' => 17},'releases' => 3,'requires' => ['XML-Simple-2.08.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::UserAgent' => 0,'XML::Simple' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-Simple-2.08.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3589,'unpacked' => 9484},'testers' => {'pass' => 1},'uses' => ['Carp','LWP::UserAgent','XML::Simple','constant','strict','vars']},'SGI-FAM-1.002.tar.gz' => {'author' => 'JGLICK','description' => 'Interface to SGI/Irix File Access Monitor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 253,'pod' => 125,'pod_errors' => 0,'total' => 378,'with_comments' => 2},'releases' => 1,'requires' => ['Data-Dumper-2.101.tar.gz','File-PathConvert-0.9.tar.gz','Getopt-Mixed-1.008.tar.gz','IO-1.20.tar.gz','MD5-2.02.tar.gz','PodParser-1.23.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => '2.07','File::Basename' => '2.5','File::PathConvert' => 0,'Getopt::Mixed' => 0,'IO::File' => 0,'MD5' => '1.7','Pod::Usage' => 1,'autouse' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-PathConvert-0.9.tar.gz','File-Spec-0.82.tar.gz','Getopt-Mixed-1.008.tar.gz','IO-1.20.tar.gz','MD5-2.02.tar.gz','PodParser-1.23.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 16675,'unpacked' => 46117},'testers' => {'fail' => 1},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'SGI-FM-0.1.tar.gz' => {'author' => 'AMOSS','description' => 'SGI\'s Font Management library','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 46,'pod' => 0,'pod_errors' => 0,'total' => 46,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2501,'unpacked' => 4301},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['AutoLoader','DynaLoader','Exporter']},'SGI-GL-0.2.tar.gz' => {'author' => 'AMOSS','description' => 'SGI\'s Iris GL library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 182,'pod' => 0,'pod_errors' => 0,'total' => 182,'with_comments' => 29},'releases' => 1,'size' => {'packed' => 6973,'unpacked' => 22128},'testers' => {'fail' => 1},'uses' => ['AutoLoader','DynaLoader','Exporter']},'SGI-SysCalls-0.1.tar.gz' => {'author' => 'AMOSS','description' => 'SGI-specific system calls','files' => ['Makefile.PL'],'lines' => {'nonpod' => 40,'pod' => 0,'pod_errors' => 0,'total' => 40,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2538,'unpacked' => 9227},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['AutoLoader','DynaLoader','Exporter']},'SGI-Syssgi-1.005.tar.gz' => {'author' => 'DEGE','description' => 'Perl interface to the IRIX syssgi system call','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 58,'pod' => 113,'pod_errors' => 1,'total' => 171,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 5453,'unpacked' => 17797},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'SGI-syssgi-1.002.tar.gz' => {'author' => 'DEGE','description' => 'Perl inteface to the IRIX syssgi system call','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 28,'pod' => 113,'pod_errors' => 1,'total' => 141,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 9345,'unpacked' => 35187},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'SGML-Grove-2.03.tar.gz' => {'author' => 'KMACLEOD','description' => 'An entity defined in an SGML or XML document','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1275,'pod' => 603,'pod_errors' => 0,'total' => 1878,'with_comments' => 128},'releases' => 1,'size' => {'packed' => 20474,'unpacked' => 74626},'testers' => {'fail' => 6},'uses' => ['Carp','Class::Visitor','FileHandle','SGML::ExtEntity','SGML::Simple::Spec','SGML::SubDocEntity','strict','vars']},'SGML-Parser-OpenSP-0.01.tar.gz' => {'author' => 'LINK','description' => 'XS Interface to the OpenSP (X|SG)ML Parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 22,'pod' => 70,'pod_errors' => 0,'total' => 92,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 14526,'unpacked' => 39218},'testers' => {},'uses' => ['5.008','Exporter','XSLoader','strict','warnings']},'SGML-SPGroveBuilder-2.01.tar.gz' => {'author' => 'KMACLEOD','description' => 'load an SGML, XML, or HTML document','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 49,'pod_errors' => 0,'total' => 88,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 9017,'unpacked' => 27475},'testers' => {},'uses' => ['DynaLoader','Exporter']},'SGMLSpm-1.03ii.tar.gz' => {'author' => 'DMEGG','description' => 'class for postprocessing the output from the B<sgmls> and B<nsgmls> parsers.','files' => ['README'],'lines' => {'nonpod' => 947,'pod' => 387,'pod_errors' => 1,'total' => 1334,'with_comments' => 178},'releases' => 1,'size' => {'packed' => 93250,'unpacked' => 395545},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','Exporter']},'SHA-2.01.tar.gz' => {'author' => 'GAAS','description' => 'Perl interface to the NIST Secure Hash Algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 37,'pod_errors' => 0,'total' => 73,'with_comments' => 1},'releases' => 4,'requires' => ['Digest-SHA1-2.04.tar.gz'],'requires_module' => {'Digest::SHA1' => 1},'requires_recursive' => ['Digest-SHA1-2.04.tar.gz'],'size' => {'packed' => 2282,'unpacked' => 3992},'testers' => {'pass' => 12},'uses' => ['Digest::SHA1','Exporter','strict','vars']},'SHA256-0.01b.tar.gz' => {'author' => 'DIDO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 76,'pod_errors' => 0,'total' => 201,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 9326,'unpacked' => 40676},'testers' => {'fail' => 4,'pass' => 5,'tests' => '7','unknown' => 3},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'SMS-Handler-0.01.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Base class for processing SMS messages in sms-agent','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2675,'pod' => 865,'pod_errors' => 1,'total' => 3540,'with_comments' => 64},'releases' => 1,'requires' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','MIME-tools-5.411a.tar.gz','Mail-Audit-2.1.tar.gz','MailTools-1.58.tar.gz','Net-SMPP-1.03.tar.gz','Params-Validate-0.64.tar.gz','Storable-2.07.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','Unicode-Map8-0.12.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Date::Parse' => 0,'Digest::MD5' => 0,'HTML::Parser' => 0,'MIME::Parser' => 0,'MIME::WordDecoder' => 0,'Mail::Address' => 0,'Mail::Audit' => 0,'Net::POP3' => 0,'Net::SMPP' => '1.04','Net::SMTP' => 0,'Params::Validate' => 0,'Storable' => 0,'Test::More' => 0,'Text::Abbrev' => 0,'Unicode::Map8' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','Mail-Audit-2.1.tar.gz','MailTools-1.58.tar.gz','Net-SMPP-1.03.tar.gz','Params-Validate-0.64.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','TimeDate-1.16.tar.gz','Unicode-Map8-0.12.tar.gz','Unicode-String-2.07.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 34883,'unpacked' => 122196},'testers' => {},'uses' => ['5.005_62','Carp','Date::Parse','Digest::MD5','Exporter','Fcntl','HTML::Parser','IO::File','MIME::Parser','MIME::WordDecoder','Mail::Address','Mail::Audit','Net::POP3','Net::SMPP','Net::SMPP::XML','Net::SMTP','POSIX','Params::Validate','Text::Abbrev','Unicode::Map8','constant','strict','vars','warnings']},'SMS-Ringtone-RTTTL-MIDI-0.04.tar.gz' => {'author' => 'CMANLEY','description' => 'convert RTTTL strings to MIDI format.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 73,'pod' => 162,'pod_errors' => 0,'total' => 235,'with_comments' => 14},'releases' => 2,'requires' => ['IO-String-1.02.tar.gz','MIDI-Perl-0.8.tar.gz','SMS-Ringtone-RTTTL-Parser-0.07.tar.gz'],'requires_module' => {'IO::String' => '1.01','MIDI::Simple' => '0.77','SMS::Ringtone::RTTTL::Parser' => '0.02'},'requires_recursive' => ['IO-String-1.02.tar.gz','MIDI-Perl-0.8.tar.gz','SMS-Ringtone-RTTTL-Parser-0.07.tar.gz'],'size' => {'packed' => 6832,'unpacked' => 24250},'testers' => {'fail' => 2},'uses' => ['Exporter','IO::String','MIDI::Simple','strict']},'SMS-Ringtone-RTTTL-Parser-0.07.tar.gz' => {'author' => 'CMANLEY','description' => 'parse and validate RTTTL strings.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 790,'pod' => 207,'pod_errors' => 0,'total' => 997,'with_comments' => 208},'releases' => 5,'size' => {'packed' => 10895,'unpacked' => 42639},'testers' => {'pass' => 2},'uses' => ['Carp','strict']},'SMTP-Server-1.0.tar.gz' => {'author' => 'MACGYVER','description' => 'A native Perl SMTP Server implementation for Perl.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 397,'pod' => 203,'pod_errors' => 0,'total' => 600,'with_comments' => 10},'releases' => 2,'size' => {'packed' => 12840,'unpacked' => 40386},'testers' => {'pass' => 4},'uses' => ['5.001','AutoLoader','Carp','Exporter','IO::Socket','Net::DNS','Net::Domain','Net::SMTP','Sys::Hostname','strict','vars']},'SMTP-Server-1.1.tar.gz' => {'author' => 'MACGYVER','description' => 'A native Perl SMTP Server implementation for Perl.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 397,'pod' => 203,'pod_errors' => 0,'total' => 600,'with_comments' => 10},'releases' => 2,'size' => {'packed' => 13166,'unpacked' => 41675},'testers' => {'pass' => 10},'uses' => ['5.001','AutoLoader','Carp','Exporter','IO::Socket','Net::DNS','Net::Domain','Net::SMTP','Sys::Hostname','strict','vars']},'SNMP-4.2.0.tar.gz' => {'author' => 'GSM','description' => 'Interface to the UCD SNMP toolkit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1325,'pod' => 629,'pod_errors' => 0,'total' => 1954,'with_comments' => 227},'releases' => 8,'size' => {'packed' => 99552,'unpacked' => 457239},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter']},'SNMP-BridgeQuery-0.56.tar.gz' => {'author' => 'JSHEARER','description' => 'Query bridge/switch for forwarding database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 117,'pod' => 43,'pod_errors' => 0,'total' => 160,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3020,'unpacked' => 6826},'testers' => {'fail' => 3,'pass' => 1},'uses' => ['Exporter','Net::SNMP','strict','vars']},'SNMP-Info-0.6.tar.gz' => {'author' => 'MAXB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4602,'pod' => 4393,'pod_errors' => 0,'total' => 8995,'with_comments' => 802},'releases' => 6,'requires' => ['Math-BigInt-1.64.tar.gz'],'requires_module' => {'Math::BigInt' => 0},'requires_recursive' => ['Math-BigInt-1.64.tar.gz'],'size' => {'packed' => 61683,'unpacked' => 276917},'testers' => {'fail' => 1,'pass' => 1,'tests' => '3'},'uses' => ['Carp','Exporter','Math::BigInt','SNMP','strict','vars']},'SNMP-MIB-Compiler-0.06.tar.gz' => {'author' => 'FTASSIN','description' => 'a MIB Compiler supporting SMIv1 and SMIv2','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2508,'pod' => 245,'pod_errors' => 0,'total' => 2753,'with_comments' => 234},'releases' => 6,'requires' => ['Data-Compare-0.02.tar.gz','Data-Dumper-2.101.tar.gz'],'requires_module' => {'Data::Compare' => 0,'Data::Dumper' => 0},'requires_recursive' => ['Data-Compare-0.02.tar.gz','Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 236438,'unpacked' => 893497},'testers' => {'pass' => 4},'uses' => ['Carp','Data::Dumper','Exporter','FileHandle','strict','vars']},'SNMP-Monitor-0.1012.tar.gz' => {'author' => 'JWIED','description' => 'a Perl package for monitoring remote hosts via SNMP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1861,'pod' => 373,'pod_errors' => 0,'total' => 2234,'with_comments' => 130},'releases' => 9,'size' => {'packed' => 30983,'unpacked' => 115316},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.004','DBI','Data::Dumper','ExtUtils::MakeMaker','File::Basename','IO::AtomicFile','Mail::Internet','SNMP','Socket','Sys::Hostname','Sys::Syslog','Time::Local','strict','vars']},'SNMP-Multi-2.0.tar.gz' => {'author' => 'JOSHUA','description' => 'Perform SNMP operations on multiple hosts simultaneously','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1759,'pod' => 416,'pod_errors' => 2,'total' => 2175,'with_comments' => 610},'releases' => 1,'requires' => ['Memoize-1.01.tar.gz','SNMP-4.2.0.tar.gz'],'requires_module' => {'Memoize' => '0.62','SNMP' => '4.2'},'requires_recursive' => ['Memoize-1.01.tar.gz','SNMP-4.2.0.tar.gz'],'size' => {'packed' => 24448,'unpacked' => 77328},'testers' => {},'uses' => ['5.005_62','Carp','Exporter','POSIX','SNMP','strict','vars','warnings']},'SNMP-NPAdmin-1.0.tar.gz' => {'author' => 'BOZZIO','description' => 'Perl API to query printers via SNMP.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1257,'pod' => 342,'pod_errors' => 3,'total' => 1599,'with_comments' => 174},'releases' => 1,'size' => {'packed' => 63375,'unpacked' => 307028},'testers' => {'fail' => 4},'uses' => ['5.005_03','SNMP','constant','strict','vars']},'SNMP-Util-1.8.tar.gz' => {'author' => 'WMARQ','description' => 'Perform SNMP set,get,walk,next,walk_hash,...','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2291,'pod' => 480,'pod_errors' => 0,'total' => 2771,'with_comments' => 192},'releases' => 9,'size' => {'packed' => 23794,'unpacked' => 151554},'testers' => {'fail' => 3},'uses' => ['FileHandle','SNMP','strict','vars']},'SOAP-0.28.tar.gz' => {'author' => 'KBROWN','description' => 'Library for SOAP clients and servers in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3234,'pod' => 1046,'pod_errors' => 1,'total' => 4280,'with_comments' => 317},'releases' => 5,'requires' => ['XML-Parser-2.31.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'Apache' => '1.26','HTTP::Request' => '1.26','LWP' => '5.47','XML::Parser::Expat' => '2.27'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 33553,'unpacked' => 132811},'testers' => {'fail' => 4,'pass' => 4},'uses' => ['5.004','Apache','Apache::Constants','Carp','Cwd','Exporter','LWP::UserAgent','SOAP::Transport','XML::Parser::Expat','strict','vars']},'SOAP-ActiveWorks-0.12.tar.gz' => {'author' => 'DYACOB','description' => 'Spec-defined constants','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 222,'pod_errors' => 0,'total' => 659,'with_comments' => 34},'releases' => 3,'requires' => ['Aw-0.16.7.tar.gz','SOAP-0.28.tar.gz'],'requires_module' => {'Aw' => 1,'SOAP' => 1},'requires_recursive' => ['Aw-0.16.7.tar.gz','CORBA-ORBit-0.4.3.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','SOAP-0.28.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7790,'unpacked' => 26846},'testers' => {},'uses' => ['','Apache','Apache::Constants','Aw::Client','Aw::Event','Carp','Cwd','Exporter','SOAP::Defs','SOAP::EnvelopeMaker','SOAP::Parser','SOAP::Transport::HTTP::Server','strict','vars']},'SOAP-AutoInvoke-0.25.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 857,'pod' => 460,'pod_errors' => 2,'total' => 1317,'with_comments' => 57},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz','SOAP-0.28.tar.gz'],'requires_module' => {'Data::Dumper' => 1,'SOAP' => 1},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','SOAP-0.28.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8325,'unpacked' => 34141},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['','5.000','Apache','Apache::Constants','Data::Dumper','Exporter','SOAP::EnvelopeMaker','SOAP::Parser','SOAP::Struct','SOAP::Transport::ActiveWorks::Client','SOAP::Transport::ActiveWorks::Defs','SOAP::Transport::HTTP::Client','SOAP::Transport::HTTP::Server','strict','vars']},'SOAP-Clean-0.02.tar.gz' => {'author' => 'STODGHIL','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4355,'pod' => 28,'pod_errors' => 0,'total' => 4383,'with_comments' => 468},'releases' => 2,'requires' => ['XML-LibXML-1.54.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.65','XML::LibXML' => '1.53'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 51570,'unpacked' => 211705},'testers' => {'fail' => 1},'uses' => ['5.006','CGI','Data::Dumper','DynaLoader','Exporter','File::Basename','File::Temp','Getopt::Long','LWP::Protocol::file','LWP::UserAgent','MIME::Base64','POSIX','SOAP::Clean::Processes','XML::LibXML','XML::Twig','strict','vars','warnings']},'SOAP-Lite-0.55.tar.gz' => {'author' => 'KULCHENKO','description' => 'Client and server side SOAP implementation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7408,'pod' => 2950,'pod_errors' => 0,'total' => 10358,'with_comments' => 781},'releases' => 30,'size' => {'packed' => 167076,'unpacked' => 625670},'testers' => {'fail' => 2,'pass' => 33,'tests' => '413'},'uses' => ['5.004','Apache','Apache::Constants','Carp','Exporter','FCGI','HTTP::Daemon','IO::File','IO::Handle','IO::Select','IO::Socket','LWP::UserAgent','MIME::Base64','MIME::Lite','MIME::Parser','MQClient::MQSeries','MQSeries','MQSeries::Message','MQSeries::Queue','MQSeries::QueueManager','Net::FTP','Net::Jabber','Net::POP3','Test','URI','URI::Escape','URI::_server','URI::_userpass','XML::Parser','bytes','constant','overload','re','strict','vars']},'SOAP-Lite-ActiveWorks-0.10.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 660,'pod' => 160,'pod_errors' => 0,'total' => 820,'with_comments' => 28},'releases' => 1,'requires' => ['Aw-0.16.7.tar.gz','SOAP-Lite-0.55.tar.gz'],'requires_module' => {'Aw' => '0.13','SOAP::Lite' => '0.44'},'requires_recursive' => ['Aw-0.16.7.tar.gz','CORBA-ORBit-0.4.3.tar.gz','SOAP-Lite-0.55.tar.gz'],'size' => {'packed' => 13536,'unpacked' => 51689},'testers' => {},'uses' => ['','Apache','Aw::Client','Aw::Event','Carp','Exporter','LWP::UserAgent','SOAP::Lite','SafePaths','strict','vars']},'SOAP-Lite-SmartProxy-0.11.tar.gz' => {'author' => 'DYACOB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 350,'pod' => 78,'pod_errors' => 0,'total' => 428,'with_comments' => 24},'releases' => 2,'requires' => ['SOAP-Lite-0.55.tar.gz'],'requires_module' => {'SOAP::Lite' => '0.46'},'requires_recursive' => ['SOAP-Lite-0.55.tar.gz'],'size' => {'packed' => 5929,'unpacked' => 20549},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Exporter','SOAP::Lite','SOAP::Transport::HTTP','strict','vars']},'SOAP-MIME-0.55-7.tar.gz' => {'author' => 'BYRNE','description' => 'Patch to SOAP::Lite to add attachment support. This module allows Perl clients to both compose messages with attachments, and to parse messages with attachments.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 618,'pod' => 82,'pod_errors' => 0,'total' => 700,'with_comments' => 119},'releases' => 1,'requires' => ['SOAP-Lite-0.55.tar.gz'],'requires_module' => {'SOAP::Lite' => '0.55'},'requires_recursive' => ['SOAP-Lite-0.55.tar.gz'],'size' => {'packed' => 11694,'unpacked' => 33470},'testers' => {'pass' => 2,'tests' => '0','unknown' => 9},'uses' => ['Compress::Zlib','SOAP::Transport::HTTP']},'SOAP-payload-1.02.tar.gz' => {'author' => 'UNIXTOWN','description' => 'Perl module to send various forms of information as SOAP envelopes.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 224,'pod' => 132,'pod_errors' => 0,'total' => 356,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2976,'unpacked' => 8912},'testers' => {'pass' => 4},'uses' => ['Exporter','strict']},'SOCKS-0.03.tar.gz' => {'author' => 'CLINTDW','description' => 'TCP/IP access through firewalls using SOCKS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 497,'pod' => 93,'pod_errors' => 0,'total' => 590,'with_comments' => 73},'releases' => 2,'size' => {'packed' => 6601,'unpacked' => 21443},'testers' => {'pass' => 10},'uses' => ['AutoLoader','Carp','Exporter','IO::Socket','strict','vars']},'SOM-0.06.zip' => {'author' => 'ILYAZ','description' => 'Perl extension for access to SOM and DSOM objects.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 295,'pod' => 396,'pod_errors' => 0,'total' => 691,'with_comments' => 32},'releases' => 3,'size' => {'packed' => 61127,'unpacked' => 190827},'testers' => {},'uses' => ['DynaLoader','Exporter','strict','vars']},'SPOPS-0.78.tar.gz' => {'author' => 'CWINTERS','description' => '- Simple Perl Object Persistence with Security','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13728,'pod' => 11513,'pod_errors' => 0,'total' => 25241,'with_comments' => 1404},'releases' => 36,'requires' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Date-1.1.6.tar.gz','Class-Factory-1.00.tar.gz','Class-Fields-0.16.tar.gz','Class-ISA-0.32.tar.gz','Data-Dumper-2.101.tar.gz','Devel-StackTrace-1.03.tar.gz','Storable-2.07.tar.gz','Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz'],'requires_module' => {'Carp::Assert' => '0.17','Class::Accessor' => '0.17','Class::Date' => 1,'Class::Factory' => 1,'Class::Fields' => '0.14','Class::ISA' => '0.32','Data::Dumper' => 2,'Devel::StackTrace' => '0.9','Storable' => 1,'Test::More' => '0.41','Time::Piece' => '1.07'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Date-1.1.6.tar.gz','Class-Factory-1.00.tar.gz','Class-Fields-0.16.tar.gz','Class-ISA-0.32.tar.gz','Data-Dumper-2.101.tar.gz','Devel-StackTrace-1.03.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 280820,'unpacked' => 1049236},'testers' => {'pass' => 3},'uses' => ['','Carp','Class::Accessor','Class::Date','Class::Factory','Class::ISA','DBI','Data::Dumper','DateTime::Format::Strptime','Devel::StackTrace','Exporter','File::Copy','GDBM_File','Net::LDAP','Net::LDAP::Entry','Net::LDAP::Util','Storable','constant','strict','utf','vars']},'SQL-Abstract-1.13.tar.gz' => {'author' => 'NWIGER','description' => 'Generate SQL from Perl data structures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 426,'pod' => 357,'pod_errors' => 0,'total' => 783,'with_comments' => 39},'releases' => 3,'size' => {'packed' => 13488,'unpacked' => 55742},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars']},'SQL-AnchoredWildcards-1.0.tar.gz' => {'author' => 'MLFISHER','description' => 'add anchors (\'^\', \'$\') to SQL wildcards','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 112,'pod' => 106,'pod_errors' => 0,'total' => 218,'with_comments' => 31},'releases' => 1,'size' => {'packed' => 4709,'unpacked' => 13714},'testers' => {'pass' => 5},'uses' => ['Exporter','vars']},'SQL-Catalog-2.3.tar.gz' => {'author' => 'TBONE','description' => 'query queries, label queries, db independant SQL, separate Perl and SQL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 489,'pod' => 252,'pod_errors' => 0,'total' => 741,'with_comments' => 25},'releases' => 11,'requires' => ['Cache-Cache-1.02.tar.gz','DBI-1.37.tar.gz','DBIx-AnyDBD-2.01.tar.gz','PApp-SQL-0.142.tar.gz','SQL-Statement-1.005.tar.gz'],'requires_module' => {'Cache::Cache' => '0.99','DBI' => '1.19','DBIx::AnyDBD' => '1.94','PApp::SQL' => '0.124','SQL::Statement' => '0.1'},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','DBI-1.37.tar.gz','DBIx-AnyDBD-2.01.tar.gz','PApp-SQL-0.142.tar.gz','SQL-Statement-1.005.tar.gz'],'size' => {'packed' => 11547,'unpacked' => 30120},'testers' => {'fail' => 2,'tests' => '2'},'uses' => ['5.005_62','Cache::Cache','Carp','DBI','DBIx::AnyDBD','Data::Dumper','Exporter','PApp::SQL','SQL::Statement','strict','warnings']},'SQL-Generator-0.02.tar.gz' => {'author' => 'MUENALAN','description' => 'Generate SQL-queries via OO perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1016,'pod' => 517,'pod_errors' => 0,'total' => 1533,'with_comments' => 64},'releases' => 2,'requires' => ['Class-Maker-0.5.14.tar.gz'],'requires_module' => {'Class::Maker' => 0},'requires_recursive' => ['Class-Maker-0.5.14.tar.gz','Data-Dumper-2.101.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz'],'size' => {'packed' => 13522,'unpacked' => 50748},'testers' => {'fail' => 1,'pass' => 6,'tests' => '10'},'uses' => ['5.005_62','Carp','Class::Maker','Class::Maker::Examples::Array','Exporter','IO::File','Types::Array','strict','vars','warnings']},'SQL-OrderBy-0.08.7.tar.gz' => {'author' => 'GENE','description' => 'Transform an SQL "order by" clause.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 197,'pod' => 186,'pod_errors' => 0,'total' => 383,'with_comments' => 42},'releases' => 18,'size' => {'packed' => 5608,'unpacked' => 19228},'testers' => {'pass' => 6},'uses' => ['Exporter','strict','vars']},'SQL-QueryBuilder-Simple-0.04.tar.gz' => {'author' => 'RRWO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 510,'pod' => 289,'pod_errors' => 0,'total' => 799,'with_comments' => 17},'releases' => 2,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'warnings::register' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 7313,'unpacked' => 23941},'testers' => {'pass' => 4},'uses' => ['5.006','Carp','Exporter','strict','warnings','warnings::register']},'SQL-Schema-0.31.tar.gz' => {'author' => 'TODD','description' => 'Convert a data dictionary into SQL statements','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2519,'pod' => 1192,'pod_errors' => 0,'total' => 3711,'with_comments' => 527},'releases' => 1,'requires' => ['DBI-1.37.tar.gz'],'requires_module' => {'DBI' => '1.13'},'requires_recursive' => ['DBI-1.37.tar.gz'],'size' => {'packed' => 33645,'unpacked' => 239897},'testers' => {'fail' => 6,'tests' => '485'},'uses' => ['5.005','Carp','SQL::Schema::Index','strict','vars']},'SQL-Snippet-0.03.tar.gz' => {'author' => 'PRL','description' => 'Conatraint-based OO Interface to RDBMS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1344,'pod' => 723,'pod_errors' => 8,'total' => 2067,'with_comments' => 217},'releases' => 3,'requires' => ['Class-MethodMaker-1.10.tar.gz','DBI-1.37.tar.gz','Term-Interact-0.44.tar.gz'],'requires_module' => {'Class::MethodMaker' => 0,'DBI' => 0,'Term::Interact' => '0.43'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','DBI-1.37.tar.gz','DateManip-5.42a.tar.gz','File-Spec-0.82.tar.gz','Term-Interact-0.44.tar.gz','TermReadKey-2.21.tar.gz','Text-Autoformat-1.12.tar.gz','Text-Reform-1.11.tar.gz'],'size' => {'packed' => 20392,'unpacked' => 93608},'testers' => {'pass' => 6},'uses' => ['diagnostics','strict','vars']},'SQL-Statement-0.1021.tar.gz' => {'author' => 'JWIED','description' => 'SQL parsing and processing engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 778,'pod' => 710,'pod_errors' => 0,'total' => 1488,'with_comments' => 17},'releases' => 24,'size' => {'packed' => 87328,'unpacked' => 386608},'testers' => {'fail' => 2,'pass' => 28},'uses' => ['5.004','SQL::Statement','strict','vars']},'SQL-Statement-1.004.tar.gz' => {'author' => 'JZUCKER','description' => 'SQL parsing and processing engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4729,'pod' => 1264,'pod_errors' => 0,'total' => 5993,'with_comments' => 739},'releases' => 24,'size' => {'packed' => 52319,'unpacked' => 197818},'testers' => {'pass' => 2},'uses' => ['$mod','5.004','SQL::Eval','SQL::Parser','SQL::Statement','mylibs','strict','vars']},'SQL-Statement-1.005.tar.gz' => {'author' => 'JZUCKER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4843,'pod' => 1264,'pod_errors' => 0,'total' => 6107,'with_comments' => 762},'releases' => 24,'size' => {'packed' => 53841,'unpacked' => 208372},'testers' => {'pass' => 13},'uses' => ['$mod','5.004','SQL::UserDefs','locale','mylibs','strict','vars']},'SQL-Translator-0.01.tar.gz' => {'author' => 'KCLARK','description' => 'convert schema from one database to another','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3322,'pod' => 759,'pod_errors' => 0,'total' => 4081,'with_comments' => 731},'releases' => 2,'requires' => ['Class-Base-0.03.tar.gz','File-Spec-0.82.tar.gz','GD-2.07.tar.gz','IO-1.20.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','XML-Dumper-0.4.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Class::Base' => 0,'File::Basename' => 0,'File::Spec' => 0,'GD' => 0,'IO::Dir' => 0,'Parse::RecDescent' => 0,'Pod::Usage' => 0,'Text::ParseWords' => 0,'XML::Dumper' => 0},'requires_recursive' => ['Class-Base-0.03.tar.gz','File-Spec-0.82.tar.gz','GD-2.07.tar.gz','IO-1.20.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Text-Balanced-1.95.tar.gz','XML-Dumper-0.4.tar.gz','XML-Parser-2.31.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 40812,'unpacked' => 183447},'testers' => {'pass' => 7},'uses' => ['Carp','Class::Base','Data::Dumper','Exporter','File::Basename','File::Spec::Functions','IO::Dir','Parse::RecDescent','Text::ParseWords','strict','vars']},'SQL-Translator-0.02.tar.gz' => {'author' => 'KCLARK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7945,'pod' => 1771,'pod_errors' => 2,'total' => 9716,'with_comments' => 1352},'releases' => 2,'requires' => ['Class-Base-0.03.tar.gz','File-Spec-0.82.tar.gz','GD-2.07.tar.gz','GraphViz-1.8.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Spreadsheet-ParseExcel-0.2602.tar.gz','Test-Simple-0.47.tar.gz','Text-RecordParser-0.03.tar.gz','XML-Writer-0.4.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Class::Base' => 0,'File::Basename' => 0,'File::Spec' => 0,'GD' => 0,'GraphViz' => 0,'IO::Dir' => 0,'IO::File' => 0,'IO::Scalar' => 0,'Parse::RecDescent' => '1.94','Pod::Usage' => 0,'Spreadsheet::ParseExcel' => 0,'Test::More' => 0,'Text::ParseWords' => 0,'Text::RecordParser' => '0.02','XML::Writer' => 0},'requires_recursive' => ['Class-Base-0.03.tar.gz','File-Spec-0.82.tar.gz','GD-2.07.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','Heap-0.50.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','IPC-Run-0.75.tar.gz','Math-Bezier-0.01.tar.gz','OLE-Storage_Lite-0.11.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Spreadsheet-ParseExcel-0.2602.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-RecordParser-0.03.tar.gz','XML-Writer-0.4.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 85186,'unpacked' => 414989},'testers' => {'pass' => 2},'uses' => ['','.$translator->format_package_name(\'DBI\').','CGI','Carp','Class::Base','Class::DBI::$from','Class::DBI::Pager','Data::Dumper','Exporter','File::Basename','File::Spec::Functions','GD','GraphViz','IO::Dir','IO::Scalar','Parse::RecDescent','Spreadsheet::ParseExcel','Text::ParseWords','Text::RecordParser','XML::Writer','constant','mixin','strict','vars']},'SQL-YASP-0.11.tar.gz' => {'author' => 'MIKO','description' => 'SQL parser and evaluater','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2475,'pod' => 1076,'pod_errors' => 6,'total' => 3551,'with_comments' => 556},'releases' => 2,'size' => {'packed' => 36577,'unpacked' => 126896},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Debug::ShowStuff','Exporter','FileHandle','Text::Soundex','Tie::IxHash','constant','strict','vars']},'SVG-1.13.tar.gz' => {'author' => 'RONAN','description' => 'Perl extension for generating Scalable Vector Graphics (SVG) documents =head2 VERSION Version 1.13, 28 October 2001','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 981,'pod' => 965,'pod_errors' => 0,'total' => 1946,'with_comments' => 49},'releases' => 21,'size' => {'packed' => 28311,'unpacked' => 105813},'testers' => {'pass' => 1},'uses' => ['Exporter','strict','vars']},'SVG-2.27.tar.gz' => {'author' => 'RONAN','description' => 'Generate xml text strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1588,'pod' => 2078,'pod_errors' => 1,'total' => 3666,'with_comments' => 159},'releases' => 21,'size' => {'packed' => 37678,'unpacked' => 158930},'testers' => {'pass' => 9},'uses' => ['Exporter','strict','vars']},'SVG-Parser-0.97.tar.gz' => {'author' => 'PETERW','description' => 'XML Parser for SVG documents','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 686,'pod' => 312,'pod_errors' => 0,'total' => 998,'with_comments' => 90},'releases' => 2,'requires' => ['SVG-2.27.tar.gz'],'requires_module' => {'SVG' => 2},'requires_recursive' => ['SVG-2.27.tar.gz'],'size' => {'packed' => 13015,'unpacked' => 46040},'testers' => {'pass' => 2},'uses' => ['5.004','Carp','SVG','XML::Parser','XML::SAX','XML::SAX::Base','constant','strict','vars']},'SVG-Plot-0.05.tar.gz' => {'author' => 'ZOOLEIKA','description' => 'a simple module to take one or more sets of x,y points and plot them on a plane','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 242,'pod' => 139,'pod_errors' => 0,'total' => 381,'with_comments' => 15},'releases' => 4,'requires' => ['Algorithm-Points-MinimumDistance-0.01.tar.gz','Class-MethodMaker-1.10.tar.gz','SVG-2.27.tar.gz','Test-XML-0.06.tar.gz','XML-XPath-1.13.tar.gz'],'requires_module' => {'Algorithm::Points::MinimumDistance' => 0,'Class::MethodMaker' => '0.1','SVG' => '0.1','Test::XML' => '0.04','XML::XPath' => 0},'requires_recursive' => ['Algorithm-Points-MinimumDistance-0.01.tar.gz','Class-MethodMaker-1.10.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','SVG-2.27.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-XML-0.06.tar.gz','XML-Parser-2.31.tar.gz','XML-SemanticDiff-0.95.tar.gz','XML-XPath-1.13.tar.gz'],'size' => {'packed' => 7799,'unpacked' => 28017},'testers' => {'fail' => 1,'pass' => 1,'tests' => '33'},'uses' => ['Algorithm::Points::MinimumDistance','Carp','SVG','strict']},'SVGGraph-0.07.tar.gz' => {'author' => 'TEUN','description' => 'Perl extension for creating SVG Graphs / Diagrams / Charts / Plots.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 427,'pod' => 81,'pod_errors' => 0,'total' => 508,'with_comments' => 67},'releases' => 7,'size' => {'packed' => 6789,'unpacked' => 19684},'testers' => {'pass' => 3},'uses' => ['strict','utf','warnings']},'SVGGraph-Pie-0.04.tar.gz' => {'author' => 'MILANO','description' => 'Perl extension for Pie as SVG','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 172,'pod' => 82,'pod_errors' => 0,'total' => 254,'with_comments' => 10},'releases' => 4,'requires' => ['SVG-2.27.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'SVG' => 0,'Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','SVG-2.27.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2965,'unpacked' => 9179},'testers' => {'pass' => 2},'uses' => ['Carp','SVG','constant','strict','vars']},'SWF-File-0.24.tar.gz' => {'author' => 'YSAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5176,'pod' => 1733,'pod_errors' => 0,'total' => 6909,'with_comments' => 227},'releases' => 13,'requires' => ['Data-TemporaryBag-0.06.tar.gz'],'requires_module' => {'Data::TemporaryBag' => '0.02'},'requires_recursive' => ['Data-TemporaryBag-0.06.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 43413,'unpacked' => 191744},'testers' => {'pass' => 3},'uses' => ['Carp','Compress::Zlib','Data::TemporaryBag','strict','v5.6.0','vars']},'SWF-Search-0.01.tar.gz' => {'author' => 'MAJCHER','description' => 'Extract strings and information from Macromedia SWF files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 407,'pod' => 72,'pod_errors' => 0,'total' => 479,'with_comments' => 43},'releases' => 1,'size' => {'packed' => 5686,'unpacked' => 15130},'testers' => {'pass' => 8},'uses' => ['5.006','Carp','IO::File','strict','warnings']},'SWIFT-Factory-ApplicationHeader-0.02.tar.gz' => {'author' => 'BIKER','description' => 'Provides the Appl. Header Block 2 for SWIFT','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 191,'pod_errors' => 1,'total' => 328,'with_comments' => 32},'releases' => 2,'size' => {'packed' => 4361,'unpacked' => 12965},'testers' => {'pass' => 7},'uses' => ['constant','strict','vars','warnings']},'SWIFT-Factory-BasicHeader-0.03.tar.gz' => {'author' => 'BIKER','description' => 'Provides the Basic Header Block 1 for SWIFT','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 121,'pod' => 180,'pod_errors' => 1,'total' => 301,'with_comments' => 23},'releases' => 3,'size' => {'packed' => 4218,'unpacked' => 11094},'testers' => {'pass' => 7},'uses' => ['constant','strict','vars','warnings']},'SWIFT-Factory-Tag-Tag15-0.02.tar.gz' => {'author' => 'BIKER','description' => 'Provides a generic TAG15 for SWIFT','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 161,'pod_errors' => 1,'total' => 286,'with_comments' => 31},'releases' => 2,'size' => {'packed' => 3847,'unpacked' => 10243},'testers' => {'pass' => 2},'uses' => ['strict','vars','warnings']},'SWIFT-Factory-Tag-Tag17-0.01.tar.gz' => {'author' => 'BIKER','description' => 'Provide a base class for the Tag17x classes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 111,'pod_errors' => 1,'total' => 184,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 2660,'unpacked' => 6515},'testers' => {'pass' => 3},'uses' => ['constant','strict','vars','warnings']},'SWIFT-Factory-Tag-Tag17A-0.01.tar.gz' => {'author' => 'BIKER','description' => 'Provide a TAG17A for a SWIFT message','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 26,'pod' => 105,'pod_errors' => 1,'total' => 131,'with_comments' => 2},'releases' => 1,'requires' => ['SWIFT-Factory-Tag-Tag17-0.01.tar.gz'],'requires_module' => {'SWIFT::Factory::Tag::Tag17' => 0},'requires_recursive' => ['SWIFT-Factory-Tag-Tag17-0.01.tar.gz'],'size' => {'packed' => 2238,'unpacked' => 4719},'testers' => {'pass' => 1},'uses' => ['SWIFT::Factory::Tag::Tag17','constant','strict','vars','warnings']},'SWIFT-Factory-Tag-Tag17T-0.01.tar.gz' => {'author' => 'BIKER','description' => 'Provide a TAG17T for a SWIFT message','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 26,'pod' => 105,'pod_errors' => 1,'total' => 131,'with_comments' => 2},'releases' => 1,'requires' => ['SWIFT-Factory-Tag-Tag17-0.01.tar.gz'],'requires_module' => {'SWIFT::Factory::Tag::Tag17' => 0},'requires_recursive' => ['SWIFT-Factory-Tag-Tag17-0.01.tar.gz'],'size' => {'packed' => 2280,'unpacked' => 4808},'testers' => {'pass' => 1},'uses' => ['SWIFT::Factory::Tag::Tag17','constant','strict','vars','warnings']},'SWIFT-Factory-Tag-Tag17U-0.01.tar.gz' => {'author' => 'BIKER','description' => 'Provide a TAG17U for a SWIFT message','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 26,'pod' => 105,'pod_errors' => 1,'total' => 131,'with_comments' => 2},'releases' => 1,'requires' => ['SWIFT-Factory-Tag-Tag17-0.01.tar.gz'],'requires_module' => {'SWIFT::Factory::Tag::Tag17' => 0},'requires_recursive' => ['SWIFT-Factory-Tag-Tag17-0.01.tar.gz'],'size' => {'packed' => 2246,'unpacked' => 4782},'testers' => {'pass' => 1},'uses' => ['SWIFT::Factory::Tag::Tag17','constant','strict','vars','warnings']},'SWIFT-Factory-Tag-Tag20-0.01.tar.gz' => {'author' => 'SCHAFFTER','description' => 'Provides TAG20 for a SWIFT message','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 141,'pod_errors' => 1,'total' => 266,'with_comments' => 31},'releases' => 1,'size' => {'packed' => 3510,'unpacked' => 9170},'testers' => {'pass' => 8},'uses' => ['constant','strict','vars','warnings']},'SWIFT-Factory-Tag-Tag21-0.01.tar.gz' => {'author' => 'SCHAFFTER','description' => 'Provide a TAG21 for a SWIFT message','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 141,'pod_errors' => 1,'total' => 266,'with_comments' => 31},'releases' => 1,'size' => {'packed' => 3482,'unpacked' => 9152},'testers' => {'pass' => 8},'uses' => ['constant','strict','vars','warnings']},'SWIFT-Factory-Tag-Tag30-0.01.tar.gz' => {'author' => 'SCHAFFTER','description' => 'Provide a TAG30 for a SWIFT message','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 121,'pod' => 147,'pod_errors' => 1,'total' => 268,'with_comments' => 23},'releases' => 1,'size' => {'packed' => 3675,'unpacked' => 9559},'testers' => {'pass' => 9},'uses' => ['constant','strict','vars','warnings']},'SWIFT-Factory-Tag-Tag30T-0.02.tar.gz' => {'author' => 'SCHAFFTER','description' => 'Provides a TAG30T for a SWIFT message','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 121,'pod_errors' => 1,'total' => 164,'with_comments' => 7},'releases' => 2,'requires' => ['SWIFT-Factory-Tag-Tag30-0.01.tar.gz'],'requires_module' => {'SWIFT::Factory::Tag::Tag30' => '0.01'},'requires_recursive' => ['SWIFT-Factory-Tag-Tag30-0.01.tar.gz'],'size' => {'packed' => 2837,'unpacked' => 6376},'testers' => {'pass' => 7},'uses' => ['SWIFT::Factory::Tag::Tag30','constant','strict','vars','warnings']},'SWIFT-Factory-Tag-Tag30V-0.01.tar.gz' => {'author' => 'SCHAFFTER','description' => 'Provides a TAG30V for SWIFT','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 121,'pod_errors' => 1,'total' => 164,'with_comments' => 7},'releases' => 1,'requires' => ['SWIFT-Factory-Tag-Tag30-0.01.tar.gz'],'requires_module' => {'SWIFT::Factory::Tag::Tag30' => '0.01'},'requires_recursive' => ['SWIFT-Factory-Tag-Tag30-0.01.tar.gz'],'size' => {'packed' => 2809,'unpacked' => 6288},'testers' => {'pass' => 8},'uses' => ['SWIFT::Factory::Tag::Tag30','constant','strict','vars','warnings']},'SWISH-0.07.tar.gz' => {'author' => 'HANK','description' => 'Perl interface to the SWISH-E search engine.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 234,'pod' => 518,'pod_errors' => 0,'total' => 752,'with_comments' => 4},'releases' => 3,'size' => {'packed' => 9412,'unpacked' => 25588},'testers' => {'pass' => 5},'uses' => ['SWISH::$driver','strict','vars']},'SWISH-Fork-0.12.tar.gz' => {'author' => 'HANK','description' => 'Perl extension for accessing the SWISH-E search engine via a fork/exec.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 623,'pod' => 57,'pod_errors' => 0,'total' => 680,'with_comments' => 64},'releases' => 2,'requires' => ['SWISH-0.07.tar.gz'],'requires_module' => {'SWISH' => 0},'requires_recursive' => ['SWISH-0.07.tar.gz'],'size' => {'packed' => 8182,'unpacked' => 23323},'testers' => {},'uses' => ['IO::Handle','SWISH','Symbol','strict','vars']},'SWISH-Stemmer-0.03.tar.gz' => {'author' => 'HANK','description' => 'Perl extension for stemming words using a modified version of the Stem routine from the SWISH search engine. (http://sunsite.berkeley.edu/SWISH-E/)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 30,'pod' => 44,'pod_errors' => 0,'total' => 74,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 8104,'unpacked' => 27669},'testers' => {'fail' => 1,'pass' => 3,'tests' => '0','unknown' => 6},'uses' => ['DynaLoader','Exporter','strict','vars']},'SZTime-0.14.tar.gz' => {'author' => 'SJSZ','description' => 'computes the local SZTime','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 33,'pod_errors' => 0,'total' => 78,'with_comments' => 4},'releases' => 4,'size' => {'packed' => 1406,'unpacked' => 2221},'testers' => {'pass' => 2},'uses' => ['CPAN::Shell','Time::HiRes','strict']},'Safe-2.09.tar.gz' => {'author' => 'ABERGMAN','description' => 'Restrict eval\'d code to safe subset of ops','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 364,'pod' => 196,'pod_errors' => 0,'total' => 560,'with_comments' => 32},'releases' => 3,'size' => {'packed' => 11465,'unpacked' => 29002},'testers' => {'pass' => 15},'uses' => ['5.003_11','Carp','strict']},'Safe-Hole-0.08.tar.gz' => {'author' => 'SEYN','description' => 'Exec subs in the original package from Safe','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 109,'pod' => 78,'pod_errors' => 1,'total' => 187,'with_comments' => 8},'releases' => 6,'size' => {'packed' => 8947,'unpacked' => 22235},'testers' => {'pass' => 13},'uses' => ['5.005','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Safe-Logs-1.00.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Perl extension to avoid terminal emulator vulnerabilities','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 108,'pod_errors' => 0,'total' => 257,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 4757,'unpacked' => 11443},'testers' => {'pass' => 8},'uses' => ['5.005','Exporter','strict','vars','warnings']},'Sample-1.3.tgz' => {'author' => 'ABIGAIL','description' => 'Knuth\'s sample algorithm','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 193,'pod' => 107,'pod_errors' => 0,'total' => 300,'with_comments' => 34},'releases' => 4,'size' => {'packed' => 3939,'unpacked' => 9800},'testers' => {'pass' => 8},'uses' => ['Exporter','strict','vars']},'Scalar-List-Utils-1.11.tar.gz' => {'author' => 'GBARR','description' => 'Scalar utilities (dualvar reftype etc)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 273,'pod' => 286,'pod_errors' => 0,'total' => 559,'with_comments' => 25},'releases' => 14,'size' => {'packed' => 15313,'unpacked' => 52809},'testers' => {'fail' => 2,'pass' => 24,'tests' => '171'},'uses' => ['Carp','DynaLoader','Exporter','vars']},'Scalar-Listify-0.01.tar.gz' => {'author' => 'TBONE','description' => 'produces an array from a scalar value or array ref.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 58,'pod' => 38,'pod_errors' => 0,'total' => 96,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 1962,'unpacked' => 3326},'testers' => {'pass' => 5},'uses' => ['5.005_62','Data::Dumper','Exporter','strict','warnings']},'Scalar-Properties-0.10.tar.gz' => {'author' => 'MARCEL','description' => 'run-time properties on scalar variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 357,'pod' => 219,'pod_errors' => 0,'total' => 576,'with_comments' => 36},'releases' => 1,'size' => {'packed' => 10205,'unpacked' => 32378},'testers' => {'pass' => 7},'uses' => ['strict','warnings']},'Schedule-At-1.04.tar.gz' => {'author' => 'JOSERODR','description' => 'OS independent interface to the at command','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 311,'pod' => 96,'pod_errors' => 0,'total' => 407,'with_comments' => 23},'releases' => 5,'size' => {'packed' => 5618,'unpacked' => 15283},'testers' => {'fail' => 3,'pass' => 3,'tests' => '6'},'uses' => ['5.004','Config','vars']},'Schedule-Cron-0.05.tar.gz' => {'author' => 'ROLAND','description' => 'cron-like scheduler for perl subroutines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 815,'pod' => 265,'pod_errors' => 0,'total' => 1080,'with_comments' => 67},'releases' => 3,'requires' => ['Time-modules-2003.0211.tar.gz'],'requires_module' => {'Time::ParseDate' => '99.00'},'requires_recursive' => ['Time-modules-2003.0211.tar.gz'],'size' => {'packed' => 15067,'unpacked' => 44964},'testers' => {'pass' => 9},'uses' => ['Config','Data::Dumper','POSIX','Term::ReadLine','Time::ParseDate','ioctl.ph','strict','subs','sys::ioctl.ph','vars']},'Schedule-Cron-Events-1.8.tar.gz' => {'author' => 'PKENT','description' => 'take a line from a crontab and find out when events will occur','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 394,'pod' => 141,'pod_errors' => 0,'total' => 535,'with_comments' => 46},'releases' => 3,'requires' => ['Set-Crontab-1.00.tar.gz','Time-Local-1.07.tar.gz'],'requires_module' => {'Set::Crontab' => 0,'Time::Local' => 0},'requires_recursive' => ['Set-Crontab-1.00.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 9282,'unpacked' => 33063},'testers' => {'pass' => 7},'uses' => ['Carp','Set::Crontab','Time::Local','strict','vars']},'Schedule-Cron-Nofork-0.03.tar.gz' => {'author' => 'CORION','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 23,'pod_errors' => 0,'total' => 80,'with_comments' => 2},'releases' => 3,'requires' => ['Schedule-Cron-0.05.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Schedule::Cron' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Schedule-Cron-0.05.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz'],'size' => {'packed' => 3967,'unpacked' => 9621},'testers' => {'pass' => 1},'uses' => ['Schedule::Cron','strict','vars','warnings']},'Schedule-Cronchik-0.4.tar.gz' => {'author' => 'IFROL','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 143,'pod' => 50,'pod_errors' => 0,'total' => 193,'with_comments' => 17},'releases' => 4,'size' => {'packed' => 2569,'unpacked' => 5208},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Fcntl','strict','vars']},'Schedule-Depend-0.31.tar.gz' => {'author' => 'LEMBARK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2220,'pod' => 724,'pod_errors' => 0,'total' => 2944,'with_comments' => 780},'releases' => 29,'requires' => ['Data-Dumper-2.101.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => '2.102','File::Basename' => '2.6','constant' => 0,'strict' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 37929,'unpacked' => 105941},'testers' => {'pass' => 5},'uses' => ['Carp','Data::Dumper','File::Basename','strict']},'Schedule-Load-3.001.tar.gz' => {'author' => 'WSNYDER','description' => 'Load distribution and status across multiple host machines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3403,'pod' => 775,'pod_errors' => 1,'total' => 4178,'with_comments' => 714},'releases' => 13,'requires' => ['IPC-Locker-1.420.tar.gz','Proc-ProcessTable-0.38.tar.gz','Storable-2.07.tar.gz','Time-HiRes-1.49.tar.gz','Unix-Processors-2.014.tar.gz'],'requires_module' => {'IPC::PidStat' => '1.41','Proc::ProcessTable' => 0,'Storable' => 0,'Time::HiRes' => 0,'Unix::Processors' => '1.7'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IPC-Locker-1.420.tar.gz','Proc-ProcessTable-0.38.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','Unix-Processors-2.014.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 52102,'unpacked' => 195035},'testers' => {'pass' => 2},'uses' => ['5.004','5.005','AutoLoader','Carp','Config','Data::Dumper','Exporter','IO::File','IO::Pipe','IO::Select','IO::Socket','IPC::PidStat','Net::hostent','POSIX','Proc::ProcessTable','Safe','Socket','Storable','Sys::Hostname','Tie::RefHash','Time::HiRes','Time::localtime','Unix::Processors','constant','strict','vars']},'Schedule-Match-0.07.tar.gz' => {'author' => 'TAIY','description' => 'Pattern-based crontab-like schedule','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 321,'pod' => 252,'pod_errors' => 1,'total' => 573,'with_comments' => 53},'releases' => 3,'requires' => ['Time-Local-1.07.tar.gz'],'requires_module' => {'Time::Local' => 0},'requires_recursive' => ['Time-Local-1.07.tar.gz'],'size' => {'packed' => 7240,'unpacked' => 22395},'testers' => {'pass' => 8},'uses' => ['Carp','Exporter','Time::Local','strict','vars']},'Schedule-Parallel-1.00.tar.gz' => {'author' => 'LEMBARK','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 218,'pod' => 59,'pod_errors' => 0,'total' => 277,'with_comments' => 87},'releases' => 1,'size' => {'packed' => 4892,'unpacked' => 9457},'testers' => {'pass' => 3},'uses' => ['5.005_62','Carp','strict']},'Schedule-SoftTime-0.030.tar.gz' => {'author' => 'MIKEDLR','description' => 'Scheduling functions (designed) for link checking','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 159,'pod' => 76,'pod_errors' => 0,'total' => 235,'with_comments' => 8},'releases' => 3,'size' => {'packed' => 10688,'unpacked' => 26595},'testers' => {'pass' => 4},'uses' => ['Carp','DB_File','Fcntl']},'SchemaView-Plus-0.16.tar.gz' => {'author' => 'MILSO','description' => 'Perl extension for hints databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1569,'pod' => 706,'pod_errors' => 0,'total' => 2275,'with_comments' => 41},'releases' => 7,'size' => {'packed' => 51299,'unpacked' => 201394},'testers' => {'pass' => 2},'uses' => ['DBI','Exporter','IO::File','IO::Handle','POSIX','Tk','strict','vars']},'Scrape-USPS-ZipLookup-1.1.tar.gz' => {'author' => 'GREGOR','description' => 'Standardize U.S. postal addresses.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 967,'pod' => 201,'pod_errors' => 0,'total' => 1168,'with_comments' => 259},'releases' => 1,'requires' => ['URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request' => 0,'HTTP::Request::Common' => 0,'HTTP::Response' => 0,'LWP::UserAgent' => 0,'URI' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7910,'unpacked' => 32067},'testers' => {'pass' => 7},'uses' => ['Carp','HTTP::Request','HTTP::Request::Common','HTTP::Response','LWP::UserAgent','URI','strict','vars']},'Scraper-2.27.tar.gz' => {'author' => 'GLENNWOOD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9861,'pod' => 5120,'pod_errors' => 3,'total' => 14981,'with_comments' => 1043},'releases' => 29,'requires' => ['HTML-Tree-3.17.tar.gz','Storable-2.07.tar.gz','Tie-Persistent-1.00.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','XML-XPath-1.13.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'HTML::Form' => '0.02','HTML::TreeBuilder' => 0,'HTTP::Cookies' => 0,'HTTP::Request' => 0,'HTTP::Response' => 0,'HTTP::Status' => 0,'LWP' => '5.48','LWP::RobotUA' => 0,'LWP::UserAgent' => 0,'Storable' => '0.6','Text::ParseWords' => '3.2','Tie::Persistent' => '0.901','URI' => 0,'URI::Escape' => 0,'URI::URL' => 0,'URI::http' => 0,'User' => '1.05','WWW::Search' => '2.28','XML::XPath' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Tie-Persistent-1.00.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','XML-Parser-2.31.tar.gz','XML-XPath-1.13.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 133420,'unpacked' => 530759},'testers' => {'pass' => 3},'uses' => ['','Class::Struct','Data::Dumper','Exporter','HTML::Form','HTTP::Cookies','LWP::Simple','LWP::UserAgent','SOAP::Lite','Storable','Text::ParseWords','Tie::Persistent','URI::URL','URI::http','URI::https','WWW::Search','WWW::Search::Scraper','WWW::Search::Scraper::TidyXML::_struct_','WWW::Search::Scraper::_struct_','WWW::SearchResult','XML::XPath','lib','strict','vars']},'Scraper-3.04.tar.gz' => {'author' => 'GLENNWOOD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8415,'pod' => 3510,'pod_errors' => 2,'total' => 11925,'with_comments' => 883},'releases' => 29,'requires' => ['HTML-Tree-3.17.tar.gz','Storable-2.07.tar.gz','Tie-Persistent-1.00.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','XML-XPath-1.13.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'HTML::Form' => '0.02','HTML::TreeBuilder' => 0,'HTTP::Cookies' => 0,'HTTP::Request' => 0,'HTTP::Response' => 0,'HTTP::Status' => 0,'LWP' => '5.48','LWP::RobotUA' => 0,'LWP::UserAgent' => 0,'Storable' => '0.6','Text::ParseWords' => '3.2','Tie::Persistent' => '0.901','URI' => 0,'URI::Escape' => 0,'URI::URL' => 0,'URI::http' => 0,'User' => '1.05','WWW::Search' => '2.35','XML::XPath' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','Tie-Persistent-1.00.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','XML-Parser-2.31.tar.gz','XML-XPath-1.13.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 107586,'unpacked' => 428394},'testers' => {'pass' => 2},'uses' => ['','Class::Struct','Data::Dumper','Exporter','HTML::Form','HTTP::Cookies','SOAP::Lite','Storable','Text::ParseWords','Tie::Persistent','URI::URL','URI::http','URI::https','WWW::Scraper::TidyXML::_struct_','WWW::Scraper::_struct_','WWW::Search','WWW::SearchResult','XML::XPath','lib','strict','vars']},'Script-0.53.tar.gz' => {'author' => 'MAKAROW','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1405,'pod' => 679,'pod_errors' => 2,'total' => 2084,'with_comments' => 124},'releases' => 4,'size' => {'packed' => 24122,'unpacked' => 74954},'testers' => {'pass' => 2},'uses' => ['5.000','Carp','Cwd','Exporter','File::Compare','File::Copy','Net::Domain','Net::FTP','Net::SMTP','Sys::Hostname','Win32::TieRegistry','strict','vars']},'Scripting-0.99.tar.gz' => {'author' => 'CLAESJAC','description' => 'Language independent framework for enabling application scripting.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 648,'pod' => 183,'pod_errors' => 1,'total' => 831,'with_comments' => 42},'releases' => 1,'requires' => ['Attribute-Handlers-0.78.tar.gz','DB_File-1.806.tar.gz','Digest-SHA1-2.04.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.78','Carp' => 0,'DB_File' => '1.72','Digest::SHA1' => '2.02','File::Find::Rule' => '0.1','File::Spec' => 0,'IO::Dir' => 0,'IO::File' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','DB_File-1.806.tar.gz','Digest-SHA1-2.04.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9262,'unpacked' => 27017},'testers' => {},'uses' => ['5.005_62','Attribute::Handlers','Carp','DB_File','Data::Dumper','Digest::SHA1','Exporter','File::Find::Rule','File::Spec','IO::Dir','IO::File','JavaScript','constant','strict','warnings']},'Se-PersonNr-0.01.tar.gz' => {'author' => 'EBOSRUP','description' => 'Module for validating and generating a Swedish personnummer.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 202,'pod' => 93,'pod_errors' => 0,'total' => 295,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 2523,'unpacked' => 6427},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['strict','warnings']},'Search-Binary-0.95.tar.gz' => {'author' => 'RANT','description' => 'Generic binary search','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 24,'pod_errors' => 0,'total' => 116,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 2182,'unpacked' => 4399},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['Exporter','strict']},'Search-Circa-1.11.tar.gz' => {'author' => 'ALIAN','description' => 'a Search Engine/Indexer running with Mysql','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2919,'pod' => 1111,'pod_errors' => 0,'total' => 4030,'with_comments' => 606},'releases' => 6,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'DBD::mysql' => 0,'DBI' => 0,'LWP::RobotUA' => 0,'URI::URL' => 0},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 55605,'unpacked' => 230232},'testers' => {'pass' => 3},'uses' => ['Cwd','DBI','DBI::DBD','Exporter','File::Copy','HTML::Entities','LWP::RobotUA','Search::Circa','Search::Circa::Categorie','Search::Circa::Parser','Search::Circa::Url','URI::URL','strict','vars']},'Search-Circa-1.18.tar.gz' => {'author' => 'ALIAN','description' => 'a Search Engine / Indexer running with Mysql','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2926,'pod' => 1172,'pod_errors' => 0,'total' => 4098,'with_comments' => 532},'releases' => 6,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'DBD::mysql' => 0,'DBI' => 0,'LWP::RobotUA' => 0,'Test::Simple' => 0,'URI::URL' => 0},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 64901,'unpacked' => 256524},'testers' => {'pass' => 1},'uses' => ['Carp','CircaConf','DBI','DBI::DBD','Exporter','File::Copy','HTML::Entities','LWP::RobotUA','Search::Circa','URI::URL','URI::WithBase','strict','vars']},'Search-Circa-1.9.tar.gz' => {'author' => 'ALIAN','description' => 'a Search Engine/Indexer running with Mysql','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2670,'pod' => 1028,'pod_errors' => 0,'total' => 3698,'with_comments' => 630},'releases' => 6,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'DBD::mysql' => 0,'DBI' => 0,'LWP::RobotUA' => 0,'URI::URL' => 0},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 52065,'unpacked' => 218922},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Cwd','DBI','DBI::DBD','Exporter','File::Copy','HTML::Entities','LWP::RobotUA','Search::Circa::Categorie','Search::Circa::Parser','Search::Circa::Url','URI::URL','strict','vars']},'Search-ContextGraph-0.06.tar.gz' => {'author' => 'MCEGLOWS','description' => 'A generic contextual network search engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 619,'pod' => 166,'pod_errors' => 0,'total' => 785,'with_comments' => 36},'releases' => 6,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 72302,'unpacked' => 216413},'testers' => {'pass' => 1},'uses' => ['Carp','DynaLoader','Storable','strict','warnings']},'Search-Equidistance-0.01.tar.gz' => {'author' => 'HSLEE','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 68,'pod_errors' => 0,'total' => 145,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 3142,'unpacked' => 5824},'testers' => {'pass' => 10},'uses' => ['5.008','Exporter','strict','warnings']},'Search-FreeText-0.05.tar.gz' => {'author' => 'SNKWATT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 693,'pod' => 346,'pod_errors' => 0,'total' => 1039,'with_comments' => 25},'releases' => 1,'requires' => ['DB_File-1.806.tar.gz','Lingua-Stem-0.60.tar.gz'],'requires_module' => {'DB_File' => '1.73','Lingua::Stem' => '0.5'},'requires_recursive' => ['DB_File-1.806.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Text-German-0.03.tar.gz'],'size' => {'packed' => 10717,'unpacked' => 33765},'testers' => {'pass' => 1},'uses' => ['Lingua::Stem','strict','warnings']},'Search-InvertedIndex-1.12.tar.gz' => {'author' => 'SNOWHARE','description' => 'A manager for inverted index maps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4605,'pod' => 1279,'pod_errors' => 0,'total' => 5884,'with_comments' => 454},'releases' => 8,'requires' => ['Class-NamedParms-1.04.tar.gz','Class-ParmList-1.03.tar.gz','DB_File-1.806.tar.gz','Digest-SHA1-2.04.tar.gz','Tie-DB_File-SplitHash-1.01.tar.gz','Tie-FileLRUCache-1.01.tar.gz'],'requires_module' => {'Class::NamedParms' => 0,'Class::ParmList' => 0,'DB_File' => 0,'Digest::SHA1' => 0,'Tie::DB_File::SplitHash' => 0,'Tie::FileLRUCache' => 0},'requires_recursive' => ['Class-NamedParms-1.04.tar.gz','Class-ParmList-1.03.tar.gz','DB_File-1.806.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tie-DB_File-SplitHash-1.01.tar.gz','Tie-FileLRUCache-1.01.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 42871,'unpacked' => 304134},'testers' => {'fail' => 1,'pass' => 5,'tests' => '11'},'uses' => ['Carp','Class::NamedParms','Class::ParmList','DBI','DB_File','Fcntl','Tie::DB_File::SplitHash','attrs','strict','vars']},'Search-InvertedIndex-DB-Pg-0.01.tar.gz' => {'author' => 'KAKE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 287,'pod' => 101,'pod_errors' => 0,'total' => 388,'with_comments' => 7},'releases' => 1,'requires' => ['DBD-Pg-1.22.tar.gz','DBI-1.37.tar.gz','Search-InvertedIndex-1.12.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'DBD::Pg' => 0,'DBI' => 0,'Search::InvertedIndex' => 0},'requires_recursive' => ['Class-NamedParms-1.04.tar.gz','Class-ParmList-1.03.tar.gz','DBD-Pg-1.22.tar.gz','DBI-1.37.tar.gz','DB_File-1.806.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','Search-InvertedIndex-1.12.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tie-DB_File-SplitHash-1.01.tar.gz','Tie-FileLRUCache-1.01.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8300,'unpacked' => 37851},'testers' => {},'uses' => ['Carp','DBD::Pg','DBI','strict','vars']},'Search-Xapian-0.03.tar.gz' => {'author' => 'KILINRAX','description' => 'Perl XS frontend to the Xapian C++ search library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 570,'pod' => 67,'pod_errors' => 0,'total' => 637,'with_comments' => 60},'releases' => 5,'size' => {'packed' => 10162,'unpacked' => 44400},'testers' => {},'uses' => ['5.006','Carp','DynaLoader','Exporter','Search::Xapian','Search::Xapian::Database','Search::Xapian::Document','Search::Xapian::MSetIterator','Search::Xapian::Query','Search::Xapian::WritableDatabase','strict','warnings']},'Search-Xapian-0.05.tar.gz' => {'author' => 'KILINRAX','description' => 'Perl XS frontend to the Xapian C++ search library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 775,'pod' => 60,'pod_errors' => 0,'total' => 835,'with_comments' => 75},'releases' => 5,'size' => {'packed' => 11919,'unpacked' => 53599},'testers' => {},'uses' => ['5.006','Carp','DynaLoader','Exporter','Tie::Array','strict','warnings']},'SearchSDK-0.99b.tar.gz' => {'author' => 'JTURNER','description' => 'Perl Wrapper for AltaVista SDK functionality','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 174,'pod_errors' => 0,'total' => 341,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 7755,'unpacked' => 31909},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'SecurID-ACEdb-0.90.tar.gz' => {'author' => 'DCARRIGAN','description' => 'Perl extension to use the ACE/Server Administration Toolkit API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 281,'pod' => 235,'pod_errors' => 0,'total' => 516,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 12467,'unpacked' => 49525},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Sed-1.11.tar.gz' => {'author' => 'DARREN','description' => 'A sed(1)-like stream editor','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 47,'pod' => 73,'pod_errors' => 0,'total' => 120,'with_comments' => 21},'releases' => 1,'size' => {'packed' => 2504,'unpacked' => 4936},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'SelfUnzip-0.01.zip' => {'author' => 'ILYAZ','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 38,'pod' => 24,'pod_errors' => 0,'total' => 62,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 3669,'unpacked' => 4697},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Semi-Semicolons-0.03.tar.gz' => {'author' => 'MSCHWERN','description' => 'writing perl code with the word \'Peterbilt\' as statement terminator, rather than a semicolon.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 37,'pod' => 38,'pod_errors' => 0,'total' => 75,'with_comments' => 0},'releases' => 3,'requires' => ['Filter-1.29.tar.gz'],'requires_module' => {'Filter::Util::Exec' => 0},'requires_recursive' => ['Filter-1.29.tar.gz'],'size' => {'packed' => 2903,'unpacked' => 6065},'testers' => {'pass' => 8},'uses' => ['Filter::Util::Exec','strict','vars']},'Sendmail-AccessDB-0.07.tar.gz' => {'author' => 'DREDD','description' => 'Interface to sendmail\'s access.db','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 201,'pod' => 159,'pod_errors' => 0,'total' => 360,'with_comments' => 2},'releases' => 6,'size' => {'packed' => 14768,'unpacked' => 61561},'testers' => {'fail' => 5,'pass' => 1,'tests' => '9'},'uses' => ['Carp','DB_File','strict','vars']},'Sendmail-Milter-0.18.tar.gz' => {'author' => 'CYING','description' => 'Write mail filters for sendmail in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 351,'pod' => 486,'pod_errors' => 0,'total' => 837,'with_comments' => 19},'releases' => 6,'size' => {'packed' => 20906,'unpacked' => 76986},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Seshat-1.1.tar.gz' => {'author' => 'BMAVT','description' => 'Perl Extension for writing modules "Seshat, her who writes..."','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 73,'pod_errors' => 0,'total' => 167,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 2354,'unpacked' => 4350},'testers' => {'pass' => 5},'uses' => ['AutoLoader','Data::Dumper','Exporter','POSIX','strict','vars']},'Seshat-Parallel-1.01.tar.gz' => {'author' => 'BMAVT','description' => 'Perl extension for Seshat','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 29,'pod_errors' => 0,'total' => 93,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 1740,'unpacked' => 3040},'testers' => {'fail' => 2,'pass' => 3},'uses' => ['AutoLoader','Data::Dumper','Exporter','Seshat','strict','vars']},'Session-0.01.tar.gz' => {'author' => 'RSOLIV','description' => 'Object Oriented wrapper around Apache::Session to avoid its tie mechanism','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 70,'pod' => 137,'pod_errors' => 0,'total' => 207,'with_comments' => 0},'releases' => 1,'requires' => ['Apache-Session-1.54.tar.gz'],'requires_module' => {'Apache::Session' => '1.54'},'requires_recursive' => ['Apache-Session-1.54.tar.gz'],'size' => {'packed' => 3294,'unpacked' => 8389},'testers' => {'pass' => 3},'uses' => ['Apache::Session::Flex','strict']},'Set-Array-0.10.tar.gz' => {'author' => 'DJBERG','description' => 'Arrays as objects with lots of handy methods (including Set comparisons) and support for method chaining.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 965,'pod' => 303,'pod_errors' => 0,'total' => 1268,'with_comments' => 72},'releases' => 10,'requires' => ['Want-0.06.tar.gz'],'requires_module' => {'Want' => '0.05'},'requires_recursive' => ['Want-0.06.tar.gz'],'size' => {'packed' => 15072,'unpacked' => 56702},'testers' => {'pass' => 8},'uses' => ['Carp','Want','attributes','overload','strict','subs','vars']},'Set-Bag-1.008.tar.gz' => {'author' => 'JHI','description' => 'Bag (multiset) class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 234,'pod' => 101,'pod_errors' => 0,'total' => 335,'with_comments' => 6},'releases' => 7,'size' => {'packed' => 4462,'unpacked' => 13952},'testers' => {'pass' => 6},'uses' => ['5.004','strict']},'Set-CheckList-1.00.tar.gz' => {'author' => 'MIKO','description' => 'Maintain a list of "to-do" items','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 131,'pod' => 102,'pod_errors' => 0,'total' => 233,'with_comments' => 33},'releases' => 1,'size' => {'packed' => 3383,'unpacked' => 10950},'testers' => {'pass' => 10},'uses' => ['Carp','strict','vars']},'Set-Crontab-1.00.tar.gz' => {'author' => 'AMS','description' => 'Expand crontab(5)-style integer lists','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 100,'pod' => 59,'pod_errors' => 0,'total' => 159,'with_comments' => 4},'releases' => 3,'size' => {'packed' => 2446,'unpacked' => 6020},'testers' => {'pass' => 8},'uses' => ['Carp','strict','vars']},'Set-CrossProduct-1.4.tar.gz' => {'author' => 'BDFOY','description' => 'interact with the cartesian product of sets','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 303,'pod' => 176,'pod_errors' => 0,'total' => 479,'with_comments' => 23},'releases' => 3,'size' => {'packed' => 4011,'unpacked' => 11105},'testers' => {'pass' => 19},'uses' => ['strict','subs','vars']},'Set-FA-0.101.tar.gz' => {'author' => 'MROGASKI','description' => 'Set class for finite automata','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 550,'pod' => 327,'pod_errors' => 0,'total' => 877,'with_comments' => 151},'releases' => 1,'requires' => ['Log-Agent-0.304.tar.gz','Set-Object-1.03a.tar.gz'],'requires_module' => {'Log::Agent' => '0.2','Set::Object' => '1.02'},'requires_recursive' => ['Log-Agent-0.304.tar.gz','Set-Object-1.03a.tar.gz'],'size' => {'packed' => 8364,'unpacked' => 30642},'testers' => {'pass' => 4},'uses' => ['5.006','AutoLoader','Log::Agent','Set::Object','attributes','strict','warnings']},'Set-Hash-0.01.tar.gz' => {'author' => 'DJBERG','description' => 'Hashes as objects with lots of handy methods (including set comparisons) and support for method chaining.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 299,'pod' => 135,'pod_errors' => 0,'total' => 434,'with_comments' => 2},'releases' => 1,'requires' => ['Set-Array-0.10.tar.gz','Want-0.06.tar.gz'],'requires_module' => {'Set::Array' => '0.10','Want' => '0.05'},'requires_recursive' => ['Set-Array-0.10.tar.gz','Want-0.06.tar.gz'],'size' => {'packed' => 7072,'unpacked' => 24813},'testers' => {'pass' => 2},'uses' => ['Carp','Set::Array','Want','attributes','overload','strict','subs','vars']},'Set-Infinite-0.49.tar.gz' => {'author' => 'FGLOCK','description' => 'Sets of intervals','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3274,'pod' => 740,'pod_errors' => 0,'total' => 4014,'with_comments' => 524},'releases' => 35,'requires' => ['Time-Local-1.07.tar.gz'],'requires_module' => {'Time::Local' => 0},'requires_recursive' => ['Time-Local-1.07.tar.gz'],'size' => {'packed' => 60206,'unpacked' => 250115},'testers' => {'pass' => 3},'uses' => ['5.005_62','Carp','Data::Dumper','Exporter','POSIX','Set::Infinite::Basic','Set::Infinite::Element_Inf','Time::Local','strict','vars','warnings']},'Set-IntRange-5.1.tar.gz' => {'author' => 'STBEY','description' => 'Set of integers (arbitrary intervals, fast)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1240,'pod' => 263,'pod_errors' => 0,'total' => 1503,'with_comments' => 40},'releases' => 2,'requires' => ['Bit-Vector-6.3.tar.gz'],'requires_module' => {'Bit::Vector' => 5},'requires_recursive' => ['Bit-Vector-6.3.tar.gz'],'size' => {'packed' => 12845,'unpacked' => 95170},'testers' => {'pass' => 8},'uses' => ['Bit::Vector','Carp','Exporter','strict','vars']},'Set-IntSpan-1.07.tar.gz' => {'author' => 'SWMCD','description' => 'Set of integers newsrc style \'1,5-9,11\' etc','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1015,'pod' => 502,'pod_errors' => 1,'total' => 1517,'with_comments' => 27},'releases' => 8,'size' => {'packed' => 13641,'unpacked' => 53409},'testers' => {'pass' => 13},'uses' => ['5.004','Exporter','integer','strict','vars']},'Set-NestedGroups-0.01.tar.gz' => {'author' => 'ABARCLAY','description' => 'Grouped data eg ACL\'s, city/state/country','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 295,'pod' => 187,'pod_errors' => 2,'total' => 482,'with_comments' => 32},'releases' => 1,'size' => {'packed' => 5773,'unpacked' => 18385},'testers' => {'pass' => 10},'uses' => ['Carp','Set::NestedGroups::Member','strict','vars']},'Set-Object-1.03a.tar.gz' => {'author' => 'SAMV','description' => 'Set of Objects (smalltalkish: IdentitySet)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 272,'pod' => 138,'pod_errors' => 0,'total' => 410,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 9367,'unpacked' => 29328},'testers' => {'pass' => 5},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','overload','strict','vars']},'Set-Range-1.0.tar.gz' => {'author' => 'SIMONFLK','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 135,'pod_errors' => 0,'total' => 227,'with_comments' => 2},'releases' => 1,'requires' => ['Date-Calc-5.3.tar.gz'],'requires_module' => {'Date::Calc' => 4},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Date-Calc-5.3.tar.gz'],'size' => {'packed' => 3778,'unpacked' => 11723},'testers' => {'pass' => 8},'uses' => ['5.005_03','Date::Calc','Exporter','constant','strict','vars']},'Set-Scalar-1.17.tar.gz' => {'author' => 'JHI','description' => 'basic set operations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1265,'pod' => 375,'pod_errors' => 0,'total' => 1640,'with_comments' => 4},'releases' => 22,'size' => {'packed' => 15286,'unpacked' => 60720},'testers' => {'pass' => 24},'uses' => ['Exporter','UNIVERSAL','constant','strict','vars']},'Set-String-0.03.tar.gz' => {'author' => 'DJBERG','description' => 'Strings as objects with lots of handy methods (including set comparisons) and support for method chaining.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 441,'pod' => 121,'pod_errors' => 0,'total' => 562,'with_comments' => 51},'releases' => 3,'requires' => ['Set-Array-0.10.tar.gz','Want-0.06.tar.gz'],'requires_module' => {'Set::Array' => '0.08','Want' => '0.05'},'requires_recursive' => ['Set-Array-0.10.tar.gz','Want-0.06.tar.gz'],'size' => {'packed' => 6694,'unpacked' => 23669},'testers' => {'pass' => 6},'uses' => ['Carp','Set::Array','Want','attributes','strict','subs','vars']},'Set-Window-1.01.tar.gz' => {'author' => 'SWMCD','description' => 'Manages an interval on the integer line','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 253,'pod' => 204,'pod_errors' => 0,'total' => 457,'with_comments' => 4},'releases' => 3,'size' => {'packed' => 5625,'unpacked' => 17314},'testers' => {'pass' => 8},'uses' => ['5.6.0','Exporter','strict','vars']},'SetDualVar-1.0.tar.gz' => {'author' => 'KJALB','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 25,'pod' => 0,'pod_errors' => 0,'total' => 25,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 1395,'unpacked' => 2103},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter']},'SetFiles-1.00.tar.gz' => {'author' => 'SBECK','description' => 'routines to work with files, each definining a single set','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1318,'pod' => 455,'pod_errors' => 1,'total' => 1773,'with_comments' => 89},'releases' => 1,'size' => {'packed' => 16027,'unpacked' => 63739},'testers' => {'pass' => 2},'uses' => ['Carp','IO::File','strict','vars']},'Sex-0.69.tar.gz' => {'author' => 'MSCHWERN','description' => 'Perl teaches the birds and the bees.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 99,'pod' => 63,'pod_errors' => 0,'total' => 162,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3567,'unpacked' => 8278},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'ShadowHash-0.07.tar.gz' => {'author' => 'RRA','description' => 'Merge multiple data sources into a hash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 263,'pod' => 88,'pod_errors' => 0,'total' => 351,'with_comments' => 59},'releases' => 4,'size' => {'packed' => 9360,'unpacked' => 24483},'testers' => {'pass' => 6},'uses' => ['5.003','Carp','strict','vars']},'Shell-Base-0.01.tar.gz' => {'author' => 'DARREN','description' => 'A generic class to build line-oriented command interpreters.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1027,'pod' => 675,'pod_errors' => 0,'total' => 1702,'with_comments' => 403},'releases' => 1,'size' => {'packed' => 21323,'unpacked' => 84273},'testers' => {'pass' => 4},'uses' => ['Carp','Env','File::Basename','IO::File','Term::ReadLine','Text::Shellwords','Text::Wrap','strict','vars']},'Shell-POSIX-Select-0.05.tar.gz' => {'author' => 'YUMPY','description' => 'The POSIX Shell\'s "select" Loop for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1692,'pod' => 722,'pod_errors' => 0,'total' => 2414,'with_comments' => 336},'releases' => 5,'requires' => ['Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'File::Spec::Functions' => 0,'Filter::Simple' => 0,'Text::Balanced' => '1.89'},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 42069,'unpacked' => 272166},'testers' => {'pass' => 2},'uses' => ['Carp','File::Spec::Functions','Text::Balanced','re','strict']},'Shell-Source-0.01.tar.gz' => {'author' => 'PJCJ','description' => 'Run programs and inherit environment changes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 180,'pod' => 53,'pod_errors' => 0,'total' => 233,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 3947,'unpacked' => 11574},'testers' => {'pass' => 6},'uses' => ['5.004','Carp','Config','FileHandle','Test','strict','vars']},'ShellScript-Env-0.0.tar.gz' => {'author' => 'SVENH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 227,'pod' => 0,'pod_errors' => 0,'total' => 227,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 1819,'unpacked' => 4975},'testers' => {},'uses' => ['strict']},'ShellScript-Env-0.1.tar.gz' => {'author' => 'SVENH','description' => 'Simple sh and csh script generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 287,'pod' => 0,'pod_errors' => 0,'total' => 287,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 3777,'unpacked' => 10484},'testers' => {'fail' => 6,'tests' => '9'},'uses' => ['File::Find','strict']},'ShiftJIS-CP932-Correct-0.05.tar.gz' => {'author' => 'SADAHIRO','description' => 'corrects a string in Windows CP-932 (a variant of Shift_JIS)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 491,'pod' => 75,'pod_errors' => 0,'total' => 566,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 5738,'unpacked' => 19600},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','strict','vars']},'ShiftJIS-CP932-MapUTF-0.32.tar.gz' => {'author' => 'SADAHIRO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 207,'pod' => 284,'pod_errors' => 0,'total' => 491,'with_comments' => 45},'releases' => 16,'size' => {'packed' => 65203,'unpacked' => 204841},'testers' => {'pass' => 1},'uses' => ['5.006','DynaLoader','Exporter','strict','vars']},'ShiftJIS-Collate-0.05.tar.gz' => {'author' => 'SADAHIRO','description' => 'collation of Shift_JIS strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1088,'pod' => 467,'pod_errors' => 0,'total' => 1555,'with_comments' => 78},'releases' => 5,'size' => {'packed' => 17624,'unpacked' => 65576},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars']},'ShiftJIS-Regexp-0.26.tar.gz' => {'author' => 'SADAHIRO','description' => 'Shift_JIS-oriented regular expressions on byte-oriented perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1530,'pod' => 474,'pod_errors' => 0,'total' => 2004,'with_comments' => 67},'releases' => 17,'size' => {'packed' => 27349,'unpacked' => 103305},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','strict','vars']},'ShiftJIS-String-1.02.tar.gz' => {'author' => 'SADAHIRO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 823,'pod' => 596,'pod_errors' => 0,'total' => 1419,'with_comments' => 76},'releases' => 19,'size' => {'packed' => 41925,'unpacked' => 161853},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','strict','vars']},'ShiftJIS-X0213-MapUTF-0.11.tar.gz' => {'author' => 'SADAHIRO','description' => 'conversion between Shift_JISX0213 and Unicode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 171,'pod' => 251,'pod_errors' => 0,'total' => 422,'with_comments' => 33},'releases' => 4,'size' => {'packed' => 70021,'unpacked' => 180030},'testers' => {'pass' => 3},'uses' => ['5.006','AutoLoader','DynaLoader','Exporter','strict','vars']},'Shishi-Prototype-0.4.tar.gz' => {'author' => 'SIMON','description' => 'Internal use prototype for the Shishi regex/parser','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 279,'pod' => 80,'pod_errors' => 0,'total' => 359,'with_comments' => 9},'releases' => 4,'size' => {'packed' => 4024,'unpacked' => 13796},'testers' => {'pass' => 2},'uses' => ['Exporter','GraphViz','constant','strict']},'Shuffle-1.4.tgz' => {'author' => 'ABIGAIL','description' => 'Knuth\'s shuffle algorithm','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 88,'pod' => 90,'pod_errors' => 0,'total' => 178,'with_comments' => 27},'releases' => 3,'size' => {'packed' => 3279,'unpacked' => 7067},'testers' => {'pass' => 19},'uses' => ['Exporter','strict','vars']},'Sig-PackageScoped-0.01.tar.gz' => {'author' => 'DROLSKY','description' => 'Make $SIG{__DIE__} and $SIG{__WARN__} package scoped','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 114,'pod' => 56,'pod_errors' => 0,'total' => 170,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 3077,'unpacked' => 8880},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'SigFigs-1.02.tar.gz' => {'author' => 'SBECK','description' => 'Math using scientific significant figures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 299,'pod' => 108,'pod_errors' => 0,'total' => 407,'with_comments' => 56},'releases' => 2,'size' => {'packed' => 6608,'unpacked' => 19682},'testers' => {'pass' => 7},'uses' => ['5.000','Carp','Exporter','strict']},'Silly-Krad-0.03.tar.gz' => {'author' => 'MSLAGLE','description' => 'Rad - Make text hard to read...','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 198,'pod' => 32,'pod_errors' => 0,'total' => 230,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2334,'unpacked' => 5960},'testers' => {'pass' => 3},'uses' => ['5.005_62','Carp','Exporter','strict','warnings']},'Silly-StringMaths-0.13.tar.gz' => {'author' => 'SKINGTON','description' => 'Do maths with letters and strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 183,'pod' => 88,'pod_errors' => 0,'total' => 271,'with_comments' => 30},'releases' => 2,'size' => {'packed' => 4091,'unpacked' => 11409},'testers' => {'pass' => 6},'uses' => ['Exporter','strict','vars']},'Silly-Werder-0.90.tar.gz' => {'author' => 'CXREG','description' => 'Meaningless gibberish generator','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1173,'pod' => 162,'pod_errors' => 0,'total' => 1335,'with_comments' => 110},'releases' => 2,'requires' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'File::Spec' => 0,'Storable' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1172117,'unpacked' => 3436288},'testers' => {'pass' => 7},'uses' => ['Exporter','File::Spec::Functions','POSIX','Storable','constant','locale','strict','vars']},'Similars-1.1.tgz' => {'author' => 'SUNTONG','description' => 'Similar files locator','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 298,'pod' => 58,'pod_errors' => 0,'total' => 356,'with_comments' => 105},'releases' => 2,'size' => {'packed' => 9855,'unpacked' => 29782},'testers' => {'fail' => 3},'uses' => ['Exporter','File::Basename','Getopt::Long','Text::Soundex','fdispatch','integer','strict','vars']},'Similars-1.2.tgz' => {'author' => 'SUNTONG','description' => 'pick out suspicious duplicate files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 296,'pod' => 58,'pod_errors' => 0,'total' => 354,'with_comments' => 105},'releases' => 2,'size' => {'packed' => 9852,'unpacked' => 29982},'testers' => {'pass' => 5},'uses' => ['Exporter','File::Basename','Getopt::Long','Text::Soundex','integer','strict','vars']},'SimpleCDB-1.0.tar.gz' => {'author' => 'BENL','description' => 'Perl-only Constant Database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 689,'pod' => 125,'pod_errors' => 0,'total' => 814,'with_comments' => 183},'releases' => 1,'size' => {'packed' => 15278,'unpacked' => 38632},'testers' => {'fail' => 6},'uses' => ['5.003','Carp','FileHandle','POSIX','Tie::Hash','strict','vars']},'SimpleProcess_1.0.zip' => {'author' => 'TEDK','description' => undef,'files' => [],'lines' => {'nonpod' => 144,'pod' => 57,'pod_errors' => 0,'total' => 201,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2535,'unpacked' => 7236},'testers' => {},'uses' => ['Win32','Win32::API','strict','warnings']},'Simran-0.01.tar.gz' => {'author' => 'SIMRAN','description' => 'This is the base class for all modules in the Simran:: area.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 125,'pod_errors' => 0,'total' => 302,'with_comments' => 57},'releases' => 1,'size' => {'packed' => 2966,'unpacked' => 8546},'testers' => {'fail' => 2,'tests' => '14'},'uses' => ['5.008','strict','warnings']},'Simulation-Automate-0.9.4.tar.gz' => {'author' => 'WVDB','description' => 'A Simulation Automation Tool The set of modules is called B<Simulation::Automate>. The tool itself is called B<SynSim>, the command C<synsim>.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2098,'pod' => 848,'pod_errors' => 5,'total' => 2946,'with_comments' => 396},'releases' => 2,'size' => {'packed' => 55473,'unpacked' => 190935},'testers' => {'pass' => 3},'uses' => ['.::Loops_$dataset','Carp','Cwd','Exporter','File::Copy','FileHandle','lib','sigtrap','strict','vars']},'Slash-Gallery-0.91.tar.gz' => {'author' => 'CNANDOR','description' => 'Picture gallery plugin for Slash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 378,'pod' => 35,'pod_errors' => 0,'total' => 413,'with_comments' => 14},'releases' => 1,'requires' => ['Image-Info-1.12.tar.gz','Imager-0.41.tar.gz'],'requires_module' => {'Image::Info' => 1,'Imager' => '0.3'},'requires_recursive' => ['Image-Info-1.12.tar.gz','Imager-0.41.tar.gz'],'size' => {'packed' => 11335,'unpacked' => 36801},'testers' => {},'uses' => ['Exporter','File::Find','File::Spec::Functions','Image::Info','Slash::DB::MySQL','Slash::DB::Utility','Slash::Utility','Time::HiRes','strict','vars']},'Slash-OurNet-1.3.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Slash WebBBS module via OurNet connectivity','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 694,'pod' => 0,'pod_errors' => 0,'total' => 694,'with_comments' => 27},'releases' => 4,'size' => {'packed' => 24453,'unpacked' => 70648},'testers' => {'pass' => 2},'uses' => ['CGI','CGI::Cookie','Date::Format','Date::Parse','Exporter','Fcntl','HTML::FromANSI','HTML::FromText','Locale::Maketext','OurNet::BBS','SDBM_File','Slash','Slash::DB','Slash::Display','Slash::Utility','Template','Text::Wrap','Time::Local','strict','warnings']},'Slash-Repository-0.9.tar.gz' => {'author' => 'KROW','description' => 'Perl extension for a system plugin fro slashcode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 236,'pod' => 21,'pod_errors' => 0,'total' => 257,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 13917,'unpacked' => 53843},'testers' => {'fail' => 2},'uses' => ['Slash','Slash::DB::MySQL','Slash::DB::Utility','Slash::Utility','strict']},'Slay-Maker-0.01.tar.gz' => {'author' => 'RBS','description' => 'An perl make engine using perl code for rules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1116,'pod' => 527,'pod_errors' => 0,'total' => 1643,'with_comments' => 64},'releases' => 1,'requires' => ['IPC-Run-0.75.tar.gz','Regexp-Shellish-0.93.tar.gz'],'requires_module' => {'IPC::Run' => 0,'Regexp::Shellish' => 0},'requires_recursive' => ['IPC-Run-0.75.tar.gz','Regexp-Shellish-0.93.tar.gz'],'size' => {'packed' => 15025,'unpacked' => 49960},'testers' => {'pass' => 2},'uses' => ['Carp','Fcntl','File::Basename','File::Copy','File::Path','File::Spec::Unix','IPC::Run','fields','strict']},'SlideShow-2.0.tar.gz' => {'author' => 'LENZO','description' => 'Perl extension remote presentation','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 464,'pod' => 83,'pod_errors' => 0,'total' => 547,'with_comments' => 28},'releases' => 1,'size' => {'packed' => 5580,'unpacked' => 14161},'testers' => {'pass' => 7},'uses' => ['CGI','HTML::Parser','LWP::UserAgent','URI::Escape','strict','vars']},'Slinke-1.00.tar.gz' => {'author' => 'BPAULSEN','description' => 'module to control the Slink-e product produced by Nirvis - visit Nirvis at http://www.nirvis.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1798,'pod' => 299,'pod_errors' => 0,'total' => 2097,'with_comments' => 71},'releases' => 1,'size' => {'packed' => 23932,'unpacked' => 95176},'testers' => {'fail' => 2},'uses' => ['Device::SerialPort','Exporter','Win32::SerialPort','strict','vars']},'Slurp-0.4.tar.gz' => {'author' => 'ROBAU','description' => 'Slurp entire files into variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 58,'pod_errors' => 0,'total' => 115,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 2441,'unpacked' => 6562},'testers' => {'pass' => 4},'uses' => ['Exporter','vars']},'Smil-0.861.tar.gz' => {'author' => 'CDAWSON','description' => 'Perl extension for dynamic generation of SMIL files.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2113,'pod' => 279,'pod_errors' => 0,'total' => 2392,'with_comments' => 109},'releases' => 5,'size' => {'packed' => 22139,'unpacked' => 77425},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','LWP::Simple']},'Smil_pm_0_63.tgz' => {'author' => 'CDAWSON','description' => 'Perl extension for dynamic generation of SMIL files.','files' => [],'lines' => {'nonpod' => 1339,'pod' => 204,'pod_errors' => 0,'total' => 1543,'with_comments' => 63},'releases' => 1,'size' => {'packed' => 12881,'unpacked' => 44240},'testers' => {'pass' => 6},'uses' => ['Carp','Exporter','SYMM::SMIL::Media_Base','SYMM::SMIL::XML_Tag']},'Snowball-Norwegian-1.0.tar.gz' => {'author' => 'ASKSH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 216,'pod' => 33,'pod_errors' => 0,'total' => 249,'with_comments' => 53},'releases' => 2,'size' => {'packed' => 127194,'unpacked' => 820235},'testers' => {'pass' => 4},'uses' => ['bytes','strict','vars']},'Snowball-Swedish-1.01.tar.gz' => {'author' => 'ASKSH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 220,'pod' => 33,'pod_errors' => 0,'total' => 253,'with_comments' => 57},'releases' => 2,'size' => {'packed' => 175939,'unpacked' => 1152213},'testers' => {'pass' => 12},'uses' => ['bytes','strict','vars']},'Socket-PassAccessRights-0.03.tar.gz' => {'author' => 'SAMPO','description' => 'Pass file descriptor via Unix domain socket','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 40,'pod_errors' => 0,'total' => 82,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 6745,'unpacked' => 17056},'testers' => {'pass' => 8},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Socket6-0.11.tar.gz' => {'author' => 'UMEMOTO','description' => 'getaddrinfo/getnameinfo support module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 111,'pod' => 167,'pod_errors' => 1,'total' => 278,'with_comments' => 33},'releases' => 8,'size' => {'packed' => 31657,'unpacked' => 149081},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','DynaLoader','Exporter','vars']},'Softref-0.02.tar.gz' => {'author' => 'ILYAZ','description' => 'Extension for weak/soft referenced SVs','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 28,'pod_errors' => 0,'total' => 59,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 5210,'unpacked' => 14396},'testers' => {'fail' => 5,'tests' => '41'},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Software-Packager-0.05.tar.gz' => {'author' => 'RBDAVISON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1367,'pod' => 534,'pod_errors' => 0,'total' => 1901,'with_comments' => 260},'releases' => 5,'requires' => ['Archive-Tar-1.03.tar.gz'],'requires_module' => {'Archive::Tar' => '0.22'},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 19180,'unpacked' => 73766},'testers' => {'pass' => 2},'uses' => ['Archive::Tar','Config','Cwd','Data::Dumper','ExtUtils::MakeMaker','File::Basename','File::Copy','File::Find','File::Path','FileHandle','Software::Packager','Software::Packager::Object','strict']},'Software-Packager-0.09.tar.gz' => {'author' => 'RBDAVISON','description' => 'Common software packaging interface','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 1313,'pod' => 503,'pod_errors' => 0,'total' => 1816,'with_comments' => 191},'releases' => 5,'requires' => ['Archive-Tar-1.03.tar.gz'],'requires_module' => {'Archive::Tar' => '0.22'},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 21789,'unpacked' => 75465},'testers' => {'fail' => 1,'pass' => 4,'tests' => '21'},'uses' => ['Archive::Tar','Config','Cwd','Data::Dumper','File::Basename','File::Copy','File::Find','File::Path','strict','vars']},'Software-Packager-Aix-0.10.tar.gz' => {'author' => 'RBDAVISON','description' => 'The Software::Packager extension for AIX 4.1 and above','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 1302,'pod' => 208,'pod_errors' => 0,'total' => 1510,'with_comments' => 189},'releases' => 6,'requires' => ['Software-Packager-0.09.tar.gz'],'requires_module' => {'Software::Packager' => '0.09'},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','File-Spec-0.82.tar.gz','Software-Packager-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 21076,'unpacked' => 72215},'testers' => {'fail' => 2,'tests' => '31'},'uses' => ['Cwd','File::Basename','File::Copy','File::Path','Software::Packager','Software::Packager::Object','strict','vars']},'Software-Packager-Darwin-0.08.tar.gz' => {'author' => 'RBDAVISON','description' => 'The Software::Packager extension for MacOS X','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 386,'pod' => 59,'pod_errors' => 0,'total' => 445,'with_comments' => 68},'releases' => 3,'requires' => ['Software-Packager-0.09.tar.gz'],'requires_module' => {'Software::Packager' => '0.06'},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','File-Spec-0.82.tar.gz','Software-Packager-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 14697,'unpacked' => 42906},'testers' => {'pass' => 3},'uses' => ['File::Basename','File::Copy','File::Path','FileHandle','Software::Packager','strict','vars']},'Software-Packager-Rpm-0.06.tar.gz' => {'author' => 'RBDAVISON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 501,'pod' => 102,'pod_errors' => 1,'total' => 603,'with_comments' => 95},'releases' => 1,'requires' => ['Software-Packager-0.09.tar.gz'],'requires_module' => {'Software::Packager' => '0.07'},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','File-Spec-0.82.tar.gz','Software-Packager-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 13946,'unpacked' => 43515},'testers' => {'fail' => 1,'pass' => 1,'tests' => '25'},'uses' => ['Cwd','File::Basename','File::Copy','File::Path','Software::Packager','Software::Packager::Object','strict','vars']},'Software-Packager-Solaris-0.08.tar.gz' => {'author' => 'RBDAVISON','description' => 'The Software::Packager extension for Solaris 2.5.1 and above','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 622,'pod' => 136,'pod_errors' => 1,'total' => 758,'with_comments' => 137},'releases' => 2,'requires' => ['Software-Packager-0.09.tar.gz'],'requires_module' => {'Software::Packager' => '0.07'},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','File-Spec-0.82.tar.gz','Software-Packager-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 14293,'unpacked' => 45009},'testers' => {'pass' => 4},'uses' => ['Cwd','File::Basename','File::Copy','File::Path','FileHandle','Software::Packager','Software::Packager::Object','strict','vars']},'Software-Packager-Svr4-1.2.tar.gz' => {'author' => 'MAHEX','description' => 'The Software::Packager extension for System VR4 packages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 424,'pod' => 142,'pod_errors' => 1,'total' => 566,'with_comments' => 37},'releases' => 2,'requires' => ['Software-Packager-0.09.tar.gz'],'requires_module' => {'Software::Packager' => '0.07'},'requires_recursive' => ['Archive-Tar-1.03.tar.gz','File-Spec-0.82.tar.gz','Software-Packager-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 13822,'unpacked' => 38967},'testers' => {'pass' => 3},'uses' => ['','File::Basename','File::Copy','File::Path','IO::File','POSIX','Software::Packager','Software::Packager::Object','strict','vars']},'Solaris-0.05a.tar.gz' => {'author' => 'ABURLISON','description' => 'Access kernel performance statistics','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 341,'pod' => 146,'pod_errors' => 0,'total' => 487,'with_comments' => 58},'releases' => 1,'size' => {'packed' => 24584,'unpacked' => 96798},'testers' => {'pass' => 1},'uses' => ['DynaLoader','Exporter','IO::File','Symbol','strict','vars']},'Solaris-ACL-0.06.tar.gz' => {'author' => 'IROBERTS','description' => 'Provides access to ACLs in Solaris','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 350,'pod' => 124,'pod_errors' => 0,'total' => 474,'with_comments' => 83},'releases' => 2,'size' => {'packed' => 11160,'unpacked' => 35585},'testers' => {'pass' => 2},'uses' => ['AutoLoader','DynaLoader','Exporter','vars']},'Solaris-DevLog-1.00.tar.gz' => {'author' => 'GBOSS','description' => 'Read from a Solaris Syslog stream','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 297,'pod' => 169,'pod_errors' => 0,'total' => 466,'with_comments' => 76},'releases' => 1,'size' => {'packed' => 7527,'unpacked' => 23115},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','DynaLoader','Exporter','IO::Handle','strict','vars','warnings']},'Solaris-Kvm-0.02.tar.gz' => {'author' => 'AGOLOMSH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 86,'pod' => 62,'pod_errors' => 0,'total' => 148,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 6385,'unpacked' => 18358},'testers' => {},'uses' => ['5.006','Carp','DynaLoader','Exporter','strict','warnings']},'Solaris-MIB2-0.02.tar.gz' => {'author' => 'AGOLOMSH','description' => 'Perl extension for reading network device status and throughput information.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 209,'pod' => 58,'pod_errors' => 0,'total' => 267,'with_comments' => 18},'releases' => 2,'size' => {'packed' => 9691,'unpacked' => 33008},'testers' => {'pass' => 1},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','constant','strict','warnings']},'Solaris-NDDI-0.01.tar.gz' => {'author' => 'AGOLOMSH','description' => 'Perl extension for interacting with Solaris Network Device Driver Interface (NDDI). This module allows for getting and setting tunable parameters that control network stack drivers, including IP, TCP, UDP, ICMP and ARP drivers.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 83,'pod' => 43,'pod_errors' => 0,'total' => 126,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 4988,'unpacked' => 13089},'testers' => {'pass' => 1},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Solaris-Procfs-0.26.tar.gz' => {'author' => 'JNOLAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1047,'pod' => 298,'pod_errors' => 0,'total' => 1345,'with_comments' => 168},'releases' => 12,'size' => {'packed' => 26643,'unpacked' => 108287},'testers' => {'pass' => 1},'uses' => ['Carp','Cwd','DynaLoader','Exporter','File::Find','Solaris::Procfs::include::sys::procfs.ph','strict','vars']},'Solaris-Sysconf-0.01.tar.gz' => {'author' => 'AGOLOMSH','description' => 'get configurable system variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 399,'pod' => 199,'pod_errors' => 0,'total' => 598,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 9476,'unpacked' => 68716},'testers' => {'pass' => 2},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Solaris-Vmem-0.01.tar.gz' => {'author' => 'AGOLOMSH','description' => 'Perl interface to virtual memory allocator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 84,'pod_errors' => 0,'total' => 127,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 4688,'unpacked' => 10058},'testers' => {'pass' => 2},'uses' => ['5.006','DynaLoader','Exporter','strict','warnings']},'Solaris-loadavg-0.01.tar.gz' => {'author' => 'AGOLOMSH','description' => 'get system load averages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 86,'pod' => 34,'pod_errors' => 0,'total' => 120,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 3685,'unpacked' => 7548},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','DynaLoader','Exporter','strict','warnings']},'Sort-ArbBiLex-3.4.tar.gz' => {'author' => 'SBURKE','description' => 'sort functions for arbitrary sort orders','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 569,'pod' => 304,'pod_errors' => 0,'total' => 873,'with_comments' => 92},'releases' => 6,'size' => {'packed' => 14771,'unpacked' => 42795},'testers' => {'pass' => 12},'uses' => ['5','Carp','integer','strict','vars']},'Sort-Array-0.26.tar.gz' => {'author' => 'MIDI','description' => 'This extended sorting algorithm allows you to a) sort an array by ANY field number, not only the first. b) find duplicates in your data-set and sort them out. The function is case-sensitive. Future versions might come without this limitation.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 252,'pod' => 286,'pod_errors' => 1,'total' => 538,'with_comments' => 55},'releases' => 3,'size' => {'packed' => 5191,'unpacked' => 20356},'testers' => {'pass' => 4},'uses' => ['5.003_03','Exporter','strict','vars']},'Sort-ArrayOfArrays-1.00.tar.gz' => {'author' => 'EARL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 199,'pod' => 79,'pod_errors' => 0,'total' => 278,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 5678,'unpacked' => 22082},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Sort-Fields-0.90.tar.gz' => {'author' => 'JNH','description' => 'sort text lines by alpha or numeric fields','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 201,'pod' => 168,'pod_errors' => 0,'total' => 369,'with_comments' => 10},'releases' => 3,'size' => {'packed' => 5318,'unpacked' => 15511},'testers' => {'fail' => 1,'pass' => 10},'uses' => ['5.003_03','Carp','Exporter','strict','vars']},'Sort-Naturally-1.01.tar.gz' => {'author' => 'SBURKE','description' => '- sort lexically, but sort numeral parts numerically','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 671,'pod' => 141,'pod_errors' => 0,'total' => 812,'with_comments' => 146},'releases' => 1,'size' => {'packed' => 8980,'unpacked' => 29468},'testers' => {'pass' => 6},'uses' => ['5','Carp','Exporter','integer','locale','strict']},'Sort-Tree-1.07.tar.gz' => {'author' => 'BRYCE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 195,'pod' => 102,'pod_errors' => 0,'total' => 297,'with_comments' => 49},'releases' => 2,'size' => {'packed' => 5316,'unpacked' => 12802},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','constant','strict']},'Sort-Versions-1.4.tar.gz' => {'author' => 'EDAVIS','description' => 'sorting of revision (and similar) numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 65,'pod_errors' => 0,'total' => 198,'with_comments' => 50},'releases' => 3,'size' => {'packed' => 4090,'unpacked' => 9845},'testers' => {'pass' => 19},'uses' => ['Exporter','vars']},'Spectrum-CLI-1.014.tar.gz' => {'author' => 'PLONKA','description' => 'API for Spectrum Enterprise Mgr. CLI','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 484,'pod' => 213,'pod_errors' => 0,'total' => 697,'with_comments' => 86},'releases' => 1,'size' => {'packed' => 19138,'unpacked' => 56774},'testers' => {'pass' => 6},'uses' => ['AutoLoader','Exporter','File::Basename','IO::File','IO::Socket','IPC::Open2','POSIX','Sys::Hostname','strict','vars']},'Speech-Recognizer-SPX-0.0602.tar.gz' => {'author' => 'DJHD','description' => 'Perl extension for the Sphinx2 speech recognizer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 596,'pod' => 397,'pod_errors' => 0,'total' => 993,'with_comments' => 45},'releases' => 1,'requires' => ['Time-HiRes-1.49.tar.gz'],'requires_module' => {'Time::HiRes' => 0},'requires_recursive' => ['Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 88086,'unpacked' => 188886},'testers' => {},'uses' => ['Carp','DynaLoader','Errno','Exporter','Fcntl','Speech::Recognizer::SPX::Config','Time::HiRes','strict','vars']},'Speech-Recognizer-ScLite-0.01.tar.gz' => {'author' => 'KAHN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 384,'pod' => 296,'pod_errors' => 0,'total' => 680,'with_comments' => 85},'releases' => 1,'size' => {'packed' => 7737,'unpacked' => 23767},'testers' => {'fail' => 2},'uses' => ['5.006','Carp','Cwd','File::Basename','File::Spec::Functions','File::Temp','FileHandle','strict','warnings']},'Speech-Recognizer-ViaVoice-0.02.tar.gz' => {'author' => 'RKILGORE','description' => 'Perl wrappers for IBM\'s ViaVoice speech Recognizer library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 85,'pod_errors' => 0,'total' => 149,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 7616,'unpacked' => 21740},'testers' => {},'uses' => ['5.006','DynaLoader','Exporter','strict','warnings']},'Speech-Rsynth-0.03.tar.gz' => {'author' => 'MOOCOW','description' => '- Perl interface to \'librsynth\' Klatt-style speech synthesis C library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 411,'pod' => 323,'pod_errors' => 1,'total' => 734,'with_comments' => 112},'releases' => 2,'size' => {'packed' => 21634,'unpacked' => 85707},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Spice-0_01.tar.gz' => {'author' => 'SROHIT','description' => 'interface calls for parsing spice netlst.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 535,'pod' => 112,'pod_errors' => 0,'total' => 647,'with_comments' => 40},'releases' => 1,'size' => {'packed' => 6592,'unpacked' => 26609},'testers' => {'pass' => 3},'uses' => ['5.001','Carp','Exporter','strict','vars']},'Spread-3.14-1.03.tar.gz' => {'author' => 'JESUS','description' => 'Perl extension for the Spread group communication system','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 180,'pod' => 108,'pod_errors' => 0,'total' => 288,'with_comments' => 14},'releases' => 2,'size' => {'packed' => 8739,'unpacked' => 29628},'testers' => {},'uses' => ['5.004','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Spread-Queue-0.4.tar.gz' => {'author' => 'JMAY','description' => 'basic FIFO queue','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 888,'pod' => 453,'pod_errors' => 4,'total' => 1341,'with_comments' => 30},'releases' => 4,'requires' => ['Data-Serializer-0.17.tar.gz','Event-0.87.tar.gz','Log-Channel-0.6.tar.gz','Spread-Session-0.4.tar.gz'],'requires_module' => {'Data::Serializer' => '0.11','Event' => '0.85','Log::Channel' => '0.4','Spread::Session' => '0.3'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Data-Serializer-0.17.tar.gz','Event-0.87.tar.gz','File-Spec-0.82.tar.gz','Log-Channel-0.6.tar.gz','Log-Dispatch-2.06.tar.gz','Spread-3.14-1.03.tar.gz','Spread-Session-0.4.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 10611,'unpacked' => 41517},'testers' => {},'uses' => ['5.005_03','Carp','Data::Serializer','Digest::MD5','Log::Channel','Spread','Spread::Session','Time::HiRes','strict','vars']},'Spread-Session-0.4.tar.gz' => {'author' => 'JMAY','description' => 'OO wrapper for Spread messaging toolkit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 260,'pod' => 143,'pod_errors' => 1,'total' => 403,'with_comments' => 14},'releases' => 4,'requires' => ['Spread-3.14-1.03.tar.gz'],'requires_module' => {'Spread' => '3.15.2-1.04'},'requires_recursive' => ['Spread-3.14-1.03.tar.gz'],'size' => {'packed' => 6468,'unpacked' => 19568},'testers' => {},'uses' => ['5.005','Carp','Spread','strict','vars','warnings']},'Spreadsheet-ParseExcel-0.2602.tar.gz' => {'author' => 'KWITKNR','description' => 'Get information from Excel file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4099,'pod' => 1020,'pod_errors' => 1,'total' => 5119,'with_comments' => 797},'releases' => 36,'requires' => ['OLE-Storage_Lite-0.11.tar.gz'],'requires_module' => {'OLE::Storage_Lite' => '0.08'},'requires_recursive' => ['IO-stringy-2.108.tar.gz','OLE-Storage_Lite-0.11.tar.gz'],'size' => {'packed' => 91945,'unpacked' => 599108},'testers' => {'pass' => 25},'uses' => ['Exporter','Jcode','OLE::Storage_Lite','Spreadsheet::WriteExcel','Unicode::Map','constant','strict','vars']},'Spreadsheet-ParseExcel-Simple-1.01.tar.gz' => {'author' => 'TMTM','description' => 'A simple interface to Excel data','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 51,'pod' => 62,'pod_errors' => 0,'total' => 113,'with_comments' => 0},'releases' => 4,'requires' => ['Spreadsheet-ParseExcel-0.2602.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Spreadsheet::ParseExcel' => '0.18','Test::More' => '0.01'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','OLE-Storage_Lite-0.11.tar.gz','Spreadsheet-ParseExcel-0.2602.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2319,'unpacked' => 4911},'testers' => {'pass' => 2},'uses' => ['Spreadsheet::ParseExcel','strict','vars']},'Spreadsheet-ParseExcel_XLHTML-0.02.tar.gz' => {'author' => 'RKITOVER','description' => 'Parse Excel Spreadsheets using xlhtml','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 172,'pod' => 86,'pod_errors' => 0,'total' => 258,'with_comments' => 10},'releases' => 2,'requires' => ['Spreadsheet-ParseExcel-0.2602.tar.gz'],'requires_module' => {'Spreadsheet::ParseExcel' => 0},'requires_recursive' => ['IO-stringy-2.108.tar.gz','OLE-Storage_Lite-0.11.tar.gz','Spreadsheet-ParseExcel-0.2602.tar.gz'],'size' => {'packed' => 4423,'unpacked' => 11691},'testers' => {'pass' => 3},'uses' => ['HTML::Entities','IO::File','Spreadsheet::ParseExcel','strict']},'Spreadsheet-WriteExcel-0.41.tar.gz' => {'author' => 'JMCNAMARA','description' => 'Write to a cross-platform Excel binary file.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8755,'pod' => 3930,'pod_errors' => 1,'total' => 12685,'with_comments' => 2877},'releases' => 22,'requires' => ['File-Temp-0.12.tar.gz','Parse-RecDescent-1.94.tar.gz'],'requires_module' => {'File::Temp' => 0,'Parse::RecDescent' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 412049,'unpacked' => 1282900},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','FileHandle','OLE::Storage_Lite','autouse','integer','strict','vars']},'Spreadsheet-WriteExcel-FromDB-0.09.tar.gz' => {'author' => 'TMTM','description' => 'Convert a database table to an Excel spreadsheet','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 194,'pod' => 78,'pod_errors' => 0,'total' => 272,'with_comments' => 7},'releases' => 8,'requires' => ['Spreadsheet-WriteExcel-Simple-0.03.tar.gz'],'requires_module' => {'Spreadsheet::WriteExcel::Simple' => '0.02'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Parse-RecDescent-1.94.tar.gz','Spreadsheet-WriteExcel-0.41.tar.gz','Spreadsheet-WriteExcel-Simple-0.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3188,'unpacked' => 7308},'testers' => {'pass' => 2},'uses' => ['Carp','Spreadsheet::WriteExcel::Simple','strict','vars']},'Spreadsheet-WriteExcel-Simple-0.03.tar.gz' => {'author' => 'TMTM','description' => 'A simple single-sheet Excel document','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 68,'pod_errors' => 0,'total' => 144,'with_comments' => 1},'releases' => 3,'requires' => ['IO-stringy-2.108.tar.gz','Spreadsheet-WriteExcel-0.41.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'IO::Scalar' => '1.126','Spreadsheet::WriteExcel' => '0.31','Test::More' => '0.04'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Parse-RecDescent-1.94.tar.gz','Spreadsheet-WriteExcel-0.41.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2710,'unpacked' => 5645},'testers' => {'pass' => 5},'uses' => ['IO::Scalar','Spreadsheet::WriteExcel','strict','vars']},'Sprite-3.21.tar.gz' => {'author' => 'SHGUN','description' => 'Limited SQL interface to flat file databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 904,'pod' => 258,'pod_errors' => 0,'total' => 1162,'with_comments' => 58},'releases' => 3,'size' => {'packed' => 14487,'unpacked' => 42006},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.002','Cwd','Fcntl','vars']},'StanzaFile-1.05.tar.gz' => {'author' => 'MUNROER','description' => 'read, parse, and write files containing "stanzas".','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 878,'pod' => 278,'pod_errors' => 1,'total' => 1156,'with_comments' => 174},'releases' => 4,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'FileHandle' => 2},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 8233,'unpacked' => 29827},'testers' => {'pass' => 1},'uses' => ['FileHandle','Stanza','strict','vars']},'Startup-0.103.tar.gz' => {'author' => 'MSCHWARTZ','description' => 'A program flow utility. I<ALPHA> version as of C<$Date: 1998/04/28 00:38:41 $>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 820,'pod' => 438,'pod_errors' => 1,'total' => 1258,'with_comments' => 63},'releases' => 3,'size' => {'packed' => 12568,'unpacked' => 40959},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Cwd','Symbol','strict']},'Stat-lsMode-0.50.tar.gz' => {'author' => 'MJD','description' => 'Translate mode 0644 to -rw-r--r--','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 159,'pod' => 94,'pod_errors' => 0,'total' => 253,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 4017,'unpacked' => 8789},'testers' => {'pass' => 7},'uses' => ['Carp','Exporter']},'StateML-0.22.tar.gz' => {'author' => 'RBS','description' => 'State Machine Markup Language, with GraphViz and template-driven code generation','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1730,'pod' => 631,'pod_errors' => 1,'total' => 2361,'with_comments' => 63},'releases' => 1,'requires' => ['Template-Toolkit-2.10.tar.gz','XML-Filter-Mode-0.02.tar.gz','XML-SAX-0.12.tar.gz'],'requires_module' => {'Template' => 2,'XML::Filter::Mode' => 0,'XML::SAX::ParserFactory' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Template-Toolkit-2.10.tar.gz','XML-Filter-Mode-0.02.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 22502,'unpacked' => 79049},'testers' => {'pass' => 1},'uses' => ['','Carp','Exporter','GraphViz','SelfTest','StateML::Machine','XML::Filter::Mode','XML::SAX::ParserFactory','strict']},'StateMachine-Gestinanna-0.06.tar.gz' => {'author' => 'JSMITH','description' => 'provides context and state machine for wizard-like applications','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 986,'pod' => 335,'pod_errors' => 4,'total' => 1321,'with_comments' => 56},'releases' => 6,'requires' => ['Class-Container-0.10.tar.gz','Data-FormValidator-3.12.tar.gz','Error-0.15.tar.gz','Params-Validate-0.64.tar.gz','YAML-0.35.tar.gz'],'requires_module' => {'Class::Container' => '0.07','Data::FormValidator' => '1.9','Error' => '0.15','Params::Validate' => '0.24','YAML' => '0.35'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Class-Container-0.10.tar.gz','Data-FormValidator-3.12.tar.gz','Error-0.15.tar.gz','Params-Validate-0.64.tar.gz','YAML-0.35.tar.gz'],'size' => {'packed' => 13717,'unpacked' => 57947},'testers' => {'pass' => 3},'uses' => ['Class::Container','Data::Dumper','Net::SMTP','Params::Validate','overload','strict','vars']},'Static-0.01.tar.gz' => {'author' => 'TILLY','description' => 'create static lexicals','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 56,'pod' => 50,'pod_errors' => 0,'total' => 106,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2466,'unpacked' => 4934},'testers' => {'pass' => 2},'uses' => []},'Statistics-ChiSquare-0.3.tar.gz' => {'author' => 'JONO','description' => 'Chi Square test - how random is your data?','files' => [],'lines' => {'nonpod' => 106,'pod' => 92,'pod_errors' => 0,'total' => 198,'with_comments' => 17},'releases' => 3,'size' => {'packed' => 3895,'unpacked' => 7772},'testers' => {'pass' => 13},'uses' => ['AutoLoader','Exporter','strict','vars']},'Statistics-Contingency-0.06.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Calculate precision, recall, F1, accuracy, etc.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 262,'pod' => 163,'pod_errors' => 0,'total' => 425,'with_comments' => 24},'releases' => 5,'requires' => ['Params-Validate-0.64.tar.gz'],'requires_module' => {'Params::Validate' => '0.23'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Params-Validate-0.64.tar.gz'],'size' => {'packed' => 7213,'unpacked' => 25574},'testers' => {'pass' => 9},'uses' => ['Params::Validate','strict']},'Statistics-ConwayLife-0_52.tar.gz' => {'author' => 'DANB','description' => 'Simulates life using Conway\'s algorithm','files' => [],'lines' => {'nonpod' => 173,'pod' => 81,'pod_errors' => 1,'total' => 254,'with_comments' => 23},'releases' => 1,'size' => {'packed' => 2536,'unpacked' => 8489},'testers' => {'fail' => 1,'tests' => '0','unknown' => 6},'uses' => ['Exporter','strict','vars']},'Statistics-DEA-0.04.tar.gz' => {'author' => 'JHI','description' => 'Discontiguous Exponential Averaging','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 98,'pod_errors' => 0,'total' => 233,'with_comments' => 4},'releases' => 4,'size' => {'packed' => 3468,'unpacked' => 9777},'testers' => {'pass' => 4},'uses' => ['Carp','strict','vars','warnings']},'Statistics-DependantTTest-0.01.tar.gz' => {'author' => 'MGLEE','description' => 'Perl module to perform Student\'s dependant or paired T-test on 2 paired samples.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 25,'pod_errors' => 0,'total' => 114,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 2507,'unpacked' => 5312},'testers' => {'pass' => 2},'uses' => ['Carp','Statistics::PointEstimation','strict','vars']},'Statistics-DependantTTest-0.03.tar.gz' => {'author' => 'MGLEE','description' => 'Perl module to perform Student\'s dependant or paired T-test on 2 paired samples.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 25,'pod_errors' => 0,'total' => 114,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 2540,'unpacked' => 5449},'testers' => {'pass' => 2},'uses' => ['Carp','Statistics::PointEstimation','strict','vars']},'Statistics-Descriptive-2.6.tar.gz' => {'author' => 'COLINK','description' => 'Descriptive statistical methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 538,'pod' => 317,'pod_errors' => 1,'total' => 855,'with_comments' => 54},'releases' => 5,'size' => {'packed' => 11252,'unpacked' => 31133},'testers' => {'pass' => 11},'uses' => ['5.00404','Carp','POSIX','strict','vars']},'Statistics-Descriptive-Discrete-0.07.tar.gz' => {'author' => 'RHETTBULL','description' => 'Compute descriptive statistics for discrete data sets.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 365,'pod' => 154,'pod_errors' => 0,'total' => 519,'with_comments' => 64},'releases' => 3,'size' => {'packed' => 6889,'unpacked' => 18914},'testers' => {'pass' => 8},'uses' => ['AutoLoader','Carp','strict','vars','warnings']},'Statistics-Distributions-1.01.tar.gz' => {'author' => 'MIKEK','description' => 'Perl module for calculating critical values','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 454,'pod' => 75,'pod_errors' => 0,'total' => 529,'with_comments' => 23},'releases' => 7,'size' => {'packed' => 5665,'unpacked' => 15589},'testers' => {'pass' => 3},'uses' => ['Exporter','constant','strict','vars']},'Statistics-Frequency-0.03.tar.gz' => {'author' => 'JHI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 215,'pod' => 170,'pod_errors' => 0,'total' => 385,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 4271,'unpacked' => 15254},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Statistics-GammaDistribution-0.01.tar.gz' => {'author' => 'NWETTERS','description' => 'represents a gamma distribution','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 155,'pod' => 58,'pod_errors' => 0,'total' => 213,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 9946,'unpacked' => 26353},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'Statistics-GaussHelmert-0.05.tar.gz' => {'author' => 'HEUEL','description' => 'General weighted least squares estimation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 653,'pod' => 180,'pod_errors' => 0,'total' => 833,'with_comments' => 140},'releases' => 3,'requires' => ['ExtUtils-F77-1.14.tar.gz','Math-Random-0.67.tar.gz','PDL-2.4.0.tar.gz'],'requires_module' => {'ExtUtils::F77' => '1.13','Math::Random' => '0.61','PDL' => '2.3.1'},'requires_recursive' => ['ExtUtils-F77-1.14.tar.gz','Math-Random-0.67.tar.gz','PDL-2.4.0.tar.gz'],'size' => {'packed' => 13416,'unpacked' => 43103},'testers' => {'pass' => 1},'uses' => ['5.6.0','Carp','Exporter','PDL','PDL::Math','PDL::Matrix','PDL::Slatec','strict','vars']},'Statistics-KruskalWallis-0.01.tar.gz' => {'author' => 'MGLEE','description' => 'Perl module to perform the Kruskall-Wallis test, use to test if differences exist between 3 or more independant groups of unequal sizes. Also includes the post-hoc Newman-Keuls test, to test if the differences between pairs of the tested group are significant.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 178,'pod' => 45,'pod_errors' => 0,'total' => 223,'with_comments' => 33},'releases' => 1,'size' => {'packed' => 3474,'unpacked' => 9701},'testers' => {'pass' => 2},'uses' => ['Carp','Statistics::Distributions','strict']},'Statistics-LSNoHistory-0.01.tgz' => {'author' => 'PLIAM','description' => 'Least-Squares linear regression package without data history','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 421,'pod' => 256,'pod_errors' => 3,'total' => 677,'with_comments' => 45},'releases' => 1,'size' => {'packed' => 9914,'unpacked' => 36834},'testers' => {'pass' => 5},'uses' => ['strict','vars']},'Statistics-LTU-2.8.tar.gz' => {'author' => 'TOMFA','description' => 'Implements Linear Threshold Units','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1482,'pod' => 165,'pod_errors' => 0,'total' => 1647,'with_comments' => 454},'releases' => 2,'size' => {'packed' => 16264,'unpacked' => 55330},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['5','Carp','Exporter']},'Statistics-Lite-1.02.tar.gz' => {'author' => 'BRIANL','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 57,'pod_errors' => 0,'total' => 231,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 2957,'unpacked' => 7214},'testers' => {'fail' => 2,'pass' => 3},'uses' => ['Exporter','strict','vars']},'Statistics-LogRank-0.01.tar.gz' => {'author' => 'MGLEE','description' => 'Perl module to perform the log rank test (also know as the Mantel-Haenszel or Mantel-Cox test) on survival data.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 34,'pod_errors' => 0,'total' => 123,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 2681,'unpacked' => 6090},'testers' => {'pass' => 2},'uses' => ['Carp','Statistics::Distributions','strict']},'Statistics-LogRank-0.03.tar.gz' => {'author' => 'MGLEE','description' => 'Perl module to perform the log rank test (also know as the Mantel-Haenszel or Mantel-Cox test) on survival data.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 34,'pod_errors' => 0,'total' => 123,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 2731,'unpacked' => 6232},'testers' => {'pass' => 2},'uses' => ['Carp','Statistics::Distributions','strict']},'Statistics-MaxEntropy-0.9.tar.gz' => {'author' => 'TERDOEST','description' => 'Maximum Entropy Modeling','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2110,'pod' => 553,'pod_errors' => 0,'total' => 2663,'with_comments' => 288},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz'],'requires_module' => {'Data::Dumper' => '2.09'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 42264,'unpacked' => 136699},'testers' => {},'uses' => ['AutoLoader','Carp','Data::Dumper','Exporter','POSIX','strict','vars']},'Statistics-OLS-0.07.tar.gz' => {'author' => 'SMORTON','description' => 'ordinary least squares (curve fitting)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 468,'pod' => 146,'pod_errors' => 1,'total' => 614,'with_comments' => 106},'releases' => 3,'size' => {'packed' => 8050,'unpacked' => 26139},'testers' => {'pass' => 11},'uses' => ['strict']},'Statistics-ROC-0.02.tar.gz' => {'author' => 'HAKESTLER','description' => 'ROC curves with nonparametric conf. bounds','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1298,'pod' => 294,'pod_errors' => 0,'total' => 1592,'with_comments' => 486},'releases' => 2,'size' => {'packed' => 36549,'unpacked' => 129720},'testers' => {'pass' => 6},'uses' => ['5','Carp','Exporter','strict','vars']},'Statistics-Shannon-0.03.tar.gz' => {'author' => 'JHI','description' => 'Shannon index','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 101,'pod' => 167,'pod_errors' => 0,'total' => 268,'with_comments' => 0},'releases' => 3,'requires' => ['Statistics-Frequency-0.03.tar.gz'],'requires_module' => {'Statistics::Frequency' => '0.03'},'requires_recursive' => ['Statistics-Frequency-0.03.tar.gz'],'size' => {'packed' => 3336,'unpacked' => 9322},'testers' => {'pass' => 2},'uses' => ['Carp','Statistics::Frequency','strict','vars']},'Statistics-Simpson-0.01.tar.gz' => {'author' => 'JHI','description' => 'Simpson index','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 87,'pod' => 149,'pod_errors' => 0,'total' => 236,'with_comments' => 0},'releases' => 1,'requires' => ['Statistics-Frequency-0.03.tar.gz'],'requires_module' => {'Statistics::Frequency' => '0.03'},'requires_recursive' => ['Statistics-Frequency-0.03.tar.gz'],'size' => {'packed' => 2696,'unpacked' => 7050},'testers' => {'pass' => 2},'uses' => ['Statistics::Frequency','strict','vars']},'Statistics-TTest-1.1.0.tar.gz' => {'author' => 'YUNFANG','description' => 'module to compute the confidence interval','files' => ['Makefile.PL'],'lines' => {'nonpod' => 499,'pod' => 178,'pod_errors' => 0,'total' => 677,'with_comments' => 9},'releases' => 3,'requires' => ['Statistics-Descriptive-2.6.tar.gz','Statistics-Distributions-1.01.tar.gz'],'requires_module' => {'Statistics::Descriptive' => '2.6','Statistics::Distributions' => '0.07'},'requires_recursive' => ['Statistics-Descriptive-2.6.tar.gz','Statistics-Distributions-1.01.tar.gz'],'size' => {'packed' => 6013,'unpacked' => 25176},'testers' => {'pass' => 2},'uses' => ['Carp','POSIX','Statistics::Descriptive','Statistics::Distributions','strict','vars']},'Statistics-Table-F-0.02.tar.gz' => {'author' => 'JONO','description' => 'Perl module for computing the statistical F-ratio','files' => [],'lines' => {'nonpod' => 302,'pod' => 76,'pod_errors' => 0,'total' => 378,'with_comments' => 14},'releases' => 1,'size' => {'packed' => 11322,'unpacked' => 37885},'testers' => {'pass' => 2,'tests' => '0','unknown' => 12},'uses' => ['AutoLoader','Exporter','strict','vars']},'StatisticsRegression.tar.gz' => {'author' => 'IAWELCH','description' => '		weighted linear regression package (line+plane fitting)','files' => [],'lines' => {'nonpod' => 339,'pod' => 123,'pod_errors' => 0,'total' => 462,'with_comments' => 34},'releases' => 1,'size' => {'packed' => 5508,'unpacked' => 19763},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['constant','strict']},'StatsView-1.4.tar.gz' => {'author' => 'ABURLISON','description' => 'Solaris performance data collection and graphing package','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2542,'pod' => 147,'pod_errors' => 0,'total' => 2689,'with_comments' => 380},'releases' => 5,'size' => {'packed' => 1471755,'unpacked' => 1584194},'testers' => {'pass' => 1,'tests' => '0','unknown' => 9},'uses' => ['$path::$monitor','DBI','File::Basename','IO::Dir','IO::File','POSIX','strict','vars']},'Storable-2.07.tar.gz' => {'author' => 'AMS','description' => 'Persistent data structure mechanism','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 650,'pod' => 346,'pod_errors' => 0,'total' => 996,'with_comments' => 122},'releases' => 35,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.41'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 96476,'unpacked' => 330625},'testers' => {'pass' => 7},'uses' => ['AutoLoader','Carp','Config','DynaLoader','Exporter','Fcntl','vars']},'Storm-Tracker_0.01.tar.gz' => {'author' => 'CARPENTER','description' => 'Perl bundle for working with national weather advisories','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2538,'pod' => 801,'pod_errors' => 1,'total' => 3339,'with_comments' => 426},'releases' => 1,'requires' => ['IO-1.20.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Path' => '1.0401','IO::Dir' => '1.03','IO::File' => '1.08','Time::Local' => 0},'requires_recursive' => ['IO-1.20.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 36502,'unpacked' => 170246},'testers' => {'pass' => 15},'uses' => ['Carp','File::Path','IO::Dir','IO::File','Time::Local','strict','vars']},'Storm-Tracker_0.02.tar.gz' => {'author' => 'CARPENTER','description' => 'Perl bundle for working with national weather advisories','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2911,'pod' => 860,'pod_errors' => 0,'total' => 3771,'with_comments' => 488},'releases' => 1,'requires' => ['IO-1.20.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Path' => '1.0401','IO::Dir' => '1.03','IO::File' => '1.08','Time::Local' => 0},'requires_recursive' => ['IO-1.20.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 52375,'unpacked' => 249054},'testers' => {'pass' => 9},'uses' => ['Carp','File::Path','IO::Dir','IO::File','Time::Local','strict','vars']},'Stream-1.00.tar.gz' => {'author' => 'GARY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 898,'pod' => 0,'pod_errors' => 0,'total' => 898,'with_comments' => 108},'releases' => 1,'size' => {'packed' => 6903,'unpacked' => 24811},'testers' => {'pass' => 2},'uses' => ['5.000','Carp','Exporter','FileHandle','POSIX','strict']},'String-Approx-3.20.tar.gz' => {'author' => 'JHI','description' => 'Approximate string matching and substitution','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 611,'pod' => 274,'pod_errors' => 0,'total' => 885,'with_comments' => 12},'releases' => 28,'size' => {'packed' => 43309,'unpacked' => 149111},'testers' => {'pass' => 6},'uses' => ['Carp','DynaLoader','Exporter','integer','strict','vars']},'String-BitCount-1.13.tar.gz' => {'author' => 'WINKO','description' => 'Count number of "1" bits in strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 42,'pod_errors' => 0,'total' => 114,'with_comments' => 3},'releases' => 3,'size' => {'packed' => 2682,'unpacked' => 5227},'testers' => {'pass' => 3},'uses' => ['5.004','Carp','Exporter','bytes','strict','vars']},'String-Buffer-0.05.tar.gz' => {'author' => 'MCKAY','description' => 'A simple string buffer class.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 61,'pod' => 58,'pod_errors' => 0,'total' => 119,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 1585,'unpacked' => 2894},'testers' => {'pass' => 7},'uses' => ['strict','vars']},'String-CRC-1.0.tar.gz' => {'author' => 'MUIR','description' => 'Cyclic redundency check generation','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 22,'pod' => 28,'pod_errors' => 0,'total' => 50,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 3028,'unpacked' => 6433},'testers' => {'fail' => 1,'pass' => 10},'uses' => ['DynaLoader','Exporter']},'String-CRC32-1.2.tar.gz' => {'author' => 'SOENKE','description' => 'ZMODEM-like CRC32 generation of strings as w','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 25,'pod' => 55,'pod_errors' => 0,'total' => 80,'with_comments' => 2},'releases' => 5,'size' => {'packed' => 6874,'unpacked' => 16356},'testers' => {'pass' => 21},'uses' => ['DynaLoader','Exporter']},'String-Checker-0.03.tar.gz' => {'author' => 'DLOWE','description' => 'An extensible string validation module (allowing commonly used checks on strings to be called more concisely and consistently).','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 418,'pod' => 130,'pod_errors' => 0,'total' => 548,'with_comments' => 76},'releases' => 1,'requires' => ['DateManip-5.42a.tar.gz'],'requires_module' => {'Date::Manip' => 0},'requires_recursive' => ['DateManip-5.42a.tar.gz'],'size' => {'packed' => 4685,'unpacked' => 15505},'testers' => {'pass' => 15},'uses' => ['Date::Manip','strict','vars']},'String-Divert-0.92.tar.gz' => {'author' => 'RSE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 693,'pod' => 290,'pod_errors' => 1,'total' => 983,'with_comments' => 170},'releases' => 3,'size' => {'packed' => 9668,'unpacked' => 38593},'testers' => {'pass' => 2},'uses' => ['5.006','Exporter','strict','warnings']},'String-Downgrade-0.03.tar.gz' => {'author' => 'DYACOB','description' => 'Generate Acceptable Spellings from Canonical.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 66,'pod_errors' => 0,'total' => 203,'with_comments' => 14},'releases' => 3,'requires' => ['Regexp-Ethiopic-0.12.tar.gz'],'requires_module' => {'Regexp::Ethiopic' => '0.10'},'requires_recursive' => ['Regexp-Ethiopic-0.12.tar.gz'],'size' => {'packed' => 6202,'unpacked' => 18486},'testers' => {'pass' => 2},'uses' => ['','Exporter','Regexp::Ethiopic::Amharic','strict','utf','vars']},'String-Ediff-0.01.tar.gz' => {'author' => 'BOXZOU','description' => 'Produce common sub-string indices for two strings','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 17,'pod' => 68,'pod_errors' => 0,'total' => 85,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 12160,'unpacked' => 49731},'testers' => {'pass' => 5},'uses' => ['DynaLoader','Exporter','vars']},'String-Escape-2002.001.tar.gz' => {'author' => 'EVO','description' => 'Registry of string functions, including backslash escapes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 302,'pod' => 323,'pod_errors' => 0,'total' => 625,'with_comments' => 43},'releases' => 3,'size' => {'packed' => 7183,'unpacked' => 21143},'testers' => {'pass' => 10},'uses' => ['5','Carp','Exporter','strict','vars']},'String-ExpandEscapes-0.01.tar.gz' => {'author' => 'MAFR','description' => 'Expand printf-style %-escapes in a string. =head1 SYNOPSIS use String::ExpandEscapes qw(expand); my %escapes = ( a => \'Tori Amos\', t => \'Silent All These Years\' ) my ($result, $error) = expand(\'%.1a/%a/%t.mp3\', \\%escapes); die "Illegal escape sequence $error\\n" if $error; =head1 ABSTRACT This module contains functions for parsing and doing substitutions in format strings similar to those used by printf. The %-escapes to be replaced can either be given using a hash, or, for maximum flexibility, using a callback function.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 178,'pod' => 74,'pod_errors' => 0,'total' => 252,'with_comments' => 71},'releases' => 1,'size' => {'packed' => 3533,'unpacked' => 7706},'testers' => {'pass' => 3},'uses' => ['5.008','Carp','Exporter','strict','warnings']},'String-Format-1.13.tar.gz' => {'author' => 'DARREN','description' => 'sprintf-like string formatting capabilities with arbitrary format definitions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 127,'pod' => 110,'pod_errors' => 0,'total' => 237,'with_comments' => 33},'releases' => 3,'size' => {'packed' => 6643,'unpacked' => 23868},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'String-Interpolate-0.1.tar.gz' => {'author' => 'NOBULL','description' => 'Wrapper for builtin the Perl interpolatation engine.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 656,'pod' => 300,'pod_errors' => 0,'total' => 956,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 10822,'unpacked' => 32483},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','Safe','Safe::Hole','Symbol','strict','warnings']},'String-KeyboardDistance-1.01.tar.gz' => {'author' => 'KRBURTON','description' => 'String Comparison Algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 326,'pod' => 203,'pod_errors' => 0,'total' => 529,'with_comments' => 18},'releases' => 2,'size' => {'packed' => 6739,'unpacked' => 26265},'testers' => {'pass' => 4},'uses' => ['5.005_62','Exporter','strict','warnings']},'String-KeyboardDistanceXS-0.02.tar.gz' => {'author' => 'KRBURTON','description' => 'String Comparison Algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 49,'pod_errors' => 0,'total' => 141,'with_comments' => 13},'releases' => 2,'size' => {'packed' => 4679,'unpacked' => 12173},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['5.005_62','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'String-LCSS-0.12.tar.gz' => {'author' => 'DYACOB','description' => 'Find The Longest Common Substring of Two Strings.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 96,'pod' => 32,'pod_errors' => 0,'total' => 128,'with_comments' => 11},'releases' => 3,'size' => {'packed' => 2923,'unpacked' => 5936},'testers' => {'pass' => 4},'uses' => ['Exporter','strict','vars']},'String-LRC-1.01.tar.gz' => {'author' => 'WHOELSE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 71,'pod' => 66,'pod_errors' => 0,'total' => 137,'with_comments' => 26},'releases' => 1,'size' => {'packed' => 5515,'unpacked' => 16838},'testers' => {'pass' => 5},'uses' => ['DynaLoader','Exporter']},'String-Multibyte-1.05.tar.gz' => {'author' => 'SADAHIRO','description' => 'manipulation of multibyte character strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1639,'pod' => 892,'pod_errors' => 0,'total' => 2531,'with_comments' => 84},'releases' => 12,'size' => {'packed' => 32395,'unpacked' => 142691},'testers' => {'pass' => 2},'uses' => ['5.008','Carp','Exporter','File::Spec','strict','vars']},'String-Nysiis-1.00.tar.gz' => {'author' => 'KRBURTON','description' => 'NYSIIS Phonetic Encoding','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 43,'pod_errors' => 0,'total' => 119,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2404,'unpacked' => 4932},'testers' => {'pass' => 3},'uses' => ['5.005_62','Exporter','strict','warnings']},'String-Parity-1.31.tar.gz' => {'author' => 'WINKO','description' => 'Parity (odd/even/mark/space) handling','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 170,'pod' => 82,'pod_errors' => 0,'total' => 252,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3586,'unpacked' => 10155},'testers' => {'pass' => 10},'uses' => ['Exporter','strict','vars']},'String-Pattern-0.90.tar.gz' => {'author' => 'IVOZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 199,'pod' => 114,'pod_errors' => 0,'total' => 313,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 3789,'unpacked' => 9146},'testers' => {'pass' => 5},'uses' => ['overload','strict','vars']},'String-REPartition-1.0.tar.gz' => {'author' => 'AVIF','description' => 'Generates a regex to partition a data set','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 381,'pod' => 43,'pod_errors' => 0,'total' => 424,'with_comments' => 97},'releases' => 2,'size' => {'packed' => 7700,'unpacked' => 18320},'testers' => {'pass' => 7},'uses' => ['5','Exporter','strict','vars']},'String-REPartition-1.1.tar.gz' => {'author' => 'AVIF','description' => 'Generates a regex to partition a data set','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 433,'pod' => 45,'pod_errors' => 0,'total' => 478,'with_comments' => 97},'releases' => 2,'size' => {'packed' => 8328,'unpacked' => 20267},'testers' => {'pass' => 8},'uses' => ['5','Exporter','strict','vars']},'String-Random-0.198.tar.gz' => {'author' => 'STEVE','description' => 'Perl module to generate random strings based','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 317,'pod' => 111,'pod_errors' => 0,'total' => 428,'with_comments' => 49},'releases' => 3,'size' => {'packed' => 6599,'unpacked' => 17686},'testers' => {'pass' => 15},'uses' => ['Carp','strict','vars']},'String-Rexx-0.01.tar.gz' => {'author' => 'IOANNIS','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 294,'pod' => 186,'pod_errors' => 0,'total' => 480,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 8904,'unpacked' => 30906},'testers' => {'pass' => 2},'uses' => ['5.006','AutoLoader','Exporter','strict','warnings']},'String-RexxParse-1.08.tar.gz' => {'author' => 'BLCKSMTH','description' => 'Perl implementation of REXX \'parse\' command','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 973,'pod' => 218,'pod_errors' => 1,'total' => 1191,'with_comments' => 43},'releases' => 6,'size' => {'packed' => 9182,'unpacked' => 38158},'testers' => {'pass' => 9},'uses' => ['5.003','Carp','Exporter','strict','vars']},'String-Scanf-2.0.tar.gz' => {'author' => 'JHI','description' => 'Implementation of C sscanf function','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 146,'pod' => 102,'pod_errors' => 0,'total' => 248,'with_comments' => 3},'releases' => 5,'size' => {'packed' => 4417,'unpacked' => 11355},'testers' => {'pass' => 6},'uses' => ['5.005','Carp','Exporter','strict','vars']},'String-ShellQuote-1.00.tar.gz' => {'author' => 'ROSCH','description' => 'Quote string for safe passage through shells','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 42,'pod_errors' => 0,'total' => 111,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 2634,'unpacked' => 5286},'testers' => {'pass' => 16},'uses' => ['Carp','Exporter','strict','vars']},'String-ShowDiff-0.03.tar.gz' => {'author' => 'BIGJ','description' => 'Perl extension to help visualize differences between strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 84,'pod_errors' => 0,'total' => 203,'with_comments' => 12},'releases' => 3,'requires' => ['ANSIColor-1.07.tar.gz','Algorithm-Diff-1.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Algorithm::Diff' => '1.15','Term::ANSIColor' => '1.04','Test::More' => 0},'requires_recursive' => ['ANSIColor-1.07.tar.gz','Algorithm-Diff-1.15.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4582,'unpacked' => 12578},'testers' => {'pass' => 3},'uses' => ['Algorithm::Diff','Exporter','Term::ANSIColor','strict','vars']},'String-Similarity-0.02.tar.gz' => {'author' => 'MLEHMANN','description' => 'Calculate the similarity of two strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 44,'pod_errors' => 0,'total' => 78,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 13978,'unpacked' => 40446},'testers' => {'pass' => 11},'uses' => ['DynaLoader']},'String-StringLib-1.02.tar.gz' => {'author' => 'BPOWERS','description' => 'Perl extension for fast, commonly used, string operations Use of String::StringLib is deprecated as of version 1.01. Please see String::Strip (version 1.01 or better) instead.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 17,'pod_errors' => 0,'total' => 51,'with_comments' => 0},'releases' => 3,'requires' => ['String-Strip-1.01.tar.gz'],'requires_module' => {'String::Strip' => '1.01'},'requires_recursive' => ['String-Strip-1.01.tar.gz'],'size' => {'packed' => 1837,'unpacked' => 3736},'testers' => {'pass' => 6},'uses' => ['Exporter','String::Strip','strict','vars']},'String-Strip-1.01.tar.gz' => {'author' => 'BPOWERS','description' => 'xs Module to remove white-space from strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 28,'pod' => 40,'pod_errors' => 0,'total' => 68,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2850,'unpacked' => 6625},'testers' => {'fail' => 1,'pass' => 13},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'String-Substrings-0.02.tar.gz' => {'author' => 'BIGJ','description' => 'module to extract some/all substrings from a string','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 74,'pod' => 48,'pod_errors' => 0,'total' => 122,'with_comments' => 1},'releases' => 2,'requires' => ['String-Random-0.198.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-ManyParams-0.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'String::Random' => 0,'Test::Differences' => 0,'Test::Exception' => 0,'Test::ManyParams' => 0,'Test::More' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Set-CrossProduct-1.4.tar.gz','String-Random-0.198.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-ManyParams-0.10.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz'],'size' => {'packed' => 3285,'unpacked' => 7572},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Exporter','strict','warnings']},'String-Thai-Segmentation-0.01.tar.gz' => {'author' => 'ROMERUN','description' => 'an object-oriented interface of Thai word segmentation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 55,'pod' => 46,'pod_errors' => 0,'total' => 101,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 8035,'unpacked' => 20285},'testers' => {},'uses' => ['5.00503','DynaLoader','Exporter','strict','vars']},'String-Tokeniser-0.01.tar.gz' => {'author' => 'SIMON','description' => 'Perl extension for, uhm, tokenising strings.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 202,'pod' => 79,'pod_errors' => 0,'total' => 281,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 3387,'unpacked' => 7055},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','strict','vars']},'String-Trigram-0.1.tar.gz' => {'author' => 'TAREKA','description' => 'Find similar strings by trigram (or 1, 2, 4, etc.-gram) method','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 706,'pod' => 289,'pod_errors' => 0,'total' => 995,'with_comments' => 130},'releases' => 3,'size' => {'packed' => 20663,'unpacked' => 64125},'testers' => {'pass' => 3},'uses' => ['5.6.0','Carp','DynaLoader','Exporter','locale','strict','warnings']},'Struct-Compare-1.0.1.tar.gz' => {'author' => 'ZENSPIDER','description' => 'Recursive diff for perl structures.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 101,'pod' => 57,'pod_errors' => 1,'total' => 158,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 3340,'unpacked' => 8191},'testers' => {'pass' => 10},'uses' => ['Carp','Exporter','constant','strict','vars']},'Sub-Assert-1.20.tar.gz' => {'author' => 'SMUELLER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 318,'pod' => 171,'pod_errors' => 0,'total' => 489,'with_comments' => 0},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Exporter' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5071,'unpacked' => 15857},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Exporter','strict','vars','warnings']},'Sub-Caller-0.60.tar.gz' => {'author' => 'SHAYH','description' => 'Add caller information to the end of @_.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 79,'pod_errors' => 0,'total' => 198,'with_comments' => 16},'releases' => 2,'size' => {'packed' => 3487,'unpacked' => 8656},'testers' => {'pass' => 2},'uses' => ['DynaLoader']},'Sub-Context-0.02.tar.gz' => {'author' => 'CHROMATIC','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 101,'pod' => 105,'pod_errors' => 0,'total' => 206,'with_comments' => 0},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.3'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3802,'unpacked' => 8116},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'Sub-Import-0.5.tar.gz' => {'author' => 'BROQ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 195,'pod' => 133,'pod_errors' => 0,'total' => 328,'with_comments' => 14},'releases' => 1,'requires' => ['Regexp-Common-2.113.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Regexp::Common' => '0.1','Text::Balanced' => '1.83'},'requires_recursive' => ['Regexp-Common-2.113.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 5821,'unpacked' => 13637},'testers' => {'pass' => 3},'uses' => ['Carp','Data::Dumper','IO::File','Regexp::Common','Text::Balanced','UNIVERSAL','strict']},'Sub-Lexical-0.81.tar.gz' => {'author' => 'BROQ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 154,'pod' => 88,'pod_errors' => 0,'total' => 242,'with_comments' => 35},'releases' => 3,'requires' => ['Filter-Simple-0.78.tar.gz','Regexp-Common-2.113.tar.gz'],'requires_module' => {'Filter::Simple' => '0.77','Regexp::Common' => '0.01'},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Regexp-Common-2.113.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 5186,'unpacked' => 13342},'testers' => {'pass' => 3},'uses' => ['Carp','Filter::Simple','Regexp::Common','constant','strict']},'Sub-NamedParams-1.01.tar.gz' => {'author' => 'OVID','description' => 'Perl extension for using named arguments with any sub','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 118,'pod' => 126,'pod_errors' => 0,'total' => 244,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 4234,'unpacked' => 9168},'testers' => {'pass' => 4},'uses' => ['5.005','Carp','Exporter','strict','vars']},'Sub-Parameters-0.03.tar.gz' => {'author' => 'RCLAMP','description' => 'enhanced parmeter handling','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 134,'pod' => 109,'pod_errors' => 0,'total' => 243,'with_comments' => 9},'releases' => 3,'requires' => ['Attribute-Handlers-0.78.tar.gz','Devel-Caller-0.08.tar.gz','Devel-LexAlias-0.04.tar.gz','Hook-LexWrap-0.20.tar.gz','PadWalker-0.09.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => 0,'Devel::Caller' => '0.02','Devel::LexAlias' => '0.01','Hook::LexWrap' => 0,'PadWalker' => '0.05','Test::More' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Devel-Caller-0.08.tar.gz','Devel-LexAlias-0.04.tar.gz','File-Spec-0.82.tar.gz','Hook-LexWrap-0.20.tar.gz','PadWalker-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4134,'unpacked' => 11979},'testers' => {'pass' => 7},'uses' => ['Attribute::Handlers','Carp','Devel::Caller','Devel::LexAlias','Exporter','Hook::LexWrap','PadWalker','strict','warnings']},'Sub-Quotelike-0.03.tar.gz' => {'author' => 'RGARCIA','description' => 'Allow to define quotelike functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 75,'pod_errors' => 0,'total' => 160,'with_comments' => 2},'releases' => 3,'requires' => ['Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Filter::Simple' => '0.61','Text::Balanced' => '1.83'},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3698,'unpacked' => 7306},'testers' => {'pass' => 7},'uses' => ['Exporter','Filter::Simple','Text::Balanced','strict','warnings']},'Sub-Regex-0.02.tar.gz' => {'author' => 'XERN','description' => 'Creating Synonymous Subroutines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 47,'pod' => 25,'pod_errors' => 0,'total' => 72,'with_comments' => 2},'releases' => 2,'requires' => ['Filter-Simple-0.78.tar.gz'],'requires_module' => {'Filter::Simple' => 0},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 1964,'unpacked' => 3086},'testers' => {'pass' => 2},'uses' => ['5.006','AutoLoader','Exporter','Filter::Simple','strict','vars']},'Sub-Uplevel-0.07-2.tar.gz' => {'author' => 'MSCHWERN','description' => 'apparently run a function in a higher stack frame','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1021,'pod' => 651,'pod_errors' => 0,'total' => 1672,'with_comments' => 65},'releases' => 1,'size' => {'packed' => 16922,'unpacked' => 46461},'testers' => {'pass' => 6},'uses' => ['5.006','Exporter','strict','vars']},'Sub-Usage-0.03.tar.gz' => {'author' => 'HASANT','description' => 'Issue subroutine/method usage','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 113,'pod' => 139,'pod_errors' => 0,'total' => 252,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 5045,'unpacked' => 13446},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','strict','warnings']},'Sub-Versive-0.01.tar.gz' => {'author' => 'SIMON','description' => 'Subroutine pre- and post-handlers','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 37,'pod_errors' => 0,'total' => 157,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 2607,'unpacked' => 5417},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['5.6.1','Carp','Devel::Peek','Exporter','strict','warnings']},'SuffixTree-0.03.tar.gz' => {'author' => 'SHLOMOY','description' => 'Efficient string manipulation data structure interface for Perl.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 115,'pod_errors' => 0,'total' => 188,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 24811,'unpacked' => 104903},'testers' => {'pass' => 2},'uses' => ['DynaLoader','Exporter','strict','vars']},'Sun-Solaris-Exacct-1.4.tar.gz' => {'author' => 'SUNCPAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 989,'pod' => 587,'pod_errors' => 0,'total' => 1576,'with_comments' => 236},'releases' => 2,'size' => {'packed' => 34310,'unpacked' => 123203},'testers' => {},'uses' => ['5.6.1','Carp','Exporter','Fcntl','XSLoader','strict','warnings']},'Sun-Solaris-Project-1.5.tar.gz' => {'author' => 'SUNCPAN','description' => 'Access Solaris Projects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 221,'pod' => 109,'pod_errors' => 0,'total' => 330,'with_comments' => 55},'releases' => 1,'size' => {'packed' => 8731,'unpacked' => 24809},'testers' => {},'uses' => ['5.6.1','Exporter','Sun::Solaris::Utils','XSLoader','strict','warnings']},'Sun-Solaris-Task-1.2.tar.gz' => {'author' => 'SUNCPAN','description' => 'Access Solaris Tasks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 60,'pod_errors' => 0,'total' => 102,'with_comments' => 16},'releases' => 1,'size' => {'packed' => 3084,'unpacked' => 6571},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['5.6.1','Exporter','XSLoader','strict','warnings']},'SuperPython-0.91.tar.gz' => {'author' => 'MJD','description' => 'Perl filter module to implement the SuperPython language','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 35,'pod_errors' => 0,'total' => 64,'with_comments' => 5},'releases' => 2,'requires' => ['Filter-Simple-0.78.tar.gz'],'requires_module' => {'Filter::Simple' => '0.5'},'requires_recursive' => ['Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 2055,'unpacked' => 41173},'testers' => {'tests' => '0','unknown' => 18},'uses' => []},'SuperSplit-0.06.tar.gz' => {'author' => 'JEROENES','description' => 'Provides methods to split/join in two or more dimensions','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 334,'pod' => 204,'pod_errors' => 0,'total' => 538,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 6108,'unpacked' => 15183},'testers' => {'pass' => 6},'uses' => ['Carp','Exporter','strict','vars']},'Switch-2.09.tar.gz' => {'author' => 'DCONWAY','description' => 'A switch statement for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 579,'pod' => 278,'pod_errors' => 0,'total' => 857,'with_comments' => 13},'releases' => 10,'requires' => ['Filter-1.29.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Filter::Util::Call' => 0,'Text::Balanced' => 0},'requires_recursive' => ['Filter-1.29.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 12132,'unpacked' => 45200},'testers' => {'pass' => 10},'uses' => ['Carp','Filter::Util::Call','Text::Balanced','strict','vars']},'Sx-2.3.tar.gz' => {'author' => 'FMC','description' => 'Simple Athena widget interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1023,'pod' => 1178,'pod_errors' => 1,'total' => 2201,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 100635,'unpacked' => 380190},'testers' => {},'uses' => ['DynaLoader','Exporter']},'Sybase-Login-1.4.tar.gz' => {'author' => 'BPOWERS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 667,'pod' => 265,'pod_errors' => 0,'total' => 932,'with_comments' => 70},'releases' => 3,'size' => {'packed' => 7138,'unpacked' => 23579},'testers' => {'pass' => 2,'tests' => '0','unknown' => 6},'uses' => ['5.002','Carp','Sybase::DBlib','Tk','Tk::Dialog','strict']},'Sybase-RepAgent-0.03.tar.gz' => {'author' => 'BDULFER','description' => 'Perl extension for building a Sybase Replication Agent which talks to a Sybase Replication Server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 396,'pod' => 683,'pod_errors' => 0,'total' => 1079,'with_comments' => 3},'releases' => 3,'requires' => ['DBD-Sybase-1.00.tar.gz','DBI-1.37.tar.gz'],'requires_module' => {'DBD::Sybase' => '0.91','DBI' => '1.1'},'requires_recursive' => ['DBD-Sybase-1.00.tar.gz','DBI-1.37.tar.gz'],'size' => {'packed' => 11878,'unpacked' => 43485},'testers' => {},'uses' => ['5.006','DBI','Exporter','strict','warnings']},'Sybase-Simple-0.54.tar.gz' => {'author' => 'MEWP','description' => 'Simplified db access using Sybase::CTlib','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 598,'pod' => 131,'pod_errors' => 0,'total' => 729,'with_comments' => 83},'releases' => 5,'size' => {'packed' => 7768,'unpacked' => 25145},'testers' => {},'uses' => ['AutoLoader','Carp','Exporter','Sybase::CTlib','strict','vars']},'Sybase-TdsServer-0.06.tar.gz' => {'author' => 'BDULFER','description' => 'A simple module to create a tds-server (like Sybase or freetds)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1803,'pod' => 799,'pod_errors' => 0,'total' => 2602,'with_comments' => 186},'releases' => 4,'size' => {'packed' => 17974,'unpacked' => 90212},'testers' => {'pass' => 3},'uses' => ['5.005_62','Exporter','IO::Select','IO::Socket','Math::BigInt','Sybase::TdsConstants','constant','strict','warnings']},'Sybase-Xfer-0.1.tar.gz' => {'author' => 'SPRAGST','description' => 'transfer data between Sybase servers via bcp.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1578,'pod' => 768,'pod_errors' => 0,'total' => 2346,'with_comments' => 341},'releases' => 6,'requires' => ['Getopt-Long-2.33.tar.gz','Tie-IxHash-1.21.tar.gz'],'requires_module' => {'Getopt::Long' => 0,'Tie::IxHash' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz','Tie-IxHash-1.21.tar.gz'],'size' => {'packed' => 24260,'unpacked' => 80962},'testers' => {},'uses' => ['5.004','5.005','Carp','Exporter','File::Basename','Getopt::Long','Sybase::DBlib','Tie::IxHash','strict','vars']},'Sybase-Xfer-0.63.tar.gz' => {'author' => 'SPRAGST','description' => 'Transfer data between sybase servers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4220,'pod' => 1032,'pod_errors' => 0,'total' => 5252,'with_comments' => 839},'releases' => 6,'requires' => ['Getopt-Long-2.33.tar.gz','Tie-IxHash-1.21.tar.gz'],'requires_module' => {'Getopt::Long' => 0,'Tie::IxHash' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz','Tie-IxHash-1.21.tar.gz'],'size' => {'packed' => 50580,'unpacked' => 185239},'testers' => {'fail' => 1},'uses' => ['5.004','5.6.1','Carp','DBD::DB2','DBD::DB2::Constants','DBI','Exporter','File::Basename','FileHandle','Getopt::Long','POSIX','Sybase::CTlib','Sybase::DBlib','Sybase::ObjectInfo','Sys::Hostname','Tie::IxHash','lib','strict','vars']},'Symbol-Approx-Sub-2.00.tar.gz' => {'author' => 'DAVECROSS','description' => 'Perl module for calling subroutines by approximate names!','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 443,'pod' => 123,'pod_errors' => 0,'total' => 566,'with_comments' => 156},'releases' => 2,'requires' => ['Devel-Symdump-2.03.tar.gz'],'requires_module' => {'Devel::Symdump' => 0},'requires_recursive' => ['Devel-Symdump-2.03.tar.gz'],'size' => {'packed' => 7540,'unpacked' => 23687},'testers' => {'pass' => 7},'uses' => ['Carp','Devel::Symdump','Text::Metaphone','Text::Soundex','strict','vars']},'Symbol-Callable-0.01.tar.gz' => {'author' => 'XERN','description' => 'Probing callable entries in symbol table','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 18,'pod' => 24,'pod_errors' => 0,'total' => 42,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 1337,'unpacked' => 2029},'testers' => {'pass' => 7},'uses' => ['5.006','Exporter','strict']},'Symbol-Table-1.01.tar.gz' => {'author' => 'GSLONDON','description' => 'OO interface to package symbols','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 383,'pod' => 252,'pod_errors' => 0,'total' => 635,'with_comments' => 31},'releases' => 2,'size' => {'packed' => 6859,'unpacked' => 19880},'testers' => {'pass' => 3},'uses' => ['5.008','Carp','Data::Dumper','strict','warnings']},'Symphero-Data-0.3.tar.gz' => {'author' => 'AMALTSEV','description' => 'low-level data manipulation modules for Symphero E-Commerce suite.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1440,'pod' => 321,'pod_errors' => 1,'total' => 1761,'with_comments' => 488},'releases' => 2,'requires' => ['Error-0.15.tar.gz'],'requires_module' => {'Error' => '0.13'},'requires_recursive' => ['Error-0.15.tar.gz'],'size' => {'packed' => 11541,'unpacked' => 40205},'testers' => {'pass' => 3},'uses' => ['Carp','Devel::CallerItem','Error','Exporter','strict','vars']},'Symphero-Web-0.5.tar.gz' => {'author' => 'AMALTSEV','description' => 'web rendering part of Symphero E-Commerce suite','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7322,'pod' => 723,'pod_errors' => 1,'total' => 8045,'with_comments' => 2068},'releases' => 3,'requires' => ['CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','Mail-Sender-0.8.06.tar.gz','Symphero-Data-0.3.tar.gz'],'requires_module' => {'CGI' => '2.46','DBI' => '1.14','Digest::MD5' => '2.12','Error' => '0.13','Mail::Sender' => '0.7','Symphero::MultiValueDB' => '1.1','Symphero::SimpleHash' => '1.1','Symphero::Utils' => '1.1'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','Mail-Sender-0.8.06.tar.gz','Symphero-Data-0.3.tar.gz'],'size' => {'packed' => 72468,'unpacked' => 252534},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.005','Carp','DBI','Digest::MD5','DynaLoader','Error','Exporter','Mail::Sender','POSIX','Symphero::Defaults','Symphero::MultiValueDB','Symphero::SimpleHash','Symphero::Utils','strict','vars']},'Syndicate-Channel-0.10.tar.gz' => {'author' => 'DRRHO','description' => 'Generalized News Syndication.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2441,'pod' => 538,'pod_errors' => 0,'total' => 2979,'with_comments' => 326},'releases' => 1,'requires' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-RSS-1.02.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XTM-0.35.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => '2.102','File::Basename' => '2.6','File::Spec' => '0.82','HTTP::Status' => '1.26','IO' => '1.2','IO::File' => '1.08','IO::Handle' => '1.21','IO::Seekable' => '1.08','LWP::Simple' => '1.35','Parse::RecDescent' => '1.8','Test::Builder' => '0.13','Test::More' => '0.42','URI' => '1.18','URI::Escape' => '3.2','XML::RSS' => '0.97','XML::SAX' => '0.1','XML::SAX::Base' => '1.02','XML::SAX::ParserFactory' => '1.01','XTM::base' => '0.35'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','MIME-Base64-2.20.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-Iconv-1.2.tar.gz','URI-1.24.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-RSS-1.02.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-Twig-3.10.tar.gz','XML-Writer-0.4.tar.gz','XTM-0.35.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17862,'unpacked' => 79707},'testers' => {'pass' => 1},'uses' => ['AutoLoader','Data::Dumper','Exporter','LWP::Simple','XML::RSS','XTM','XTM::AsTMa','XTM::PSI','XTM::Path','XTM::XML','strict','vars','warnings']},'Syndication-ESF-0.01.tar.gz' => {'author' => 'BRICAS','description' => 'Create and update ESF files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 158,'pod' => 84,'pod_errors' => 0,'total' => 242,'with_comments' => 13},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3610,'unpacked' => 9285},'testers' => {'pass' => 2},'uses' => ['Carp','strict']},'Syndication-NITF-0.02.tar.gz' => {'author' => 'BQUINN','description' => '- Parser for NITF v3.0 documents','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2944,'pod' => 215,'pod_errors' => 0,'total' => 3159,'with_comments' => 724},'releases' => 2,'requires' => ['XML-DOM-1.42.tar.gz'],'requires_module' => {'XML::DOM' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 27545,'unpacked' => 129682},'testers' => {'fail' => 1,'pass' => 2,'tests' => '1'},'uses' => ['Carp','Time::Local','XML::DOM','constant','vars']},'Syndication-NewsML-0.10.tar.gz' => {'author' => 'BQUINN','description' => '- Parser for NewsML documents','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2382,'pod' => 321,'pod_errors' => 0,'total' => 2703,'with_comments' => 450},'releases' => 5,'requires' => ['XML-DOM-1.42.tar.gz'],'requires_module' => {'XML::DOM' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 78168,'unpacked' => 611897},'testers' => {'fail' => 1,'pass' => 2,'tests' => '1'},'uses' => ['Carp','NewsML::AssignmentNode','NewsML::CatalogNode','NewsML::CommentNode','NewsML::DOMUtils','NewsML::DataNode','NewsML::DateNode','NewsML::FormalNameNode','NewsML::IdNode','NewsML::Node','NewsML::OriginNode','NewsML::PartyNode','NewsML::PropertyNode','NewsML::References','NewsML::TopicNode','NewsML::TopicSetNode','NewsML::XmlLangNode','Time::Local','XML::DOM','constant','vars']},'Syntax-Highlight-Perl-1.0.tar.gz' => {'author' => 'JOHNSCA','description' => 'Perform syntax highlighting of Perl code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2515,'pod' => 400,'pod_errors' => 0,'total' => 2915,'with_comments' => 752},'releases' => 1,'size' => {'packed' => 34391,'unpacked' => 128694},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['Carp','Data::Dumper','Exporter','constant','strict','vars']},'Sys-Apm-0.05.tar.gz' => {'author' => 'RLZWART','description' => 'Perl extension for APM','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 81,'pod_errors' => 0,'total' => 150,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 2321,'unpacked' => 4475},'testers' => {'pass' => 1},'uses' => ['strict','warnings']},'Sys-CPU-0.35.tar.gz' => {'author' => 'MZSANFORD','description' => 'Access CPU info. number, etc on Win and UNIX','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 33,'pod' => 30,'pod_errors' => 0,'total' => 63,'with_comments' => 5},'releases' => 7,'size' => {'packed' => 3957,'unpacked' => 10250},'testers' => {'pass' => 3},'uses' => ['DynaLoader','Exporter','strict','vars']},'Sys-CpuLoad-0.03.tar.gz' => {'author' => 'CLINTDW','description' => 'a module to retrieve system load averages.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 27,'pod_errors' => 0,'total' => 96,'with_comments' => 12},'releases' => 3,'size' => {'packed' => 2806,'unpacked' => 5699},'testers' => {'pass' => 5},'uses' => ['AutoLoader','DynaLoader','Exporter','IO::File','strict','vars']},'Sys-Headers-0.01.tar.gz' => {'author' => 'CWEST','description' => 'Perl interface to system headers.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 67,'pod_errors' => 0,'total' => 144,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 2574,'unpacked' => 5434},'testers' => {'pass' => 2},'uses' => ['5.00503','Carp','Config','Cwd','File::Spec::Functions','lib','strict','vars']},'Sys-HostIP-1.0.tar.gz' => {'author' => 'FIVE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 18,'pod_errors' => 0,'total' => 100,'with_comments' => 18},'releases' => 5,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'IO::Socket' => 0,'Sys::Hostname' => 0},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2052,'unpacked' => 4107},'testers' => {'pass' => 6},'uses' => ['Exporter','IO::Socket','Sys::Hostname','vars']},'Sys-Hostname-FQDN-0.01.tar.gz' => {'author' => 'MIKER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 116,'pod_errors' => 0,'total' => 211,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 10407,'unpacked' => 27736},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','vars','warnings']},'Sys-Hostname-Long-1.0.tar.gz' => {'author' => 'SCOTT','description' => 'Return the hosts fully qualified name','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 58,'pod' => 51,'pod_errors' => 0,'total' => 109,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 2286,'unpacked' => 3532},'testers' => {'fail' => 2,'pass' => 4,'tests' => '1'},'uses' => ['Carp','Exporter','Sys::Hostname','strict','vars']},'Sys-Lastlog-1.2.tar.gz' => {'author' => 'JSTOWE','description' => 'Provide a moderately Object Oreiented Interf','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 136,'pod' => 98,'pod_errors' => 0,'total' => 234,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 5125,'unpacked' => 14904},'testers' => {'pass' => 8},'uses' => ['Carp','DynaLoader','strict','vars']},'Sys-Load-0.2.tar.gz' => {'author' => 'BARABAS','description' => 'Perl module for getting the current system load and uptime','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 29,'pod_errors' => 0,'total' => 65,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 1794,'unpacked' => 2755},'testers' => {'pass' => 2},'uses' => ['5.006','DynaLoader','Exporter','constant','strict','warnings']},'Sys-Mmap-0.11.tar.gz' => {'author' => 'SWALTERS','description' => 'uses mmap to map in a file as a Perl variable','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 193,'pod' => 86,'pod_errors' => 0,'total' => 279,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 13448,'unpacked' => 36467},'testers' => {'pass' => 2},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Sys-OutPut-2.1.tar.gz' => {'author' => 'AKSTE','description' => '- Perl module to help make output easier.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 71,'pod' => 55,'pod_errors' => 0,'total' => 126,'with_comments' => 13},'releases' => 3,'size' => {'packed' => 10534,'unpacked' => 30822},'testers' => {'pass' => 2},'uses' => ['Exporter']},'Sys-Ptrace-0.05.tar.gz' => {'author' => 'BBB','description' => 'Perl interface to the ptrace(2) command','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 132,'pod' => 74,'pod_errors' => 0,'total' => 206,'with_comments' => 12},'releases' => 3,'size' => {'packed' => 6311,'unpacked' => 19704},'testers' => {'fail' => 1,'pass' => 1,'tests' => '9'},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Sys-Pushd-0.001.tar.gz' => {'author' => 'JGLICK','description' => 'change directory temporarily','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 32,'pod_errors' => 0,'total' => 61,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 1549,'unpacked' => 2117},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Cwd','strict','vars']},'Sys-Signal-0.02.tar.gz' => {'author' => 'DOUGM','description' => 'Set signal handlers with restoration of existing C sighandler','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 16,'pod' => 28,'pod_errors' => 0,'total' => 44,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2615,'unpacked' => 5216},'testers' => {'fail' => 1,'pass' => 5},'uses' => []},'Sys-UniqueID-1.0.tar.gz' => {'author' => 'FIVE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 21,'pod' => 20,'pod_errors' => 0,'total' => 41,'with_comments' => 1},'releases' => 1,'requires' => ['Sys-HostIP-1.0.tar.gz'],'requires_module' => {'Sys::HostIP' => 0},'requires_recursive' => ['IO-1.20.tar.gz','Sys-HostIP-1.0.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 1592,'unpacked' => 2481},'testers' => {'pass' => 6},'uses' => ['Exporter','Sys::HostIP','strict','vars']},'Sys-Utmp-1.5.tar.gz' => {'author' => 'JSTOWE','description' => 'Object(ish) Interface to UTMP files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 161,'pod_errors' => 1,'total' => 383,'with_comments' => 38},'releases' => 5,'size' => {'packed' => 7282,'unpacked' => 22878},'testers' => {'fail' => 1,'pass' => 6},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'SysConfig-0.2.tar.gz' => {'author' => 'PATRICK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 767,'pod' => 500,'pod_errors' => 3,'total' => 1267,'with_comments' => 104},'releases' => 2,'size' => {'packed' => 8602,'unpacked' => 35951},'testers' => {'pass' => 3},'uses' => ['5.005','Carp','strict','warnings']},'SyslogScan-0.32.tar.gz' => {'author' => 'RHNELSON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2050,'pod' => 844,'pod_errors' => 0,'total' => 2894,'with_comments' => 147},'releases' => 5,'size' => {'packed' => 38302,'unpacked' => 215746},'testers' => {'fail' => 6,'tests' => '28'},'uses' => ['Carp','strict']},'System-Index-0.1.zip' => {'author' => 'JBRYAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 128,'pod' => 74,'pod_errors' => 1,'total' => 202,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 4049,'unpacked' => 8386},'testers' => {'pass' => 3},'uses' => ['5.005_62','Benchmark','Exporter','strict','warnings']},'System2-0.82.tar.gz' => {'author' => 'REICHERT','description' => 'like system(), but with STDOUT, STDERR avail','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 190,'pod' => 48,'pod_errors' => 0,'total' => 238,'with_comments' => 38},'releases' => 3,'size' => {'packed' => 4879,'unpacked' => 10976},'testers' => {'pass' => 8},'uses' => ['AutoLoader','Carp','Exporter','Fcntl','POSIX','strict','vars']},'SystemC-Vregs-1.241.tar.gz' => {'author' => 'WSNYDER','description' => 'Build Registers, Classes, Enums from HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4500,'pod' => 890,'pod_errors' => 10,'total' => 5390,'with_comments' => 772},'releases' => 7,'requires' => ['Bit-Vector-6.3.tar.gz','HTML-TableExtract-1.08.tar.gz','Verilog-Perl-2.224.tar.gz'],'requires_module' => {'Bit::Vector' => 0,'HTML::TableExtract' => 0,'Verilog::Language' => '1.12'},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableExtract-1.08.tar.gz','HTML-Tagset-3.03.tar.gz','Verilog-Perl-2.224.tar.gz'],'size' => {'packed' => 84323,'unpacked' => 420853},'testers' => {'pass' => 1},'uses' => ['Bit::Vector','Bit::Vector::Overload','Carp','Data::Dumper','File::Basename','HTML::TableExtract','IO::File','Verilog::Language','strict','vars']},'SystemPerl-1.142.tar.gz' => {'author' => 'WSNYDER','description' => 'SystemC Netlist','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2985,'pod' => 637,'pod_errors' => 0,'total' => 3622,'with_comments' => 550},'releases' => 15,'requires' => ['Verilog-Perl-2.224.tar.gz'],'requires_module' => {'Verilog::Getopt' => '2.211','Verilog::Netlist' => '2.21'},'requires_recursive' => ['Verilog-Perl-2.224.tar.gz'],'size' => {'packed' => 70564,'unpacked' => 272824},'testers' => {'fail' => 1,'tests' => '43'},'uses' => ['Carp','Class::Struct','DynaLoader','File::Basename','IO::File','Verilog::Netlist','Verilog::Netlist::Subclass','strict','vars']},'TAPORlib-8.70.tar.gz' => {'author' => 'SNEMAROV','description' => 'TAPORlib is a Perl module that contains some useful functions.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1991,'pod' => 445,'pod_errors' => 0,'total' => 2436,'with_comments' => 31},'releases' => 2,'size' => {'packed' => 38747,'unpacked' => 150981},'testers' => {'pass' => 1,'tests' => '0','unknown' => 9},'uses' => ['Carp','Exporter','IO::Select','IO::Socket','POSIX','Socket','strict','vars']},'TDB_File-0.50.tar.gz' => {'author' => 'ANGUSLEES','description' => 'Perl access to the trivial database library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 189,'pod_errors' => 0,'total' => 308,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 8642,'unpacked' => 23830},'testers' => {},'uses' => ['5.006','Carp','DynaLoader','Errno','Exporter','strict','warnings']},'TEI-Lite-0.50.tar.gz' => {'author' => 'DHAGEMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2381,'pod' => 522,'pod_errors' => 0,'total' => 2903,'with_comments' => 728},'releases' => 5,'requires' => ['Exporter-Cluster-0.31.tar.gz','XML-LibXML-1.54.tar.gz'],'requires_module' => {'Exporter::Cluster' => 0,'XML::LibXML' => '1.52'},'requires_recursive' => ['Exporter-Cluster-0.31.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 56646,'unpacked' => 375148},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','Date::Calc','Exporter','Exporter::Cluster','XML::LibXML','strict','warnings']},'TERN-it-0.01.tar.gz' => {'author' => 'DAVIDNICO','description' => 'Perl extension for easing nonautovivifying aggregate accesses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 60,'pod' => 66,'pod_errors' => 0,'total' => 126,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2503,'unpacked' => 4536},'testers' => {'pass' => 3},'uses' => ['5.00000','Exporter','strict','vars']},'TFTP-1.0b3.tar.gz' => {'author' => 'GSM','description' => 'Interface to TFTP (rfc1350)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 352,'pod' => 87,'pod_errors' => 0,'total' => 439,'with_comments' => 63},'releases' => 1,'size' => {'packed' => 5409,'unpacked' => 16229},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['5.001','Socket','Time::localtime','strict','vars']},'TSM_0.60.tar.gz' => {'author' => 'SWORDSMAN','description' => 'Perl extension for the Tivoli Storage Manager','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 305,'pod' => 137,'pod_errors' => 0,'total' => 442,'with_comments' => 101},'releases' => 1,'size' => {'packed' => 5321,'unpacked' => 13722},'testers' => {},'uses' => ['AutoLoader','Carp','Exporter','strict','vars']},'TUI-1.00.tar.gz' => {'author' => 'SBECK','description' => 'User interface based on Term::ReadLine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 380,'pod' => 198,'pod_errors' => 0,'total' => 578,'with_comments' => 48},'releases' => 1,'size' => {'packed' => 5990,'unpacked' => 18282},'testers' => {'pass' => 3,'tests' => '0','unknown' => 6},'uses' => ['5.000','Exporter','Term::ReadLine','Text::Abbrev','strict','vars']},'TUXEDO_1_00.zip' => {'author' => 'AFRYER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 603,'pod' => 464,'pod_errors' => 0,'total' => 1067,'with_comments' => 16},'releases' => 1,'size' => {'packed' => 13770,'unpacked' => 56228},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'TXTCOD-4.7.1-eng.tar.gz' => {'author' => 'ALAMAZ','description' => 'Encoding module using the SAC system.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 380,'pod' => 100,'pod_errors' => 0,'total' => 480,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 7007,'unpacked' => 33713},'testers' => {'tests' => '0','unknown' => 6},'uses' => []},'Table-ParentChild-0.05.tar.gz' => {'author' => 'MIKEWONG','description' => 'Fast lookup for Parent-Child relationships','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 213,'pod' => 79,'pod_errors' => 0,'total' => 292,'with_comments' => 30},'releases' => 1,'size' => {'packed' => 6426,'unpacked' => 19050},'testers' => {'pass' => 2},'uses' => ['5.005_62','5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Table.tar.gz' => {'author' => 'GUYDX','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 263,'pod' => 343,'pod_errors' => 1,'total' => 606,'with_comments' => 4},'releases' => 5,'size' => {'packed' => 52662,'unpacked' => 204572},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Tk::Widget']},'TableMap-1.0.tar.gz' => {'author' => 'DLUX','description' => 'Maps relational tables into hashes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 513,'pod' => 223,'pod_errors' => 4,'total' => 736,'with_comments' => 12},'releases' => 3,'size' => {'packed' => 9013,'unpacked' => 27917},'testers' => {'fail' => 2},'uses' => ['Carp','DBI','Storable','strict','vars']},'TacacsPlus-0.16.tar.gz' => {'author' => 'MSHOYHER','description' => 'Authentication on tacacs+ server','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 87,'pod_errors' => 0,'total' => 193,'with_comments' => 13},'releases' => 3,'size' => {'packed' => 20203,'unpacked' => 67515},'testers' => {'fail' => 5},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Taco-0.04.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Dynamic web page system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1926,'pod' => 1014,'pod_errors' => 0,'total' => 2940,'with_comments' => 194},'releases' => 4,'requires' => ['Tie-LLHash-1.002.tar.gz'],'requires_module' => {'Tie::LLHash' => '0.02'},'requires_recursive' => ['Tie-LLHash-1.002.tar.gz'],'size' => {'packed' => 29988,'unpacked' => 91201},'testers' => {'fail' => 2},'uses' => ['Apache::Constants','Carp','Exporter','IO::File','LWP::UserAgent','Safe','Taco','Taco::Arg','Taco::ServiceRegistry','Tie::LLHash','strict','vars']},'Taint-0.09.tar.gz' => {'author' => 'PHOENIX','description' => 'Utilities related to tainting','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 609,'pod' => 241,'pod_errors' => 0,'total' => 850,'with_comments' => 133},'releases' => 3,'size' => {'packed' => 17096,'unpacked' => 45475},'testers' => {'fail' => 7,'tests' => '77'},'uses' => ['5.004','Carp','Exporter','strict','vars']},'Tangram-2.04.tar.gz' => {'author' => 'JLLEROY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7655,'pod' => 2784,'pod_errors' => 0,'total' => 10439,'with_comments' => 273},'releases' => 10,'requires' => ['DBI-1.37.tar.gz','Set-Object-1.03a.tar.gz'],'requires_module' => {'DBI' => 0,'Set::Object' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Set-Object-1.03a.tar.gz'],'size' => {'packed' => 89399,'unpacked' => 334260},'testers' => {},'uses' => ['','Carp','DBI','Data::Dumper','Exporter','Person','SelfLoader','Set::Object','SpringfieldObject','Tangram','Tangram::AbstractCollExpr','Tangram::Core','Tangram::CursorObject','Tangram::Number','Tangram::RefOnDemand','Tangram::String','constant','integer','strict','vars']},'Tangram-2.06.tar.gz' => {'author' => 'SAMV','description' => 'Object persistence in relational databases','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 8210,'pod' => 2800,'pod_errors' => 0,'total' => 11010,'with_comments' => 294},'releases' => 10,'requires' => ['DBI-1.37.tar.gz','Set-Object-1.03a.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DBI' => 0,'Set::Object' => '1.03','Test::More' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','Set-Object-1.03a.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 98754,'unpacked' => 363877},'testers' => {},'uses' => ['Carp','DBI','Data::Dumper','Date::Manip','Exporter','SelfLoader','Set::Object','Tangram::AbstractArray','Tangram::AbstractHash','Tangram::AbstractSet','Tangram::Array','Tangram::Coll','Tangram::Core','Tangram::Cursor','Tangram::DMDateTime','Tangram::Expr','Tangram::FlatArray','Tangram::FlatHash','Tangram::Hash','Tangram::IntrArray','Tangram::IntrSet','Tangram::PerlDump','Tangram::RawDate','Tangram::RawDateTime','Tangram::RawTime','Tangram::Ref','Tangram::Relational','Tangram::Relational::Engine','Tangram::Scalar','Tangram::Schema','Tangram::Set','Tangram::Storage','Tangram::Type','constant','integer','strict','vars']},'Tanker-0.021.tar.gz' => {'author' => 'SIMONW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 404,'pod' => 221,'pod_errors' => 0,'total' => 625,'with_comments' => 47},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz','Net-IRC-0.73.tar.gz','POE-0.26.tar.gz','POE-Component-IRC-2.9.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Net::IRC' => 0,'POE' => '0.18','POE::Component::IRC' => '1.9'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','IO-1.20.tar.gz','Net-IRC-0.73.tar.gz','POE-0.26.tar.gz','POE-Component-IRC-2.9.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6544,'unpacked' => 18665},'testers' => {},'uses' => ['Data::Dumper','POE','POE::Component::IRC','strict','vars','warnings']},'Tar-0.04.tar.gz' => {'author' => 'CDYBED','description' => 'module for manipulation of tar archives.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 430,'pod' => 73,'pod_errors' => 0,'total' => 503,'with_comments' => 58},'releases' => 4,'size' => {'packed' => 4731,'unpacked' => 12233},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','strict','vars']},'Tasks-1.3.tar.gz' => {'author' => 'SERGEY','description' => 'Module for tasks/projects and time tracking','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 837,'pod' => 97,'pod_errors' => 0,'total' => 934,'with_comments' => 135},'releases' => 3,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '0'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 17222,'unpacked' => 63497},'testers' => {'pass' => 6},'uses' => ['AutoLoader','DynaLoader','Exporter','XML::Parser','strict','vars']},'Tcl-0.71.tar.gz' => {'author' => 'VKON','description' => 'Complete access to Tcl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 246,'pod' => 189,'pod_errors' => 0,'total' => 435,'with_comments' => 28},'releases' => 5,'size' => {'packed' => 12738,'unpacked' => 35000},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','DynaLoader','strict','vars']},'TclTk-b2.tar.gz' => {'author' => 'MICB','description' => 'Complete access to Tk *via Tcl*','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 74,'pod_errors' => 0,'total' => 279,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 4749,'unpacked' => 11859},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['DynaLoader','Exporter','Tcl']},'TeX-DVI-0.101.tar.gz' => {'author' => 'JANPAZ','description' => 'Methods for writing DVI (DeVice Independent)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 468,'pod' => 215,'pod_errors' => 0,'total' => 683,'with_comments' => 7},'releases' => 6,'requires' => ['Font-TFM-0.130.tar.gz'],'requires_module' => {'Font::TFM' => '0.100'},'requires_recursive' => ['Font-TFM-0.130.tar.gz'],'size' => {'packed' => 9172,'unpacked' => 24973},'testers' => {'pass' => 11},'uses' => ['FileHandle','Font::TFM']},'TeX-Hyphen-0.140.tar.gz' => {'author' => 'JANPAZ','description' => '- hyphenate words using TeX\'s patterns','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4946,'pod' => 165,'pod_errors' => 0,'total' => 5111,'with_comments' => 50},'releases' => 11,'size' => {'packed' => 22493,'unpacked' => 49131},'testers' => {'pass' => 7},'uses' => ['strict','vars']},'Telephony-CTPort-1.01.tar.gz' => {'author' => 'VOICET','description' => 'Computer Telephony programming in Perl','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 703,'pod' => 107,'pod_errors' => 0,'total' => 810,'with_comments' => 62},'releases' => 1,'size' => {'packed' => 6189,'unpacked' => 19422},'testers' => {'fail' => 1},'uses' => ['5.005_62','Carp','Cwd','Exporter','IO::Handle','IO::Socket','POSIX','strict','warnings']},'Template-Plugin-Apache-SessionManager-0.01.tar.gz' => {'author' => 'ENRYS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 123,'pod_errors' => 0,'total' => 202,'with_comments' => 2},'releases' => 1,'requires' => ['Apache-SessionManager-0.05.tar.gz','Template-Toolkit-2.10.tar.gz'],'requires_module' => {'Apache::SessionManager' => '0.04','Template' => '2.07'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','Apache-SessionManager-0.05.tar.gz','Template-Toolkit-2.10.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 3123,'unpacked' => 7229},'testers' => {},'uses' => ['','Apache::SessionManager','Template::Plugin','strict','vars']},'Template-Plugin-Cache-0.11.tar.gz' => {'author' => 'PERRIN','description' => 'cache output of templates','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 78,'pod_errors' => 0,'total' => 198,'with_comments' => 29},'releases' => 2,'requires' => ['Cache-Cache-1.02.tar.gz','Template-Toolkit-2.10.tar.gz'],'requires_module' => {'Cache::Cache' => '1.02','Template' => '2.07'},'requires_recursive' => ['Cache-Cache-1.02.tar.gz','Template-Toolkit-2.10.tar.gz'],'size' => {'packed' => 3775,'unpacked' => 12031},'testers' => {'pass' => 1},'uses' => ['','Cache::FileCache','Template::Plugin','strict','vars']},'Template-Plugin-Chump-1.1.tar.gz' => {'author' => 'SIMONW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 155,'pod_errors' => 0,'total' => 245,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 4056,'unpacked' => 11991},'testers' => {'fail' => 1},'uses' => ['Template::Plugin::Filter','Text::Chump','strict','vars']},'Template-Plugin-Clickable-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Make URLs clickable in HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 46,'pod_errors' => 0,'total' => 99,'with_comments' => 0},'releases' => 3,'requires' => ['Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz','URI-Find-0.13.tar.gz'],'requires_module' => {'Template' => '2.07','Test::More' => '0.32','URI::Find' => '0.12'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','URI-Find-0.13.tar.gz'],'size' => {'packed' => 2031,'unpacked' => 4243},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['Template::Plugin','URI::Find','strict','vars']},'Template-Plugin-Comma-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'TT Plugin to commify numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 41,'pod_errors' => 0,'total' => 73,'with_comments' => 0},'releases' => 3,'requires' => ['Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Template' => '2.07','Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1755,'unpacked' => 3318},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['Template::Plugin','strict','vars']},'Template-Plugin-DBI-0.11.tar.gz' => {'author' => 'SAM','description' => 'Template Plugin interface to the DBI.pm module','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 588,'pod' => 153,'pod_errors' => 1,'total' => 741,'with_comments' => 158},'releases' => 3,'requires' => ['DBI-1.37.tar.gz','Template-Toolkit-2.10.tar.gz'],'requires_module' => {'DBI' => 0,'Template' => '1.05'},'requires_recursive' => ['DBI-1.37.tar.gz','Template-Toolkit-2.10.tar.gz'],'size' => {'packed' => 8697,'unpacked' => 43369},'testers' => {'pass' => 4},'uses' => ['','5.004','DBI','Template::Base','Template::Exception','Template::Iterator','Template::Plugin','strict','vars']},'Template-Plugin-FillInForm-0.04.tar.gz' => {'author' => 'MIYAGAWA','description' => 'TT plugin for HTML::FillInForm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 40,'pod' => 41,'pod_errors' => 0,'total' => 81,'with_comments' => 0},'releases' => 4,'requires' => ['HTML-FillInForm-1.02.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTML::FillInForm' => 0,'Template' => '2.07','Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-FillInForm-1.02.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2179,'unpacked' => 4563},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['HTML::FillInForm','Template::Plugin','strict','vars']},'Template-Plugin-HTML-Template-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => 'HTML::Template filter in TT','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 40,'pod_errors' => 0,'total' => 83,'with_comments' => 0},'releases' => 2,'requires' => ['HTML-Template-2.6.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTML::Template' => '2.5','Template' => '2.08','Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Template-2.6.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2086,'unpacked' => 4393},'testers' => {'pass' => 1},'uses' => ['HTML::Template','Template::Plugin::Filter','strict','vars']},'Template-Plugin-Java-0.4.tar.gz' => {'author' => 'RKITOVER','description' => 'Generate Java Classes from XML description files and templates.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1103,'pod' => 503,'pod_errors' => 0,'total' => 1606,'with_comments' => 43},'releases' => 4,'requires' => ['Template-Toolkit-2.10.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'Template' => 0,'XML::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz'],'size' => {'packed' => 18375,'unpacked' => 57085},'testers' => {'pass' => 4},'uses' => ['Carp','DBI','Exporter','File::Basename','IO::File','Template','Template::Constants','Template::Plugin','URI::file','XML::Simple','constant','strict','vars']},'Template-Plugin-Jcode-0.02.tar.gz' => {'author' => 'KURIHARA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 31,'pod_errors' => 0,'total' => 74,'with_comments' => 0},'releases' => 2,'requires' => ['Jcode-0.83.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Jcode' => '0.82','Template' => '2.08','Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Jcode-0.83.tar.gz','MIME-Base64-2.20.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1961,'unpacked' => 3434},'testers' => {'pass' => 2},'uses' => ['Jcode','Template::Plugin','Template::Stash','strict','vars']},'Template-Plugin-MP3-1.02.tar.gz' => {'author' => 'DARREN','description' => undef,'files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 154,'pod_errors' => 0,'total' => 259,'with_comments' => 15},'releases' => 2,'size' => {'packed' => 18578,'unpacked' => 30360},'testers' => {'pass' => 1},'uses' => ['','File::Spec','Template::Plugin','strict','vars']},'Template-Plugin-MobileAgent-0.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'TT interface for HTTP::MobileAgent','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 23,'pod' => 24,'pod_errors' => 0,'total' => 47,'with_comments' => 0},'releases' => 1,'requires' => ['HTTP-MobileAgent-0.16.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTTP::MobileAgent' => '0.04','Template' => '2.08','Test::More' => '0.32'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTTP-MobileAgent-0.16.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 1269,'unpacked' => 1797},'testers' => {'fail' => 2},'uses' => ['HTTP::MobileAgent','Template::Plugin','strict','vars']},'Template-Plugin-Number-Format-1.01.tar.gz' => {'author' => 'DARREN','description' => 'Plugin/filter interface to Number::Format','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 120,'pod_errors' => 0,'total' => 258,'with_comments' => 47},'releases' => 1,'requires' => ['Number-Format-1.45.tar.gz','Template-Toolkit-2.10.tar.gz'],'requires_module' => {'Number::Format' => undef,'Template' => '2.07'},'requires_recursive' => ['Number-Format-1.45.tar.gz','Template-Toolkit-2.10.tar.gz'],'size' => {'packed' => 3801,'unpacked' => 10297},'testers' => {},'uses' => ['Number::Format','Template::Plugin::Filter','strict','vars']},'Template-Plugin-Page-0.10.tar.gz' => {'author' => 'LBROCARD','description' => 'a plugin to help when paging through sets of results','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 138,'pod_errors' => 0,'total' => 197,'with_comments' => 1},'releases' => 1,'requires' => ['Data-Page-0.18.tar.gz','Template-Toolkit-2.10.tar.gz'],'requires_module' => {'Data::Page' => '0.14','Template' => '2.07'},'requires_recursive' => ['Data-Page-0.18.tar.gz','File-Spec-0.82.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3231,'unpacked' => 14180},'testers' => {'pass' => 2},'uses' => ['Data::Page','Template::Plugin','strict','vars']},'Template-Plugin-PerlTidy-0.03.tar.gz' => {'author' => 'BRIAC','description' => 'Perl::Tidy filter for Template Toolkit','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 74,'pod' => 61,'pod_errors' => 0,'total' => 135,'with_comments' => 1},'releases' => 3,'requires' => ['IO-stringy-2.108.tar.gz','Perl-Tidy-20021130.tar.gz','Template-Toolkit-2.10.tar.gz'],'requires_module' => {'IO::Scalar' => 0,'IO::ScalarArray' => 0,'Perl::Tidy' => 0,'Template' => 2},'requires_recursive' => ['IO-stringy-2.108.tar.gz','Perl-Tidy-20021130.tar.gz','Template-Toolkit-2.10.tar.gz'],'size' => {'packed' => 2743,'unpacked' => 6893},'testers' => {'pass' => 2},'uses' => ['','Perl::Tidy','Template::Plugin::Filter','strict','vars']},'Template-Plugin-RSSLite-0.03.tar.gz' => {'author' => 'SENSEI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 27,'pod' => 32,'pod_errors' => 0,'total' => 59,'with_comments' => 1},'releases' => 3,'requires' => ['Template-Toolkit-2.10.tar.gz','XML-RSSLite-0.11.tgz'],'requires_module' => {'Template' => 2,'XML::RSSLite' => '0.11'},'requires_recursive' => ['Template-Toolkit-2.10.tar.gz','XML-RSSLite-0.11.tgz'],'size' => {'packed' => 2943,'unpacked' => 5851},'testers' => {'pass' => 2},'uses' => ['','5.006','Data::Dumper','Template::Plugin','XML::RSSLite','strict','warnings']},'Template-Plugin-Session-0.01.tar.gz' => {'author' => 'ENRYS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 84,'pod' => 151,'pod_errors' => 0,'total' => 235,'with_comments' => 2},'releases' => 1,'requires' => ['Apache-Session-1.54.tar.gz','Template-Toolkit-2.10.tar.gz'],'requires_module' => {'Apache::Session' => '1.54','Template' => '2.07'},'requires_recursive' => ['Apache-Session-1.54.tar.gz','Template-Toolkit-2.10.tar.gz'],'size' => {'packed' => 3647,'unpacked' => 8532},'testers' => {'pass' => 1},'uses' => ['','Apache::Session::Flex','Template::Plugin','strict','vars']},'Template-Plugin-Shuffle-0.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'TT Vmethods for shuffling lists','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 26,'pod_errors' => 0,'total' => 46,'with_comments' => 0},'releases' => 1,'requires' => ['Shuffle-1.4.tgz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Algorithm::Numerical::Shuffle' => '1.4','Template' => '2.08','Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Shuffle-1.4.tgz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1470,'unpacked' => 2378},'testers' => {'pass' => 2},'uses' => ['Algorithm::Numerical::Shuffle','Template::Plugin','Template::Stash','strict','vars']},'Template-Plugin-StickyQuery-0.02.tar.gz' => {'author' => 'KOBAYASI','description' => 'TT plugin for  HTML::StickyQuery','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 35,'pod' => 37,'pod_errors' => 0,'total' => 72,'with_comments' => 0},'releases' => 2,'requires' => ['HTML-StickyQuery-0.11.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTML::StickyQuery' => 0,'Template' => '2.07','Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-StickyQuery-0.11.tar.gz','HTML-Tagset-3.03.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz'],'size' => {'packed' => 1784,'unpacked' => 3302},'testers' => {'pass' => 1},'uses' => ['HTML::StickyQuery','Template::Plugin::Filter','strict','vars']},'Template-Plugin-TagRescue-0.02.tar.gz' => {'author' => 'TANIMOTO','description' => 'TT Plugin to escape html tags except for marked','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 35,'pod_errors' => 0,'total' => 111,'with_comments' => 0},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTML::Parser' => '3.08','Template' => '2.07','Test::More' => '0.32'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2173,'unpacked' => 4879},'testers' => {'pass' => 1},'uses' => ['Apache::Util','HTML::Entities','HTML::Parser','Template::Plugin','strict','vars']},'Template-Plugin-TextToHtml-0.02.tar.gz' => {'author' => 'CWEST','description' => 'Plugin interface to HTML::FromText','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 40,'pod' => 39,'pod_errors' => 0,'total' => 79,'with_comments' => 0},'releases' => 1,'requires' => ['HTML-FromText-1.005.tar.gz','Template-Toolkit-2.10.tar.gz'],'requires_module' => {'HTML::FromText' => '1.005','Template' => '2.0'},'requires_recursive' => ['HTML-FromText-1.005.tar.gz','Template-Toolkit-2.10.tar.gz'],'size' => {'packed' => 1713,'unpacked' => 2961},'testers' => {'pass' => 2},'uses' => ['','5.004','HTML::FromText','Template::Plugin','strict','vars']},'Template-Plugin-Textile-1.01.tar.gz' => {'author' => 'MARKF','description' => 'textile plugin for the Template Toolkit','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 54,'pod_errors' => 0,'total' => 83,'with_comments' => 1},'releases' => 1,'requires' => ['Template-Toolkit-2.10.tar.gz','Text-Textile-0.5.tar.gz'],'requires_module' => {'Template' => '2','Text::Textile' => '0.5'},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Template-Toolkit-2.10.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Textile-0.5.tar.gz'],'size' => {'packed' => 2930,'unpacked' => 6454},'testers' => {'pass' => 2},'uses' => ['Text::Textile','strict','vars','warnings']},'Template-Plugin-XML-LibXML-1.06.tar.gz' => {'author' => 'MARKF','description' => 'XML::LibXML Template Toolkit Plugin','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 396,'pod' => 225,'pod_errors' => 0,'total' => 621,'with_comments' => 148},'releases' => 3,'requires' => ['Template-Toolkit-2.10.tar.gz','XML-LibXML-1.54.tar.gz'],'requires_module' => {'Template' => '2.06','XML::LibXML' => '1.52'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Template-Toolkit-2.10.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13138,'unpacked' => 46203},'testers' => {'pass' => 1},'uses' => ['5.004','Template::Exception','Template::Plugin','XML::LibXML','strict','vars']},'Template-Toolkit-1.07.tar.gz' => {'author' => 'ABW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11202,'pod' => 4589,'pod_errors' => 0,'total' => 15791,'with_comments' => 2733},'releases' => 23,'requires' => ['AppConfig-1.55.tar.gz'],'requires_module' => {'AppConfig' => '1.52'},'requires_recursive' => ['AppConfig-1.55.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 228910,'unpacked' => 817308},'testers' => {'fail' => 2,'pass' => 4,'tests' => '1386'},'uses' => ['','$delmod','5.004','CGI','Exporter','File::Basename','File::Path','Symbol','Template','Template::Constants','Template::Context','Template::Directive','Template::Exception','Template::Filters','Template::Grammar','Template::Iterator','Template::Parser','Template::Plugin','Template::Stash','XML::DOM','XML::RSS','constant','strict','vars']},'Template-Toolkit-2.09.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 26760,'pod' => 17885,'pod_errors' => 0,'total' => 44645,'with_comments' => 6585},'releases' => 23,'requires' => ['AppConfig-1.55.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz'],'requires_module' => {'AppConfig' => '1.52','File::Spec' => '0.8','File::Temp' => '0.12'},'requires_recursive' => ['AppConfig-1.55.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'testers' => {'fail' => 3,'pass' => 2,'tests' => '2494'},'uses' => ['','$delmod','5.004','5.005','CGI','Cwd','DBI','Data::Dumper','DynaLoader','Exporter','File::Basename','File::Path','File::Spec','File::Temp','GD','GD::Graph::area','GD::Graph::bars','GD::Graph::bars3d','GD::Graph::lines','GD::Graph::lines3d','GD::Graph::linespoints','GD::Graph::mixed','GD::Graph::pie','GD::Graph::pie3d','GD::Graph::points','GD::Text','GD::Text::Align','GD::Text::Wrap','Image::Info','Image::Size','Pod::POM','Text::Autoformat','Text::Wrap','XML::DOM','XML::RSS','XML::Simple','XML::XPath','constant','overload','strict','vars']},'Term-ANSIMenu-0.02.tar.gz' => {'author' => 'JADEV','description' => 'An infrastructure for creating menus in ANSI capable terminals','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2846,'pod' => 1136,'pod_errors' => 0,'total' => 3982,'with_comments' => 192},'releases' => 1,'requires' => ['TermReadKey-2.21.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Term::ReadKey' => 0},'requires_recursive' => ['TermReadKey-2.21.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 20471,'unpacked' => 114266},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['5.006','Carp','Term::ReadKey','constant','strict','warnings']},'Term-ANSIScreen-1.40.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Terminal control using ANSI escape sequences','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 373,'pod' => 224,'pod_errors' => 0,'total' => 597,'with_comments' => 25},'releases' => 2,'size' => {'packed' => 8557,'unpacked' => 22956},'testers' => {'pass' => 7},'uses' => ['5.001','Carp','Exporter','strict','vars']},'Term-Cap-1.08.tar.gz' => {'author' => 'JSTOWE','description' => 'Basic termcap: Tgetent, Tputs, Tgoto','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 470,'pod' => 195,'pod_errors' => 1,'total' => 665,'with_comments' => 90},'releases' => 8,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.33'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 9918,'unpacked' => 26269},'testers' => {'pass' => 11},'uses' => ['Carp','strict','vars']},'Term-Clui-1.17.tar.gz' => {'author' => 'PJB','description' => 'Perl module offering a Command-Line User Interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1008,'pod' => 202,'pod_errors' => 0,'total' => 1210,'with_comments' => 101},'releases' => 8,'size' => {'packed' => 20681,'unpacked' => 62305},'testers' => {'pass' => 2},'uses' => ['Exporter']},'Term-EditLine-0.03.tar.gz' => {'author' => 'PHINYX','description' => 'Perl interface to the NetBSD editline lib','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 100,'pod' => 222,'pod_errors' => 0,'total' => 322,'with_comments' => 16},'releases' => 3,'size' => {'packed' => 16244,'unpacked' => 60110},'testers' => {},'uses' => ['AutoLoader','Carp','Exporter','XSLoader','strict','warnings']},'Term-Getch-0.20.zip' => {'author' => 'JBRYAN','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 49,'pod_errors' => 0,'total' => 121,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 2862,'unpacked' => 4339},'testers' => {},'uses' => ['Exporter','Win32::Console','strict']},'Term-Gnuplot-0.5704.tar.gz' => {'author' => 'ILYAZ','description' => 'Draw vector graphics on terminals etc','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1802,'pod' => 2110,'pod_errors' => 0,'total' => 3912,'with_comments' => 111},'releases' => 15,'size' => {'packed' => 486477,'unpacked' => 1874030},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Config','Cwd','DynaLoader','Exporter','File::Basename','File::Spec','Text::ParseWords','Tk::Font']},'Term-InKey-1.02.tar.gz' => {'author' => 'RAZINF','description' => 'Perl extension for clearing the screen and receiving a keystroke.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 234,'pod' => 54,'pod_errors' => 0,'total' => 288,'with_comments' => 3},'releases' => 4,'size' => {'packed' => 3281,'unpacked' => 7231},'testers' => {'pass' => 3},'uses' => ['Exporter','POSIX','Term::Cap','Win32::Console','strict','vars']},'Term-Info-1.1.tar.gz' => {'author' => 'KJALB','description' => 'Terminfo interface (currently just Tput)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 0,'pod_errors' => 0,'total' => 34,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 885,'unpacked' => 1042},'testers' => {'pass' => 7},'uses' => ['5.000','Carp','Exporter']},'Term-Interact-0.44.tar.gz' => {'author' => 'PRL','description' => 'Get Data Interactively From User','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1536,'pod' => 481,'pod_errors' => 5,'total' => 2017,'with_comments' => 144},'releases' => 5,'requires' => ['DateManip-5.42a.tar.gz','File-Spec-0.82.tar.gz','TermReadKey-2.21.tar.gz','Text-Autoformat-1.12.tar.gz'],'requires_module' => {'Date::Manip' => '0.00','File::Spec' => '0.00','Term::ReadKey' => '0.00','Text::Autoformat' => '0.00'},'requires_recursive' => ['DateManip-5.42a.tar.gz','File-Spec-0.82.tar.gz','TermReadKey-2.21.tar.gz','Text-Autoformat-1.12.tar.gz','Text-Reform-1.11.tar.gz'],'size' => {'packed' => 22749,'unpacked' => 93409},'testers' => {'pass' => 8},'uses' => ['Date::Manip','File::Spec','Term::ReadKey','Text::Autoformat','diagnostics','sigtrap','strict','vars']},'Term-Newt-0.01.tar.gz' => {'author' => 'DANIEL','description' => 'Interface to the Newt text windowing library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 723,'pod' => 109,'pod_errors' => 0,'total' => 832,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 11778,'unpacked' => 51063},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Term-ProgressBar-2.03.tar.gz' => {'author' => 'FLUFFY','description' => 'Progress bar in just ASCII / using Term','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1672,'pod' => 839,'pod_errors' => 0,'total' => 2511,'with_comments' => 190},'releases' => 5,'size' => {'packed' => 24270,'unpacked' => 89707},'testers' => {},'uses' => ['','5.005','5.00503','Carp','Class::MethodMaker','Config','Cwd','Env','Exporter','ExtUtils::MakeMaker','Fatal','Fcntl','File::Compare','File::Find','File::Path','File::Spec','FindBin','POSIX','Pipeline::DataFlow','Term::ReadKey','Test','constant','happy','strict','vars']},'Term-Prompt-0.11.tar.gz' => {'author' => 'ALLENS','description' => 'Prompt a user','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 579,'pod' => 202,'pod_errors' => 1,'total' => 781,'with_comments' => 40},'releases' => 11,'requires' => ['TermReadKey-2.21.tar.gz'],'requires_module' => {'Term::ReadKey' => '2.13'},'requires_recursive' => ['TermReadKey-2.21.tar.gz'],'size' => {'packed' => 9555,'unpacked' => 32840},'testers' => {'pass' => 15},'uses' => ['5.002','Carp','Exporter','Term::ReadKey','Text::Wrap','vars']},'Term-Query-2.0.tar.gz' => {'author' => 'AKSTE','description' => 'Table-driven query routine.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1193,'pod' => 391,'pod_errors' => 0,'total' => 1584,'with_comments' => 363},'releases' => 2,'size' => {'packed' => 29681,'unpacked' => 93552},'testers' => {'fail' => 7,'tests' => '0','unknown' => 3},'uses' => ['5.001','Array::PrintCols','Carp','Exporter']},'Term-ReadLine-Gnu-1.14.tar.gz' => {'author' => 'HAYASHI','description' => 'GNU Readline XS library wrapper','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1488,'pod' => 1078,'pod_errors' => 0,'total' => 2566,'with_comments' => 272},'releases' => 18,'size' => {'packed' => 65140,'unpacked' => 237211},'testers' => {'fail' => 1,'pass' => 4,'tests' => '193'},'uses' => ['AutoLoader','Carp','DynaLoader','Term::ReadLine::Gnu::XS','strict','vars']},'Term-ReadLine-Perl-1.0203.tar.gz' => {'author' => 'ILYAZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4198,'pod' => 0,'pod_errors' => 0,'total' => 4198,'with_comments' => 1350},'releases' => 13,'size' => {'packed' => 40904,'unpacked' => 129654},'testers' => {'fail' => 2,'pass' => 17},'uses' => ['Carp','SelfLoader','Term::Cap','Term::ReadKey','strict','vars']},'Term-ReadPassword-0.01.tar.gz' => {'author' => 'PHOENIX','description' => 'Asking the user for a password','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 197,'pod' => 74,'pod_errors' => 0,'total' => 271,'with_comments' => 46},'releases' => 1,'size' => {'packed' => 5645,'unpacked' => 16528},'testers' => {'fail' => 1,'pass' => 10},'uses' => ['Exporter','POSIX','Term::ReadLine','strict','vars']},'Term-Report-1.16.tar.gz' => {'author' => 'SHAYH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 350,'pod' => 135,'pod_errors' => 1,'total' => 485,'with_comments' => 56},'releases' => 8,'requires' => ['Number-Format-1.45.tar.gz','Term-StatusBar-1.16.tar.gz'],'requires_module' => {'Number::Format' => '1.44','Term::StatusBar' => '1.0'},'requires_recursive' => ['Number-Format-1.45.tar.gz','Term-Size-0.2.tar.gz','Term-StatusBar-1.16.tar.gz'],'size' => {'packed' => 6383,'unpacked' => 22049},'testers' => {'pass' => 2},'uses' => ['5.6.0']},'Term-Sample-0.25.zip' => {'author' => 'JBRYAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 907,'pod' => 401,'pod_errors' => 2,'total' => 1308,'with_comments' => 53},'releases' => 1,'size' => {'packed' => 25710,'unpacked' => 87353},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Time::HiRes','Win32::Console','strict']},'Term-Screen-1.02.tar.gz' => {'author' => 'JSTOWE','description' => 'Basic screen + input class (uses Term::Cap)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 474,'pod' => 154,'pod_errors' => 0,'total' => 628,'with_comments' => 43},'releases' => 2,'requires' => ['Term-Cap-1.08.tar.gz'],'requires_module' => {'Term::Cap' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Term-Cap-1.08.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7318,'unpacked' => 18763},'testers' => {'pass' => 2},'uses' => ['Term::Cap','strict','vars']},'Term-Screen-ReadLine-0.33.tar.gz' => {'author' => 'OESTERHOL','description' => 'Term::Screen extended with ReadLine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 294,'pod' => 93,'pod_errors' => 0,'total' => 387,'with_comments' => 14},'releases' => 4,'requires' => ['Term-Screen-1.02.tar.gz'],'requires_module' => {'Term::Screen' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Term-Cap-1.08.tar.gz','Term-Screen-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4464,'unpacked' => 17418},'testers' => {'pass' => 2},'uses' => ['Term::Screen','strict','vars']},'Term-Screen-Wizard-0.56.tar.gz' => {'author' => 'OESTERHOL','description' => 'A wizard on your terminal...','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 566,'pod' => 216,'pod_errors' => 0,'total' => 782,'with_comments' => 7},'releases' => 16,'requires' => ['Term-Screen-1.02.tar.gz','Term-Screen-ReadLine-0.33.tar.gz'],'requires_module' => {'Term::Screen' => 0,'Term::Screen::ReadLine' => '0.33'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Term-Cap-1.08.tar.gz','Term-Screen-1.02.tar.gz','Term-Screen-ReadLine-0.33.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8556,'unpacked' => 29485},'testers' => {},'uses' => ['Term::Screen::ReadLine','strict','vars']},'Term-ScreenColor-1.09.tar.gz' => {'author' => 'RUITTENB','description' => 'terminal control + ANSI color support','files' => ['Makefile.PL'],'lines' => {'nonpod' => 133,'pod' => 83,'pod_errors' => 0,'total' => 216,'with_comments' => 21},'releases' => 2,'size' => {'packed' => 11363,'unpacked' => 30026},'testers' => {'fail' => 2,'tests' => '1'},'uses' => ['Term::Screen']},'Term-Shell-0.01.tar.gz' => {'author' => 'NEILW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1014,'pod' => 682,'pod_errors' => 0,'total' => 1696,'with_comments' => 66},'releases' => 1,'size' => {'packed' => 17596,'unpacked' => 54251},'testers' => {'fail' => 4,'pass' => 11,'tests' => '14'},'uses' => ['Data::Dumper','IO::Select','Term::ReadLine','strict']},'Term-ShellKit-1.002.tar.gz' => {'author' => 'EVO','description' => 'Reusable command-line Perl environment','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1108,'pod' => 580,'pod_errors' => 0,'total' => 1688,'with_comments' => 60},'releases' => 1,'size' => {'packed' => 12540,'unpacked' => 39698},'testers' => {'pass' => 2,'tests' => '0','unknown' => 3},'uses' => ['5.004','Carp','Cwd','DBI','Data::ShowTable','Dumpvalue','File::Find','IO::Handle','Term::ReadLine','Text::ParseWords','strict','vars']},'Term-Size-0.2.tar.gz' => {'author' => 'TIMPX','description' => 'Simple way to get terminal size','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 64,'pod_errors' => 0,'total' => 96,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2755,'unpacked' => 5330},'testers' => {'pass' => 16},'uses' => ['Carp','strict','vars']},'Term-Slang-0.07.tar.gz' => {'author' => 'DANIEL','description' => 'Interface to the S-Lang terminal library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 237,'pod' => 75,'pod_errors' => 0,'total' => 312,'with_comments' => 13},'releases' => 4,'size' => {'packed' => 11019,'unpacked' => 38314},'testers' => {'pass' => 2},'uses' => ['Data::Dumper','DynaLoader','Exporter','Tie::Hash','strict','vars']},'Term-StatusBar-1.16.tar.gz' => {'author' => 'SHAYH','description' => 'Dynamic progress bar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 125,'pod_errors' => 0,'total' => 562,'with_comments' => 53},'releases' => 8,'requires' => ['Term-Size-0.2.tar.gz'],'requires_module' => {'Term::Size' => '.2'},'requires_recursive' => ['Term-Size-0.2.tar.gz'],'size' => {'packed' => 6835,'unpacked' => 23106},'testers' => {'pass' => 2},'uses' => ['5.6.0']},'Term-TtyRec-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'handles ttyrec data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 112,'pod_errors' => 0,'total' => 231,'with_comments' => 2},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'Test::More' => '0.18','Time::HiRes' => '1.2'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 3727,'unpacked' => 9590},'testers' => {'pass' => 1},'uses' => ['Carp','IO::Handle','Time::HiRes','strict','vars']},'Term-Twiddle-2.70.tar.gz' => {'author' => 'SCOTTW','description' => 'twiddles baton while-u-wait for long subrout','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 328,'pod' => 188,'pod_errors' => 0,'total' => 516,'with_comments' => 16},'releases' => 4,'requires' => ['Time-HiRes-1.49.tar.gz'],'requires_module' => {'Time::HiRes' => '1.3'},'requires_recursive' => ['Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 6392,'unpacked' => 17359},'testers' => {'pass' => 2},'uses' => ['5.005','Time::HiRes','strict','vars']},'Term-UI-0.02.tar.gz' => {'author' => 'KANE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 146,'pod_errors' => 0,'total' => 384,'with_comments' => 2},'releases' => 1,'requires' => ['Locale-Maketext-Simple-0.02.tar.gz','Params-Check-0.03.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Locale::Maketext::Simple' => 0,'Params::Check' => 0,'Term::ReadLine' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Locale-Maketext-Simple-0.02.tar.gz','Params-Check-0.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4944,'unpacked' => 14713},'testers' => {'pass' => 1},'uses' => ['Locale::Maketext::Simple','Params::Check','Term::ReadLine','strict','vars']},'Term-VT102-0.78.tar.gz' => {'author' => 'AJWOOD','description' => 'Emulates a colour VT102 terminal in memory','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1626,'pod' => 291,'pod_errors' => 0,'total' => 1917,'with_comments' => 477},'releases' => 6,'size' => {'packed' => 23641,'unpacked' => 94848},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Term-Visual-0.04.tar.gz' => {'author' => 'LUNARTEAR','description' => 'Curses interface with POE for multitasking','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1678,'pod' => 365,'pod_errors' => 0,'total' => 2043,'with_comments' => 210},'releases' => 3,'requires' => ['Curses-1.06.tar.gz','POE-0.26.tar.gz'],'requires_module' => {'Curses' => '','POE' => '0.19'},'requires_recursive' => ['Curses-1.06.tar.gz','POE-0.26.tar.gz'],'size' => {'packed' => 16956,'unpacked' => 74679},'testers' => {'pass' => 2},'uses' => ['Carp','Curses','POE','Symbol','strict','vars','warnings']},'Term-WinConsole-0.01.tar.gz' => {'author' => 'JMVILOMET','description' => 'Perl extension for text based windows management.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1364,'pod' => 322,'pod_errors' => 0,'total' => 1686,'with_comments' => 115},'releases' => 2,'size' => {'packed' => 12081,'unpacked' => 44841},'testers' => {'pass' => 2},'uses' => ['5.005_62','Exporter','strict','vars','warnings']},'Term-WinConsole-0.02.tar.gz' => {'author' => 'JMVILOMET','description' => 'Perl extension for text based windows management.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1364,'pod' => 322,'pod_errors' => 0,'total' => 1686,'with_comments' => 115},'releases' => 2,'size' => {'packed' => 12155,'unpacked' => 44981},'testers' => {'pass' => 5},'uses' => ['5.005_62','Exporter','strict','vars','warnings']},'TermReadKey-2.14.tar.gz' => {'author' => 'KJALB','description' => 'A perl module for simple terminal control','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1010,'pod' => 332,'pod_errors' => 0,'total' => 1342,'with_comments' => 99},'releases' => 18,'size' => {'packed' => 31704,'unpacked' => 111984},'testers' => {'pass' => 7},'uses' => ['AutoLoader','Carp','Config','Cwd','DynaLoader','Exporter']},'TermReadKey-2.21.tar.gz' => {'author' => 'JSTOWE','description' => 'Read keystrokes and change terminal modes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1079,'pod' => 334,'pod_errors' => 0,'total' => 1413,'with_comments' => 104},'releases' => 18,'size' => {'packed' => 34878,'unpacked' => 121624},'testers' => {'fail' => 2,'pass' => 27},'uses' => ['AutoLoader','Carp','Config','Cwd','DynaLoader','Exporter','strict','vars']},'Test-1.24.tar.gz' => {'author' => 'SBURKE','description' => 'Utilities for writing test scripts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 416,'pod' => 342,'pod_errors' => 0,'total' => 758,'with_comments' => 54},'releases' => 25,'requires' => ['Test-Harness-2.29.tar.gz'],'requires_module' => {'Test::Harness' => '1.1601'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 13195,'unpacked' => 33478},'testers' => {'pass' => 5},'uses' => ['5.004','Carp','Exporter','strict']},'Test-Builder-Tester-0.09.tar.gz' => {'author' => 'MARKF','description' => 'test testsuites that have been built with Test::Builder','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 413,'pod' => 178,'pod_errors' => 0,'total' => 591,'with_comments' => 67},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Builder' => '0.12'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8563,'unpacked' => 26579},'testers' => {'pass' => 66},'uses' => ['Carp','Exporter','Symbol','Test::Builder','strict','vars']},'Test-CGI-Untaint-1.01.tar.gz' => {'author' => 'PROFERO','description' => 'Test CGI::Untaint Local Extraction Handlers','files' => ['Makefile.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 131,'pod' => 71,'pod_errors' => 0,'total' => 202,'with_comments' => 24},'releases' => 2,'requires' => ['CGI-Untaint-0.90.tar.gz','Test-Builder-Tester-0.09.tar.gz'],'requires_module' => {'CGI::Untaint' => '0.82','Test::Builder::Tester' => '0.09'},'requires_recursive' => ['CGI-Untaint-0.90.tar.gz','Exporter-Lite-0.01.tar.gz','File-Spec-0.82.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','UNIVERSAL-exports-0.03.tar.gz'],'size' => {'packed' => 3974,'unpacked' => 10010},'testers' => {'pass' => 3},'uses' => ['CGI','CGI::Untaint','Carp','Exporter','strict','vars','warnings']},'Test-Class-0.03.tar.gz' => {'author' => 'ADIE','description' => 'Easily create test classes in an xUnit style.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 439,'pod' => 1047,'pod_errors' => 0,'total' => 1486,'with_comments' => 3},'releases' => 2,'requires' => ['Attribute-Handlers-0.78.tar.gz','Class-ISA-0.32.tar.gz','IO-1.20.tar.gz','Storable-2.07.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.77','Class::ISA' => '0.32','IO::File' => '1.08','Storable' => '2.04','Test::Builder' => '0.15','Test::Builder::Tester' => '0.09','Test::Differences' => '0.43','Test::Exception' => '0.1','Test::More' => '0.44'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Attribute-Handlers-0.78.tar.gz','Class-ISA-0.32.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Storable-2.07.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz'],'size' => {'packed' => 23240,'unpacked' => 79079},'testers' => {'fail' => 2,'pass' => 20,'tests' => '133'},'uses' => ['5.006','Attribute::Handlers','Carp','Class::ISA','Storable','Test::Builder','strict','warnings']},'Test-ClassAPI-0.1.tar.gz' => {'author' => 'ADAMK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 131,'pod' => 27,'pod_errors' => 0,'total' => 158,'with_comments' => 25},'releases' => 1,'requires' => ['Class-Inspector-1.tar.gz','Config-Tiny-1.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Inspector' => 1,'Config::Tiny' => 1,'Test::More' => 0},'requires_recursive' => ['Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','Config-Tiny-1.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9470,'unpacked' => 24516},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Class::Inspector','Config::Tiny','Test::More','UNIVERSAL','strict','vars']},'Test-Cmd-1.05.tar.gz' => {'author' => 'KNIGHT','description' => 'Portable test infrastructure for commands','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1416,'pod' => 865,'pod_errors' => 1,'total' => 2281,'with_comments' => 65},'releases' => 9,'size' => {'packed' => 31104,'unpacked' => 160663},'testers' => {'pass' => 7},'uses' => ['Algorithm::DiffOld','Config','Cwd','Exporter','File::Find','File::Spec','Win32','strict','vars']},'Test-Data-0.92.tar.gz' => {'author' => 'PETDANCE','description' => 'Check data and variable properties and value','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 742,'pod' => 361,'pod_errors' => 0,'total' => 1103,'with_comments' => 7},'releases' => 6,'requires' => ['Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Find' => '0','File::Spec' => '0','List::Util' => '0','Scalar::Util' => '0','Test::Builder' => '0','Test::Builder::Tester' => '0','Test::More' => '0','base' => '0'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7964,'unpacked' => 32948},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['Carp','Exporter','List::Util','Scalar::Util','Test::Builder','strict','vars']},'Test-DatabaseRow-1.00.tar.gz' => {'author' => 'PROFERO','description' => 'simple database tests','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 447,'pod' => 183,'pod_errors' => 0,'total' => 630,'with_comments' => 68},'releases' => 1,'requires' => ['DBI-1.37.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'DBI' => 0,'Test::Builder' => '0.15','Test::Builder::Tester' => '0.09'},'requires_recursive' => ['DBI-1.37.tar.gz','File-Spec-0.82.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10556,'unpacked' => 36489},'testers' => {'pass' => 10},'uses' => ['Carp','Exporter','Regexp::Common','Test::Builder','strict','vars','warnings']},'Test-Debugger-0.14.tar.gz' => {'author' => 'KOLIBRIE','description' => 'Create Test Scripts which Generate Log Files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 508,'pod' => 237,'pod_errors' => 0,'total' => 745,'with_comments' => 42},'releases' => 1,'size' => {'packed' => 8965,'unpacked' => 31520},'testers' => {'pass' => 1},'uses' => ['5.005_03','Exporter','strict','vars']},'Test-Deep-0.06.tar.gz' => {'author' => 'FDALY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2670,'pod' => 413,'pod_errors' => 0,'total' => 3083,'with_comments' => 28},'releases' => 6,'requires' => ['Scalar-List-Utils-1.11.tar.gz','Test-NoWarnings-0.05.tar.gz','Test-Tester-0.06.tar.gz'],'requires_module' => {'List::Util' => '1.09','Scalar::Util' => '1.09','Test::NoWarnings' => '0.02','Test::Tester' => '0.04'},'requires_recursive' => ['Scalar-List-Utils-1.11.tar.gz','Test-NoWarnings-0.05.tar.gz','Test-Tester-0.06.tar.gz'],'size' => {'packed' => 20803,'unpacked' => 88159},'testers' => {'pass' => 1},'uses' => ['Carp','Data::Dumper','Exporter','Scalar::Util','Test::Builder','overload','strict','vars','warnings']},'Test-Differences-0.47.tar.gz' => {'author' => 'RBS','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 297,'pod' => 188,'pod_errors' => 0,'total' => 485,'with_comments' => 19},'releases' => 10,'requires' => ['Text-Diff-0.35.tar.gz'],'requires_module' => {'Text::Diff' => '0.34'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Text-Diff-0.35.tar.gz'],'size' => {'packed' => 8322,'unpacked' => 21671},'testers' => {'pass' => 4},'uses' => ['Carp','Data::Dumper','Exporter','Text::Diff','constant','strict']},'Test-Distribution-1.02.tar.gz' => {'author' => 'MARCEL','description' => 'perform tests on all modules of a distribution','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 124,'pod' => 100,'pod_errors' => 0,'total' => 224,'with_comments' => 2},'releases' => 1,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Find::Rule' => '0.03','Test::More' => '0.45','Test::Pod' => '0.62'},'requires_recursive' => ['File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 4148,'unpacked' => 11444},'testers' => {'pass' => 4},'uses' => ['File::Find::Rule','Test::More','Test::Pod','strict','warnings']},'Test-Easy-0.01.tar.gz' => {'author' => 'DANPEDER','description' => 'Much \'Easy\' than \'Simple\'.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 94,'pod' => 63,'pod_errors' => 0,'total' => 157,'with_comments' => 7},'releases' => 1,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Exporter' => '5.562','strict' => 0,'warnings' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 2602,'unpacked' => 6741},'testers' => {'pass' => 4},'uses' => ['5.005_62','Exporter','strict','warnings']},'Test-Env-0.06.tar.gz' => {'author' => 'BDFOY','description' => 'Test the environment','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 32,'pod_errors' => 0,'total' => 77,'with_comments' => 1},'releases' => 1,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','Test::Builder' => '0','Test::Builder::Tester' => '0','Test::More' => '0','Test::Pod' => '0','Test::Prereq' => '0'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 2020,'unpacked' => 3915},'testers' => {'fail' => 1,'pass' => 1,'tests' => '6'},'uses' => ['Exporter','Test::Builder','strict','vars']},'Test-Exception-0.15.tar.gz' => {'author' => 'ADIE','description' => 'Functions for testing exception-based code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 197,'pod_errors' => 0,'total' => 322,'with_comments' => 1},'releases' => 7,'requires' => ['Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Sub::Uplevel' => '0.06','Test::Builder' => '0.13','Test::Builder::Tester' => '0.08','Test::More' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 7497,'unpacked' => 22536},'testers' => {'pass' => 16},'uses' => ['5.005','Exporter','Sub::Uplevel','Test::Builder','strict','vars','warnings']},'Test-Extreme-0.12.tar.gz' => {'author' => 'ASIMJALIS','description' => 'A perlish unit testing framework','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 381,'pod' => 134,'pod_errors' => 0,'total' => 515,'with_comments' => 7},'releases' => 5,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Exporter' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 4799,'unpacked' => 16741},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','strict','vars']},'Test-FIT-0.11.tar.gz' => {'author' => 'INGY','description' => 'A FIT Test Framework for Perl','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 948,'pod' => 259,'pod_errors' => 0,'total' => 1207,'with_comments' => 29},'releases' => 2,'size' => {'packed' => 15817,'unpacked' => 58219},'testers' => {'pass' => 3},'uses' => ['$self->{path}::$self->{dispatch}','CGI','CGI::Carp','Config','Exporter','ExtUtils::MM_Unix','File::Basename','File::Find','File::Spec','LWP::Simple','Module::Install','Module::Install::Base','YAML','inc::Module::Install','strict','vars']},'Test-File-0.05.tar.gz' => {'author' => 'BDFOY','description' => 'test file attributes through Test::Builder','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 343,'pod' => 99,'pod_errors' => 0,'total' => 442,'with_comments' => 0},'releases' => 1,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Find::Rule' => 0,'Test::Builder' => 0,'Test::Builder::Tester' => 0,'Test::More' => 0,'Test::Pod' => 0,'Test::Prereq' => 0},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Prereq-0.19.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 3160,'unpacked' => 12128},'testers' => {'pass' => 3},'uses' => ['Exporter','Test::Builder','strict','vars']},'Test-HTML-Content-0.03.tar.gz' => {'author' => 'CORION','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 389,'pod' => 109,'pod_errors' => 0,'total' => 498,'with_comments' => 17},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTML::TokeParser' => 0,'Test::Builder' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 9175,'unpacked' => 43832},'testers' => {'fail' => 1,'pass' => 7,'tests' => '180'},'uses' => ['5.005_62','Exporter','HTML::TokeParser','Test::Builder','strict','vars']},'Test-HTTPStatus-0.61.tar.gz' => {'author' => 'BDFOY','description' => 'check an HTTP status','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 88,'pod' => 40,'pod_errors' => 0,'total' => 128,'with_comments' => 1},'releases' => 2,'requires' => ['HTTP-SimpleLinkChecker-1.04.tar.gz','Test-Manifest-0.91.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => undef,'HTTP::SimpleLinkChecker' => undef,'Test::Builder' => undef,'Test::Manifest' => undef,'Test::More' => undef,'URI' => undef},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTTP-SimpleLinkChecker-1.04.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2067,'unpacked' => 4390},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['5.004','Carp','HTTP::SimpleLinkChecker','Test::Builder','URI','constant','strict','vars']},'Test-Harness-2.29.tar.gz' => {'author' => 'PETDANCE','description' => 'Executes perl-style tests','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 3087,'pod' => 1579,'pod_errors' => 0,'total' => 4666,'with_comments' => 122},'releases' => 27,'requires' => ['File-Spec-0.82.tar.gz'],'requires_module' => {'File::Spec' => '0.6'},'requires_recursive' => ['File-Spec-0.82.tar.gz'],'size' => {'packed' => 51738,'unpacked' => 188977},'testers' => {'pass' => 3},'uses' => ['5.004','Benchmark','Carp','Config','Devel::CoreStack','Exporter','POSIX','strict','vars','vmsish','wait.ph']},'Test-Helper-0.002.tar.gz' => {'author' => 'JGLICK','description' => 'easy creation of test scripts','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 88,'pod' => 30,'pod_errors' => 0,'total' => 118,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 2187,'unpacked' => 3702},'testers' => {'pass' => 1,'tests' => '0','unknown' => 15},'uses' => ['Carp','Exporter','IO::File','vars']},'Test-Inline-0.15.tar.gz' => {'author' => 'MSCHWERN','description' => 'Inlining your tests next to the code being tested.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 473,'pod' => 469,'pod_errors' => 0,'total' => 942,'with_comments' => 7},'releases' => 5,'requires' => ['Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Harness' => '1.22','Test::More' => '0.33'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 14074,'unpacked' => 42818},'testers' => {'fail' => 2,'pass' => 34,'tests' => '37'},'uses' => ['5.004','strict','vars']},'Test-LongString-0.02.tar.gz' => {'author' => 'RGARCIA','description' => 'tests strings for equality','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 103,'pod' => 37,'pod_errors' => 0,'total' => 140,'with_comments' => 4},'releases' => 2,'requires' => ['Test-Builder-Tester-0.09.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Builder' => '0.12','Test::Builder::Tester' => '0.09'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2862,'unpacked' => 6216},'testers' => {'pass' => 4},'uses' => ['Exporter','Test::Builder','strict','vars']},'Test-Mail-0.03.tar.gz' => {'author' => 'SKUD','description' => 'Test framework for email applications','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 104,'pod' => 95,'pod_errors' => 1,'total' => 199,'with_comments' => 8},'releases' => 1,'requires' => ['MailTools-1.58.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Mail::Header' => '1.19','Test::More' => '0.18'},'requires_recursive' => ['File-Spec-0.82.tar.gz','MailTools-1.58.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3436,'unpacked' => 7209},'testers' => {'fail' => 5,'pass' => 2,'tests' => '3'},'uses' => ['Carp','Exporter','Mail::Address','Mail::Header','Test::More','strict','vars']},'Test-Manifest-0.91.tar.gz' => {'author' => 'BDFOY','description' => 'configure which test files to run','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 103,'pod' => 77,'pod_errors' => 0,'total' => 180,'with_comments' => 2},'releases' => 6,'requires' => ['ExtUtils-MakeMaker-6.05.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'ExtUtils::MakeMaker' => '6.03','Test::More' => '0'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3079,'unpacked' => 6465},'testers' => {'fail' => 1,'pass' => 119,'tests' => '10'},'uses' => ['Carp','Exporter','File::Spec','Test::Harness','strict','vars']},'Test-ManyParams-0.10.tar.gz' => {'author' => 'BIGJ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 317,'pod' => 243,'pod_errors' => 0,'total' => 560,'with_comments' => 13},'releases' => 10,'requires' => ['Data-Dumper-2.101.tar.gz','Set-CrossProduct-1.4.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Set::CrossProduct' => 0,'Test::Builder' => 0,'Test::Builder::Tester' => 0,'Test::Differences' => 0,'Test::Exception' => 0,'Test::More' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Set-CrossProduct-1.4.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz'],'size' => {'packed' => 9588,'unpacked' => 38191},'testers' => {'pass' => 2},'uses' => ['5.006','Data::Dumper','Exporter','Set::CrossProduct','Test::Builder','strict','warnings']},'Test-MockObject-0.12.tar.gz' => {'author' => 'CHROMATIC','description' => 'Perl extension for emulating troublesome interfaces','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 355,'pod' => 284,'pod_errors' => 0,'total' => 639,'with_comments' => 2},'releases' => 9,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Simple' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 11208,'unpacked' => 31358},'testers' => {'pass' => 16},'uses' => ['Carp','Test::Builder','strict','vars']},'Test-NoWarnings-0.05.tar.gz' => {'author' => 'FDALY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 284,'pod' => 132,'pod_errors' => 0,'total' => 416,'with_comments' => 6},'releases' => 5,'requires' => ['Test-Tester-0.06.tar.gz'],'requires_module' => {'Test::Tester' => '0.06'},'requires_recursive' => ['Test-Tester-0.06.tar.gz'],'size' => {'packed' => 5185,'unpacked' => 15644},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','Test::Builder','strict','vars','warnings']},'Test-Pod-0.95.tar.gz' => {'author' => 'PETDANCE','description' => 'test POD files for errors and warnings','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 107,'pod' => 118,'pod_errors' => 1,'total' => 225,'with_comments' => 8},'releases' => 9,'requires' => ['IO-stringy-2.108.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'IO::Scalar' => '0','Pod::Simple' => '0','Test::Builder::Tester' => '0','Test::More' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 3701,'unpacked' => 7996},'testers' => {'pass' => 18},'uses' => ['5.004','Exporter','Pod::Simple','Test::Builder','constant','strict','vars']},'Test-Prereq-0.19.tar.gz' => {'author' => 'BDFOY','description' => 'check if Makefile.PL has the right pre-requisites','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 352,'pod' => 132,'pod_errors' => 0,'total' => 484,'with_comments' => 18},'releases' => 12,'requires' => ['File-Find-Rule-0.10.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','Module::Build' => '0','Module::CoreList' => '0','Module::Info' => '0','Test::Builder' => '0','Test::Builder::Tester' => '0','Test::Manifest' => '0.91','Test::More' => '0','Test::Pod' => '0.90'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Module-Build-0.19.tar.gz','Module-CoreList-1.91.tar.gz','Module-Info-0.20.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 6901,'unpacked' => 18552},'testers' => {'pass' => 3},'uses' => ['CPAN','Carp','Exporter','ExtUtils::MakeMaker','File::Find::Rule','Module::Build','Module::CoreList','Module::Info','Test::Builder','strict','vars']},'Test-Reporter-1.20.tar.gz' => {'author' => 'FOX','description' => 'sends test results to cpan-testers@perl.org','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1357,'pod' => 378,'pod_errors' => 0,'total' => 1735,'with_comments' => 118},'releases' => 5,'requires' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'File::Spec' => 0,'File::Temp' => 0,'Net::SMTP' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-1.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21844,'unpacked' => 70687},'testers' => {'pass' => 41},'uses' => ['5.002','Carp','Config','Cwd','Exporter','File::Temp','Mac::InternetConfig','Net::SMTP','Time::Local','strict','vars']},'Test-STDmaker-0.05.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6816,'pod' => 5581,'pod_errors' => 13,'total' => 12397,'with_comments' => 934},'releases' => 4,'requires' => ['DataPort-DataFile-0.03.tar.gz','DataPort-FileType-FormDB-0.03.tar.gz','DataPort-Maker-0.03.tar.gz','File-AnySpec-0.03.tar.gz','File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Column-0.01.tar.gz','Text-Replace-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'requires_module' => {'DataPort::DataFile' => '0.02','DataPort::FileType::FormDB' => '0.02','DataPort::Maker' => '0','File::AnySpec' => '0','File::PM2File' => '0','File::Package' => '0','File::SmartNL' => '0','File::SubPM' => '0','File::TestPath' => '0','Test::Tech' => '1.08','Text::Column' => '0','Text::Replace' => '0','Text::Scrub' => '0'},'requires_recursive' => ['DataPort-DataFile-0.03.tar.gz','DataPort-FileType-FormDB-0.03.tar.gz','DataPort-Maker-0.03.tar.gz','File-AnySpec-0.03.tar.gz','File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Column-0.01.tar.gz','Text-Replace-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'size' => {'packed' => 64447,'unpacked' => 338845},'testers' => {},'uses' => ['5.001','Cwd','Data::Dumper','DataPort::FileType::FormDB','DataPort::Maker','File::AnySpec','File::Data','File::Glob','File::PM2File','File::Package','File::SmartNL','File::Spec','File::SubPM','File::TestPath','Getopt::Long','STD::Tester','Test::Harness','Test::Tech','Text::Column','Text::Replace','strict','vars','warnings','warnings::register']},'Test-Signature-1.04.tar.gz' => {'author' => 'SPOON','description' => 'Convenience automated testing of SIGNATUREs','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 3791,'pod' => 193,'pod_errors' => 0,'total' => 3984,'with_comments' => 420},'releases' => 4,'size' => {'packed' => 42835,'unpacked' => 139217},'testers' => {'pass' => 4},'uses' => ['$self->{path}::$self->{dispatch}','5.004','Carp','Config','Exporter','ExtUtils::MM_Unix','File::Find','File::Path','Module::Install','Module::Install::Base','Module::Signature','Socket','Test::Builder','YAML','YAML::Error','YAML::Node','YAML::Transfer','constant','inc::Module::Install','strict','threads::shared','vars']},'Test-Simple-0.47.tar.gz' => {'author' => 'MSCHWERN','description' => 'Basic utilities for writing tests','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1955,'pod' => 1592,'pod_errors' => 0,'total' => 3547,'with_comments' => 73},'releases' => 32,'requires' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz'],'requires_module' => {'File::Spec' => '0.6','Test::Harness' => '2.03'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 45820,'unpacked' => 148701},'testers' => {'fail' => 1,'pass' => 51},'uses' => ['5.004','Carp','Config','Exporter','strict','threads::shared','vars']},'Test-SimpleUnit-1.21.tar.gz' => {'author' => 'GED','description' => 'Simplified Perl unit-testing framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 867,'pod' => 348,'pod_errors' => 0,'total' => 1215,'with_comments' => 193},'releases' => 5,'size' => {'packed' => 20388,'unpacked' => 90272},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Compare','Data::Dumper','Exporter','Fcntl','IO::File','IO::Handle','Scalar::Util','constant','strict','vars','warnings']},'Test-Smoke-1.17.06.tar.gz' => {'author' => 'ABELTJE','description' => 'The Perl core test smoke suite','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3190,'pod' => 1492,'pod_errors' => 0,'total' => 4682,'with_comments' => 174},'releases' => 12,'requires' => ['File-Spec-0.82.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Spec' => '0.82','Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 110463,'unpacked' => 398696},'testers' => {'pass' => 6},'uses' => ['Archive::Tar','Carp','Compress::Zlib','Cwd','Exporter','File::Basename','File::Copy','File::Find','File::Path','File::Spec','MIME::Lite','Mail::Sendmail','Net::FTP','POSIX','Socket','Text::ParseWords','Time::Local','strict','vars']},'Test-Smoke-Database-1.6.tar.gz' => {'author' => 'ALIAN','description' => 'Add / parse /display perl reports smoke database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1482,'pod' => 202,'pod_errors' => 0,'total' => 1684,'with_comments' => 241},'releases' => 5,'requires' => ['CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','GDGraph-1.43.tar.gz','NNTPClient-0.37.tar.gz'],'requires_module' => {'CGI' => 0,'DBI' => 0,'Data::Dumper' => 0,'GD::Graph' => 0,'News::NNTPClient' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','GD-2.07.tar.gz','GDGraph-1.43.tar.gz','GDTextUtil-0.86.tar.gz','NNTPClient-0.37.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 32774,'unpacked' => 281628},'testers' => {'pass' => 2},'uses' => ['CGI','Carp','DBI','Data::Dumper','Exporter','GD::Graph::Data','GD::Graph::colour','GD::Graph::mixed','LWP::Simple','News::NNTPClient','POSIX','strict','vars']},'Test-Tech-0.11.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1597,'pod' => 1097,'pod_errors' => 1,'total' => 2694,'with_comments' => 289},'releases' => 10,'requires' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'requires_module' => {'File::Package' => '0','File::SmartNL' => '0','File::TestPath' => '0','Text::Scrub' => '0'},'requires_recursive' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz','Text-Scrub-0.01.tar.gz'],'size' => {'packed' => 29641,'unpacked' => 123164},'testers' => {'pass' => 1},'uses' => ['5.001','Data::Dumper','Exporter','strict','vars','warnings','warnings::register']},'Test-Tester-0.06.tar.gz' => {'author' => 'FDALY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 522,'pod' => 90,'pod_errors' => 1,'total' => 612,'with_comments' => 13},'releases' => 5,'size' => {'packed' => 6558,'unpacked' => 20211},'testers' => {'pass' => 5},'uses' => ['Config','Exporter','Test::Builder','strict','threads::shared','vars']},'Test-Timestamp-1.2.tar.gz' => {'author' => 'PKENT','description' => 'Create timestamp objects for testing or profiling','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 209,'pod' => 126,'pod_errors' => 0,'total' => 335,'with_comments' => 32},'releases' => 1,'requires' => ['Time-HiRes-1.49.tar.gz'],'requires_module' => {'Time::HiRes' => 0},'requires_recursive' => ['Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 6351,'unpacked' => 20733},'testers' => {'pass' => 4},'uses' => ['Time::HiRes','strict','vars']},'Test-Unit-0.13.tar.gz' => {'author' => 'CLEMBURG','description' => 'Procedural style unit testing interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2877,'pod' => 893,'pod_errors' => 0,'total' => 3770,'with_comments' => 139},'releases' => 8,'size' => {'packed' => 33720,'unpacked' => 117133},'testers' => {'pass' => 5},'uses' => ['$class','5.002','Benchmark','Carp','Config','Exporter','File::Basename','FileHandle','Test::Unit','Test::Unit::Assert','Test::Unit::Exception','Test::Unit::ExceptionError','Test::Unit::ExceptionFailure','Test::Unit::InnerClass','Test::Unit::Test','Test::Unit::TestCase','Test::Unit::TestFailure','Test::Unit::TestListener','Test::Unit::TestLoader','Test::Unit::TestResult','Test::Unit::TestRunner','Test::Unit::TestSuite','Test::Unit::UnitHarness','Test::Unit::tests::SuiteTest','Test::Unit::tests::TornDown','Test::Unit::tests::WasRun','Tk','Tk::BrowseEntry','Tk::Canvas','Tk::Derived','Tk::DialogBox','Tk::ROText','constant','strict','vars']},'Test-Unit-0.14.tar.gz' => {'author' => 'CLEMBURG','description' => 'Procedural style unit testing interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3696,'pod' => 1041,'pod_errors' => 0,'total' => 4737,'with_comments' => 161},'releases' => 8,'size' => {'packed' => 45591,'unpacked' => 149652},'testers' => {'pass' => 3},'uses' => ['$class','5.002','Benchmark','Carp','Config','Exporter','File::Basename','FileHandle','Test::Unit','Test::Unit::Assertion::Scalar','Test::Unit::tests::TornDown','Test::Unit::tests::WasRun','Test::Unit::tests::_SuperClass','Tk','Tk::BrowseEntry','Tk::Canvas','Tk::Derived','Tk::DialogBox','Tk::ROText','constant','strict','vars']},'Test-Unit-0.24.tar.gz' => {'author' => 'ASPIERS','description' => 'the PerlUnit testing framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5384,'pod' => 1487,'pod_errors' => 0,'total' => 6871,'with_comments' => 217},'releases' => 8,'requires' => ['Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','Devel-Symdump-2.03.tar.gz','Error-0.15.tar.gz'],'requires_module' => {'Class::Inner' => 0,'Devel::Symdump' => 0,'Error' => 0,'base' => 1},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','Devel-Symdump-2.03.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 76044,'unpacked' => 263041},'testers' => {'fail' => 8,'pass' => 12,'tests' => '83'},'uses' => ['5.002','Attribute::Handlers','Benchmark','Carp','Class::Inner','Config','Data::Dumper','Devel::Symdump','Error','Exporter','File::Basename','FileHandle','Test::Unit::Assert','Test::Unit::Assertion','Test::Unit::Assertion::Boolean','Test::Unit::Assertion::CodeRef','Test::Unit::Assertion::Regexp','Test::Unit::Assertion::Scalar','Test::Unit::Exception','Test::Unit::Test','Test::Unit::TestCase','Test::Unit::TestRunner','Test::Unit::TestSuite','Test::Unit::UnitHarness','Tk','Tk::BrowseEntry','Tk::Canvas','Tk::Derived','Tk::DialogBox','Tk::ROText','overload','strict','vars']},'Test-Verbose-0.009.tar.gz' => {'author' => 'RBS','description' => 'Run \'make TEST_VERBOSE=1\' on one or more test files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 703,'pod' => 215,'pod_errors' => 0,'total' => 918,'with_comments' => 54},'releases' => 5,'size' => {'packed' => 14294,'unpacked' => 42864},'testers' => {'pass' => 4},'uses' => ['...','Carp','Cwd','Exporter','File::Find','File::Spec','IPC::Open3','strict']},'Test-Version-0.02.zip' => {'author' => 'PARTICLE','description' => 'check for VERSION information in modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 68,'pod_errors' => 0,'total' => 184,'with_comments' => 0},'releases' => 2,'requires' => ['Test-Builder-Tester-0.09.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Builder::Tester' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4930,'unpacked' => 6113},'testers' => {'pass' => 5},'uses' => ['5.006_001','Carp','Exporter','Test::Builder','strict','warnings']},'Test-Warn-0.07.tar.gz' => {'author' => 'BIGJ','description' => 'Perl extension to test methods for warnings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 336,'pod' => 145,'pod_errors' => 0,'total' => 481,'with_comments' => 9},'releases' => 8,'requires' => ['Array-Compare-1.03.tar.gz','File-Spec-0.82.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz','Tree-DAG_Node-1.04.tar.gz'],'requires_module' => {'Array::Compare' => 0,'File::Spec' => 0,'Sub::Uplevel' => 0,'Test::Builder' => '0.13','Test::Builder::Tester' => 0,'Test::Exception' => 0,'Tree::DAG_Node' => 0},'requires_recursive' => ['Array-Compare-1.03.tar.gz','File-Spec-0.82.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tree-DAG_Node-1.04.tar.gz'],'size' => {'packed' => 8829,'unpacked' => 35936},'testers' => {'pass' => 7},'uses' => ['5.006','Array::Compare','Carp','Exporter','Sub::Uplevel','Test::Builder','Tree::DAG_Node','strict','warnings']},'Test-Warn-None-0.02.tar.gz' => {'author' => 'FDALY','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 107,'pod_errors' => 0,'total' => 259,'with_comments' => 2},'releases' => 3,'requires' => ['Test-Tester-0.06.tar.gz'],'requires_module' => {'Test::Tester' => '0.06'},'requires_recursive' => ['Test-Tester-0.06.tar.gz'],'size' => {'packed' => 3428,'unpacked' => 7944},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','Test::Builder','strict','vars','warnings']},'Test-Without-Module-0.06.tar.gz' => {'author' => 'CORION','description' => 'Test fallback behaviour in absence of modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 121,'pod' => 50,'pod_errors' => 0,'total' => 171,'with_comments' => 23},'releases' => 4,'size' => {'packed' => 4671,'unpacked' => 10528},'testers' => {'pass' => 6},'uses' => ['Carp','File::Temp','constant','strict','vars']},'Test-XML-0.06.tar.gz' => {'author' => 'SEMANTICO','description' => 'Compare XML in perl tests','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 520,'pod' => 268,'pod_errors' => 0,'total' => 788,'with_comments' => 53},'releases' => 6,'requires' => ['Test-Simple-0.47.tar.gz','XML-SemanticDiff-0.95.tar.gz'],'requires_module' => {'Test::More' => 0,'XML::SemanticDiff' => '0.95'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Parser-2.31.tar.gz','XML-SemanticDiff-0.95.tar.gz'],'size' => {'packed' => 9197,'unpacked' => 33426},'testers' => {'pass' => 2},'uses' => ['Carp','Test::Builder','Test::More','XML::SAX','XML::SAX::ParserFactory','XML::SAX::Writer','XML::SemanticDiff','XML::Twig','strict','vars','warnings']},'Text-ASCIITable-0.10.tar.gz' => {'author' => 'LUNATIC','description' => 'Prints a \'ASCII-art\' formatted table','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 430,'pod' => 258,'pod_errors' => 0,'total' => 688,'with_comments' => 21},'releases' => 9,'requires' => ['Text-Tabs+Wrap-2001.0929.tar.gz'],'requires_module' => {'Text::Wrap' => '2001.0131'},'requires_recursive' => ['Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 12983,'unpacked' => 43154},'testers' => {'pass' => 3},'uses' => ['Carp','Data::Dumper','Exporter','Text::Wrap','strict']},'Text-Aligner-0.01.tar.gz' => {'author' => 'ANNO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 337,'pod' => 89,'pod_errors' => 0,'total' => 426,'with_comments' => 64},'releases' => 1,'size' => {'packed' => 14907,'unpacked' => 40576},'testers' => {'pass' => 13},'uses' => ['strict','vars','warnings']},'Text-Annotated-Line-0.02.tar.gz' => {'author' => 'WIMV','description' => 'strings with annotation about their origin','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 244,'pod' => 172,'pod_errors' => 0,'total' => 416,'with_comments' => 28},'releases' => 2,'requires' => ['Text-Filter-1.7.tar.gz'],'requires_module' => {'Text::Filter' => '1.7'},'requires_recursive' => ['IO-1.20.tar.gz','Text-Filter-1.7.tar.gz'],'size' => {'packed' => 5171,'unpacked' => 15014},'testers' => {'pass' => 5},'uses' => ['Text::Filter','fields','strict','vars']},'Text-Aspell-0.02.tar.gz' => {'author' => 'HANK','description' => 'Perl interface to the GNU Aspell library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 86,'pod' => 246,'pod_errors' => 0,'total' => 332,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 8597,'unpacked' => 31306},'testers' => {},'uses' => ['DynaLoader','vars']},'Text-Autoformat-1.12.tar.gz' => {'author' => 'DCONWAY','description' => 'Automatic text wrapping and reformatting','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 928,'pod' => 422,'pod_errors' => 1,'total' => 1350,'with_comments' => 58},'releases' => 8,'requires' => ['Text-Reform-1.11.tar.gz'],'requires_module' => {'Text::Reform' => 0},'requires_recursive' => ['Text-Reform-1.11.tar.gz'],'size' => {'packed' => 16658,'unpacked' => 47330},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.005','Carp','Data::Dumper','Exporter','Text::Reform','Text::Tabs','overload','strict','utf','vars']},'Text-Balanced-1.95.tar.gz' => {'author' => 'DCONWAY','description' => 'Extract balanced-delimiter substrings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1430,'pod' => 872,'pod_errors' => 0,'total' => 2302,'with_comments' => 106},'releases' => 22,'size' => {'packed' => 28133,'unpacked' => 104091},'testers' => {'pass' => 7},'uses' => ['5.005','Carp','Exporter','SelfLoader','strict','vars']},'Text-BarGraph-0.3.tar.gz' => {'author' => 'KBAUCOM','description' => 'Generate text bar graph from data in a hash','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 186,'pod' => 48,'pod_errors' => 0,'total' => 234,'with_comments' => 25},'releases' => 3,'size' => {'packed' => 3834,'unpacked' => 9414},'testers' => {'pass' => 1,'tests' => '0','unknown' => 6},'uses' => ['strict','vars']},'Text-BasicTemplate-2.006.1.tar.gz' => {'author' => 'DCARRAWAY','description' => '- Simple lexical text/html/etc template parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1704,'pod' => 570,'pod_errors' => 1,'total' => 2274,'with_comments' => 172},'releases' => 9,'size' => {'packed' => 32391,'unpacked' => 103102},'testers' => {'pass' => 2},'uses' => ['5','AutoLoader','Exporter','Fcntl','re','strict','vars']},'Text-Bastardize-0.06.tar.gz' => {'author' => 'AYRNIEU','description' => 'corrupts text in various ways','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 228,'pod' => 74,'pod_errors' => 0,'total' => 302,'with_comments' => 37},'releases' => 1,'size' => {'packed' => 3467,'unpacked' => 7646},'testers' => {'pass' => 8},'uses' => ['strict']},'Text-BibTeX-0.31.tar.gz' => {'author' => 'GWARD','description' => 'Parse BibTeX files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3567,'pod' => 1899,'pod_errors' => 0,'total' => 5466,'with_comments' => 501},'releases' => 8,'size' => {'packed' => 82679,'unpacked' => 278457},'testers' => {'pass' => 3},'uses' => ['5.004','Carp','DynaLoader','Exporter','IO::File','Text::BibTeX::BibFormat','Text::BibTeX::BibSort','Text::BibTeX::Entry','Text::BibTeX::File','Text::BibTeX::Name','Text::BibTeX::NameFormat','Text::BibTeX::Structure','UNIVERSAL','strict','vars']},'Text-BibTeX-0.34.tar.gz' => {'author' => 'GWARD','description' => 'interface to read and parse BibTeX files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3582,'pod' => 1903,'pod_errors' => 0,'total' => 5485,'with_comments' => 501},'releases' => 8,'size' => {'packed' => 85236,'unpacked' => 287483},'testers' => {'fail' => 1,'pass' => 2,'tests' => '337'},'uses' => ['5.004','Carp','DynaLoader','Exporter','IO::File','Text::BibTeX','UNIVERSAL','strict','vars']},'Text-Bind-0.04.tar.gz' => {'author' => 'EHOOD','description' => 'Bind Perl structures to text files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 343,'pod' => 287,'pod_errors' => 0,'total' => 630,'with_comments' => 68},'releases' => 4,'size' => {'packed' => 6889,'unpacked' => 20095},'testers' => {'pass' => 2},'uses' => ['Carp','FileHandle','strict','vars']},'Text-Brew-0.01.tar.gz' => {'author' => 'DREE','description' => 'An implementation of the Brew edit distance','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 230,'pod' => 125,'pod_errors' => 0,'total' => 355,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 3993,'unpacked' => 11685},'testers' => {'pass' => 7},'uses' => ['Carp','Exporter','constant','strict','vars','warnings']},'Text-CSV-0.01.tar.gz' => {'author' => 'ALANCITT','description' => 'Manipulate comma-separated value strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 354,'pod' => 134,'pod_errors' => 0,'total' => 488,'with_comments' => 118},'releases' => 1,'size' => {'packed' => 4856,'unpacked' => 17704},'testers' => {'pass' => 20},'uses' => ['5.002','AutoLoader','strict','vars']},'Text-CSV_XS-0.23.tar.gz' => {'author' => 'JWIED','description' => 'Fast 8bit clean version of Text::CSV','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 360,'pod' => 226,'pod_errors' => 0,'total' => 586,'with_comments' => 146},'releases' => 11,'size' => {'packed' => 16164,'unpacked' => 56411},'testers' => {'fail' => 1,'pass' => 49},'uses' => ['5.004','strict','vars']},'Text-Capitalize-0.1.tar.gz' => {'author' => 'SYP','description' => 'capitalize strings ("uGly STrIngS" becomes "Cool Strings")','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 33,'pod' => 57,'pod_errors' => 0,'total' => 90,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1388,'unpacked' => 2942},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['5.000','Exporter','strict','vars']},'Text-CharWidth-0.04.tar.gz' => {'author' => 'KUBOTA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 38,'pod' => 40,'pod_errors' => 0,'total' => 78,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 8387,'unpacked' => 21180},'testers' => {'pass' => 2},'uses' => ['5.008','Exporter','XSLoader','strict','warnings']},'Text-Chump-1.01.tar.gz' => {'author' => 'SIMONW','description' => 'a module for parsing Chump like syntax','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 469,'pod' => 310,'pod_errors' => 0,'total' => 779,'with_comments' => 36},'releases' => 2,'size' => {'packed' => 8189,'unpacked' => 27787},'testers' => {'pass' => 7},'uses' => ['Carp','Text::DelimMatch','Tie::IxHash','URI::Find','strict','vars']},'Text-Cipher-1.00.tar.gz' => {'author' => 'CHIA','description' => 'Flexible text cipher class and interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 127,'pod' => 181,'pod_errors' => 1,'total' => 308,'with_comments' => 9},'releases' => 1,'requires' => ['Regexp-Tr-0.05.tar.gz'],'requires_module' => {'Regexp::Tr' => '0.05'},'requires_recursive' => ['Regexp-Tr-0.05.tar.gz'],'size' => {'packed' => 4430,'unpacked' => 10814},'testers' => {'pass' => 2},'uses' => ['Carp','Regexp::Tr','strict','warnings']},'Text-Column-0.01.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1009,'pod' => 564,'pod_errors' => 1,'total' => 1573,'with_comments' => 89},'releases' => 1,'requires' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz'],'requires_module' => {'File::Package' => '0','File::SmartNL' => '0','File::TestPath' => '0','Test::Tech' => '1.08'},'requires_recursive' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz'],'size' => {'packed' => 12873,'unpacked' => 63318},'testers' => {'pass' => 1},'uses' => ['5.001','strict','vars','warnings','warnings::register']},'Text-Context-3.0.tar.gz' => {'author' => 'SIMON','description' => 'Handle highlighting search result context snippets','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 240,'pod' => 41,'pod_errors' => 2,'total' => 281,'with_comments' => 8},'releases' => 5,'size' => {'packed' => 5102,'unpacked' => 12491},'testers' => {'fail' => 2,'tests' => '24'},'uses' => ['Text::Context::EitherSide','constant','strict','warnings']},'Text-Context-EitherSide-1.1.tar.gz' => {'author' => 'SIMON','description' => 'Get n words either side of search keywords','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 107,'pod' => 105,'pod_errors' => 0,'total' => 212,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 4120,'unpacked' => 9597},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','constant','strict','warnings']},'Text-ConvertPlatform-1.00.tar.gz' => {'author' => 'PHILIPM','description' => 'an object class for formatting text between 			different platforms.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 113,'pod' => 34,'pod_errors' => 0,'total' => 147,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 3161,'unpacked' => 6984},'testers' => {'pass' => 5},'uses' => ['strict','vars']},'Text-DHCPparse-0.07.tar.gz' => {'author' => 'JSHEARER','description' => 'Perl extension for parsing dhcpd lease files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 65,'pod_errors' => 0,'total' => 160,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 2938,'unpacked' => 6998},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Text-Diff-0.35.tar.gz' => {'author' => 'RBS','description' => 'Perform diffs on files and record sets','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 794,'pod' => 342,'pod_errors' => 0,'total' => 1136,'with_comments' => 74},'releases' => 8,'requires' => ['Algorithm-Diff-1.15.tar.gz'],'requires_module' => {'Algorithm::Diff' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz'],'size' => {'packed' => 14746,'unpacked' => 46940},'testers' => {'fail' => 1,'pass' => 21,'tests' => '23'},'uses' => ['Algorithm::Diff','Carp','Exporter','constant','strict','utf']},'Text-Document-1.07.tar.gz' => {'author' => 'ASPINELLI','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1109,'pod' => 888,'pod_errors' => 2,'total' => 1997,'with_comments' => 57},'releases' => 2,'requires' => ['Bit-Vector-6.3.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Bit::Vector' => 6,'FileHandle' => 2},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13450,'unpacked' => 59060},'testers' => {'pass' => 4},'uses' => ['Bit::Vector','Compress::Zlib','DB_File','FileHandle','strict','warnings']},'Text-Domain-0.9.tar.gz' => {'author' => 'JSMITH','description' => 'Localization of gettext domain settings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 88,'pod_errors' => 0,'total' => 127,'with_comments' => 1},'releases' => 1,'requires' => ['gettext-1.01.tar.gz'],'requires_module' => {'Locale::gettext' => '1.01'},'requires_recursive' => ['gettext-1.01.tar.gz'],'size' => {'packed' => 1848,'unpacked' => 5277},'testers' => {'pass' => 2},'uses' => ['Exporter','Locale::gettext','vars']},'Text-DoubleMetaphone-0.05.tar.gz' => {'author' => 'MAURICE','description' => 'Convert string to phonetic encoding','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 50,'pod_errors' => 0,'total' => 113,'with_comments' => 4},'releases' => 5,'size' => {'packed' => 10125,'unpacked' => 36518},'testers' => {'pass' => 5},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Text-EP3-1.00.tar.gz' => {'author' => 'GSPIVEY','description' => 'The Extensible Perl PreProcessor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1656,'pod' => 339,'pod_errors' => 0,'total' => 1995,'with_comments' => 366},'releases' => 1,'size' => {'packed' => 23692,'unpacked' => 89420},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','Cwd','Env','Exporter','FileHandle','Getopt::Long','Text::EP3::Verilog','strict','vars']},'Text-EP3-Verilog-1.00.tar.gz' => {'author' => 'GSPIVEY','description' => 'Verilog extension for the EP3 preprocessor.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 326,'pod' => 86,'pod_errors' => 0,'total' => 412,'with_comments' => 73},'releases' => 1,'size' => {'packed' => 5589,'unpacked' => 18600},'testers' => {'fail' => 2},'uses' => ['AutoLoader','Carp','Exporter','strict','vars']},'Text-Echelon-0.02.tar.gz' => {'author' => 'IDORU','description' => 'get random Echelon related words.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 824,'pod' => 78,'pod_errors' => 0,'total' => 902,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 13205,'unpacked' => 31201},'testers' => {'pass' => 4},'uses' => ['strict','vars','warnings']},'Text-EtText-2.2.tar.gz' => {'author' => 'JMASON','description' => 'editable-text format for HTML output','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1787,'pod' => 271,'pod_errors' => 1,'total' => 2058,'with_comments' => 242},'releases' => 4,'size' => {'packed' => 148249,'unpacked' => 472144},'testers' => {'pass' => 6},'uses' => ['Carp','Cwd','File::Path','HTML::Entities','locale','strict','vars']},'Text-ExtractWords-0.05.tar.gz' => {'author' => 'HDIAS','description' => 'Perl extension for extract words from strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 36,'pod' => 37,'pod_errors' => 0,'total' => 73,'with_comments' => 14},'releases' => 5,'size' => {'packed' => 4494,'unpacked' => 11286},'testers' => {'pass' => 2},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Text-FIGlet-1.06.tar.gz' => {'author' => 'JPIERCE','description' => 'a perl module to provide FIGlet abilities, akin to banner','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 261,'pod' => 161,'pod_errors' => 0,'total' => 422,'with_comments' => 14},'releases' => 5,'size' => {'packed' => 25175,'unpacked' => 93379},'testers' => {'pass' => 2},'uses' => ['5','Carp','File::Basename','File::Spec','Text::Wrap','strict','vars']},'Text-FastTemplate-0.95.tar.gz' => {'author' => 'BOZZIO','description' => 'Perl subs from line-oriented templates','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 974,'pod' => 407,'pod_errors' => 1,'total' => 1381,'with_comments' => 165},'releases' => 5,'size' => {'packed' => 16173,'unpacked' => 49024},'testers' => {'pass' => 11},'uses' => ['5.005_05','Carp','Cwd','Data::Dumper','constant','integer','strict','vars']},'Text-FillIn-0.05.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Fill-in text templates','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 406,'pod' => 240,'pod_errors' => 0,'total' => 646,'with_comments' => 27},'releases' => 5,'size' => {'packed' => 10154,'unpacked' => 27126},'testers' => {'pass' => 7},'uses' => ['Carp','FileHandle','strict','vars']},'Text-Filter-1.7.tar.gz' => {'author' => 'JV','description' => 'base class for objects that can read and write text lines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 326,'pod' => 236,'pod_errors' => 0,'total' => 562,'with_comments' => 11},'releases' => 4,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO' => 0},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 7447,'unpacked' => 24445},'testers' => {'pass' => 3},'uses' => ['Carp','IO','strict','vars']},'Text-Filter-Chain-0.02.tar.gz' => {'author' => 'WIMV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 77,'pod_errors' => 0,'total' => 210,'with_comments' => 14},'releases' => 2,'requires' => ['Text-Filter-1.7.tar.gz'],'requires_module' => {'Text::Filter' => '1.7'},'requires_recursive' => ['IO-1.20.tar.gz','Text-Filter-1.7.tar.gz'],'size' => {'packed' => 3864,'unpacked' => 9409},'testers' => {'pass' => 5},'uses' => ['fields','strict','vars']},'Text-FixedLength-0.12.tar.gz' => {'author' => 'DIONALM','description' => 'Parse and create fixed length field records','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 189,'pod' => 99,'pod_errors' => 0,'total' => 288,'with_comments' => 63},'releases' => 2,'size' => {'packed' => 4424,'unpacked' => 15425},'testers' => {'pass' => 4},'uses' => ['Exporter','strict']},'Text-FixedLength-Extra-1.1.tar.gz' => {'author' => 'TBONE','description' => 'various niceties for Text::FixedLength lovers.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 139,'pod' => 96,'pod_errors' => 0,'total' => 235,'with_comments' => 18},'releases' => 3,'requires' => ['Text-FixedLength-0.12.tar.gz'],'requires_module' => {'Text::FixedLength' => '0.12'},'requires_recursive' => ['Text-FixedLength-0.12.tar.gz'],'size' => {'packed' => 3460,'unpacked' => 7535},'testers' => {'pass' => 3},'uses' => ['5.005_62','Exporter','Text::FixedLength','strict','warnings']},'Text-Flowchart-1.00.tar.gz' => {'author' => 'JIMT','description' => 'ASCII Flowchart maker','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 884,'pod' => 586,'pod_errors' => 1,'total' => 1470,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 12584,'unpacked' => 46694},'testers' => {'pass' => 7},'uses' => ['Carp']},'Text-Flowchart-Script-0.02.tar.gz' => {'author' => 'XERN','description' => 'Scripting language for Text::Flowchart','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 475,'pod' => 91,'pod_errors' => 0,'total' => 566,'with_comments' => 67},'releases' => 1,'requires' => ['IO-stringy-2.108.tar.gz','Parse-Yapp-1.05.tar.gz','llg-1.07.tar.gz'],'requires_module' => {'IO::Scalar' => '0','Lex' => '0','Parse::Yapp::Driver' => '1.05'},'requires_recursive' => ['IO-stringy-2.108.tar.gz','Parse-Yapp-1.05.tar.gz','llg-1.07.tar.gz'],'size' => {'packed' => 5261,'unpacked' => 18132},'testers' => {'fail' => 1},'uses' => ['5.006','Exporter','IO::Scalar','Lex','Parse::Yapp::Driver','Text::Flowchart','strict','vars']},'Text-Flowed-0.14.tar.gz' => {'author' => 'PMAK','description' => 'text formatting routines for RFC2646 format=flowed','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 202,'pod' => 61,'pod_errors' => 0,'total' => 263,'with_comments' => 53},'releases' => 4,'size' => {'packed' => 4165,'unpacked' => 10789},'testers' => {'pass' => 13},'uses' => ['Exporter','strict','vars']},'Text-Forge-2.15.tar.gz' => {'author' => 'MAURICE','description' => 'templating system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 598,'pod' => 519,'pod_errors' => 0,'total' => 1117,'with_comments' => 31},'releases' => 2,'requires' => ['Class-Accessor-0.18.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'Class::Accessor::Fast' => 0,'File::Spec' => 0,'HTML::Entities' => 0,'Test::More' => 0,'URI::Escape' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14590,'unpacked' => 36830},'testers' => {'pass' => 3},'uses' => ['','Apache::Constants','CGI','Carp','Class::Accessor::Fast','DynaLoader','Mail::Send','strict','vars']},'Text-Format0.52+NWrap0.11.tar.gz' => {'author' => 'GABOR','description' => 'a simple text wrapping module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 795,'pod' => 261,'pod_errors' => 0,'total' => 1056,'with_comments' => 37},'releases' => 1,'size' => {'packed' => 12395,'unpacked' => 43923},'testers' => {'pass' => 2},'uses' => ['5.003','Carp','Text::Format','strict','vars']},'Text-Format0.52.tar.gz' => {'author' => 'GABOR','description' => 'Advanced paragraph formatting','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 746,'pod' => 217,'pod_errors' => 0,'total' => 963,'with_comments' => 37},'releases' => 1,'size' => {'packed' => 11661,'unpacked' => 41591},'testers' => {},'uses' => ['5.003','Carp','strict','vars']},'Text-FormatTable-1.00.tar.gz' => {'author' => 'DSCHWEI','description' => 'Format text tables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 384,'pod' => 69,'pod_errors' => 0,'total' => 453,'with_comments' => 23},'releases' => 2,'size' => {'packed' => 4337,'unpacked' => 13084},'testers' => {'pass' => 7},'uses' => ['Carp','strict','vars']},'Text-GenderFromName-0.2.tar.gz' => {'author' => 'JONO','description' => undef,'files' => [],'lines' => {'nonpod' => 125,'pod' => 46,'pod_errors' => 0,'total' => 171,'with_comments' => 69},'releases' => 4,'size' => {'packed' => 29911,'unpacked' => 108368},'testers' => {'pass' => 5},'uses' => ['Exporter']},'Text-German-0.03.tar.gz' => {'author' => 'ULPFR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2093,'pod' => 19,'pod_errors' => 0,'total' => 2112,'with_comments' => 248},'releases' => 2,'size' => {'packed' => 13081,'unpacked' => 51120},'testers' => {'pass' => 11},'uses' => ['Exporter']},'Text-Glob-0.05.tar.gz' => {'author' => 'RCLAMP','description' => 'match globbing patterns against text','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 99,'pod' => 83,'pod_errors' => 0,'total' => 182,'with_comments' => 3},'releases' => 5,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2987,'unpacked' => 7631},'testers' => {'pass' => 39},'uses' => ['Exporter','constant','strict','vars']},'Text-Graphics-1.0001.tar.gz' => {'author' => 'SFARRELL','description' => 'Graphics rendering toolkit with text output','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 689,'pod' => 152,'pod_errors' => 1,'total' => 841,'with_comments' => 173},'releases' => 2,'requires' => ['Text-Wrapper-1.000.tar.gz'],'requires_module' => {'Text::Wrapper' => '0.007'},'requires_recursive' => ['Text-Wrapper-1.000.tar.gz'],'size' => {'packed' => 6236,'unpacked' => 21889},'testers' => {'pass' => 9},'uses' => ['Carp','Exporter','Text::Wrapper','strict','vars']},'Text-Header-1.03.tar.gz' => {'author' => 'NWIGER','description' => 'Content-independent RFC 822 header functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 117,'pod_errors' => 0,'total' => 233,'with_comments' => 35},'releases' => 2,'size' => {'packed' => 4719,'unpacked' => 13687},'testers' => {'pass' => 11},'uses' => ['5.004','Exporter','strict','vars']},'Text-Hyphenate-0.02.tar.gz' => {'author' => 'MJD','description' => 'Perl extension for blah blah blah','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 4759,'pod' => 31,'pod_errors' => 0,'total' => 4790,'with_comments' => 16},'releases' => 2,'size' => {'packed' => 19074,'unpacked' => 40076},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Text-Iconv-1.2.tar.gz' => {'author' => 'MPIOTR','description' => 'Interface to iconv codeset conversion','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 47,'pod_errors' => 0,'total' => 92,'with_comments' => 8},'releases' => 3,'size' => {'packed' => 6455,'unpacked' => 15424},'testers' => {'fail' => 4,'pass' => 26,'tests' => '14'},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Text-Ispell-0.04.tar.gz' => {'author' => 'JDPORTER','description' => 'a module encapsulating access to the Ispell program.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 379,'pod' => 171,'pod_errors' => 0,'total' => 550,'with_comments' => 20},'releases' => 4,'size' => {'packed' => 7958,'unpacked' => 27075},'testers' => {'pass' => 6},'uses' => ['Carp','Exporter','FileHandle','IPC::Open2','strict','vars']},'Text-JavE-0.0.1.tar.gz' => {'author' => 'OSFAMERON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 13,'pod_errors' => 0,'total' => 190,'with_comments' => 16},'releases' => 1,'size' => {'packed' => 7162,'unpacked' => 50065},'testers' => {'pass' => 4},'uses' => ['strict']},'Text-Kakasi-2.04.tar.gz' => {'author' => 'DANKOGAI','description' => 'perl frontend to kakasi','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 363,'pod' => 278,'pod_errors' => 0,'total' => 641,'with_comments' => 63},'releases' => 4,'size' => {'packed' => 22990,'unpacked' => 71656},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars','warnings']},'Text-Label-Prepender-1.0.tar.gz' => {'author' => 'TBONE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 91,'pod' => 63,'pod_errors' => 0,'total' => 154,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 2920,'unpacked' => 5684},'testers' => {'pass' => 1},'uses' => ['5.006','Exporter','strict','warnings']},'Text-Levenshtein-0.03.tar.gz' => {'author' => 'DREE','description' => 'An implementation of the Levenshtein edit distance','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 31,'pod_errors' => 0,'total' => 116,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2275,'unpacked' => 4563},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Text-LevenshteinXS-0.01.tar.gz' => {'author' => 'DREE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 35,'pod_errors' => 0,'total' => 74,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2680,'unpacked' => 5591},'testers' => {'pass' => 3},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Text-LineEditor-0.03.tar.gz' => {'author' => 'GOSSAMER','description' => 'simple line editor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 36,'pod_errors' => 1,'total' => 171,'with_comments' => 30},'releases' => 2,'size' => {'packed' => 2967,'unpacked' => 6638},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Exporter','Term::ReadLine','strict','vars']},'Text-Macro-0.07.tgz' => {'author' => 'MARAIST','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 443,'pod' => 184,'pod_errors' => 0,'total' => 627,'with_comments' => 100},'releases' => 7,'size' => {'packed' => 12796,'unpacked' => 42977},'testers' => {'pass' => 5},'uses' => ['5.006','IO::File','fields','integer','strict','warnings']},'Text-MacroScript-1.37.tar.gz' => {'author' => 'SUMMER','description' => 'A macro pre-processor with embedded perl capability','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 842,'pod' => 832,'pod_errors' => 0,'total' => 1674,'with_comments' => 153},'releases' => 7,'size' => {'packed' => 36902,'unpacked' => 128960},'testers' => {'pass' => 3},'uses' => ['5.004','Carp','Cwd','integer','strict','vars']},'Text-Macros-0.04.tar.gz' => {'author' => 'JDPORTER','description' => 'template macro expander (OO)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 193,'pod_errors' => 0,'total' => 367,'with_comments' => 10},'releases' => 3,'size' => {'packed' => 7077,'unpacked' => 23251},'testers' => {'pass' => 9},'uses' => ['strict','vars']},'Text-MagicTemplate-1.31.tar.gz' => {'author' => 'DOMIZIO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 193,'pod' => 1040,'pod_errors' => 4,'total' => 1233,'with_comments' => 8},'releases' => 15,'size' => {'packed' => 16847,'unpacked' => 59565},'testers' => {'pass' => 10},'uses' => ['5.005','Carp','Text::MagicTemplate','Text::MagicTemplate::Utilities','strict']},'Text-MagicTemplate-2.05.tar.gz' => {'author' => 'DOMIZIO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 275,'pod' => 1689,'pod_errors' => 0,'total' => 1964,'with_comments' => 4},'releases' => 15,'size' => {'packed' => 26061,'unpacked' => 96881},'testers' => {'fail' => 3,'pass' => 4,'tests' => '17'},'uses' => ['5.005','Carp','strict']},'Text-MagicTemplateX-HTML-1.05.tar.gz' => {'author' => 'DOMIZIO','description' => 'HTML extensions for Text::MagicTemplate used in a HTML environment.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 282,'pod_errors' => 0,'total' => 321,'with_comments' => 0},'releases' => 6,'requires' => ['HTML-FillInForm-1.02.tar.gz','HTML-TableTiler-1.05.tar.gz','Text-MagicTemplate-2.05.tar.gz'],'requires_module' => {'HTML::FillInForm' => 1,'HTML::TableTiler' => 1,'Text::MagicTemplate' => 2},'requires_recursive' => ['HTML-FillInForm-1.02.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableTiler-1.05.tar.gz','HTML-Tagset-3.03.tar.gz','Text-MagicTemplate-2.05.tar.gz'],'size' => {'packed' => 4558,'unpacked' => 14942},'testers' => {'fail' => 4,'pass' => 3,'tests' => '4'},'uses' => ['Text::MagicTemplate','strict']},'Text-Merge-0.34.tar.gz' => {'author' => 'SHARRIS','description' => 'v.0.34 General purpose text/data merging methods in Perl.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 945,'pod' => 459,'pod_errors' => 0,'total' => 1404,'with_comments' => 49},'releases' => 10,'size' => {'packed' => 44104,'unpacked' => 174775},'testers' => {'pass' => 12},'uses' => ['AutoLoader','FileHandle','strict']},'Text-MessageFormat-0.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Language neutral way to display messages','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 101,'pod' => 45,'pod_errors' => 0,'total' => 146,'with_comments' => 0},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'requires_module' => {'Test::More' => '0.32','Text::Balanced' => '1.89'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 2606,'unpacked' => 5832},'testers' => {'pass' => 2},'uses' => ['Text::Balanced','Text::MessageFormat::Element','strict','vars']},'Text-MessageLibrary-0.15.tar.gz' => {'author' => 'JCLYMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 221,'pod' => 237,'pod_errors' => 0,'total' => 458,'with_comments' => 27},'releases' => 1,'size' => {'packed' => 7108,'unpacked' => 19689},'testers' => {},'uses' => ['Carp','strict','vars','warnings']},'Text-MetaMarkup-0.01.tar.gz' => {'author' => 'JUERD','description' => 'Simple structured POD/Wiki-ish markup','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 423,'pod' => 319,'pod_errors' => 0,'total' => 742,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 6508,'unpacked' => 22353},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['','5.006','Carp','URI','strict']},'Text-MetaText-0.22.tar.gz' => {'author' => 'ABW','description' => 'Text processing/markup meta-language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2960,'pod' => 1266,'pod_errors' => 0,'total' => 4226,'with_comments' => 1082},'releases' => 3,'requires' => ['TimeDate-1.16.tar.gz'],'requires_module' => {'Date::Format' => 0},'requires_recursive' => ['TimeDate-1.16.tar.gz'],'size' => {'packed' => 87700,'unpacked' => 290402},'testers' => {'fail' => 9,'tests' => '35'},'uses' => ['5.004','Date::Format','FileHandle','constant','strict','vars']},'Text-Metaphone-1.96.tar.gz' => {'author' => 'MSCHWERN','description' => 'A modern soundex. Phonetic encoding of words','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 70,'pod_errors' => 0,'total' => 129,'with_comments' => 1},'releases' => 6,'size' => {'packed' => 10192,'unpacked' => 26694},'testers' => {'pass' => 12,'tests' => '0','unknown' => 3},'uses' => ['DynaLoader','Exporter','integer','strict','vars']},'Text-Metaphone-Amharic-0.09.tar.gz' => {'author' => 'DYACOB','description' => 'The Metaphone Algorithm for Amharic.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 368,'pod' => 115,'pod_errors' => 0,'total' => 483,'with_comments' => 56},'releases' => 9,'requires' => ['Regexp-Ethiopic-0.12.tar.gz'],'requires_module' => {'Regexp::Ethiopic' => '0.06'},'requires_recursive' => ['Regexp-Ethiopic-0.12.tar.gz'],'size' => {'packed' => 9261,'unpacked' => 28023},'testers' => {'pass' => 2},'uses' => ['Regexp::Ethiopic::Amharic','strict','utf','vars']},'Text-MicroMason-1.04.tar.gz' => {'author' => 'EVO','description' => 'Simplified HTML::Mason Templating','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 307,'pod' => 410,'pod_errors' => 0,'total' => 717,'with_comments' => 36},'releases' => 2,'size' => {'packed' => 10164,'unpacked' => 33094},'testers' => {'pass' => 10},'uses' => ['Carp','Safe','strict','vars']},'Text-Munge-Vowels-0.5.1.tar.gz' => {'author' => 'RRWO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 102,'pod' => 46,'pod_errors' => 0,'total' => 148,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 2742,'unpacked' => 6117},'testers' => {'pass' => 6},'uses' => ['5.000','Carp','Exporter','vars']},'Text-NLP-0.1.tar.gz' => {'author' => 'ALIZTA','description' => 'Perl module for Natural Language Processing =head1 DESCRIPTION Initial release, documentation and updates will follow.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 38,'pod_errors' => 0,'total' => 260,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2471,'unpacked' => 5516},'testers' => {'pass' => 8},'uses' => ['Data::Dumper','strict']},'Text-Netstring-0.04.tar.gz' => {'author' => 'JRAFTERY','description' => 'Create and manipulate netstrings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 150,'pod' => 74,'pod_errors' => 0,'total' => 224,'with_comments' => 23},'releases' => 4,'size' => {'packed' => 3985,'unpacked' => 11280},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'Text-Ngram-0.03.tar.gz' => {'author' => 'SIMON','description' => 'Basis for n-gram analysis','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 76,'pod_errors' => 0,'total' => 154,'with_comments' => 3},'releases' => 3,'size' => {'packed' => 9466,'unpacked' => 25940},'testers' => {'pass' => 3},'uses' => ['5.006','Exporter','XSLoader','strict','warnings']},'Text-Ngrams-0.04.tar.gz' => {'author' => 'VLADO','description' => 'Flexible Ngram analysis (for characters, words, and more)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 358,'pod' => 333,'pod_errors' => 0,'total' => 691,'with_comments' => 16},'releases' => 4,'size' => {'packed' => 10962,'unpacked' => 32258},'testers' => {'pass' => 1},'uses' => ['Exporter','strict','vars']},'Text-Number-0.80.tar.gz' => {'author' => 'FIXLER','description' => 'Overloaded class for printing numbers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 287,'pod' => 143,'pod_errors' => 0,'total' => 430,'with_comments' => 11},'releases' => 2,'size' => {'packed' => 5169,'unpacked' => 13648},'testers' => {'pass' => 7},'uses' => ['Exporter','POSIX','constant','strict','vars']},'Text-Orientation-0.04.tar.gz' => {'author' => 'XERN','description' => 'Text Rotator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 186,'pod' => 73,'pod_errors' => 0,'total' => 259,'with_comments' => 17},'releases' => 4,'requires' => ['String-Multibyte-1.05.tar.gz'],'requires_module' => {'String::Multibyte' => '1'},'requires_recursive' => ['String-Multibyte-1.05.tar.gz'],'size' => {'packed' => 3556,'unpacked' => 8602},'testers' => {'pass' => 9},'uses' => ['5.006','String::Multibyte']},'Text-Oyster-0.32.tar.gz' => {'author' => 'MCKAY','description' => 'evaluate perl code embedded in text.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 220,'pod' => 107,'pod_errors' => 0,'total' => 327,'with_comments' => 20},'releases' => 6,'requires' => ['Parse-Tokens-0.27.tar.gz'],'requires_module' => {'Parse::Tokens' => '0.17'},'requires_recursive' => ['Parse-Tokens-0.27.tar.gz'],'size' => {'packed' => 3185,'unpacked' => 7420},'testers' => {'pass' => 8},'uses' => ['Carp','strict','vars']},'Text-PDF-0.25.tar.gz' => {'author' => 'MHOSKEN','description' => 'Inherits from L<Text::PDF::String> and stores PDF names (things beginning with /)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 3688,'pod' => 873,'pod_errors' => 3,'total' => 4561,'with_comments' => 227},'releases' => 20,'requires' => ['Compress-Zlib-1.22.tar.gz'],'requires_module' => {'Compress::Zlib' => 0},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz'],'size' => {'packed' => 58843,'unpacked' => 190911},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['$t','Compress::Zlib','Exporter','Font::TTF::Font','IO::File','strict','vars']},'Text-ParagraphDiff-2.20.tar.gz' => {'author' => 'JRYAN','description' => 'Visual Difference for paragraphed text.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 437,'pod' => 89,'pod_errors' => 0,'total' => 526,'with_comments' => 16},'releases' => 8,'requires' => ['Algorithm-Diff-1.15.tar.gz','HTML-Parser-3.28.tar.gz'],'requires_module' => {'Algorithm::Diff' => '1.1','HTML::Entities' => 1},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz'],'size' => {'packed' => 8141,'unpacked' => 46225},'testers' => {'pass' => 6},'uses' => ['Algorithm::Diff','Data::Dumper','Exporter','POSIX','strict','vars','warnings']},'Text-PhraseDistance-0.02.tar.gz' => {'author' => 'DREE','description' => 'A measure of the degree of proximity of 2 given phrases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 313,'pod' => 174,'pod_errors' => 0,'total' => 487,'with_comments' => 13},'releases' => 2,'size' => {'packed' => 5407,'unpacked' => 16137},'testers' => {'pass' => 7},'uses' => ['Carp','Exporter','strict','vars','warnings']},'Text-Pspell-0.03.tar.gz' => {'author' => 'HANK','description' => 'Perl interface to the Pspell library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 153,'pod_errors' => 0,'total' => 226,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 6858,'unpacked' => 22928},'testers' => {},'uses' => ['DynaLoader','vars']},'Text-Query-0.07.tar.gz' => {'author' => 'EBOHLMAN','description' => 'Query processing framework','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1494,'pod' => 676,'pod_errors' => 0,'total' => 2170,'with_comments' => 314},'releases' => 2,'size' => {'packed' => 13127,'unpacked' => 70811},'testers' => {'pass' => 2},'uses' => ['5.005','Carp','re','strict','vars']},'Text-Query-Advanced-0.05.tar.gz' => {'author' => 'EBOHLMAN','description' => 'Match text against Boolean expression','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 280,'pod' => 168,'pod_errors' => 0,'total' => 448,'with_comments' => 16},'releases' => 4,'size' => {'packed' => 5909,'unpacked' => 16179},'testers' => {'pass' => 2},'uses' => ['strict']},'Text-Query-SQL-0.09.tar.gz' => {'author' => 'LDACHARY','description' => 'Base class for SQL query builders','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1011,'pod' => 252,'pod_errors' => 0,'total' => 1263,'with_comments' => 246},'releases' => 6,'size' => {'packed' => 19670,'unpacked' => 85820},'testers' => {},'uses' => ['Carp','Data::Dumper','Text::Query::Build','Text::Query::Solve','strict','vars']},'Text-Query-Simple-0.03.tar.gz' => {'author' => 'EBOHLMAN','description' => 'Match text against simple query expression and return relevance value for ranking','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 157,'pod' => 105,'pod_errors' => 0,'total' => 262,'with_comments' => 11},'releases' => 2,'size' => {'packed' => 4512,'unpacked' => 11055},'testers' => {'pass' => 2},'uses' => ['5.005','re','strict']},'Text-Quote-0.3.tar.gz' => {'author' => 'YVES','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 641,'pod' => 195,'pod_errors' => 0,'total' => 836,'with_comments' => 100},'releases' => 1,'requires' => ['Carp-Assert-0.17.tar.gz','Compress-Zlib-1.22.tar.gz','MIME-Base64-2.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Carp::Assert' => '0.13','Compress::Zlib' => '1.16','MIME::Base64' => '2.12','Test::More' => '0.41'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Compress-Zlib-1.22.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12068,'unpacked' => 30796},'testers' => {'fail' => 1,'pass' => 7,'tests' => '52'},'uses' => ['Carp::Assert','Compress::Zlib','Data::Dumper','MIME::Base64','strict','vars','warnings','warnings::register']},'Text-Quoted-1.2.tar.gz' => {'author' => 'SIMON','description' => 'Extract the structure of a quoted mail message','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 216,'pod' => 51,'pod_errors' => 0,'total' => 267,'with_comments' => 40},'releases' => 3,'requires' => ['Text-Autoformat-1.12.tar.gz'],'requires_module' => {'Text::Autoformat' => 0},'requires_recursive' => ['Text-Autoformat-1.12.tar.gz','Text-Reform-1.11.tar.gz'],'size' => {'packed' => 6211,'unpacked' => 20251},'testers' => {'pass' => 2},'uses' => ['5.006','Exporter','Text::Tabs','strict','warnings']},'Text-RecordParser-0.03.tar.gz' => {'author' => 'KCLARK','description' => 'read record-oriented files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 513,'pod' => 287,'pod_errors' => 0,'total' => 800,'with_comments' => 26},'releases' => 3,'size' => {'packed' => 10329,'unpacked' => 42359},'testers' => {'pass' => 2},'uses' => ['Carp','IO::Scalar','Text::ParseWords','strict','vars']},'Text-Refer-1.106.tar.gz' => {'author' => 'ERYQ','description' => 'Parse refer(1)-style bibliography files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 526,'pod' => 486,'pod_errors' => 0,'total' => 1012,'with_comments' => 76},'releases' => 1,'size' => {'packed' => 32185,'unpacked' => 93401},'testers' => {'pass' => 7},'uses' => ['Carp','strict','vars']},'Text-Reflow-1.04.tar.gz' => {'author' => 'MWARD','description' => 'Perl module for reflowing text files using Knuth\'s paragraphing algorithm.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 675,'pod' => 141,'pod_errors' => 0,'total' => 816,'with_comments' => 126},'releases' => 4,'size' => {'packed' => 15354,'unpacked' => 55727},'testers' => {'pass' => 3},'uses' => ['5.005_62','Carp','DynaLoader','Exporter','integer','strict','vars','warnings']},'Text-Reform-1.11.tar.gz' => {'author' => 'DCONWAY','description' => 'Manual text wrapping and reformatting','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 953,'pod' => 909,'pod_errors' => 0,'total' => 1862,'with_comments' => 28},'releases' => 5,'size' => {'packed' => 20902,'unpacked' => 69896},'testers' => {'pass' => 5},'uses' => ['5.005','Carp','Exporter','POSIX','TeX::Hyphen','strict','vars']},'Text-Replace-0.01.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 810,'pod' => 588,'pod_errors' => 1,'total' => 1398,'with_comments' => 53},'releases' => 1,'requires' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz'],'requires_module' => {'File::Package' => '0','File::SmartNL' => '0','File::TestPath' => '0','Test::Tech' => '1.08'},'requires_recursive' => ['File-PM2File-0.04.tar.gz','File-SmartNL-0.02.tar.gz','File-TestPath-0.01.tar.gz'],'size' => {'packed' => 10801,'unpacked' => 53545},'testers' => {'pass' => 1},'uses' => ['5.001','strict','vars','warnings','warnings::register']},'Text-Repository-1.04.tar.gz' => {'author' => 'DARREN','description' => 'A simple way to manage text without mixing it with Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 247,'pod' => 158,'pod_errors' => 0,'total' => 405,'with_comments' => 33},'releases' => 1,'size' => {'packed' => 6335,'unpacked' => 20545},'testers' => {'pass' => 3},'uses' => ['Carp','File::Spec','IO::File','constant','strict','subs','vars']},'Text-Roman-3.01.tar.gz' => {'author' => 'SYP','description' => 'Converts roman algarism in integer numbers and the contrary, recognize algarisms.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 184,'pod' => 75,'pod_errors' => 0,'total' => 259,'with_comments' => 13},'releases' => 4,'size' => {'packed' => 2925,'unpacked' => 8683},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['5.000','Exporter']},'Text-Scan-0.15.tar.gz' => {'author' => 'IWOODHEAD','description' => 'Fast text search for large number of keys','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 731,'pod' => 127,'pod_errors' => 0,'total' => 858,'with_comments' => 7},'releases' => 11,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.43'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 52191,'unpacked' => 180034},'testers' => {'fail' => 1,'pass' => 2,'tests' => '572'},'uses' => ['5.005_62','ExtUtils::Embed','Inline','strict','vars','warnings']},'Text-ScriptTemplate-0.07.tar.gz' => {'author' => 'TAIY','description' => 'Lightweight full-featured template processor','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 193,'pod' => 217,'pod_errors' => 0,'total' => 410,'with_comments' => 13},'releases' => 2,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'FileHandle' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 7149,'unpacked' => 24660},'testers' => {'pass' => 6},'uses' => ['Carp','FileHandle','strict','vars']},'Text-Scrub-0.01.tar.gz' => {'author' => 'SOFTDIA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 656,'pod' => 327,'pod_errors' => 0,'total' => 983,'with_comments' => 60},'releases' => 1,'requires' => ['File-PM2File-0.04.tar.gz'],'requires_module' => {'File::Package' => '0'},'requires_recursive' => ['File-PM2File-0.04.tar.gz'],'size' => {'packed' => 9416,'unpacked' => 40526},'testers' => {'pass' => 2},'uses' => ['5.001','SelfLoader','strict','vars','warnings','warnings::register']},'Text-Shellwords-1.02.tar.gz' => {'author' => 'LDS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 34,'pod_errors' => 0,'total' => 73,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 2162,'unpacked' => 4531},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'Text-Shift-1.00.tar.gz' => {'author' => 'CHIA','description' => 'Perform shift mappings on text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 125,'pod_errors' => 0,'total' => 274,'with_comments' => 28},'releases' => 1,'requires' => ['Crypt-Cipher-0.03.tar.gz'],'requires_module' => {'Crypt::Cipher' => '0.02'},'requires_recursive' => ['Crypt-Cipher-0.03.tar.gz','Regexp-Tr-0.05.tar.gz','Text-Cipher-1.00.tar.gz'],'size' => {'packed' => 4050,'unpacked' => 8791},'testers' => {'pass' => 1},'uses' => ['5.008','Carp','Crypt::Cipher','integer','strict','warnings']},'Text-Shoebox-0.22.tar.gz' => {'author' => 'SBURKE','description' => '- read and write SIL Shoebox Standard Format (.sf) files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 410,'pod' => 129,'pod_errors' => 0,'total' => 539,'with_comments' => 74},'releases' => 2,'size' => {'packed' => 8181,'unpacked' => 21557},'testers' => {'pass' => 2},'uses' => ['5','Carp','Exporter','integer','strict','vars']},'Text-Shortcuts-0.02.tar.gz' => {'author' => 'MUNCHIE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 104,'pod' => 87,'pod_errors' => 0,'total' => 191,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 3324,'unpacked' => 7188},'testers' => {'pass' => 3},'uses' => ['Text::xSV','strict']},'Text-SimpleTemplate-0.36.tar.gz' => {'author' => 'TAIY','description' => 'Template for dynamic text generation','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 161,'pod_errors' => 0,'total' => 313,'with_comments' => 17},'releases' => 6,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'FileHandle' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 6140,'unpacked' => 19840},'testers' => {'pass' => 6},'uses' => ['Carp','FileHandle','strict','vars']},'Text-Soundex-3.02.tar.gz' => {'author' => 'MARKM','description' => 'Encode a string as a soundex value.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 163,'pod' => 88,'pod_errors' => 0,'total' => 251,'with_comments' => 34},'releases' => 7,'size' => {'packed' => 8606,'unpacked' => 23622},'testers' => {'fail' => 1,'pass' => 12},'uses' => ['5.006','Carp','strict']},'Text-Starfish-0.04.tar.gz' => {'author' => 'VLADO','description' => 'Yet another embedded Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 809,'pod' => 347,'pod_errors' => 0,'total' => 1156,'with_comments' => 81},'releases' => 2,'size' => {'packed' => 16130,'unpacked' => 64577},'testers' => {'pass' => 2},'uses' => ['$Text::Starfish::Sfish_conf_dir::starfish.conf','Carp','Exporter','strict','vars']},'Text-Striphigh-0.02.tar.gz' => {'author' => 'JPC','description' => 'Perl extension to strip the high bit off of ISO-8859-1 text.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 38,'pod_errors' => 0,'total' => 199,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 3626,'unpacked' => 6877},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'Text-T9-1.0.tar.gz' => {'author' => 'CADE','description' => 'Text in 9 keys (T9) input.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 72,'pod_errors' => 0,'total' => 111,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 9003,'unpacked' => 21898},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','strict','warnings']},'Text-TWikiFormat-SAX-0.03.tar.gz' => {'author' => 'ALGDR','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 516,'pod' => 24,'pod_errors' => 0,'total' => 540,'with_comments' => 37},'releases' => 3,'requires' => ['HTML-Parser-3.28.tar.gz','Test-Exception-0.15.tar.gz','Test-Simple-0.47.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'HTML::Parser' => 0,'Test::Exception' => 0,'Test::More' => 0,'XML::SAX::Base' => 0,'XML::SAX::DocumentLocator' => 0,'XML::SAX::Writer' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8059,'unpacked' => 38558},'testers' => {'pass' => 1},'uses' => ['HTML::Parser','XML::SAX::Base','XML::SAX::DocumentLocator','XML::SAX::Writer','strict','vars']},'Text-Table-0.05.tar.gz' => {'author' => 'ANNO','description' => 'Organize Data in Tables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 635,'pod' => 320,'pod_errors' => 0,'total' => 955,'with_comments' => 77},'releases' => 5,'requires' => ['Text-Aligner-0.01.tar.gz'],'requires_module' => {'Text::Aligner' => '0.01'},'requires_recursive' => ['Text-Aligner-0.01.tar.gz'],'size' => {'packed' => 20992,'unpacked' => 60110},'testers' => {'pass' => 10},'uses' => ['Carp','Text::Aligner','strict','vars','warnings']},'Text-Tabs+Wrap-2001.0929.tar.gz' => {'author' => 'MUIR','description' => 'Wraps lines to make simple paragraphs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 215,'pod' => 93,'pod_errors' => 0,'total' => 308,'with_comments' => 4},'releases' => 10,'size' => {'packed' => 7557,'unpacked' => 20983},'testers' => {'pass' => 17},'uses' => ['Exporter','re','strict','vars']},'Text-TabularDisplay-1.18.tar.gz' => {'author' => 'DARREN','description' => 'Display text in formatted table output','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 313,'pod' => 236,'pod_errors' => 0,'total' => 549,'with_comments' => 86},'releases' => 2,'size' => {'packed' => 13557,'unpacked' => 53033},'testers' => {'pass' => 3},'uses' => ['integer','strict','vars']},'Text-TagTemplate-1.6.tar.gz' => {'author' => 'MATISSE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 871,'pod' => 543,'pod_errors' => 1,'total' => 1414,'with_comments' => 128},'releases' => 4,'size' => {'packed' => 28697,'unpacked' => 95418},'testers' => {'pass' => 4},'uses' => ['5.004','English','Exporter','IO::File','strict','vars']},'Text-Templar-2.42.tar.gz' => {'author' => 'GED','description' => 'An object-oriented text templating system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4128,'pod' => 1682,'pod_errors' => 0,'total' => 5810,'with_comments' => 1011},'releases' => 6,'requires' => ['Class-Translucent-1.18.tar.gz','Data-Dumper-2.101.tar.gz','IO-1.20.tar.gz','Parse-RecDescent-1.94.tar.gz','Scalar-List-Utils-1.11.tar.gz'],'requires_module' => {'Class::Translucent' => '1.18','Data::Dumper' => 0,'IO::File' => 0,'IO::Handle' => 0,'Parse::RecDescent' => 0,'Scalar::Util' => 0},'requires_recursive' => ['Class-Translucent-1.18.tar.gz','Data-Dumper-2.101.tar.gz','IO-1.20.tar.gz','Parse-RecDescent-1.94.tar.gz','Scalar-List-Utils-1.11.tar.gz','Text-Balanced-1.95.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 70891,'unpacked' => 313199},'testers' => {'pass' => 9},'uses' => ['5.006','Carp','Class::Translucent','Data::Dumper','Exporter','IO::File','IO::Handle','Scalar::Util','Text::Templar::Exception','Text::Templar::Parser','constant','strict','vars','warnings']},'Text-Template-1.44.tar.gz' => {'author' => 'MJD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1035,'pod' => 1057,'pod_errors' => 0,'total' => 2092,'with_comments' => 51},'releases' => 13,'size' => {'packed' => 43481,'unpacked' => 138994},'testers' => {'pass' => 4},'uses' => ['5.004','Carp','Exporter','strict','vars']},'Text-TemplateFill-1.7.tar.gz' => {'author' => 'ADDW','description' => 'Formatting of reports with templates from files, use for I18N','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 786,'pod' => 255,'pod_errors' => 0,'total' => 1041,'with_comments' => 193},'releases' => 1,'requires' => ['Math-Expression-1.14.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Math::Expression' => 1,'POSIX' => 0,'Time::Local' => 0},'requires_recursive' => ['Math-Expression-1.14.tar.gz','Time-Local-1.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 22147,'unpacked' => 73784},'testers' => {'pass' => 3},'uses' => ['Exporter','Math::Expression','POSIX','vars']},'Text-Textile-0.5.tar.gz' => {'author' => 'TOMI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 401,'pod' => 32,'pod_errors' => 0,'total' => 433,'with_comments' => 72},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'HTML::Entities' => undef,'Test::Simple' => undef},'requires_recursive' => ['File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5849,'unpacked' => 16581},'testers' => {'pass' => 3},'uses' => ['Exporter','HTML::Entities','strict','warnings']},'Text-Thesaurus-ISO-1.0.tar.gz' => {'author' => 'MHAMILTON','description' => 'A class to handle ISO thesaurii','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 300,'pod' => 95,'pod_errors' => 0,'total' => 395,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 4722,'unpacked' => 13479},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'Text-Thread-0.1.tar.gz' => {'author' => 'CLKAO','description' => 'format threaded items to ascii tree','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 43,'pod_errors' => 0,'total' => 85,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 1939,'unpacked' => 3748},'testers' => {'fail' => 1,'pass' => 6,'tests' => '7'},'uses' => []},'Text-Tmpl-0.29.tar.gz' => {'author' => 'DLOWE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 283,'pod' => 632,'pod_errors' => 0,'total' => 915,'with_comments' => 31},'releases' => 26,'size' => {'packed' => 42164,'unpacked' => 192924},'testers' => {'pass' => 1},'uses' => ['AutoLoader','DynaLoader','Exporter','constant','strict','vars']},'Text-TransMetaphone-0.06.tar.gz' => {'author' => 'DYACOB','description' => 'Translingual phonetic encoding of words.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1478,'pod' => 456,'pod_errors' => 0,'total' => 1934,'with_comments' => 224},'releases' => 2,'requires' => ['Regexp-Ethiopic-0.12.tar.gz'],'requires_module' => {'Regexp::Ethiopic' => 0},'requires_recursive' => ['Regexp-Ethiopic-0.12.tar.gz'],'size' => {'packed' => 30337,'unpacked' => 123717},'testers' => {'pass' => 3},'uses' => ['','Carp','DynaLoader','Exporter','Regexp::Ethiopic::Amharic','strict','utf','vars']},'Text-TreeFile-0.39.tar.gz' => {'author' => 'JNK','description' => 'Reads tree of strings into a data structure','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 261,'pod' => 203,'pod_errors' => 0,'total' => 464,'with_comments' => 14},'releases' => 2,'size' => {'packed' => 12840,'unpacked' => 41520},'testers' => {'pass' => 10},'uses' => ['5.002','AutoLoader','Exporter','FileHandle','strict','vars']},'Text-Trie-0.21.tar.gz' => {'author' => 'ILYAZ','description' => 'Find common heads and tails from strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 93,'pod' => 58,'pod_errors' => 0,'total' => 151,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 2872,'unpacked' => 5979},'testers' => {'pass' => 6},'uses' => ['5.000','Exporter','integer']},'Text-Truncate-0.01.tar.gz' => {'author' => 'RRWO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 48,'pod' => 67,'pod_errors' => 0,'total' => 115,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2285,'unpacked' => 6213},'testers' => {'pass' => 5},'uses' => ['5.00500','Carp','Exporter','strict','vars']},'Text-Typoifier-0.04a.tar.gz' => {'author' => 'JHARDING','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 142,'pod' => 49,'pod_errors' => 1,'total' => 191,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 2334,'unpacked' => 5288},'testers' => {'pass' => 5},'uses' => ['5.005_62','POSIX','strict','warnings']},'Text-UPF-1.0.1.tar.gz' => {'author' => 'AHICOX','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 422,'pod' => 212,'pod_errors' => 0,'total' => 634,'with_comments' => 82},'releases' => 2,'requires' => ['Config-Framework-1.05.tar.gz','DBIx-YAWM-2.2.4.tar.gz','Text-Wrapper-1.000.tar.gz','TimeDate-1.16.tar.gz'],'requires_module' => {'Config::Framework' => '1.01','DBIx::YAWM' => '','Date::Parse' => '2.2','Text::Wrapper' => 1},'requires_recursive' => ['Array-RefElem-0.02.tar.gz','Config-Framework-1.05.tar.gz','Crypt-CBC-2.08.tar.gz','DBI-1.37.tar.gz','DBIx-YAWM-2.2.4.tar.gz','Data-DumpXML-1.05.tar.gz','Digest-MD5-2.26.tar.gz','MIME-Base64-2.20.tar.gz','Text-Wrapper-1.000.tar.gz','TimeDate-1.16.tar.gz','XML-Parser-2.31.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9279,'unpacked' => 27676},'testers' => {'pass' => 3},'uses' => ['5.6.0','AutoLoader','Config::Framework','DBIx::YAWM','Date::Parse','Exporter','Text::Wrapper','warnings']},'Text-Unaccent-1.01.tar.gz' => {'author' => 'LDACHARY','description' => 'Remove accents from a string','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 36,'pod_errors' => 0,'total' => 89,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 53062,'unpacked' => 391675},'testers' => {'fail' => 4,'pass' => 3,'tests' => '3'},'uses' => ['DynaLoader','Exporter','strict','vars']},'Text-Unidecode-0.04.tar.gz' => {'author' => 'SBURKE','description' => '- US-ASCII transliterations of Unicode text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3862,'pod' => 170,'pod_errors' => 0,'total' => 4032,'with_comments' => 216},'releases' => 2,'size' => {'packed' => 103091,'unpacked' => 407531},'testers' => {'pass' => 1},'uses' => ['5.006','Exporter','integer','strict','utf','vars']},'Text-Vpp-1.16.tar.gz' => {'author' => 'DDUMONT','description' => 'Versatile text pre-processor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 993,'pod' => 242,'pod_errors' => 0,'total' => 1235,'with_comments' => 60},'releases' => 14,'size' => {'packed' => 18195,'unpacked' => 61819},'testers' => {'pass' => 6},'uses' => ['5.6.0','AutoLoader','Carp','IO::File','Safe','strict','vars']},'Text-WagnerFischer-0.04.tar.gz' => {'author' => 'DREE','description' => 'An implementation of the Wagner-Fischer edit distance','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 85,'pod_errors' => 0,'total' => 245,'with_comments' => 21},'releases' => 4,'size' => {'packed' => 3461,'unpacked' => 8440},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','strict','vars']},'Text-WagnerFischer-Amharic-0.01.tar.gz' => {'author' => 'DYACOB','description' => 'The Wagner-Fischer Algorithm for Amharic.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 140,'pod' => 58,'pod_errors' => 0,'total' => 198,'with_comments' => 36},'releases' => 1,'requires' => ['Regexp-Ethiopic-0.12.tar.gz','Text-WagnerFischer-0.04.tar.gz'],'requires_module' => {'Regexp::Ethiopic' => '0.06','Text::WagnerFischer' => '0.03'},'requires_recursive' => ['Regexp-Ethiopic-0.12.tar.gz','Text-WagnerFischer-0.04.tar.gz'],'size' => {'packed' => 3590,'unpacked' => 8406},'testers' => {'pass' => 3},'uses' => ['','Regexp::Ethiopic::Amharic','Text::WagnerFischer','strict','utf','vars']},'Text-WikiFormat-0.6.tar.gz' => {'author' => 'CHROMATIC','description' => 'module for translating Wiki formatted text into other formats','files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 343,'pod' => 187,'pod_errors' => 0,'total' => 530,'with_comments' => 2},'releases' => 6,'size' => {'packed' => 21557,'unpacked' => 58366},'testers' => {'pass' => 10},'uses' => ['URI::Escape','strict','vars']},'Text-WikiFormat-SAX-0.03.tar.gz' => {'author' => 'MSERGEANT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 285,'pod' => 24,'pod_errors' => 0,'total' => 309,'with_comments' => 5},'releases' => 3,'requires' => ['XML-SAX-0.12.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'XML::SAX' => 0,'XML::SAX::Writer' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3037,'unpacked' => 9239},'testers' => {'pass' => 1},'uses' => ['XML::SAX::Base','XML::SAX::DocumentLocator','strict','vars']},'Text-WrapI18N-0.06.tar.gz' => {'author' => 'KUBOTA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 207,'pod' => 32,'pod_errors' => 0,'total' => 239,'with_comments' => 43},'releases' => 5,'requires' => ['Text-CharWidth-0.04.tar.gz'],'requires_module' => {'Text::CharWidth' => '0.02'},'requires_recursive' => ['Text-CharWidth-0.04.tar.gz'],'size' => {'packed' => 3812,'unpacked' => 8907},'testers' => {'pass' => 2},'uses' => ['Exporter','Text::CharWidth','strict','vars','warnings']},'Text-WrapProp-0.03.tar.gz' => {'author' => 'JBRIGGS','description' => 'proportional line wrapping to form simple paragraphs','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 98,'pod' => 32,'pod_errors' => 0,'total' => 130,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 2770,'unpacked' => 6679},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'Text-Wrapper-1.000.tar.gz' => {'author' => 'CJM','description' => 'Simple word wrapping routine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 138,'pod' => 63,'pod_errors' => 0,'total' => 201,'with_comments' => 42},'releases' => 3,'size' => {'packed' => 5940,'unpacked' => 17515},'testers' => {'pass' => 11},'uses' => ['5.004','Carp','strict','vars']},'Text-Yats-0.03.tar.gz' => {'author' => 'HDIAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 152,'pod_errors' => 0,'total' => 312,'with_comments' => 14},'releases' => 3,'size' => {'packed' => 4761,'unpacked' => 14051},'testers' => {'pass' => 3},'uses' => ['5','Exporter','strict','vars']},'Text-vCard-0.6.tar.gz' => {'author' => 'LLAP','description' => 'a package to parse, edit and create vCards (RFC 2426)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 449,'pod' => 461,'pod_errors' => 0,'total' => 910,'with_comments' => 25},'releases' => 9,'requires' => ['Test-Simple-0.47.tar.gz','Text-vFile-0.5.tar.gz'],'requires_module' => {'Test::More' => '0.1','Text::vFile' => ''},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-vFile-0.5.tar.gz'],'size' => {'packed' => 7280,'unpacked' => 22106},'testers' => {'pass' => 2},'uses' => ['Carp','Text::vCard::Part','Text::vCard::Part::Address','Text::vCard::Part::Geo','Text::vCard::Part::Name','Text::vFile::Base','strict','vars']},'Text-vCard-1.0.tar.gz' => {'author' => 'LLAP','description' => 'a package to parse, edit and create vCards (RFC 2426)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 630,'pod' => 575,'pod_errors' => 0,'total' => 1205,'with_comments' => 37},'releases' => 9,'requires' => ['Test-Simple-0.47.tar.gz','Text-vFile-0.5.tar.gz'],'requires_module' => {'Test::More' => '0.1','Text::vFile' => ''},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-vFile-0.5.tar.gz'],'size' => {'packed' => 9426,'unpacked' => 31955},'testers' => {'pass' => 1},'uses' => ['Carp','Text::vFile::Base','strict','vars']},'Text-vFile-0.5.tar.gz' => {'author' => 'JLAWRENC','description' => 'Parses vCard RFC2426 and vCal RFC2445 files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 540,'pod' => 313,'pod_errors' => 0,'total' => 853,'with_comments' => 22},'releases' => 4,'size' => {'packed' => 15342,'unpacked' => 45127},'testers' => {'pass' => 3},'uses' => ['Carp','Data::Dumper','Encode','lib','strict','vars']},'Text-xSV-0.05.tar.gz' => {'author' => 'TILLY','description' => 'Read CSV files, handling embedded returns','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 230,'pod' => 84,'pod_errors' => 0,'total' => 314,'with_comments' => 9},'releases' => 2,'size' => {'packed' => 5301,'unpacked' => 11896},'testers' => {'pass' => 7},'uses' => ['Carp','strict']},'TextStructured-0.02.tar.gz' => {'author' => 'PSHARPE','description' => 'Manipulate fixed-format pages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 190,'pod' => 125,'pod_errors' => 0,'total' => 315,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 4682,'unpacked' => 12186},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars']},'Thesaurus-0.21.tar.gz' => {'author' => 'DROLSKY','description' => 'Maintains lists of associated items','files' => ['Makefile.PL','README','Build.PL','MANIFEST'],'lines' => {'nonpod' => 522,'pod' => 153,'pod_errors' => 0,'total' => 675,'with_comments' => 8},'releases' => 8,'size' => {'packed' => 7687,'unpacked' => 21749},'testers' => {'pass' => 1},'uses' => ['BerkeleyDB','File::Basename','IO::File','Params::Validate','Storable','Test::More','Text::CSV_XS','strict','vars']},'Thread-Barrier-0.101.tar.gz' => {'author' => 'MROGASKI','description' => 'thread execution barrier','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 57,'pod_errors' => 0,'total' => 139,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 2839,'unpacked' => 7279},'testers' => {'pass' => 1},'uses' => ['5.008','strict','threads','threads::shared','warnings']},'Thread-Conveyor-0.13.tar.gz' => {'author' => 'ELIZABETH','description' => 'transport of any data-structure between threads','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1024,'pod' => 316,'pod_errors' => 0,'total' => 1340,'with_comments' => 421},'releases' => 13,'requires' => ['Thread-Tie-0.08.tar.gz'],'requires_module' => {'Thread::Tie' => '0.08'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Thread-Serialize-0.05.tar.gz','Thread-Tie-0.08.tar.gz','load-0.05.tar.gz'],'size' => {'packed' => 11079,'unpacked' => 48010},'testers' => {},'uses' => ['load','strict']},'Thread-Conveyor-Monitored-0.09.tar.gz' => {'author' => 'ELIZABETH','description' => 'monitor a belt for specific content','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 507,'pod' => 362,'pod_errors' => 0,'total' => 869,'with_comments' => 184},'releases' => 9,'requires' => ['Thread-Conveyor-0.13.tar.gz'],'requires_module' => {'Thread::Conveyor' => '0.13'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Thread-Conveyor-0.13.tar.gz','Thread-Serialize-0.05.tar.gz','Thread-Tie-0.08.tar.gz','load-0.05.tar.gz'],'size' => {'packed' => 9997,'unpacked' => 35540},'testers' => {},'uses' => ['load','strict']},'Thread-Deadlock-0.04.tar.gz' => {'author' => 'ELIZABETH','description' => 'report deadlocks with stacktrace','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 548,'pod' => 192,'pod_errors' => 0,'total' => 740,'with_comments' => 198},'releases' => 4,'size' => {'packed' => 8166,'unpacked' => 25458},'testers' => {},'uses' => ['AutoLoader','sigtrap','strict','threads']},'Thread-Exit-0.04.tar.gz' => {'author' => 'ELIZABETH','description' => 'provide thread-local exit(), BEGIN {} and END {}','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 305,'pod' => 171,'pod_errors' => 0,'total' => 476,'with_comments' => 103},'releases' => 4,'requires' => ['Thread-Serialize-0.05.tar.gz'],'requires_module' => {'Thread::Serialize' => '0.05'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Thread-Serialize-0.05.tar.gz','load-0.05.tar.gz'],'size' => {'packed' => 6706,'unpacked' => 20606},'testers' => {},'uses' => ['load','strict']},'Thread-Needs-0.02.tar.gz' => {'author' => 'ELIZABETH','description' => 'remove unneeded modules from CLONEd memory','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 200,'pod' => 112,'pod_errors' => 0,'total' => 312,'with_comments' => 51},'releases' => 2,'size' => {'packed' => 5113,'unpacked' => 13322},'testers' => {},'uses' => ['strict']},'Thread-Pool-0.28.tar.gz' => {'author' => 'ELIZABETH','description' => 'Worker pools to run Perl code asynchronously','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1417,'pod' => 744,'pod_errors' => 0,'total' => 2161,'with_comments' => 491},'releases' => 21,'requires' => ['Thread-Conveyor-0.13.tar.gz','Thread-Conveyor-Monitored-0.09.tar.gz'],'requires_module' => {'Thread::Conveyor' => '0.13','Thread::Conveyor::Monitored' => '0.09'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Thread-Conveyor-0.13.tar.gz','Thread-Conveyor-Monitored-0.09.tar.gz','Thread-Serialize-0.05.tar.gz','Thread-Tie-0.08.tar.gz','load-0.05.tar.gz'],'size' => {'packed' => 25931,'unpacked' => 101778},'testers' => {},'uses' => ['load','strict']},'Thread-Pool-Resolve-0.08.tar.gz' => {'author' => 'ELIZABETH','description' => 'resolve logs asynchronously','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 738,'pod' => 487,'pod_errors' => 0,'total' => 1225,'with_comments' => 224},'releases' => 8,'requires' => ['Thread-Pool-0.28.tar.gz'],'requires_module' => {'Thread::Pool' => '0.28'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Thread-Conveyor-0.13.tar.gz','Thread-Conveyor-Monitored-0.09.tar.gz','Thread-Pool-0.28.tar.gz','Thread-Serialize-0.05.tar.gz','Thread-Tie-0.08.tar.gz','load-0.05.tar.gz'],'size' => {'packed' => 15781,'unpacked' => 53313},'testers' => {},'uses' => ['POSIX','load','strict']},'Thread-Queue-Any-0.05.tar.gz' => {'author' => 'ELIZABETH','description' => 'thread-safe queues for any data-structure','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 92,'pod_errors' => 0,'total' => 181,'with_comments' => 24},'releases' => 4,'requires' => ['Storable-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Storable' => 0,'Thread::Queue' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3735,'unpacked' => 9297},'testers' => {},'uses' => ['strict']},'Thread-Queue-Any-Monitored-0.05.tar.gz' => {'author' => 'ELIZABETH','description' => 'monitor a queue for any specific content','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 159,'pod' => 189,'pod_errors' => 0,'total' => 348,'with_comments' => 48},'releases' => 5,'requires' => ['Thread-Queue-Any-0.05.tar.gz','Thread-Queue-Monitored-0.06.tar.gz'],'requires_module' => {'Thread::Queue::Any' => 0,'Thread::Queue::Monitored' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Thread-Queue-Any-0.05.tar.gz','Thread-Queue-Monitored-0.06.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5617,'unpacked' => 15371},'testers' => {},'uses' => ['strict']},'Thread-Queue-Monitored-0.06.tar.gz' => {'author' => 'ELIZABETH','description' => 'monitor a queue for specific content','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 245,'pod' => 187,'pod_errors' => 0,'total' => 432,'with_comments' => 88},'releases' => 6,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Thread::Queue' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 6002,'unpacked' => 17520},'testers' => {},'uses' => ['strict']},'Thread-RWLock-1.02.tar.gz' => {'author' => 'AFERBER','description' => 'rwlock implementation for perl threads','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 59,'pod_errors' => 0,'total' => 151,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 2361,'unpacked' => 5974},'testers' => {'fail' => 5},'uses' => ['Thread']},'Thread-Rand-0.04.tar.gz' => {'author' => 'ELIZABETH','description' => 'repeatable random sequences between threads','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 105,'pod_errors' => 0,'total' => 254,'with_comments' => 55},'releases' => 4,'requires' => ['Thread-Tie-0.08.tar.gz'],'requires_module' => {'Thread::Tie' => '0.08'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Thread-Serialize-0.05.tar.gz','Thread-Tie-0.08.tar.gz','load-0.05.tar.gz'],'size' => {'packed' => 3752,'unpacked' => 9993},'testers' => {},'uses' => ['load','strict']},'Thread-Serialize-0.05.tar.gz' => {'author' => 'ELIZABETH','description' => 'serialize data-structures between threads','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 128,'pod' => 67,'pod_errors' => 0,'total' => 195,'with_comments' => 40},'releases' => 5,'requires' => ['Storable-2.07.tar.gz','load-0.05.tar.gz'],'requires_module' => {'Storable' => 0,'load' => '0.02'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','load-0.05.tar.gz'],'size' => {'packed' => 3851,'unpacked' => 8703},'testers' => {'pass' => 1},'uses' => ['load','strict']},'Thread-Status-0.03.tar.gz' => {'author' => 'ELIZABETH','description' => 'report stack status of all running threads','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 712,'pod' => 250,'pod_errors' => 0,'total' => 962,'with_comments' => 274},'releases' => 3,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Thread::Signal' => '1.06'},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 9774,'unpacked' => 32253},'testers' => {},'uses' => ['load','strict']},'Thread-Tie-0.08.tar.gz' => {'author' => 'ELIZABETH','description' => 'tie variables into a thread of their own','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1159,'pod' => 425,'pod_errors' => 0,'total' => 1584,'with_comments' => 509},'releases' => 8,'requires' => ['Thread-Serialize-0.05.tar.gz'],'requires_module' => {'Thread::Serialize' => '0.05'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Thread-Serialize-0.05.tar.gz','load-0.05.tar.gz'],'size' => {'packed' => 14518,'unpacked' => 59544},'testers' => {},'uses' => ['Thread::Serialize','load','strict']},'Thread-Use-0.03.tar.gz' => {'author' => 'ELIZABETH','description' => 'use a module inside a thread only','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 86,'pod' => 84,'pod_errors' => 0,'total' => 170,'with_comments' => 27},'releases' => 3,'size' => {'packed' => 3233,'unpacked' => 7383},'testers' => {},'uses' => ['strict']},'ThreadIterator-0.1.tar.gz' => {'author' => 'MICB','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 57,'pod' => 0,'pod_errors' => 0,'total' => 57,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1728,'unpacked' => 3052},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Exporter','Thread','Thread::Queue','Thread::Semaphore','strict','vars']},'Tib-Rv-0.02.tar.gz' => {'author' => 'STURM','description' => 'Perl bindings and Object-Oriented library for TIBCO\'s TIB/Rendezvous','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 796,'pod' => 43,'pod_errors' => 0,'total' => 839,'with_comments' => 55},'releases' => 1,'size' => {'packed' => 6570,'unpacked' => 22265},'testers' => {},'uses' => ['','Carp','Inline','constant','overload','vars']},'Tibco-Rv-1.10.tar.gz' => {'author' => 'STURM','description' => 'Perl bindings and Object-Oriented library for TIBCO\'s TIB/Rendezvous','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4246,'pod' => 1934,'pod_errors' => 0,'total' => 6180,'with_comments' => 12},'releases' => 9,'size' => {'packed' => 38167,'unpacked' => 189292},'testers' => {},'uses' => ['','Carp','constant','overload','vars']},'Tie-Alias-0.01.tar.gz' => {'author' => 'DAVIDNICO','description' => 'create aliases for lexicals in pure perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 59,'pod' => 47,'pod_errors' => 0,'total' => 106,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2160,'unpacked' => 3680},'testers' => {'pass' => 3},'uses' => ['5.008','Carp','Tie::Alias::Array','Tie::Alias::Handle','Tie::Alias::Hash','strict','warnings']},'Tie-Alias-Array-0.01.tar.gz' => {'author' => 'DAVIDNICO','description' => 'required by Tie::Alias::TIEARRAY','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 9,'pod_errors' => 0,'total' => 78,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 1565,'unpacked' => 2483},'testers' => {'pass' => 3},'uses' => ['5.008','Carp','strict','warnings']},'Tie-Alias-Handle-0.01.tar.gz' => {'author' => 'DAVIDNICO','description' => 'required by Tie::Alias::TIEHANDLE','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 43,'pod' => 17,'pod_errors' => 0,'total' => 60,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 1697,'unpacked' => 2606},'testers' => {'pass' => 3},'uses' => ['5.008','Carp','strict','warnings']},'Tie-Alias-Hash-0.01.tar.gz' => {'author' => 'DAVIDNICO','description' => 'required by Tie::Alias::TIEHASH','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 9,'pod_errors' => 0,'total' => 59,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 1466,'unpacked' => 2200},'testers' => {'pass' => 3},'uses' => ['5.008','Carp','strict','warnings']},'Tie-AliasHash-1.01.tar.gz' => {'author' => 'ACALPINI','description' => 'Hash with key aliases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 281,'pod' => 255,'pod_errors' => 0,'total' => 536,'with_comments' => 18},'releases' => 2,'size' => {'packed' => 5865,'unpacked' => 18309},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'Tie-Array-FileWriter-0.1.tar.gz' => {'author' => 'GREGOR','description' => 'A Perl module for writing records to files as items are pushed onto a virtual array','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 116,'pod' => 36,'pod_errors' => 0,'total' => 152,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 2874,'unpacked' => 6242},'testers' => {'pass' => 4},'uses' => ['5.006','Carp','FileHandle','strict','warnings']},'Tie-Array-Iterable-0.03.tar.gz' => {'author' => 'MNEYLON','description' => 'Allows creation of iterators for lists and arrays','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 775,'pod' => 268,'pod_errors' => 0,'total' => 1043,'with_comments' => 83},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.33'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8900,'unpacked' => 38564},'testers' => {'pass' => 4},'uses' => ['5.006','Data::Dumper','Tie::Array','strict','vars']},'Tie-Array-RestrictUpdates-0.0.1.tar.gz' => {'author' => 'BEATNIK','description' => undef,'files' => [],'lines' => {'nonpod' => 88,'pod' => 57,'pod_errors' => 0,'total' => 145,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 2341,'unpacked' => 5551},'testers' => {'pass' => 1,'tests' => '0','unknown' => 6},'uses' => ['Tie::Array','strict','vars']},'Tie-CArray-0.12.tar.gz' => {'author' => 'RURBAN','description' => 'Space-efficient, typed, external C Arrays (Alpha)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 354,'pod' => 440,'pod_errors' => 1,'total' => 794,'with_comments' => 90},'releases' => 1,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Tie::Array' => 1},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 31586,'unpacked' => 117334},'testers' => {'pass' => 5},'uses' => ['5.005','Autoloader','Carp','DynaLoader','Tie::Array','integer','strict','vars']},'Tie-CPHash-1.001.tar.gz' => {'author' => 'CJM','description' => 'Case preserving but case insensitive hash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 142,'pod' => 47,'pod_errors' => 0,'total' => 189,'with_comments' => 67},'releases' => 2,'size' => {'packed' => 3141,'unpacked' => 8362},'testers' => {'pass' => 10},'uses' => ['5.000','strict','vars']},'Tie-CSV_File-0.21.tar.gz' => {'author' => 'BIGJ','description' => 'ties a csv-file to an array of arrays','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 512,'pod' => 284,'pod_errors' => 0,'total' => 796,'with_comments' => 29},'releases' => 21,'requires' => ['Data-Compare-0.02.tar.gz','File-Temp-0.12.tar.gz','Params-Validate-0.64.tar.gz','Test-Exception-0.15.tar.gz','Test-ManyParams-0.10.tar.gz','Test-Simple-0.47.tar.gz','Test-Warn-0.07.tar.gz','Text-CSV_XS-0.23.tar.gz','Tie-File-0.96.tar.gz'],'requires_module' => {'Data::Compare' => 0,'File::Temp' => 0,'Params::Validate' => 0,'Test::Exception' => 0,'Test::ManyParams' => 0,'Test::More' => 0,'Test::Warn' => '0.05','Text::CSV_XS' => 0,'Tie::File' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Array-Compare-1.03.tar.gz','Attribute-Handlers-0.78.tar.gz','Data-Compare-0.02.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Params-Validate-0.64.tar.gz','Set-CrossProduct-1.4.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Differences-0.47.tar.gz','Test-Exception-0.15.tar.gz','Test-Harness-2.29.tar.gz','Test-ManyParams-0.10.tar.gz','Test-Simple-0.47.tar.gz','Test-Warn-0.07.tar.gz','Text-CSV_XS-0.23.tar.gz','Text-Diff-0.35.tar.gz','Tie-File-0.96.tar.gz','Tree-DAG_Node-1.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13228,'unpacked' => 44915},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Dumper','Exporter','Params::Validate','Text::CSV_XS','Tie::Array','Tie::File','strict','warnings']},'Tie-Cache-0.17.tar.gz' => {'author' => 'CHAMAS','description' => 'In memory size limited LRU cache','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 544,'pod' => 153,'pod_errors' => 0,'total' => 697,'with_comments' => 4},'releases' => 9,'size' => {'packed' => 11627,'unpacked' => 36045},'testers' => {'pass' => 12},'uses' => ['strict','vars']},'Tie-Cache-LRU-0.21.tar.gz' => {'author' => 'MSCHWERN','description' => 'A Least-Recently Used cache','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 627,'pod' => 255,'pod_errors' => 0,'total' => 882,'with_comments' => 30},'releases' => 4,'requires' => ['Carp-Assert-0.17.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Virtual-0.03.tar.gz','enum-1.016.tar.gz'],'requires_module' => {'Carp::Assert' => 0,'Class::Data::Inheritable' => 0,'Class::Virtual' => 0,'enum' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-ISA-0.32.tar.gz','Class-Virtual-0.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','enum-1.016.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 142338,'unpacked' => 454569},'testers' => {'pass' => 17},'uses' => ['Carp::Assert','Class::Data::Inheritable','Class::Virtual','constant','enum','strict','vars']},'Tie-CacheHash-0.50.tar.gz' => {'author' => 'JAMCC','description' => 'Maintains sorted lists of top entries','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 799,'pod' => 57,'pod_errors' => 0,'total' => 856,'with_comments' => 192},'releases' => 1,'size' => {'packed' => 12496,'unpacked' => 39785},'testers' => {'fail' => 1,'pass' => 4,'tests' => '14'},'uses' => ['5.003','Carp','strict','vars']},'Tie-Cacher-0.04.tar.gz' => {'author' => 'THOSPEL','description' => 'Cache a (sub)set of key/value pairs. Tie and OO interface.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 639,'pod' => 363,'pod_errors' => 0,'total' => 1002,'with_comments' => 27},'releases' => 2,'size' => {'packed' => 12618,'unpacked' => 56870},'testers' => {'pass' => 2},'uses' => ['5.006','AutoLoader','Carp','Tie::Hash','constant','fields','strict','warnings']},'Tie-Cfg-0.32.tar.gz' => {'author' => 'OESTERHOL','description' => 'Ties simple configuration (.ini) files to hashes. Handles arrays and recurrent sections.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 269,'pod' => 157,'pod_errors' => 1,'total' => 426,'with_comments' => 3},'releases' => 9,'requires' => ['LockFile-Simple-0.2.5.tar.gz'],'requires_module' => {'LockFile::Simple' => '0.2.5'},'requires_recursive' => ['LockFile-Simple-0.2.5.tar.gz'],'size' => {'packed' => 5710,'unpacked' => 16610},'testers' => {'pass' => 9},'uses' => ['LockFile::Simple','strict','vars']},'Tie-CharArray-1.00.tar.gz' => {'author' => 'ILTZU','description' => 'Manipulate strings as arrays of characters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 113,'pod_errors' => 0,'total' => 238,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 4905,'unpacked' => 12308},'testers' => {'pass' => 11},'uses' => ['5.005','Exporter','strict','vars']},'Tie-Config-0.04.tar.gz' => {'author' => 'KOZO','description' => 'class definitions for tied hashes config file reading','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 179,'pod' => 68,'pod_errors' => 0,'total' => 247,'with_comments' => 37},'releases' => 1,'size' => {'packed' => 3987,'unpacked' => 10268},'testers' => {'pass' => 5},'uses' => ['Carp','Data::Dumper','Exporter','Fcntl','IO::File','Tie::Hash','strict','vars']},'Tie-Coupler-0.01.tar.gz' => {'author' => 'UARUN','description' => 'Tie based implementation of coupled scalars','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 242,'pod' => 124,'pod_errors' => 1,'total' => 366,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 5036,'unpacked' => 16896},'testers' => {'pass' => 5},'uses' => ['Carp','strict','vars']},'Tie-Cycle-1.06.tar.gz' => {'author' => 'BDFOY','description' => 'Cycle through a list of values via a scalar.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 92,'pod' => 62,'pod_errors' => 0,'total' => 154,'with_comments' => 1},'releases' => 5,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','Test::Manifest' => '0.91','Test::More' => '0','Test::Pod' => '0.90'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 2878,'unpacked' => 5619},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Tie-DBI-0.86.tar.gz' => {'author' => 'LDS','description' => 'Tie hashes to relational databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1178,'pod' => 530,'pod_errors' => 0,'total' => 1708,'with_comments' => 81},'releases' => 5,'size' => {'packed' => 22238,'unpacked' => 67686},'testers' => {'fail' => 7,'tests' => '49'},'uses' => ['Carp','DBI','Storable','strict','vars']},'Tie-DBI-0.91.tar.gz' => {'author' => 'LDS','description' => 'Tie hash to a DBI handle','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1174,'pod' => 519,'pod_errors' => 0,'total' => 1693,'with_comments' => 80},'releases' => 5,'size' => {'packed' => 21880,'unpacked' => 67312},'testers' => {'fail' => 6,'pass' => 8,'tests' => '52'},'uses' => ['Carp','DBI','Storable','strict','vars']},'Tie-DB_File-SplitHash-1.01.tar.gz' => {'author' => 'SNOWHARE','description' => 'A wrapper around the DB_File Berkeley database system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 326,'pod' => 56,'pod_errors' => 0,'total' => 382,'with_comments' => 24},'releases' => 2,'requires' => ['DB_File-1.806.tar.gz','Digest-SHA1-2.04.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'DB_File' => 0,'Digest::SHA1' => 0,'Fcntl' => 0},'requires_recursive' => ['DB_File-1.806.tar.gz','Digest-SHA1-2.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4240,'unpacked' => 12784},'testers' => {'pass' => 11},'uses' => ['Carp','DB_File','Digest::SHA1','Exporter','Fcntl','File::Path','Tie::Hash','strict','vars']},'Tie-DB_FileLock-0.10.tar.gz' => {'author' => 'JMV','description' => 'Locking access to Berkeley DB 1.x.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 254,'pod' => 91,'pod_errors' => 0,'total' => 345,'with_comments' => 39},'releases' => 2,'size' => {'packed' => 14228,'unpacked' => 57650},'testers' => {'fail' => 4,'pass' => 7,'tests' => '269'},'uses' => ['5.004','Carp','DB_File','Fcntl','FileHandle','Tie::Hash','strict','vars']},'Tie-DB_Lock-0.07.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Tie DB_File with automatic locking','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 263,'pod' => 84,'pod_errors' => 0,'total' => 347,'with_comments' => 26},'releases' => 6,'size' => {'packed' => 6876,'unpacked' => 17084},'testers' => {'pass' => 6},'uses' => ['Carp','DB_File','Fcntl','FileHandle','strict','vars']},'Tie-DNS-0.41.tar.gz' => {'author' => 'DIEDERICH','description' => 'Tie interface to Net::DNS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 343,'pod' => 144,'pod_errors' => 0,'total' => 487,'with_comments' => 12},'releases' => 2,'requires' => ['Net-DNS-0.38.tar.gz'],'requires_module' => {'Net::DNS' => '0.12'},'requires_recursive' => ['Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Net-DNS-0.38.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5889,'unpacked' => 17983},'testers' => {'pass' => 3},'uses' => ['Carp','Net::DNS','strict']},'Tie-DictFile-0.03.tar.gz' => {'author' => 'ANUNES','description' => 'tie a hash to local dictionary file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 433,'pod' => 95,'pod_errors' => 0,'total' => 528,'with_comments' => 32},'releases' => 2,'requires' => ['Class-ISA-0.32.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::ISA' => 0,'Test::More' => 0},'requires_recursive' => ['Class-ISA-0.32.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 5489,'unpacked' => 15911},'testers' => {'pass' => 2},'uses' => ['Carp','IO::File','strict','vars']},'Tie-Dir-1.02.tar.gz' => {'author' => 'GBARR','description' => 'Tie hash for reading directories','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 65,'pod_errors' => 0,'total' => 170,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 2223,'unpacked' => 4266},'testers' => {'pass' => 9},'uses' => ['Carp','Exporter','Symbol','Tie::Hash','strict','vars']},'Tie-DirHandle-1.10.tar.gz' => {'author' => 'PINYAN','description' => 'definitions for tied directory handles','files' => [],'lines' => {'nonpod' => 44,'pod' => 56,'pod_errors' => 0,'total' => 100,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2491,'unpacked' => 6018},'testers' => {'pass' => 4},'uses' => ['Carp']},'Tie-Discovery-1.00.tar.gz' => {'author' => 'SIMON','description' => 'Discover data by caching sub results','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 69,'pod_errors' => 0,'total' => 126,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2853,'unpacked' => 6866},'testers' => {'pass' => 15},'uses' => ['Carp','Tie::Hash','strict']},'Tie-DxHash-0.93.tar.gz' => {'author' => 'KRUSCOE','description' => 'Keeps insertion order; allows duplicate keys','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 200,'pod' => 52,'pod_errors' => 0,'total' => 252,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 4772,'unpacked' => 11457},'testers' => {'pass' => 9},'uses' => ['Tie::Hash','strict','vars']},'Tie-EncryptedHash-1.21.tar.gz' => {'author' => 'VIPUL','description' => 'Hashes (and objects based on hashes) with encrypting fields.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 319,'pod' => 132,'pod_errors' => 0,'total' => 451,'with_comments' => 40},'releases' => 3,'requires' => ['Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Crypt-DES-2.03.tar.gz'],'requires_module' => {'Crypt::Blowfish' => 0,'Crypt::CBC' => 0,'Crypt::DES' => 0},'requires_recursive' => ['Crypt-Blowfish-2.09.tar.gz','Crypt-CBC-2.08.tar.gz','Crypt-DES-2.03.tar.gz','Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 10768,'unpacked' => 46391},'testers' => {'pass' => 9},'uses' => ['Carp','Crypt::CBC','Data::Dumper','Digest::MD5','strict','vars']},'Tie-File-0.96.tar.gz' => {'author' => 'MJD','description' => 'Tie array to lines of a file','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2241,'pod' => 375,'pod_errors' => 0,'total' => 2616,'with_comments' => 451},'releases' => 13,'size' => {'packed' => 67992,'unpacked' => 302001},'testers' => {'pass' => 5},'uses' => ['5.005','Carp','Fcntl','POSIX','Symbol','strict']},'Tie-FileHandle-Base-0.1.tar.gz' => {'author' => 'ROBWALKER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 165,'pod' => 79,'pod_errors' => 0,'total' => 244,'with_comments' => 35},'releases' => 2,'size' => {'packed' => 2981,'unpacked' => 7238},'testers' => {'pass' => 3},'uses' => ['strict','vars']},'Tie-FileHandle-Buffer-0.11.tar.gz' => {'author' => 'ROBWALKER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 31,'pod_errors' => 0,'total' => 70,'with_comments' => 6},'releases' => 2,'requires' => ['Tie-FileHandle-Base-0.1.tar.gz'],'requires_module' => {'Tie::FileHandle::Base' => '0.1'},'requires_recursive' => ['Tie-FileHandle-Base-0.1.tar.gz'],'size' => {'packed' => 1785,'unpacked' => 3527},'testers' => {'pass' => 6},'uses' => ['Tie::FileHandle::Base','vars']},'Tie-FileHandle-MultiPlex-0.1.tar.gz' => {'author' => 'ROBWALKER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 26,'pod' => 27,'pod_errors' => 0,'total' => 53,'with_comments' => 5},'releases' => 1,'requires' => ['Tie-FileHandle-Base-0.1.tar.gz'],'requires_module' => {'Tie::FileHandle::Base' => '0.1'},'requires_recursive' => ['Tie-FileHandle-Base-0.1.tar.gz'],'size' => {'packed' => 1663,'unpacked' => 3081},'testers' => {'pass' => 2},'uses' => ['Tie::FileHandle::Base','vars']},'Tie-FileLRUCache-1.01.tar.gz' => {'author' => 'SNOWHARE','description' => 'File based persistent LRU cache','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 618,'pod' => 181,'pod_errors' => 0,'total' => 799,'with_comments' => 111},'releases' => 2,'requires' => ['Class-NamedParms-1.04.tar.gz','Class-ParmList-1.03.tar.gz','Digest-SHA1-2.04.tar.gz','Storable-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Class::NamedParms' => 0,'Class::ParmList' => 0,'Digest::SHA1' => 0,'Storable' => 0},'requires_recursive' => ['Class-NamedParms-1.04.tar.gz','Class-ParmList-1.03.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5687,'unpacked' => 24383},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['Carp','Class::NamedParms','Class::ParmList','Digest::SHA1','Fcntl','File::Path','Storable','Tie::Hash','strict','vars']},'Tie-GHash-0.12.tar.gz' => {'author' => 'LBROCARD','description' => 'A smaller hash; interface to Gnome glib hash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 37,'pod_errors' => 0,'total' => 213,'with_comments' => 8},'releases' => 2,'size' => {'packed' => 4133,'unpacked' => 10751},'testers' => {'pass' => 2},'uses' => ['Exporter','Inline','Tie::Hash','strict','vars']},'Tie-Google-0.03.tar.gz' => {'author' => 'DARREN','description' => 'Single-variable access to Google search results','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 549,'pod' => 177,'pod_errors' => 0,'total' => 726,'with_comments' => 238},'releases' => 2,'size' => {'packed' => 9954,'unpacked' => 34267},'testers' => {'pass' => 1},'uses' => ['Carp','Net::Google','Symbol','strict','vars']},'Tie-HTML-Entities+URI-Escape-0.05.tar.gz' => {'author' => 'RRWO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 144,'pod' => 175,'pod_errors' => 0,'total' => 319,'with_comments' => 0},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz'],'requires_module' => {'HTML::Entities' => 0,'URI::Escape' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','URI-1.24.tar.gz'],'size' => {'packed' => 2894,'unpacked' => 9112},'testers' => {'fail' => 4,'pass' => 1,'tests' => '68'},'uses' => ['5.00500','HTML::Entities','URI::Escape','strict','vars']},'Tie-Handle-Scalar-0.1.tar.gz' => {'author' => 'ANWILL','description' => 'Perl extension for tieing a scalar to a filehandle.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 83,'pod_errors' => 1,'total' => 202,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2562,'unpacked' => 4942},'testers' => {},'uses' => ['5.006','Carp','Exporter','FileHandle','strict','vars']},'Tie-Hash-Approx-0.03.tar.gz' => {'author' => 'BRIAC','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 54,'pod_errors' => 0,'total' => 130,'with_comments' => 7},'releases' => 3,'requires' => ['String-Approx-3.20.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'String::Approx' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','String-Approx-3.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2658,'unpacked' => 5704},'testers' => {'pass' => 2},'uses' => ['Exporter','String::Approx','Tie::Hash','strict','vars']},'Tie-Hash-Array-0.01.tar.gz' => {'author' => 'FANY','description' => 'a hash which is internally implemented as a sorted array','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 203,'pod' => 170,'pod_errors' => 0,'total' => 373,'with_comments' => 7},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Test::More' => 0,'Text::Abbrev' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13438,'unpacked' => 41153},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Tie-Hash-Cannabinol-1.06.tar.gz' => {'author' => 'DAVECROSS','description' => 'Perl extension for creating hashes that forget things','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 33,'pod_errors' => 0,'total' => 111,'with_comments' => 36},'releases' => 6,'requires' => ['Attribute-Handlers-0.78.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.76','Test::Pod' => 0,'Test::Simple' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 2832,'unpacked' => 5218},'testers' => {'pass' => 3},'uses' => ['Tie::Hash','strict','vars']},'Tie-Hash-FixedKeys-1.07.tar.gz' => {'author' => 'DAVECROSS','description' => 'Perl extension for hashes with fixed keys','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 49,'pod_errors' => 0,'total' => 146,'with_comments' => 32},'releases' => 6,'requires' => ['Attribute-Handlers-0.78.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.76','Test::Pod' => 0,'Test::Simple' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 3082,'unpacked' => 6140},'testers' => {'pass' => 2},'uses' => ['Carp','Tie::Hash','strict','vars']},'Tie-Hash-Layered-0.9.tar.gz' => {'author' => 'SIMONW','description' => 'Perl extension for layerable hash values','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 215,'pod' => 96,'pod_errors' => 0,'total' => 311,'with_comments' => 21},'releases' => 1,'size' => {'packed' => 4109,'unpacked' => 11462},'testers' => {'pass' => 5},'uses' => ['5.005_62','AutoLoader','Exporter','strict','warnings']},'Tie-Hash-Rank-1.0.1.tar.gz' => {'author' => 'DCANTRELL','description' => 'A hash which turns values into ranking positions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 105,'pod' => 62,'pod_errors' => 0,'total' => 167,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 3282,'unpacked' => 8786},'testers' => {},'uses' => ['strict']},'Tie-Hash-Regex-0.09.tar.gz' => {'author' => 'DAVECROSS','description' => 'Look up values in hashes using regexes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 128,'pod' => 64,'pod_errors' => 0,'total' => 192,'with_comments' => 46},'releases' => 7,'requires' => ['Attribute-Handlers-0.78.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Attribute::Handlers' => '0.76','Test::Pod' => 0,'Test::Simple' => 0},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz'],'size' => {'packed' => 3609,'unpacked' => 7337},'testers' => {'pass' => 6},'uses' => ['Exporter','Tie::Hash','strict','vars']},'Tie-Hash-Stack-0.09.tar.gz' => {'author' => 'MNEYLON','description' => 'Maintains an array of hashes like a stack','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 243,'pod' => 100,'pod_errors' => 0,'total' => 343,'with_comments' => 17},'releases' => 1,'size' => {'packed' => 5700,'unpacked' => 28471},'testers' => {'pass' => 5},'uses' => ['Carp','strict','vars']},'Tie-Hash-Transactional-1.0.tar.gz' => {'author' => 'DCANTRELL','description' => 'A hash with checkpoints and rollbacks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 74,'pod_errors' => 0,'total' => 159,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 3264,'unpacked' => 8889},'testers' => {'pass' => 3},'uses' => ['strict']},'Tie-Hash-TwoWay-1.07.tar.gz' => {'author' => 'TEODOR','description' => 'Perl extension for two-way mapping between two disjoint sets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 184,'pod' => 62,'pod_errors' => 0,'total' => 246,'with_comments' => 25},'releases' => 2,'size' => {'packed' => 3112,'unpacked' => 7497},'testers' => {'pass' => 3},'uses' => ['5.005_62','Carp','Tie::Hash','constant','strict','vars']},'Tie-HashDefaults-0.01.tar.gz' => {'author' => 'JDPORTER','description' => 'Let a hash have default values','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 44,'pod_errors' => 0,'total' => 191,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 3520,'unpacked' => 8637},'testers' => {'pass' => 11},'uses' => ['Carp','strict','vars']},'Tie-HashHistory-0.03.tar.gz' => {'author' => 'MJD','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 143,'pod' => 71,'pod_errors' => 0,'total' => 214,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 3692,'unpacked' => 10667},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp']},'Tie-InsertOrderHash-0.01.tar.gz' => {'author' => 'BINKLEY','description' => 'insert-order-preserving tied hash','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 64,'pod' => 55,'pod_errors' => 0,'total' => 119,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 2389,'unpacked' => 5556},'testers' => {'pass' => 8},'uses' => ['Tie::Hash','strict','warnings']},'Tie-IntegerArray-0.01.tar.gz' => {'author' => 'SAMTREGAR','description' => 'provides a tied array of packed integers of any bit length','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 230,'pod' => 106,'pod_errors' => 1,'total' => 336,'with_comments' => 18},'releases' => 1,'requires' => ['Bit-Vector-6.3.tar.gz'],'requires_module' => {'Bit::Vector' => 0},'requires_recursive' => ['Bit-Vector-6.3.tar.gz'],'size' => {'packed' => 12762,'unpacked' => 36006},'testers' => {'pass' => 4},'uses' => ['5.6.0','Bit::Vector','Carp','Tie::Array','integer','strict','warnings']},'Tie-IxHash-1.21.tar.gz' => {'author' => 'GSAR','description' => 'Indexed hash (ordered array/hash composite)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 476,'pod' => 154,'pod_errors' => 0,'total' => 630,'with_comments' => 109},'releases' => 2,'size' => {'packed' => 6446,'unpacked' => 17615},'testers' => {'pass' => 35},'uses' => ['5.003','Tie::Hash','integer']},'Tie-LDAP-0.06.tar.gz' => {'author' => 'TAIY','description' => 'Tie LDAP database to Perl hash.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 280,'pod' => 119,'pod_errors' => 0,'total' => 399,'with_comments' => 11},'releases' => 4,'requires' => ['Net-LDAPapi-1.42.tar.gz'],'requires_module' => {'Net::LDAPapi' => 0},'requires_recursive' => ['Net-LDAPapi-1.42.tar.gz'],'size' => {'packed' => 4090,'unpacked' => 11185},'testers' => {},'uses' => ['Carp','Net::LDAPapi','diagnostics','strict','vars']},'Tie-LLHash-1.002.tar.gz' => {'author' => 'KWILLIAMS','description' => 'Fast ordered hashes via linked lists','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 267,'pod' => 138,'pod_errors' => 0,'total' => 405,'with_comments' => 22},'releases' => 5,'size' => {'packed' => 5869,'unpacked' => 16019},'testers' => {'pass' => 9},'uses' => ['Carp','strict','vars']},'Tie-LazyList-0.05.tar.gz' => {'author' => 'GENIE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 397,'pod' => 189,'pod_errors' => 0,'total' => 586,'with_comments' => 65},'releases' => 3,'size' => {'packed' => 8036,'unpacked' => 25377},'testers' => {},'uses' => ['5.006','Carp','Exporter','strict','warnings']},'Tie-ListKeyedHash-0.41.tar.gz' => {'author' => 'SNOWHARE','description' => 'Use lists to key multi-level hashes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 510,'pod' => 187,'pod_errors' => 0,'total' => 697,'with_comments' => 119},'releases' => 1,'size' => {'packed' => 4369,'unpacked' => 20423},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','Tie::Hash','strict','vars']},'Tie-LogFile-0.1.tar.gz' => {'author' => 'CREIN','description' => 'Simple Log Autoformating','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 213,'pod' => 132,'pod_errors' => 0,'total' => 345,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 4943,'unpacked' => 12563},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','strict','warnings']},'Tie-MLDBM-1.04.tar.gz' => {'author' => 'ROBAU','description' => 'Multi-Level Storage and Locking Class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 483,'pod' => 283,'pod_errors' => 0,'total' => 766,'with_comments' => 62},'releases' => 5,'requires' => ['Tie-DBI-0.91.tar.gz'],'requires_module' => {'Tie::DBI' => '0.91'},'requires_recursive' => ['Tie-DBI-0.91.tar.gz'],'size' => {'packed' => 7907,'unpacked' => 31565},'testers' => {},'uses' => ['Carp','DB_File','Fcntl','IO::File','Storable','Tie::DBI','Tie::Hash','strict','vars']},'Tie-Math-0.10.tar.gz' => {'author' => 'MSCHWERN','description' => 'Hashes which represent mathematical functions.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 179,'pod' => 135,'pod_errors' => 0,'total' => 314,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 5270,'unpacked' => 14381},'testers' => {'pass' => 6},'uses' => ['5.006','Exporter','constant','strict','vars']},'Tie-MmapArray-0.04.tar.gz' => {'author' => 'ANDREWF','description' => 'Ties a file to an array','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 44,'pod' => 140,'pod_errors' => 0,'total' => 184,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 21372,'unpacked' => 68186},'testers' => {'fail' => 3,'pass' => 6},'uses' => ['DynaLoader','strict','vars']},'Tie-Multidim-0.04.tar.gz' => {'author' => 'JDPORTER','description' => '"tie"-like multidimensional data structures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 115,'pod' => 76,'pod_errors' => 0,'total' => 191,'with_comments' => 5},'releases' => 4,'size' => {'packed' => 3740,'unpacked' => 9106},'testers' => {'pass' => 12},'uses' => ['strict','vars']},'Tie-NetAddr-IP-1.51.tar.gz' => {'author' => 'LUISMUNOZ','description' => 'Implements a Hash where the key is a subnet','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 154,'pod' => 69,'pod_errors' => 0,'total' => 223,'with_comments' => 2},'releases' => 3,'requires' => ['NetAddr-IP-3.14.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'NetAddr::IP' => 3,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','NetAddr-IP-3.14.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4641,'unpacked' => 11996},'testers' => {'pass' => 8},'uses' => ['Carp','NetAddr::IP','strict','vars']},'Tie-NumRange-0.021.tar.gz' => {'author' => 'PINYAN','description' => 'Keeps a number within a range of values.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 62,'pod_errors' => 0,'total' => 125,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 2297,'unpacked' => 5352},'testers' => {'pass' => 9},'uses' => []},'Tie-OffsetArray-0.01.tar.gz' => {'author' => 'JDPORTER','description' => 'Tie one array to another, with index offset','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 63,'pod' => 31,'pod_errors' => 0,'total' => 94,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 7787,'unpacked' => 22597},'testers' => {'fail' => 1,'pass' => 7},'uses' => ['5.005','Tie::Array','strict','vars']},'Tie-OneOff-0.2.tar.gz' => {'author' => 'NOBULL','description' => 'create tied variables without defining a separate package','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 45,'pod_errors' => 0,'total' => 117,'with_comments' => 2},'releases' => 2,'requires' => ['Scalar-List-Utils-1.11.tar.gz'],'requires_module' => {'Scalar::Util' => '1.07'},'requires_recursive' => ['Scalar-List-Utils-1.11.tar.gz'],'size' => {'packed' => 2660,'unpacked' => 5029},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','Scalar::Util','Tie::\\u\\L$type','strict','vars','warnings']},'Tie-PerFH-1.00.tar.gz' => {'author' => 'PINYAN','description' => 'creates scalars specific to a filehandle','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 17,'pod' => 31,'pod_errors' => 0,'total' => 48,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1516,'unpacked' => 2737},'testers' => {'pass' => 6},'uses' => []},'Tie-PerfectHash-0.01.tar.gz' => {'author' => 'XERN','description' => 'Minimal Perfect Hash','files' => [],'lines' => {'nonpod' => 149,'pod' => 115,'pod_errors' => 0,'total' => 264,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 3564,'unpacked' => 9075},'testers' => {'pass' => 3},'uses' => ['5.005_62','DynaLoader','Exporter','strict','warnings']},'Tie-Persistent-1.00.tar.gz' => {'author' => 'RGIERSIG','description' => 'Persistent data structures via tie made easy','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 582,'pod' => 209,'pod_errors' => 0,'total' => 791,'with_comments' => 88},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz'],'requires_module' => {'Data::Dumper' => '2.09','File::Spec' => '0.6','Storable' => '0.6'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 10125,'unpacked' => 31651},'testers' => {'pass' => 20},'uses' => ['Carp','Data::Dumper','File::Basename','File::Spec','Storable','strict','vars']},'Tie-Proxy-Hash-1.01.tar.gz' => {'author' => 'FLUFFY','description' => 'Effieciently merge & translate hashes.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1453,'pod' => 703,'pod_errors' => 0,'total' => 2156,'with_comments' => 149},'releases' => 2,'size' => {'packed' => 19451,'unpacked' => 74746},'testers' => {'pass' => 2},'uses' => ['','5.005','5.00503','5.005_62','Carp','Config','Cwd','Env','Exporter','ExtUtils::MakeMaker','Fatal','Fcntl','File::Basename','File::Compare','File::Find','File::Path','File::Spec','FindBin','POSIX','Pipeline::DataFlow','Test','constant','happy','strict','vars','warnings']},'Tie-PureDB-0.04.tar.gz' => {'author' => 'PODMASTER','description' => 'Perl extension for pure-db','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 186,'pod' => 167,'pod_errors' => 0,'total' => 353,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 258467,'unpacked' => 1113083},'testers' => {'fail' => 1,'pass' => 6,'tests' => '182'},'uses' => ['Carp','strict','vars']},'Tie-RangeHash-0.72.tar.gz' => {'author' => 'RRWO','description' => 'Hashes with \'low,high\' ranges as keys','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 722,'pod' => 203,'pod_errors' => 0,'total' => 925,'with_comments' => 150},'releases' => 9,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'warnings::register' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 11492,'unpacked' => 34825},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','integer','strict','warnings::register']},'Tie-RegexpHash-0.12.tar.gz' => {'author' => 'RRWO','description' => 'Use regular expressions as hash keys','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 281,'pod' => 108,'pod_errors' => 0,'total' => 389,'with_comments' => 25},'releases' => 2,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'warnings::register' => 0},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 3753,'unpacked' => 10998},'testers' => {'pass' => 5},'uses' => ['5.005','Carp','strict','vars']},'Tie-RemoteVar-0.02.tar.gz' => {'author' => 'XERN','description' => 'Share variables everywhere','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 418,'pod' => 116,'pod_errors' => 0,'total' => 534,'with_comments' => 9},'releases' => 2,'requires' => ['Net-Server-0.85.tar.gz','Net-Telnet-3.03.tar.gz'],'requires_module' => {'Net::Server' => '0.84','Net::Telnet' => '3'},'requires_recursive' => ['IO-1.20.tar.gz','Net-Server-0.85.tar.gz','Net-Telnet-3.03.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5857,'unpacked' => 20066},'testers' => {'pass' => 2},'uses' => ['5.006','Exporter','Net::Server','Net::Telnet','constant','strict']},'Tie-Restore-0.11.tar.gz' => {'author' => 'ROBWALKER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 25,'pod' => 35,'pod_errors' => 0,'total' => 60,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 1694,'unpacked' => 3203},'testers' => {'pass' => 6},'uses' => []},'Tie-STDERR-0.26.tar.gz' => {'author' => 'JANPAZ','description' => 'Send output of your STDERR to a process or mail','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 170,'pod' => 55,'pod_errors' => 0,'total' => 225,'with_comments' => 9},'releases' => 4,'size' => {'packed' => 4318,'unpacked' => 9208},'testers' => {'pass' => 3},'uses' => ['Apache','strict']},'Tie-Scalar-Decay-1.1.1.tar.gz' => {'author' => 'DCANTRELL','description' => 'Scalar variables that decay','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 106,'pod' => 73,'pod_errors' => 0,'total' => 179,'with_comments' => 6},'releases' => 3,'requires' => ['Time-HiRes-1.49.tar.gz'],'requires_module' => {'Time::HiRes' => '1.2'},'requires_recursive' => ['Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 3906,'unpacked' => 10779},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['Time::HiRes','strict']},'Tie-Scalar-Escaped-0.01.tar.gz' => {'author' => 'DAVIDNICO','description' => 'a variable that gives you a safe value','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 66,'pod' => 47,'pod_errors' => 0,'total' => 113,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2089,'unpacked' => 3506},'testers' => {'pass' => 2},'uses' => ['strict','vars','warnings']},'Tie-Scalar-OK-1.02.tar.gz' => {'author' => 'JEFFA','description' => 'generate numbered \'ok/not ok\' strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 42,'pod_errors' => 0,'total' => 92,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 2358,'unpacked' => 4069},'testers' => {'pass' => 6},'uses' => ['Tie::Scalar','strict','vars']},'Tie-Scalar-RestrictUpdates-0.0.1b.tar.gz' => {'author' => 'BEATNIK','description' => undef,'files' => [],'lines' => {'nonpod' => 30,'pod' => 38,'pod_errors' => 0,'total' => 68,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1640,'unpacked' => 2565},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['strict','vars']},'Tie-Scalar-Timeout-1.3.2.tar.gz' => {'author' => 'MARCEL','description' => 'Scalar variables that time out','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 142,'pod' => 95,'pod_errors' => 0,'total' => 237,'with_comments' => 22},'releases' => 4,'size' => {'packed' => 4625,'unpacked' => 12801},'testers' => {'fail' => 1,'pass' => 9},'uses' => ['Tie::Scalar','Time::Local','strict','warnings']},'Tie-Scalar-Transactional-0.01.tar.gz' => {'author' => 'UARUN','description' => 'Implementation of Transactional Scalars','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 148,'pod' => 128,'pod_errors' => 0,'total' => 276,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 4009,'unpacked' => 13976},'testers' => {'pass' => 5},'uses' => ['Carp','Exporter','strict','vars']},'Tie-SecureHash-1.03.tar.gz' => {'author' => 'DCONWAY','description' => 'Enforced encapsulation of Perl objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 452,'pod' => 183,'pod_errors' => 0,'total' => 635,'with_comments' => 36},'releases' => 2,'size' => {'packed' => 7994,'unpacked' => 31698},'testers' => {'pass' => 11},'uses' => ['Carp','strict','vars']},'Tie-SentientHash-0.55.tar.gz' => {'author' => 'ANDREWF','description' => 'Tracks changes to nested data structures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 811,'pod' => 172,'pod_errors' => 0,'total' => 983,'with_comments' => 84},'releases' => 3,'size' => {'packed' => 13406,'unpacked' => 62281},'testers' => {'fail' => 1,'pass' => 15},'uses' => ['Carp','constant','strict','vars']},'Tie-SortHash-1.01.tar.gz' => {'author' => 'CTWETEN','description' => 'Provides persistent sorting for hashes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 172,'pod' => 125,'pod_errors' => 0,'total' => 297,'with_comments' => 32},'releases' => 2,'size' => {'packed' => 4429,'unpacked' => 10071},'testers' => {'pass' => 12},'uses' => ['strict','vars']},'Tie-StrictHash-1.0.tar.gz' => {'author' => 'KVAIL','description' => 'A hash with strict-like semantics','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 232,'pod' => 193,'pod_errors' => 1,'total' => 425,'with_comments' => 51},'releases' => 1,'size' => {'packed' => 4955,'unpacked' => 15476},'testers' => {'pass' => 11},'uses' => ['5.005','Carp','Tie::Hash','strict','vars']},'Tie-Sysctl-0.05.tar.gz' => {'author' => 'RLZWART','description' => 'Tie a hash to /proc/sys','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 117,'pod' => 23,'pod_errors' => 0,'total' => 140,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 2239,'unpacked' => 4494},'testers' => {'pass' => 2},'uses' => ['Tie::Hash']},'Tie-Syslog-1.07.tar.gz' => {'author' => 'BROCSEIB','description' => 'Tie a filehandle to Syslog. If you Tie STDERR, then all STDERR errors are automatically caught, or you can debug by Carp\'ing to STDERR, etc. (Good for CGI error logging.)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 225,'pod' => 86,'pod_errors' => 0,'total' => 311,'with_comments' => 24},'releases' => 5,'size' => {'packed' => 7466,'unpacked' => 17713},'testers' => {'pass' => 3},'uses' => ['Sys::Syslog','strict','vars']},'Tie-Table-1.1.2.tar.gz' => {'author' => 'DLUX','description' => 'Maps relational tables into hashes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 598,'pod' => 326,'pod_errors' => 3,'total' => 924,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 10804,'unpacked' => 33943},'testers' => {'pass' => 3},'uses' => ['Carp','DBI','Storable','UNIVERSAL','strict','vars']},'Tie-TextDir-0.05.tar.gz' => {'author' => 'KWILLIAMS','description' => 'ties a hash to a directory of textfiles','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 189,'pod' => 65,'pod_errors' => 0,'total' => 254,'with_comments' => 7},'releases' => 5,'size' => {'packed' => 4736,'unpacked' => 10668},'testers' => {'pass' => 2},'uses' => ['Carp','Fcntl','File::Spec','FileHandle','strict','vars']},'Tie-TieDict-0.2.tar.gz' => {'author' => 'RANDYM','description' => '- A Perl tie to a dictionary file','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 251,'pod' => 33,'pod_errors' => 0,'total' => 284,'with_comments' => 31},'releases' => 1,'size' => {'packed' => 9004,'unpacked' => 24678},'testers' => {'pass' => 3},'uses' => ['AutoLoader','POSIX','Search::Dict','strict','vars']},'Tie-Tk-Listbox-1.01.tar.gz' => {'author' => 'SMUELLER','description' => 'Access Tk::Listbox widgets et al as arrays','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 186,'pod' => 59,'pod_errors' => 0,'total' => 245,'with_comments' => 6},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz','Tk-800.024.tar.gz'],'requires_module' => {'Test::More' => 0,'Tk' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tk-800.024.tar.gz'],'size' => {'packed' => 4172,'unpacked' => 12068},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','strict','vars','warnings']},'Tie-Toggle-1.03.tar.gz' => {'author' => 'BDFOY','description' => 'a scalar flip-flops between two values','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 42,'pod_errors' => 0,'total' => 73,'with_comments' => 1},'releases' => 3,'requires' => ['File-Find-Rule-0.10.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Tie-Cycle-1.06.tar.gz'],'requires_module' => {'File::Find::Rule' => '0','Test::Manifest' => '0.91','Test::More' => '0','Test::Pod' => '0.90','Tie::Cycle' => '1.05'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Find-Rule-0.10.tar.gz','File-Spec-0.82.tar.gz','IO-stringy-2.108.tar.gz','Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Test-Builder-Tester-0.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Pod-0.95.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Tie-Cycle-1.06.tar.gz'],'size' => {'packed' => 2124,'unpacked' => 3424},'testers' => {'pass' => 1},'uses' => ['','Tie::Cycle','strict','vars']},'Tie-Tools-1.03.tar.gz' => {'author' => 'SCHOP','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 375,'pod' => 31,'pod_errors' => 0,'total' => 406,'with_comments' => 3},'releases' => 4,'requires' => ['Tie-Cache-0.17.tar.gz'],'requires_module' => {'Tie::Cache' => '0.08'},'requires_recursive' => ['Tie-Cache-0.17.tar.gz'],'size' => {'packed' => 4019,'unpacked' => 10188},'testers' => {'fail' => 1},'uses' => ['Tie::Cache','Tie::DBI','Tie::Hash','strict','vars']},'Tie-TransactHash-0.03.tar.gz' => {'author' => 'MIKEDLR','description' => 'Allows edits on a hash without disturbing it','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 364,'pod' => 90,'pod_errors' => 0,'total' => 454,'with_comments' => 53},'releases' => 3,'requires' => ['Tie-IxHash-1.21.tar.gz'],'requires_module' => {'Tie::IxHash' => '1.2'},'requires_recursive' => ['Tie-IxHash-1.21.tar.gz'],'size' => {'packed' => 16718,'unpacked' => 48651},'testers' => {'pass' => 9},'uses' => ['5.002','Carp','Tie::IxHash','strict']},'Tie-TwoLevelHash-1.2.tar.gz' => {'author' => 'KMELTZ','description' => 'Tied interface to multi-dimensional (Two-Level) hash files','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 483,'pod' => 309,'pod_errors' => 0,'total' => 792,'with_comments' => 55},'releases' => 3,'size' => {'packed' => 7366,'unpacked' => 23165},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars']},'Tie-VecArray-0.01.tar.gz' => {'author' => 'MSCHWERN','description' => 'An array interface to a bit vector.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 114,'pod' => 79,'pod_errors' => 0,'total' => 193,'with_comments' => 6},'releases' => 1,'requires' => ['Class-Fields-0.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'POSIX' => 0,'base' => 0,'fields' => 0},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3270,'unpacked' => 7592},'testers' => {'fail' => 1,'pass' => 7,'tests' => '13'},'uses' => ['POSIX','Tie::Array','fields','strict','vars']},'Tie-WarnGlobal-0.04.tar.gz' => {'author' => 'STEPHEN','description' => 'Ties variables to functions, warns on use','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 251,'pod' => 120,'pod_errors' => 0,'total' => 371,'with_comments' => 4},'releases' => 3,'size' => {'packed' => 5160,'unpacked' => 14188},'testers' => {'pass' => 5},'uses' => ['Carp','Tie::WarnGlobal::Scalar','fields','strict','vars']},'Tie-Watch-1.1.tar.gz' => {'author' => 'LUSOL','description' => 'Watch variables, run code when read/written','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 371,'pod' => 178,'pod_errors' => 0,'total' => 549,'with_comments' => 67},'releases' => 10,'size' => {'packed' => 8681,'unpacked' => 26214},'testers' => {'pass' => 2},'uses' => ['5.004_57','Carp','strict','subs','vars']},'Tie_Counter-1.1.tgz' => {'author' => 'ABIGAIL','description' => 'Have a counter in a scalar.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 49,'pod' => 41,'pod_errors' => 0,'total' => 90,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 1742,'unpacked' => 3253},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Tie_FlipFlop-1.1.tgz' => {'author' => 'ABIGAIL','description' => 'Alternate between two values.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 49,'pod' => 37,'pod_errors' => 0,'total' => 86,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 1699,'unpacked' => 3037},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars']},'Tie_Pick-1.1.tgz' => {'author' => 'ABIGAIL','description' => 'Randomly pick (and remove) an element from a set.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 64,'pod_errors' => 0,'total' => 141,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 2645,'unpacked' => 4987},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars']},'Tiger-hash-1.0b.tar.gz' => {'author' => 'DIDO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 88,'pod' => 43,'pod_errors' => 0,'total' => 131,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 22410,'unpacked' => 53817},'testers' => {'pass' => 5,'tests' => '0','unknown' => 3},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Time-Avail-1.00.tar.gz' => {'author' => 'PSANTORO','description' => 'Calculate min. remaining in time interval','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 211,'pod' => 89,'pod_errors' => 0,'total' => 300,'with_comments' => 40},'releases' => 1,'size' => {'packed' => 3910,'unpacked' => 14178},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.003','diagnostics','integer','strict']},'Time-Beat-1.02.tar.gz' => {'author' => 'JDUNCAN','description' => 'Module to convert from standard time to swatch \'beat\' time.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 35,'pod_errors' => 0,'total' => 80,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 1197,'unpacked' => 1740},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['','Exporter','vars']},'Time-Duration-1.02.tar.gz' => {'author' => 'SBURKE','description' => 'rounded or exact English expression of durations','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 317,'pod' => 128,'pod_errors' => 0,'total' => 445,'with_comments' => 58},'releases' => 2,'size' => {'packed' => 8288,'unpacked' => 33332},'testers' => {'pass' => 6},'uses' => ['Exporter','constant','strict']},'Time-Duration-sv-1.01.tar.gz' => {'author' => 'ABERGMAN','description' => 'rounded or exact Swedish duratations','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 145,'pod' => 42,'pod_errors' => 0,'total' => 187,'with_comments' => 25},'releases' => 2,'requires' => ['Time-Duration-1.02.tar.gz'],'requires_module' => {'Time::Duration' => '1.02'},'requires_recursive' => ['Time-Duration-1.02.tar.gz'],'size' => {'packed' => 4909,'unpacked' => 18457},'testers' => {'pass' => 4},'uses' => ['Data::Dumper','Exporter','Time::Duration','constant','strict']},'Time-Epoch-0.02.tar.gz' => {'author' => 'CNANDOR','description' => 'Convert between Perl epoch and other epochs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 49,'pod_errors' => 0,'total' => 128,'with_comments' => 0},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2080,'unpacked' => 4038},'testers' => {'pass' => 2},'uses' => ['Exporter','Time::Local','strict','vars']},'Time-Format-0.12.tar.gz' => {'author' => 'ROODE','description' => 'Easy-to-use date/time formatting','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 558,'pod' => 325,'pod_errors' => 0,'total' => 883,'with_comments' => 90},'releases' => 11,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Simple' => '0.40'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 36811,'unpacked' => 75474},'testers' => {'pass' => 1},'uses' => ['I18N::Langinfo','strict','subs','vars']},'Time-Format_XS-0.12.tar.gz' => {'author' => 'ROODE','description' => 'Companion module for Time::Format, to speed up time formatting.','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 41,'pod_errors' => 0,'total' => 91,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 16001,'unpacked' => 60841},'testers' => {'pass' => 1},'uses' => ['XSLoader','strict','vars']},'Time-HR-0.02.tar.gz' => {'author' => 'AGOLOMSH','description' => 'Perl interface to high-resolution timer.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 80,'pod' => 31,'pod_errors' => 0,'total' => 111,'with_comments' => 13},'releases' => 2,'size' => {'packed' => 3442,'unpacked' => 7372},'testers' => {'pass' => 2},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Time-HiRes-1.49.tar.gz' => {'author' => 'JHI','description' => 'High resolution time, sleep, and alarm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 145,'pod' => 208,'pod_errors' => 0,'total' => 353,'with_comments' => 3},'releases' => 32,'size' => {'packed' => 27931,'unpacked' => 84403},'testers' => {'pass' => 6},'uses' => ['DynaLoader','Exporter','strict','vars']},'Time-Human-1.02.tar.gz' => {'author' => 'SIMON','description' => 'Convert localtime() format to "speaking clock" time','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 107,'pod' => 34,'pod_errors' => 0,'total' => 141,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 2771,'unpacked' => 5179},'testers' => {'pass' => 5},'uses' => ['5.005_62','Exporter','strict','warnings']},'Time-Interval-1.0.tar.gz' => {'author' => 'AHICOX','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 137,'pod_errors' => 0,'total' => 274,'with_comments' => 29},'releases' => 1,'size' => {'packed' => 3157,'unpacked' => 7926},'testers' => {'pass' => 2},'uses' => ['Date::Parse','Exporter','strict']},'Time-Local-1.07.tar.gz' => {'author' => 'DROLSKY','description' => 'Implements timelocal() and timegm()','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 214,'pod' => 75,'pod_errors' => 0,'total' => 289,'with_comments' => 15},'releases' => 3,'size' => {'packed' => 13758,'unpacked' => 35022},'testers' => {'pass' => 5},'uses' => ['Carp','Config','Exporter','integer','strict','vars']},'Time-Object-1.00.tar.gz' => {'author' => 'MSERGEANT','description' => 'Object Oriented time objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 641,'pod' => 217,'pod_errors' => 0,'total' => 858,'with_comments' => 24},'releases' => 8,'size' => {'packed' => 13525,'unpacked' => 44659},'testers' => {'fail' => 2,'pass' => 13,'tests' => '79'},'uses' => ['Carp','DynaLoader','Exporter','Time::Seconds','UNIVERSAL','constant','integer','strict','vars']},'Time-Piece-1.08.tar.gz' => {'author' => 'MSERGEANT','description' => 'Object Oriented time objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 752,'pod' => 240,'pod_errors' => 0,'total' => 992,'with_comments' => 41},'releases' => 8,'size' => {'packed' => 18824,'unpacked' => 56986},'testers' => {'pass' => 17},'uses' => ['Carp','DynaLoader','Exporter','Time::Local','UNIVERSAL','constant','integer','strict','vars']},'Time-Piece-ISO-0.04.tar.gz' => {'author' => 'DWHEELER','description' => 'ISO 8601 Subclass of Time::Piece','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 62,'pod' => 57,'pod_errors' => 0,'total' => 119,'with_comments' => 2},'releases' => 3,'requires' => ['Time-Piece-1.08.tar.gz'],'requires_module' => {'Time::Piece' => '1.01'},'requires_recursive' => ['Time-Piece-1.08.tar.gz'],'size' => {'packed' => 3035,'unpacked' => 6872},'testers' => {'pass' => 8},'uses' => ['Exporter','strict','vars']},'Time-Piece-MySQL-0.03.tar.gz' => {'author' => 'KASEI','description' => 'MySQL-specific functions for Time::Piece','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 115,'pod' => 71,'pod_errors' => 0,'total' => 186,'with_comments' => 2},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz'],'requires_module' => {'Test::More' => '0.47','Time::Piece' => '1.03'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz'],'size' => {'packed' => 2626,'unpacked' => 6966},'testers' => {'fail' => 1,'pass' => 2,'tests' => '46'},'uses' => ['Time::Piece','Time::Seconds','strict','vars']},'Time-Piece-Range-0.9.tar.gz' => {'author' => 'TMTM','description' => 'deal with a range of Time::Piece objects','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 24,'pod' => 40,'pod_errors' => 0,'total' => 64,'with_comments' => 0},'releases' => 1,'requires' => ['Date-Range-1.1.tar.gz'],'requires_module' => {'Date::Range' => '1.0'},'requires_recursive' => ['Date-Range-1.1.tar.gz','Date-Simple-1.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1946,'unpacked' => 4728},'testers' => {'fail' => 1,'pass' => 6},'uses' => ['Carp','Date::Range','Time::Piece','Time::Seconds','strict','vars']},'Time-Progress-1.1.tar.gz' => {'author' => 'CADE','description' => 'Elapsed and estimated finish time reporting.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 162,'pod' => 205,'pod_errors' => 0,'total' => 367,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 10588,'unpacked' => 26849},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','strict','warnings']},'Time-SoFar-1.00.tgz' => {'author' => 'ELIJAH','description' => 'Perl module to calculate run time','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 86,'pod' => 77,'pod_errors' => 0,'total' => 163,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 3300,'unpacked' => 10052},'testers' => {'fail' => 1,'pass' => 4,'tests' => '11'},'uses' => ['Exporter','integer','vars']},'Time-Stopwatch-1.00.tar.gz' => {'author' => 'ILTZU','description' => 'Tied variables that count seconds','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 97,'pod_errors' => 0,'total' => 166,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 4026,'unpacked' => 9353},'testers' => {'pass' => 11},'uses' => ['strict']},'Time-TAI64-1.8.tar.gz' => {'author' => 'SPOON','description' => 'Time manipulation in the TAI64* formats','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 123,'pod' => 170,'pod_errors' => 0,'total' => 293,'with_comments' => 5},'releases' => 3,'requires' => ['Test-Differences-0.47.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Differences' => '0.45','Test::More' => '0.41'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','File-Spec-0.82.tar.gz','Test-Differences-0.47.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Diff-0.35.tar.gz'],'size' => {'packed' => 34092,'unpacked' => 109234},'testers' => {'fail' => 5,'pass' => 1,'tests' => '40'},'uses' => ['5.008','AutoLoader','Carp','Exporter','XSLoader','strict','warnings']},'Time-Tradedates-0.1.2.tar.gz' => {'author' => 'DSPIZZ','description' => 'Perl extension for last and first trade dates in a month','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 134,'pod' => 35,'pod_errors' => 0,'total' => 169,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 3108,'unpacked' => 7677},'testers' => {'pass' => 2},'uses' => ['Exporter','Time::Local','strict']},'Time-Travel-0.03.tar.gz' => {'author' => 'ROMM','description' => 'provide a tool to travel across the time for a given distance.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 168,'pod' => 94,'pod_errors' => 0,'total' => 262,'with_comments' => 9},'releases' => 3,'requires' => ['Time-modules-2003.0211.tar.gz','TimeDate-1.16.tar.gz'],'requires_module' => {'Date::Parse' => '2.20','Time::DaysInMonth' => '96.032702','Time::ParseDate' => '101'},'requires_recursive' => ['Time-modules-2003.0211.tar.gz','TimeDate-1.16.tar.gz'],'size' => {'packed' => 3936,'unpacked' => 8878},'testers' => {'fail' => 2,'tests' => '4'},'uses' => ['Carp','Date::Parse','Time::DaysInMonth','strict','warnings']},'Time-Unix-1.03.tar.gz' => {'author' => 'NWIGER','description' => 'Force time() to return secs since UNIX epoch','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 70,'pod' => 31,'pod_errors' => 0,'total' => 101,'with_comments' => 33},'releases' => 3,'size' => {'packed' => 2735,'unpacked' => 5830},'testers' => {'pass' => 8},'uses' => ['5.003','Exporter','Time::Local','strict','vars']},'Time-Warp-0.5.tar.gz' => {'author' => 'JPRIT','description' => 'Change the start and speed of Event time','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 33,'pod' => 50,'pod_errors' => 0,'total' => 83,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 3096,'unpacked' => 5989},'testers' => {'pass' => 11},'uses' => ['DynaLoader','Exporter','strict','vars']},'Time-ZoneInfo-0.2.tar.gz' => {'author' => 'SCOTT','description' => 'Perl extension for returning a list of Time Zones...','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 80,'pod' => 48,'pod_errors' => 0,'total' => 128,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 2719,'unpacked' => 4938},'testers' => {'fail' => 1,'pass' => 4,'tests' => '3'},'uses' => ['IO::File','strict','vars']},'Time-modules-2003.0211.tar.gz' => {'author' => 'MUIR','description' => 'Parses many forms of dates and times','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1719,'pod' => 302,'pod_errors' => 0,'total' => 2021,'with_comments' => 233},'releases' => 19,'size' => {'packed' => 21508,'unpacked' => 69856},'testers' => {'pass' => 2},'uses' => ['5.000','5.002','Carp','Exporter','integer','strict','vars']},'TimeDate-1.16.tar.gz' => {'author' => 'GBARR','description' => '- miscellaneous timezone manipulations routines','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2099,'pod' => 215,'pod_errors' => 0,'total' => 2314,'with_comments' => 235},'releases' => 16,'size' => {'packed' => 22366,'unpacked' => 82146},'testers' => {'pass' => 6},'uses' => ['5.000','5.002','Carp','Exporter','Time::Local','strict','utf','vars']},'TipJar-MTA-0.14.tar.gz' => {'author' => 'DAVIDNICO','description' => 'outgoing SMTP with exponential random backoff.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1148,'pod' => 159,'pod_errors' => 0,'total' => 1307,'with_comments' => 96},'releases' => 9,'requires' => ['dateheader-1.0.tar.gz'],'requires_module' => {'dateheader' => 0},'requires_recursive' => ['dateheader-1.0.tar.gz'],'size' => {'packed' => 12289,'unpacked' => 35912},'testers' => {'pass' => 1},'uses' => ['Carp','Fcntl','Socket','Sys::Hostname','dateheader','strict','vars','warnings']},'TipJar-MTA-queue-0.02.tar.gz' => {'author' => 'DAVIDNICO','description' => 'send e-mail via TipJar::MTA','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 100,'pod_errors' => 0,'total' => 229,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 4128,'unpacked' => 8235},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Fcntl','TipJar::fields','strict','vars','warnings']},'TipJar-fields-0.01.tar.gz' => {'author' => 'DAVIDNICO','description' => 'generate constants and accessors for array-based objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 41,'pod' => 39,'pod_errors' => 0,'total' => 80,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1829,'unpacked' => 2886},'testers' => {'pass' => 3},'uses' => ['Carp','strict','vars','warnings']},'Tivoli_0.01.tar.gz' => {'author' => 'RHASE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 660,'pod' => 1214,'pod_errors' => 11,'total' => 1874,'with_comments' => 48},'releases' => 1,'size' => {'packed' => 14312,'unpacked' => 107036},'testers' => {'pass' => 4},'uses' => ['Exporter']},'Tk-800.024.tar.gz' => {'author' => 'NI-S','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 44009,'pod' => 21767,'pod_errors' => 19,'total' => 65776,'with_comments' => 4369},'releases' => 1,'size' => {'packed' => 3489636,'unpacked' => 14959413},'testers' => {'fail' => 4,'pass' => 6,'tests' => '838'},'uses' => ['5.002','5.004','5.00404','5.004_57','AutoLoader','Carp','Config','Cwd','DirHandle','DynaLoader','English','Exporter','ExtUtils::MakeMaker','File::Basename','IO::Handle','Text::Tabs','Tie::Scalar','Tie::Watch','Tk::$_','Tk::$method','Tk::${need}','Tk::Config','Tk::LabRadio','Tk::Menu::Button','Tk::Reindex','Tk::ReindexedROText','UNIVERSAL','overload','strict','subs','vars']},'Tk-ACH-0.03.tar.gz' => {'author' => 'ACH','description' => 'Entry with bg color depending on -state','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 200,'pod' => 100,'pod_errors' => 0,'total' => 300,'with_comments' => 9},'releases' => 2,'requires' => ['ExtUtils-MakeMaker-6.05.tar.gz','Tk-800.024.tar.gz'],'requires_module' => {'ExtUtils::MakeMaker' => '5.41','Tk' => '402.002'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','Tk-800.024.tar.gz'],'size' => {'packed' => 10214,'unpacked' => 25457},'testers' => {'fail' => 1,'pass' => 1,'tests' => '35'},'uses' => ['Tk','Tk::Button','Tk::Derived','Tk::Entry','Tk::FileSelect','Tk::Frame','Tk::Label','Tk::Widget','strict','vars']},'Tk-ActivityBar-0.01.tar.gz' => {'author' => 'AARDEN','description' => 'Adds an indeterminate progress display to Tk::ProgressBar. =for category Derived Widgets','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 200,'pod' => 83,'pod_errors' => 1,'total' => 283,'with_comments' => 3},'releases' => 1,'requires' => ['Tk-GBARR-1.0401.tar.gz'],'requires_module' => {'Tk::ProgressBar' => '3.012'},'requires_recursive' => ['Tk-800.024.tar.gz','Tk-GBARR-1.0401.tar.gz'],'size' => {'packed' => 3440,'unpacked' => 8776},'testers' => {'fail' => 1},'uses' => ['Tk::Derived','Tk::ProgressBar','strict','vars']},'Tk-Autoscroll-1.11.tar.gz' => {'author' => 'SREZIC','description' => 'Alternative way to scroll','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 257,'pod' => 62,'pod_errors' => 0,'total' => 319,'with_comments' => 32},'releases' => 1,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => undef},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 4454,'unpacked' => 11677},'testers' => {'pass' => 2},'uses' => ['Tk::Widget','strict','vars']},'Tk-Browser-0.81.tar.gz' => {'author' => 'RKIES','description' => '- Perl library browser.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1226,'pod' => 166,'pod_errors' => 0,'total' => 1392,'with_comments' => 32},'releases' => 3,'requires' => ['Lib-Module-0.67.tar.gz'],'requires_module' => {'Lib::Module' => '0.65'},'requires_recursive' => ['Lib-Module-0.67.tar.gz'],'size' => {'packed' => 19641,'unpacked' => 71254},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','DB','IO::File','Lib::Module','POSIX','Pod::Text','Tk','Tk::Button','Tk::Dialog','Tk::DialogBox','Tk::FileSelect','Tk::MainWindow','Tk::Widget','vars']},'Tk-Calculator-RPN-HP-0.6.tar.gz' => {'author' => 'LUSOL','description' => 'Hewlett-Packard RPN calculators','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1351,'pod' => 165,'pod_errors' => 0,'total' => 1516,'with_comments' => 203},'releases' => 2,'requires' => ['Tk-LCD-1.3.tar.gz','Tk-ProgressBar-Mac-1.1.tar.gz','Tk-SlideSwitch-1.1.tar.gz','Tk-Splashscreen-1.0.tar.gz'],'requires_module' => {'Tk::LCD' => '1.2','Tk::ProgressBar::Mac' => '1.1','Tk::SlideSwitch' => '1.1','Tk::Splashscreen' => 1},'requires_recursive' => ['Tk-LCD-1.3.tar.gz','Tk-ProgressBar-Mac-1.1.tar.gz','Tk-SlideSwitch-1.1.tar.gz','Tk-Splashscreen-1.0.tar.gz'],'size' => {'packed' => 229988,'unpacked' => 263425},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Exporter','POSIX','Tk::Frame','Tk::LCD','Tk::widgets','strict','subs']},'Tk-CanvasFig-1.014.tar.gz' => {'author' => 'SREZIC','description' => 'additional Tk::Canvas methods for dealing with figs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 643,'pod' => 52,'pod_errors' => 0,'total' => 695,'with_comments' => 95},'releases' => 1,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 8190,'unpacked' => 26322},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Config','File::Basename','File::Spec','Tk::Canvas','Tk::Font','strict','vars']},'Tk-CheckbuttonGroup-0.2.2.tar.gz' => {'author' => 'JANNINO','description' => 'widget displays and manages a group of related checkbuttons','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 201,'pod' => 74,'pod_errors' => 0,'total' => 275,'with_comments' => 34},'releases' => 3,'requires' => ['Tie-IxHash-1.21.tar.gz','Tk-800.024.tar.gz'],'requires_module' => {'Tie::IxHash' => 0,'Tk' => '402.000'},'requires_recursive' => ['Tie-IxHash-1.21.tar.gz','Tk-800.024.tar.gz'],'size' => {'packed' => 4255,'unpacked' => 12447},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['','Tie::IxHash','Tk::Frame','Tk::widgets','strict']},'Tk-Clock-0.06.tar.gz' => {'author' => 'HMBRAND','description' => 'Canvas based Clock widget','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 465,'pod' => 43,'pod_errors' => 0,'total' => 508,'with_comments' => 39},'releases' => 4,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '402.000'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 6196,'unpacked' => 18327},'testers' => {'fail' => 1,'pass' => 6,'tests' => '10'},'uses' => ['Carp','Tk::Canvas','Tk::Derived','Tk::Widget','strict','vars']},'Tk-CodeText-0.3.1.tar.gz' => {'author' => 'HANJE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1559,'pod' => 699,'pod_errors' => 1,'total' => 2258,'with_comments' => 59},'releases' => 1,'requires' => ['Syntax-Highlight-Perl-1.0.tar.gz'],'requires_module' => {'Syntax::Highlight::Perl' => '1.0'},'requires_recursive' => ['Syntax-Highlight-Perl-1.0.tar.gz'],'size' => {'packed' => 14928,'unpacked' => 52488},'testers' => {'pass' => 1},'uses' => ['Data::Dumper','File::Basename','Storable','Syntax::Highlight::Perl','Tk::Derived','Tk::DialogBox','Tk::LabEntry','Tk::LabFrame','Tk::Listbox','Tk::TextUndo','strict','vars']},'Tk-CollapsableFrame-1.2.tar.gz' => {'author' => 'LUSOL','description' => 'Frame that opens and closes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 155,'pod' => 89,'pod_errors' => 0,'total' => 244,'with_comments' => 20},'releases' => 3,'size' => {'packed' => 3732,'unpacked' => 9137},'testers' => {'pass' => 1},'uses' => ['Carp','Tk::Frame','Tk::widgets','strict','vars']},'Tk-ColourChooser-1.50.tar.gz' => {'author' => 'SUMMER','description' => 'Perl/Tk module providing a Colour selection dialogue box.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 381,'pod' => 102,'pod_errors' => 0,'total' => 483,'with_comments' => 25},'releases' => 10,'size' => {'packed' => 6893,'unpacked' => 23433},'testers' => {'pass' => 4},'uses' => ['5.004','Carp','Symbol','Tk','Tk::Toplevel','strict','vars']},'Tk-ContextHelp-0.10.tar.gz' => {'author' => 'SREZIC','description' => 'A context-sensitive help system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 544,'pod' => 135,'pod_errors' => 0,'total' => 679,'with_comments' => 34},'releases' => 4,'requires' => ['Tk-800.024.tar.gz','Tk-Pod-0.9919.tar.gz'],'requires_module' => {'Tk' => '402.002','Tk::Pod' => 4},'requires_recursive' => ['Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Tk-800.024.tar.gz','Tk-HistEntry-0.40.tar.gz','Tk-Pod-0.9919.tar.gz','perlindex-1.301.tar.gz'],'size' => {'packed' => 9673,'unpacked' => 30607},'testers' => {'pass' => 1},'uses' => ['Config','Tk::InputO','Tk::Pod','Tk::ROText','Tk::Toplevel','strict','vars']},'Tk-Contrib-0.05.tar.gz' => {'author' => 'ACH','description' => 'an alternative to the Scale widget','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 661,'pod' => 224,'pod_errors' => 0,'total' => 885,'with_comments' => 8},'releases' => 5,'size' => {'packed' => 10772,'unpacked' => 28669},'testers' => {'fail' => 1,'pass' => 2,'tests' => '4'},'uses' => ['5.002','5.004','Carp','Tk','Tk::Canvas','Tk::Frame','Tk::Listbox','vars']},'Tk-Contrib-0.07.tar.gz' => {'author' => 'ACH','description' => 'Gang together Listboxes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 650,'pod' => 248,'pod_errors' => 0,'total' => 898,'with_comments' => 8},'releases' => 5,'size' => {'packed' => 12468,'unpacked' => 33145},'testers' => {'fail' => 2,'pass' => 1,'tests' => '36'},'uses' => ['5.004','Carp','Tk','Tk::Canvas','Tk::Frame','Tk::Listbox','strict','vars']},'Tk-Copy-Mac-1.3.tar.gz' => {'author' => 'LUSOL','description' => 'simulate a Macintosh Classic copy dialog','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 902,'pod' => 233,'pod_errors' => 0,'total' => 1135,'with_comments' => 68},'releases' => 1,'size' => {'packed' => 10263,'unpacked' => 33145},'testers' => {'pass' => 2},'uses' => ['5.004','Fcntl','File::Basename','File::Find','File::NCopy','File::Spec','Tk::ProgressBar::Mac','Tk::Toplevel','Tk::widgets','strict','vars']},'Tk-CursorControl-0.2.tar.gz' => {'author' => 'DUNNIGANJ','description' => 'Manipulate the mouse cursor programmatically','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 576,'pod' => 139,'pod_errors' => 0,'total' => 715,'with_comments' => 73},'releases' => 1,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '800.015'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 11006,'unpacked' => 30091},'testers' => {'pass' => 1},'uses' => ['5.005_62','Carp','Tk','strict']},'Tk-DBI-Form-0.03.tar.gz' => {'author' => 'XPIX','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 943,'pod' => 324,'pod_errors' => 0,'total' => 1267,'with_comments' => 111},'releases' => 3,'requires' => ['JBrowseEntry.4.22.tar.gz','Tk-800.024.tar.gz','Tk-Date-0.40.tar.gz','Tk-GBARR-2.06.tar.gz','Tk-XDialogBox-0.01.tar.gz'],'requires_module' => {'Tk' => 0,'Tk::Date' => 0,'Tk::FBox' => 0,'Tk::JBrowseEntry' => 0,'Tk::LabFrame' => 0,'Tk::NumEntry' => 0,'Tk::XDialogBox' => 0},'requires_recursive' => ['JBrowseEntry.4.22.tar.gz','Tk-800.024.tar.gz','Tk-Date-0.40.tar.gz','Tk-GBARR-2.06.tar.gz','Tk-XDialogBox-0.01.tar.gz'],'size' => {'packed' => 11221,'unpacked' => 38933},'testers' => {},'uses' => ['Data::Dumper','Date::Manip','Tk::Date','Tk::FBox','Tk::Frame','Tk::JBrowseEntry','Tk::LabFrame','Tk::NumEntry','Tk::ROText','Tk::XDialogBox','strict']},'Tk-DBI-Table-0.02.tar.gz' => {'author' => 'XPIX','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 358,'pod' => 109,'pod_errors' => 0,'total' => 467,'with_comments' => 53},'releases' => 2,'requires' => ['Tk-800.024.tar.gz','Tk-ResizeButton-0.01.tar.gz'],'requires_module' => {'Tk' => 0,'Tk::ResizeButton' => 0},'requires_recursive' => ['Tk-800.024.tar.gz','Tk-ResizeButton-0.01.tar.gz'],'size' => {'packed' => 5039,'unpacked' => 14475},'testers' => {'pass' => 1},'uses' => ['Data::Dumper','Tk::Compound','Tk::Derived','Tk::Frame','Tk::HList','Tk::ResizeButton','strict']},'Tk-DBI-Tree-0.03.tar.gz' => {'author' => 'XPIX','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 667,'pod' => 280,'pod_errors' => 0,'total' => 947,'with_comments' => 71},'releases' => 3,'requires' => ['DBIx-Tree-1.9.tar.gz','Tk-800.024.tar.gz','Tk-ResizeButton-0.01.tar.gz'],'requires_module' => {'DBIx::Tree' => 0,'Tk' => 0,'Tk::ResizeButton' => 0},'requires_recursive' => ['DBD-mysql-2.9002.tar.gz','DBIx-Tree-1.9.tar.gz','Tk-800.024.tar.gz','Tk-ResizeButton-0.01.tar.gz'],'size' => {'packed' => 9619,'unpacked' => 32248},'testers' => {},'uses' => ['DBIx::Tree','Tk::Compound','Tk::Derived','Tk::Frame','Tk::ItemStyle','Tk::ResizeButton','Tk::Tree','strict']},'Tk-DKW-0.01.tar.gz' => {'author' => 'DKWILSON','description' => 'Multi column lists w/ resizable borders','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4317,'pod' => 409,'pod_errors' => 10,'total' => 4726,'with_comments' => 75},'releases' => 3,'requires' => ['Tk-800.024.tar.gz','Tk-Contrib-0.07.tar.gz','Tk-GBARR-1.0401.tar.gz'],'requires_module' => {'Tk' => '402.002','Tk::Pane' => '0','Tk::TiedListbox' => '0'},'requires_recursive' => ['Tk-800.024.tar.gz','Tk-Contrib-0.07.tar.gz','Tk-GBARR-1.0401.tar.gz'],'size' => {'packed' => 38907,'unpacked' => 176826},'testers' => {'pass' => 1},'uses' => ['Carp','Tk','Tk::Button','Tk::Canvas','Tk::ChildNotification','Tk::Derived','Tk::Entry','Tk::Frame','Tk::Label','Tk::Listbox','Tk::Pane','Tk::Scrollbar','Tk::SplitFrame','Tk::TabFrame','Tk::TabbedForm','Tk::TiedListbox','Tk::Toplevel','Tk::Widget','strict','vars']},'Tk-DKW-0.02.tar.gz' => {'author' => 'DKWILSON','description' => 'Canvas with movable iconic interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5995,'pod' => 1249,'pod_errors' => 29,'total' => 7244,'with_comments' => 196},'releases' => 3,'requires' => ['Tk-800.024.tar.gz','Tk-Contrib-0.07.tar.gz','Tk-GBARR-1.0401.tar.gz'],'requires_module' => {'Tk' => '800.005','Tk::Pane' => '0','Tk::TiedListbox' => '0'},'requires_recursive' => ['Tk-800.024.tar.gz','Tk-Contrib-0.07.tar.gz','Tk-GBARR-1.0401.tar.gz'],'size' => {'packed' => 50027,'unpacked' => 236554},'testers' => {'pass' => 3},'uses' => ['Carp','Tk','Tk::Button','Tk::Canvas','Tk::Columns','Tk::Derived','Tk::DockFrame::Base','Tk::Entry','Tk::Frame','Tk::Label','Tk::Listbox','Tk::Pane','Tk::Scrollbar','Tk::TiedListbox','Tk::Toplevel','Tk::Widget','strict','vars']},'Tk-DKW-0.03.tar.gz' => {'author' => 'DKWILSON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6024,'pod' => 1251,'pod_errors' => 29,'total' => 7275,'with_comments' => 196},'releases' => 3,'requires' => ['Tk-800.024.tar.gz','Tk-Contrib-0.07.tar.gz','Tk-GBARR-1.0401.tar.gz'],'requires_module' => {'Tk' => '800.005','Tk::Pane' => '0','Tk::TiedListbox' => '0'},'requires_recursive' => ['Tk-800.024.tar.gz','Tk-Contrib-0.07.tar.gz','Tk-GBARR-1.0401.tar.gz'],'size' => {'packed' => 50997,'unpacked' => 239617},'testers' => {'pass' => 3},'uses' => ['Carp','Tk','Tk::Button','Tk::Canvas','Tk::ChildNotification','Tk::Columns','Tk::Derived','Tk::DockFrame::Base','Tk::Entry','Tk::Frame','Tk::Label','Tk::Listbox','Tk::Pane','Tk::Scrollbar','Tk::SplitFrame','Tk::TabFrame','Tk::TabbedForm','Tk::TiedListbox','Tk::Toplevel','Tk::Widget','strict','vars']},'Tk-Date-0.40.tar.gz' => {'author' => 'SREZIC','description' => 'A date/time widget','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1190,'pod' => 268,'pod_errors' => 1,'total' => 1458,'with_comments' => 72},'releases' => 15,'requires' => ['Tk-800.024.tar.gz','Tk-GBARR-2.06.tar.gz'],'requires_module' => {'Tk' => '402.002','Tk::FireButton' => '0.05','Tk::NumEntry' => '1.08','Tk::NumEntryPlain' => '0.02'},'requires_recursive' => ['Tk-800.024.tar.gz','Tk-GBARR-2.06.tar.gz'],'size' => {'packed' => 18100,'unpacked' => 60853},'testers' => {'pass' => 3},'uses' => ['Date::Format','POSIX','Time::Local','Tk::FireButton','Tk::Menubutton','Tk::NumEntry','Tk::NumEntryPlain','Tk::Optionmenu','strict','vars']},'Tk-DateEntry-1.36.tar.gz' => {'author' => 'SREZIC','description' => 'Drop down calendar for selecting dates','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 743,'pod' => 192,'pod_errors' => 0,'total' => 935,'with_comments' => 132},'releases' => 7,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 400},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 9670,'unpacked' => 26783},'testers' => {'pass' => 4},'uses' => ['Carp','Time::Local','Tk','Tk::FireButton','Tk::Frame','strict','vars']},'Tk-DatePick-1.02.tar.gz' => {'author' => 'LAWGON','description' => 'A simple widget for date entry','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 515,'pod' => 67,'pod_errors' => 0,'total' => 582,'with_comments' => 54},'releases' => 3,'requires' => ['Tk-800.024.tar.gz','Tk-GBARR-2.06.tar.gz'],'requires_module' => {'Tk' => 0,'Tk::FireButton' => 0},'requires_recursive' => ['Tk-800.024.tar.gz','Tk-GBARR-2.06.tar.gz'],'size' => {'packed' => 5308,'unpacked' => 18197},'testers' => {'pass' => 2},'uses' => ['Tk::FireButton','Tk::Frame','Tk::Label','strict','warnings']},'Tk-DirSelect-1.03.tar.gz' => {'author' => 'KRISTI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 200,'pod' => 0,'pod_errors' => 0,'total' => 200,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 2478,'unpacked' => 5578},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Cwd','English','Tk::Derived','Tk::Toplevel','Tk::widgets','Win32API::File','strict','vars']},'Tk-EMatrix-0.01.tar.gz' => {'author' => 'DJBERG','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 264,'pod' => 88,'pod_errors' => 1,'total' => 352,'with_comments' => 62},'releases' => 1,'size' => {'packed' => 10297,'unpacked' => 62027},'testers' => {},'uses' => ['Exporter','Tie::IxHash','Tk::TableMatrix','warnings']},'Tk-Enscript-1.05.tar.gz' => {'author' => 'SREZIC','description' => 'Create postscript from text files using Tk','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 306,'pod' => 25,'pod_errors' => 0,'total' => 331,'with_comments' => 17},'releases' => 2,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => undef},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 4704,'unpacked' => 12639},'testers' => {},'uses' => ['Config','Exporter','IO::Pipe','Text::Tabs','Tk','Tk::Font','Tk::X11Font','strict','vars']},'Tk-FileDialog-1.3.tar.gz' => {'author' => 'BPOWERS','description' => 'A highly configurable file selection widget','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 900,'pod' => 257,'pod_errors' => 0,'total' => 1157,'with_comments' => 142},'releases' => 1,'size' => {'packed' => 9599,'unpacked' => 30955},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.002','Carp','Tk','Tk::Dialog','strict']},'Tk-FilterEntry-0.02.tar.gz' => {'author' => 'PERRAD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 117,'pod' => 121,'pod_errors' => 0,'total' => 238,'with_comments' => 0},'releases' => 2,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 2996,'unpacked' => 7769},'testers' => {'pass' => 3},'uses' => ['Tk','Tk::Derived','Tk::Entry','strict','vars']},'Tk-FontDialog-0.08.tar.gz' => {'author' => 'SREZIC','description' => 'A font dialog widget for perl/Tk','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 590,'pod' => 119,'pod_errors' => 0,'total' => 709,'with_comments' => 38},'releases' => 6,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 800},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 8036,'unpacked' => 23765},'testers' => {},'uses' => ['Tk','Tk::HList','Tk::ItemStyle','strict','vars']},'Tk-GBARR-1.0401.tar.gz' => {'author' => 'ACH','description' => 'A Frame with a title','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3197,'pod' => 472,'pod_errors' => 0,'total' => 3669,'with_comments' => 57},'releases' => 10,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '402.002'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 29725,'unpacked' => 105610},'testers' => {'fail' => 2,'pass' => 3,'tests' => '87'},'uses' => ['Carp','Tk','Tk::Button','Tk::Canvas','Tk::Cloth','Tk::Derived','Tk::Entry','Tk::FireButton','Tk::Frame','Tk::NumEntryPlain','Tk::Widget','strict','vars']},'Tk-GBARR-2.06.tar.gz' => {'author' => 'SREZIC','description' => 'A Titled Frame widget','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2508,'pod' => 348,'pod_errors' => 0,'total' => 2856,'with_comments' => 53},'releases' => 10,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '402.002'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 25067,'unpacked' => 87149},'testers' => {'pass' => 2},'uses' => ['Carp','Tk','Tk::Button','Tk::Canvas','Tk::Cloth::Item','Tk::Cloth::Object','Tk::Derived','Tk::Entry','Tk::Frame','strict','vars']},'Tk-Getopt-0.48.tar.gz' => {'author' => 'SREZIC','description' => 'Configuration interface to Getopt::Long','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1371,'pod' => 427,'pod_errors' => 0,'total' => 1798,'with_comments' => 84},'releases' => 10,'size' => {'packed' => 21359,'unpacked' => 70560},'testers' => {'fail' => 1,'pass' => 1,'tests' => '38'},'uses' => ['5.003','Cwd','File::Basename','Getopt::Long','Safe','Tk','Tk::BrowseEntry','Tk::CmdLine','Tk::DirSelect','Tk::DirTree','Tk::FileDialog','Tk::FileSelect','Tk::Font','Tk::FontDialog','Tk::PathEntry','Tk::Photo','Tk::Pixmap','Tk::Tiler','constant','strict','vars']},'Tk-Graph-0.06.tar.gz' => {'author' => 'XPIX','description' => 'Realtime Chart Canvas','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1647,'pod' => 258,'pod_errors' => 0,'total' => 1905,'with_comments' => 233},'releases' => 5,'requires' => ['Tie-Watch-1.1.tar.gz','Tk-800.024.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Math::Trig' => '0','Tie::Watch' => '0','Tk' => '0'},'requires_recursive' => ['Tie-Watch-1.1.tar.gz','Tk-800.024.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15775,'unpacked' => 74190},'testers' => {'pass' => 1},'uses' => ['Carp','Math::Trig','Tie::Watch','Tk::Canvas','Tk::Derived','strict']},'Tk-GraphViz-0.06.tar.gz' => {'author' => 'JGS','description' => 'Render an interactive GraphViz graph','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2481,'pod' => 182,'pod_errors' => 0,'total' => 2663,'with_comments' => 604},'releases' => 4,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '800.02'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 100675,'unpacked' => 336282},'testers' => {'pass' => 2},'uses' => ['5.004','Carp','IO','Tk','Tk::Canvas','Tk::Derived','Tk::Font','strict','vars','warnings']},'Tk-HTML-3.002.tar.gz' => {'author' => 'NI-S','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1930,'pod' => 19,'pod_errors' => 0,'total' => 1949,'with_comments' => 50},'releases' => 1,'size' => {'packed' => 19126,'unpacked' => 71547},'testers' => {'pass' => 3},'uses' => ['AutoLoader','Carp','HTML::Parse','LWP::Debug','MIME::QuotedPrint','Tk','Tk::Bitmap','Tk::JPEG','Tk::LabEntry','Tk::Photo','Tk::Pixmap','Tk::Pretty','Tk::ROText','strict','vars']},'Tk-HexEntry-0.01.tar.gz' => {'author' => 'XPIX','description' => 'A hexadecimal Entry widget with inc. & dec. Buttons','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 374,'pod' => 177,'pod_errors' => 0,'total' => 551,'with_comments' => 10},'releases' => 1,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 5258,'unpacked' => 14832},'testers' => {'pass' => 1},'uses' => ['Tk::Derived','Tk::Entry','Tk::FireButton','Tk::Frame','strict','vars']},'Tk-HideCursor-0.01.tar.gz' => {'author' => 'GBROCK','description' => 'Hide the cursor when it passes over your widget','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 41,'pod_errors' => 0,'total' => 138,'with_comments' => 23},'releases' => 1,'size' => {'packed' => 2409,'unpacked' => 5180},'testers' => {'fail' => 1,'pass' => 1,'tests' => '4'},'uses' => ['5.6.0','Carp','strict','warnings']},'Tk-HistEntry-0.40.tar.gz' => {'author' => 'SREZIC','description' => 'An entry widget with history capability','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 493,'pod' => 174,'pod_errors' => 0,'total' => 667,'with_comments' => 43},'releases' => 10,'size' => {'packed' => 9873,'unpacked' => 37517},'testers' => {'fail' => 4,'pass' => 3,'tests' => '64'},'uses' => ['Tk','Tk::BrowseEntry','Tk::Derived','Tk::Entry','matching','strict','vars']},'Tk-IPEntry-0.03.tar.gz' => {'author' => 'XPIX','description' => 'A megawidget for input of IP-Adresses','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 337,'pod' => 88,'pod_errors' => 0,'total' => 425,'with_comments' => 59},'releases' => 3,'requires' => ['Net-IP-1.20.tar.gz','Tie-Watch-1.1.tar.gz','Tk-800.024.tar.gz','Tk-GBARR-2.06.tar.gz','Tk-HexEntry-0.01.tar.gz'],'requires_module' => {'Net::IP' => 0,'Tie::Watch' => 0,'Tk' => 0,'Tk::HexEntry' => 0,'Tk::NumEntry' => 0},'requires_recursive' => ['Net-IP-1.20.tar.gz','Tie-Watch-1.1.tar.gz','Tk-800.024.tar.gz','Tk-GBARR-2.06.tar.gz','Tk-HexEntry-0.01.tar.gz'],'size' => {'packed' => 5429,'unpacked' => 17233},'testers' => {'pass' => 1},'uses' => ['Carp','Net::IP','Tie::Watch','Tk','Tk::Frame','Tk::HexEntry','Tk::NumEntry','strict']},'Tk-JComboBox-0.02.tar.gz' => {'author' => 'RCS','description' => 'another combo box (similar to the java comp)','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 860,'pod' => 0,'pod_errors' => 0,'total' => 860,'with_comments' => 58},'releases' => 2,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 25689,'unpacked' => 89248},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','Class::Struct','Tk','Tk::Frame','vars']},'Tk-JListbox-0.01.tar.gz' => {'author' => 'DJBERG','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 289,'pod' => 79,'pod_errors' => 0,'total' => 368,'with_comments' => 80},'releases' => 2,'size' => {'packed' => 9075,'unpacked' => 31987},'testers' => {'fail' => 2,'pass' => 4},'uses' => ['Tk::Derived','Tk::Listbox','vars','warnings']},'Tk-JListbox-0.02.tar.gz' => {'author' => 'DJBERG','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 440,'pod' => 69,'pod_errors' => 0,'total' => 509,'with_comments' => 75},'releases' => 2,'size' => {'packed' => 6398,'unpacked' => 25906},'testers' => {'fail' => 2,'pass' => 3},'uses' => ['Tk::Derived','Tk::Listbox','Tk::Toplevel','vars','warnings']},'Tk-JPEG-2.014.tar.gz' => {'author' => 'NI-S','description' => 'JPEG loader for Tk::Photo','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 24,'pod' => 22,'pod_errors' => 0,'total' => 46,'with_comments' => 1},'releases' => 9,'size' => {'packed' => 737301,'unpacked' => 2364657},'testers' => {'fail' => 1,'pass' => 5,'tests' => '42'},'uses' => ['DynaLoader','Tk','Tk::Image','Tk::Photo','vars']},'Tk-JPEG-Lite-2.01402.tar.gz' => {'author' => 'SREZIC','description' => 'lite JPEG loader for Tk::Photo','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 22,'pod' => 22,'pod_errors' => 0,'total' => 44,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 19058,'unpacked' => 58350},'testers' => {'pass' => 1},'uses' => ['DynaLoader','Tk','Tk::Image','Tk::Photo','vars']},'Tk-LCD-1.3.tar.gz' => {'author' => 'LUSOL','description' => 'display Liquid Crystal Display symbols','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 244,'pod' => 97,'pod_errors' => 0,'total' => 341,'with_comments' => 34},'releases' => 3,'size' => {'packed' => 4642,'unpacked' => 11466},'testers' => {'pass' => 1},'uses' => ['Tk::Canvas','Tk::Derived','Tk::Trace','strict','subs','vars']},'Tk-LabPopEntry-0.05.tar.gz' => {'author' => 'DJBERG','description' => 'A LabEntry widget with an automatic, configurable right-click menu built in, plus input masks. =head2 SYNOPSIS use LabPopEntry; $dw = $parent->LabPopEntry( -pattern => \'alpha\', \'alphanum\', \'capsonly\', \'signed_int\', \'unsigned_int\', \'float\', \'nondigit\', or any supplied regexp. -nomenu => 0 or 1, -case => \'upper\', \'lower\', \'capitalize\', -maxwidth => int, -minvalue => int, -maxvalue => int, -nospace => 0 or 1, -menuitems => [\'string\', \'callback\', \'binding\', \'index\'], ); $dw->pack; =head2 DESCRIPTION LabPopEntry is a LabEntry widget with a right-click menu automatically attached. In addition, certain field masks can easily be applied to the entry widget in order to force the end-user into entering only the values you want him or her to enter. By default, there are five items attached to the right-click menu: Cut, Copy, Paste, Delete and Sel. All. The default bindings for the items are Control-x, Control-c, Control-v, Control-d, and Control-a, respectively. The difference between \'Cut\' and \'Delete\' is that the former automatically copies the contents that were cut to the clipboard, while the latter does not. =head2 OPTIONS B<-pattern =E<gt>> I<string> S< The pattern specified here creates an input mask for the LabPopEntry widget. There are seven pre-defined masks:> =over 4 =item * alpha - Upper and lower case a-z only. =item * alphanum - Alpha-numeric characters only. =item * capsonly - Upper case A-Z only. =item * nondigit - Any characters except 0-9. =item * float - A float value, which may or may not include a decimal. =item * signed_int - A signed integer value, which may or may not include a \'+\'. =item * unsigned_int - An unsigned integer value. =back S<You may also specify a regular expression of your own design using Perl\'s standard regular expression mechanisms. Be sure to use single quotes, e.g. \'/\\d\\w\\d/\'> B<-nomenu =E<gt>> I<B<0> or 1> S< If set to true, then no right-click menu will appear. Presumably, you would set this if you were only interested in the input-mask functionality. The default is, of course, 0.> B<-nospace =E<gt>> I<B<0> or 1> S< If set to true (1), the user may not enter whitespace before, after or between words within that LabPopEntry widget. The default is 0.> B<-maxwidth =E<gt>> I<int> S< Specifies the maximum number of characters that the user can enter in that particular LabPopEntry widget. Note that this is not the same as the width of the widget itself.> B<-maxvalue =E<gt>> I<int or float> S< If one of the pre-defined numeric patterns is chosen, this specifies the maximum allowable value that may be entered by a user for the widget.> B<-minvalue =E<gt>> I<int or float> S< If one of the pre-defined numeric patterns is chosen, this specifies the minimum allowable value for the first digit (0-9). This should work better.> B<-menuitems =E<gt>> I<[\'string\', \'callback\', \'E<lt>bindingE<gt>\', \'underline_index\']> S< If specified, this creates a user-defined right-click menu rather than the one that is provided by default. The value specified must be a four element nested anonymous array that contains (in this order):> =over 4 =item 1 a string that appears on the menu, =item 2 a callback (in \'package::callback\' syntax format), =item 3 a binding for that option (see below), =item 4 an index value specifying the character in the string to be underlined. =back S<The binding specified need only be in the form, \'E<lt>Control-xE<gt>\'. You needn\'t explicitly bind it yourself. Your callback will automatically be bound to the event sequence you specified.> =head2 METHODS B<$lpe-E<gt>deleteItem(index, ?index?)> S< Deletes the menu option at the specified index. A range of values may be deleted as well, e.g. $lpe-E<gt>deleteItem(3,\'end\'); Returns an array reference if a single item is deleted, or a reference to an array of references if more than one item is deleted.> B<$lpe-E<gt>addItem(?index?, $item)> S< Adds a menu option at the specified index, where $item is an anonymous array consisting of four elements (see the -menuitems option for details). If no index is specified, the new item will be added at the end of the menu. If an item already exists at that index, the current menu items will be "bumped" down. Returns the list of menuitems.> =head2 ADVERTISED SUBWIDGETS B<$lpe-E<gt>Subwidget(\'popupmenu\')> S<Returns a reference to the popupmenu (a toplevel widget).> =head2 KNOWN BUGS The -minvalue only works for the first digit. There is still potential for odd results if your bind happens to coincide with a binding already used by the Window Manager. In windows, where I did most of my testing, this meant that Control-v would paste twice, once because MS Windows told it to, and once because I told it to. =head2 PLANNED CHANGES Fix the issues mentioned above. Automatically bind the \'Alt\' key to the underlined character. Give the option to remove bindings completely. =head2 AUTHOR Daniel J. Berger djberg96@hotmail.com =head2 SEE ALSO Entry, LabEntry','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 684,'pod' => 127,'pod_errors' => 0,'total' => 811,'with_comments' => 121},'releases' => 5,'size' => {'packed' => 8651,'unpacked' => 28656},'testers' => {'pass' => 1},'uses' => ['Tk::LabEntry','strict','vars']},'Tk-ListboxDnD-1.3.tar.gz' => {'author' => 'GSLONDON','description' => 'A Tk::Listbox widget with drag and drop capability.','files' => [],'lines' => {'nonpod' => 98,'pod' => 68,'pod_errors' => 1,'total' => 166,'with_comments' => 9},'releases' => 3,'size' => {'packed' => 2034,'unpacked' => 4960},'testers' => {},'uses' => ['Tk::Derived','Tk::Listbox','Tk::widgets','strict','vars','warnings']},'Tk-LockDisplay-1.3.tar.gz' => {'author' => 'LUSOL','description' => 'Screen saver/lock widget with animation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 705,'pod' => 128,'pod_errors' => 0,'total' => 833,'with_comments' => 176},'releases' => 4,'size' => {'packed' => 57087,'unpacked' => 180601},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.004','Carp','File::Basename','POSIX','Tk::Derived','Tk::Toplevel','strict','subs','vars']},'Tk-MDI-0.2.tar.gz' => {'author' => 'AQUMSIEH','description' => 'Multiple Document Interface for Tk =for category Tk Widget Classes','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2073,'pod' => 181,'pod_errors' => 0,'total' => 2254,'with_comments' => 202},'releases' => 2,'size' => {'packed' => 23284,'unpacked' => 90112},'testers' => {'pass' => 2},'uses' => ['Carp','Tk::Frame','strict','vars']},'Tk-MListbox-1.11.tar.gz' => {'author' => 'RCS','description' => 'Multicolumn Listbox.','files' => ['Makefile.PL'],'lines' => {'nonpod' => 1319,'pod' => 359,'pod_errors' => 0,'total' => 1678,'with_comments' => 211},'releases' => 6,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 49345,'unpacked' => 161474},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['Carp','Tk','Tk::Button','Tk::Derived','Tk::Frame','Tk::Listbox','Tk::Pane','strict','vars','warnings']},'Tk-MatchEntry-0.2.tar.gz' => {'author' => 'WHOM','description' => 'Entry widget with advanced auto-completion','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1317,'pod' => 311,'pod_errors' => 0,'total' => 1628,'with_comments' => 231},'releases' => 2,'size' => {'packed' => 15345,'unpacked' => 60353},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Dumper','Tk::Frame','Tk::LabEntry','strict','vars','warnings']},'Tk-MenuHash-1.12.tar.gz' => {'author' => 'ZENIN','description' => 'Ties a Tk::Menubutton widget to a hash object thingy','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 156,'pod' => 118,'pod_errors' => 0,'total' => 274,'with_comments' => 6},'releases' => 2,'requires' => ['Tk-800.024.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3981,'unpacked' => 10902},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Carp','Tk','strict','vars']},'Tk-MesgBox-1.12.tar.gz' => {'author' => 'SUMMER','description' => 'Perl/Tk module for message and button dialogue boxes.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 278,'pod' => 132,'pod_errors' => 0,'total' => 410,'with_comments' => 19},'releases' => 6,'size' => {'packed' => 5113,'unpacked' => 19350},'testers' => {'fail' => 1,'pass' => 3},'uses' => ['5.004','Carp','Tk','Tk::Toplevel','strict','vars']},'Tk-MinMaxScale-0.07.tar.gz' => {'author' => 'JPVIDAL','description' => 'Two Scale(s) to get a (min, max) values pair','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 201,'pod' => 128,'pod_errors' => 0,'total' => 329,'with_comments' => 15},'releases' => 7,'size' => {'packed' => 3994,'unpacked' => 10375},'testers' => {'pass' => 3},'uses' => ['Carp','Tk']},'Tk-Month-1.4.tar.gz' => {'author' => 'ARIF','description' => 'Calendar widget which shows one month at a time.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2135,'pod' => 247,'pod_errors' => 0,'total' => 2382,'with_comments' => 372},'releases' => 5,'size' => {'packed' => 16040,'unpacked' => 54275},'testers' => {'pass' => 6},'uses' => ['5','5.001','Carp','Exporter','POSIX','Text::Abbrev','Time::Local','Tk','Tk::Button','Tk::Label','Tk::Menubutton','Tk::Optionmenu','Tk::Widget','strict','vars']},'Tk-Multi-1.004.tar.gz' => {'author' => 'DDUMONT','description' => 'Do not use','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1142,'pod' => 578,'pod_errors' => 0,'total' => 1720,'with_comments' => 109},'releases' => 17,'requires' => ['Tie-IxHash-1.21.tar.gz','Tk-800.024.tar.gz','Tk-GBARR-1.0401.tar.gz','Tk-ObjScanner-2.004.tar.gz','Tk-Pod-0.9919.tar.gz'],'requires_module' => {'Tie::IxHash' => 0,'Tk' => '800.013','Tk::ObjScanner' => '1.016','Tk::Pod' => 0,'Tk::TFrame' => 0},'requires_recursive' => ['Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Tie-IxHash-1.21.tar.gz','Tk-800.024.tar.gz','Tk-GBARR-1.0401.tar.gz','Tk-HistEntry-0.40.tar.gz','Tk-ObjScanner-2.004.tar.gz','Tk-Pod-0.9919.tar.gz','WeakRef-0.01.tar.gz','perlindex-1.301.tar.gz'],'size' => {'packed' => 14804,'unpacked' => 60735},'testers' => {},'uses' => ['Carp','Tie::IxHash','Tk::Adjuster','Tk::Canvas','Tk::Derived','Tk::Dialog','Tk::Frame','Tk::Label','Tk::Menubutton','Tk::ObjScanner','Tk::Pod','Tk::Pod::Text','Tk::ROText','Tk::TFrame','Tk::Toplevel','strict','vars']},'Tk-OS2src-1.04.zip' => {'author' => 'ILYAZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4,'pod' => 9,'pod_errors' => 0,'total' => 13,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 245761,'unpacked' => 315549},'testers' => {'tests' => '0','unknown' => 3},'uses' => []},'Tk-ObjEditor-2.002.tar.gz' => {'author' => 'DDUMONT','description' => 'Tk widget to edit data or objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 472,'pod' => 120,'pod_errors' => 0,'total' => 592,'with_comments' => 28},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz','Storable-2.07.tar.gz','Tk-800.024.tar.gz','Tk-ObjScanner-2.004.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Storable' => 0,'Tk' => 0,'Tk::ObjScanner' => '2.001'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Tk-800.024.tar.gz','Tk-ObjScanner-2.004.tar.gz','WeakRef-0.01.tar.gz'],'size' => {'packed' => 8082,'unpacked' => 26330},'testers' => {'pass' => 1},'uses' => ['Carp','Storable','Tk::Derived','Tk::Dialog','Tk::DialogBox','Tk::Frame','Tk::ObjScanner','strict','vars','warnings']},'Tk-ObjScanner-2.004.tar.gz' => {'author' => 'DDUMONT','description' => 'Tk data or object scanner','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 650,'pod' => 137,'pod_errors' => 0,'total' => 787,'with_comments' => 76},'releases' => 20,'requires' => ['Tk-800.024.tar.gz','WeakRef-0.01.tar.gz'],'requires_module' => {'Tk' => 0,'Tk::Adjuster' => 0,'Tk::HList' => 0,'Tk::ROText' => 0,'WeakRef' => '0.01'},'requires_recursive' => ['Tk-800.024.tar.gz','WeakRef-0.01.tar.gz'],'size' => {'packed' => 13350,'unpacked' => 45892},'testers' => {'pass' => 1},'uses' => ['B::Deparse','Data::Dumper','Tk','Tk::Adjuster','Tk::Derived','Tk::Frame','Tk::HList','Tk::Menubutton','Tk::ROText','WeakRef','strict','warnings']},'Tk-ObjectHandler-0.03.tar.gz' => {'author' => 'CAILLTE','description' => 'Perl extension for Tk','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 211,'pod' => 138,'pod_errors' => 0,'total' => 349,'with_comments' => 14},'releases' => 1,'size' => {'packed' => 8377,'unpacked' => 28856},'testers' => {},'uses' => ['Carp','Text::Wrap','Tk','strict','vars']},'Tk-PNG-2.005.tar.gz' => {'author' => 'NI-S','description' => 'PNG loader for Tk::Photo','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 23,'pod' => 20,'pod_errors' => 0,'total' => 43,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 284123,'unpacked' => 1233373},'testers' => {'fail' => 1,'pass' => 6,'tests' => '4'},'uses' => ['DynaLoader','Tk','Tk::Image','Tk::Photo','vars']},'Tk-PathEntry-2.17.tar.gz' => {'author' => 'SREZIC','description' => 'Entry widget for selecting paths with completion','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 449,'pod' => 100,'pod_errors' => 0,'total' => 549,'with_comments' => 60},'releases' => 3,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '800.02'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 6873,'unpacked' => 20082},'testers' => {'fail' => 1,'pass' => 2,'tests' => '7'},'uses' => ['Tk::Derived','Tk::DialogBox','Tk::Entry','strict','vars']},'Tk-Pgplot-0.30.tar.gz' => {'author' => 'CPHIL','description' => 'Pgplot widget for Tk','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 0,'pod_errors' => 0,'total' => 20,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 67479,'unpacked' => 265618},'testers' => {},'uses' => ['Tk','Tk::Widget','vars']},'Tk-Pod-0.9919.tar.gz' => {'author' => 'SREZIC','description' => 'A more (or less) like text widget','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3653,'pod' => 648,'pod_errors' => 0,'total' => 4301,'with_comments' => 297},'releases' => 14,'requires' => ['Pod-Simple-0.96.tar.gz','Tk-800.024.tar.gz','Tk-HistEntry-0.40.tar.gz','perlindex-1.301.tar.gz'],'requires_module' => {'Pod::Simple' => 0,'Text::English' => 0,'Tk' => '800.004','Tk::HistEntry' => '0.4'},'requires_recursive' => ['Pod-Escapes-1.03.tar.gz','Pod-Simple-0.96.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','Tk-800.024.tar.gz','Tk-HistEntry-0.40.tar.gz','perlindex-1.301.tar.gz'],'size' => {'packed' => 44723,'unpacked' => 134532},'testers' => {'pass' => 2},'uses' => ['5','Benchmark','CPAN','Carp','Class::Struct','Config','Data::Dumper','Exporter','ExtUtils::MakeMaker','Fcntl','File::Basename','File::Find','File::Spec','POSIX','Pod::Simple::PullParser','Pod::Simple::PullParserEndToken','Pod::Simple::PullParserStartToken','Pod::Simple::PullParserTextToken','Pod::Simple::RTF','Pod::Simple::Text','Safe','Text::English','Text::Wrap','Tk','Tk::BrowseEntry','Tk::Derived','Tk::FileSelect','Tk::Frame','Tk::HistEntry','Tk::ItemStyle','Tk::LabEntry','Tk::ROText','Tk::Toplevel','Tk::Tree','Win32','strict','vars']},'Tk-PopEntry-0.06.tar.gz' => {'author' => 'DJBERG','description' => 'An Entry widget with an automatic, configurable right-click menu built in, plus input masks. =head2 SYNOPSIS use PopEntry; $dw = $parent->PopEntry( -pattern => \'alpha\', \'alphanum\', \'capsonly\', \'signed_int\', \'unsigned_int\', \'float\', \'nondigit\', or any supplied regexp. -nomenu => 0 or 1, -case => \'upper\', \'lower\', \'capitalize\', -maxwidth => int, -minvalue => int, -maxvalue => int, -nospace => 0 or 1, -menuitems => [\'string\', \'package::callback\', \'binding\', \'index\'], ); $dw->pack; =head2 DESCRIPTION An Entry widget with a right-click menu attached automatically. In addition, certain field masks can easily be applied to the Entry widget in order to force the end-user into entering only the values you want him or her to enter. By default, there are five items attached to the right-click menu: Cut, Copy, Paste, Delete and Sel. All. The default bindings for the items are Control-x, Control-c, Control-v, Control-d, and Control-a, respectively. The difference between \'Cut\' and \'Delete\' is that the former automatically copies the contents that were cut to the clipboard, while the latter does not. =head2 OPTIONS B<-pattern =E<gt>> I<string> S< The pattern specified here creates an input mask for the PopEntry widget. There are seven pre-defined masks:> =over 4 =item * alpha - Upper and lower case a-z only. =item * alphanum - Alpha-numeric characters only. =item * capsonly - Upper case A-Z only. =item * nondigit - Any characters except 0-9. =item * float - A float value, which may or may not include a decimal. =item * signed_int - A signed integer value, which may or may not include a \'+\'. =item * unsigned_int - An unsigned integer value. =back S<You may also specify a regular expression of your own design using Perl\'s standard regular expression mechanisms. Be sure to use single quotes, e.g. \'/\\d\\w\\d/\'> B<-nomenu =E<gt>> I<B<0> or 1> S< If set to true, then no right-click menu will appear. Presumably, you would set this if you were only interested in the input-mask functionality. The default is, of course, 0.> B<-nospace =E<gt>> I<B<0> or 1> S< If set to true (1), the user may not enter whitespace before, after or between words within that PopEntry widget. The default is 0.> B<-maxwidth =E<gt>> I<int> S< Specifies the maximum number of characters that the user can enter in that particular PopEntry widget. Note that this is not the same as the width of the widget itself.> B<-maxvalue =E<gt>> I<int or float> S< If one of the pre-defined numeric patterns is chosen, this specifies the maximum allowable value that may be entered by a user for the widget.> B<-minvalue =E<gt>> I<int or float> S< If one of the pre-defined numeric patterns is chosen, this specifies the minimum allowable value for the first digit (0-9). This should work better.> B<-menuitems =E<gt>> I<[\'string\', \'callback\', \'E<lt>bindingE<gt>\', \'underline_index\']> S< If specified, this creates a user-defined right-click menu rather than the one that is provided by default. The value specified must be a four element nested anonymous array that contains (in this order):> =over 4 =item 1 a string that appears on the menu, =item 2 a callback (in \'package::callback\' syntax format), =item 3 a binding for that option (see below), =item 4 an index value specifying the character in the string to be underlined. =back S<The binding specified need only be in the form, \'E<lt>Control-xE<gt>\'. You needn\'t explicitly bind it yourself. Your callback will automatically be bound to the event sequence you specified.> =head2 METHODS B<$lpe-E<gt>deleteItem(index, ?index?)> S< Deletes the menu option at the specified index. A range of values may be deleted as well, e.g. $lpe-E<gt>deleteItem(3,\'end\'); Returns an array reference if a single item is deleted, or a reference to an array of references if more than one item is deleted.> B<$lpe-E<gt>addItem(?index?, $item)> S< Adds a menu option at the specified index, where $item is an anonymous array consisting of four elements (see the -menuitems option for details). If no index is specified, the new item will be added at the end of the menu. If an item already exists at that index, the current menu items will be "bumped" down. Returns the list of menuitems.> =head2 ADVERTISED SUBWIDGETS B<$lpe-E<gt>Subwidget(\'popupmenu\')> S<Returns a reference to the popupmenu (a toplevel widget).> =head2 KNOWN BUGS The -minvalue only works for the first digit. There is still potential for odd results if your bind happens to coincide with a binding already used by the Window Manager. In windows, where I did most of my testing, this meant that Control-v would paste twice, once because MS Windows told it to, and once because I told it to. I got different (bad) results with Control-v in KDE on Mandrake 7.2. =head2 PLANNED CHANGES Fix the issues mentioned above. Automatically bind the \'Alt\' key to the underlined character. Give the option to remove bindings completely. =head2 AUTHOR Daniel J. Berger djberg96@hotmail.com =head2 SEE ALSO Entry','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 623,'pod' => 127,'pod_errors' => 0,'total' => 750,'with_comments' => 112},'releases' => 6,'size' => {'packed' => 8400,'unpacked' => 26577},'testers' => {'pass' => 1},'uses' => ['Tk::Entry','strict','vars']},'Tk-Preferences-0.2.tar.gz' => {'author' => 'AHICOX','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 104,'pod' => 128,'pod_errors' => 0,'total' => 232,'with_comments' => 19},'releases' => 1,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '800.024'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 4194,'unpacked' => 10632},'testers' => {'pass' => 1},'uses' => []},'Tk-Program-0.03.tar.gz' => {'author' => 'XPIX','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 496,'pod' => 235,'pod_errors' => 0,'total' => 731,'with_comments' => 51},'releases' => 3,'requires' => ['Tk-800.024.tar.gz','Tk-Getopt-0.48.tar.gz','Tk-Splashscreen-1.0.tar.gz','Tk-ToolBar-0.07.tar.gz'],'requires_module' => {'Tk' => 0,'Tk::Balloon' => 0,'Tk::Getopt' => 0,'Tk::Splashscreen' => 0,'Tk::ToolBar' => 0},'requires_recursive' => ['Tk-800.024.tar.gz','Tk-CursorControl-0.2.tar.gz','Tk-Getopt-0.48.tar.gz','Tk-Splashscreen-1.0.tar.gz','Tk-ToolBar-0.07.tar.gz'],'size' => {'packed' => 17354,'unpacked' => 31718},'testers' => {'pass' => 1},'uses' => ['Data::Dumper','IO::File','Tk::Balloon','Tk::DialogBox','Tk::Getopt','Tk::MainWindow','Tk::ROText','Tk::Splashscreen','Tk::ToolBar','strict','vars']},'Tk-ProgressBar-Mac-1.1.tar.gz' => {'author' => 'LUSOL','description' => 'blue 3-D Macintosh Classic progress bar','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 188,'pod' => 89,'pod_errors' => 0,'total' => 277,'with_comments' => 56},'releases' => 1,'size' => {'packed' => 3659,'unpacked' => 9902},'testers' => {'pass' => 4},'uses' => ['Tk::Frame','strict','vars']},'Tk-RadiobuttonGroup-0.2.2.tar.gz' => {'author' => 'JANNINO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 179,'pod' => 74,'pod_errors' => 0,'total' => 253,'with_comments' => 30},'releases' => 3,'requires' => ['Tie-IxHash-1.21.tar.gz','Tk-800.024.tar.gz'],'requires_module' => {'Tie::IxHash' => 0,'Tk' => '402.000'},'requires_recursive' => ['Tie-IxHash-1.21.tar.gz','Tk-800.024.tar.gz'],'size' => {'packed' => 4009,'unpacked' => 11637},'testers' => {'fail' => 2,'pass' => 2},'uses' => ['','Data::Dumper','Tie::IxHash','Tk::Frame','Tk::widgets','strict']},'Tk-RemoteFileSelect-0.59.tar.gz' => {'author' => 'RKIES','description' => '-Browse directories with FTP.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 870,'pod' => 46,'pod_errors' => 0,'total' => 916,'with_comments' => 19},'releases' => 3,'size' => {'packed' => 16287,'unpacked' => 53753},'testers' => {'pass' => 2},'uses' => ['Carp','Cwd','File::Basename','Tk','Tk::Button','Tk::Dialog','Tk::DialogBox','Tk::Frame','Tk::LabEntry','Tk::Listbox','Tk::Toplevel','Tk::widgets','strict','vars']},'Tk-ReportBox-1.02.tar.gz' => {'author' => 'LAWGON','description' => 'Perl extension for Displaying Reports','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 159,'pod' => 74,'pod_errors' => 0,'total' => 233,'with_comments' => 1},'releases' => 3,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 3708,'unpacked' => 10305},'testers' => {'pass' => 1,'tests' => '0','unknown' => 6},'uses' => ['Tk::Button','Tk::Entry','Tk::FileSelect','Tk::Frame','Tk::Label','Tk::Listbox','Tk::Toplevel','strict','warnings']},'Tk-ResizeButton-0.01.tar.gz' => {'author' => 'XPIX','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 87,'pod_errors' => 0,'total' => 292,'with_comments' => 38},'releases' => 1,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 3946,'unpacked' => 10725},'testers' => {'pass' => 1},'uses' => []},'Tk-RotCanvas-1.2.tar.gz' => {'author' => 'AQUMSIEH','description' => 'Canvas with arbitrary rotation support','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 263,'pod' => 59,'pod_errors' => 0,'total' => 322,'with_comments' => 29},'releases' => 2,'size' => {'packed' => 3626,'unpacked' => 9992},'testers' => {'pass' => 2},'uses' => ['Carp','Tk::Canvas','Tk::Derived','Tk::widgets','strict','vars']},'Tk-SelFile-0.02.tar.gz' => {'author' => 'ALSCH','description' => 'a widget for choosing a file to read or write','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 516,'pod' => 95,'pod_errors' => 0,'total' => 611,'with_comments' => 21},'releases' => 2,'size' => {'packed' => 7453,'unpacked' => 21266},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','Cwd','English','Tk','Tk::Dialog','Tk::LabEntry','Tk::ScrlListbox','Tk::Toplevel','strict']},'Tk-Separator-0.50.tar.gz' => {'author' => 'WGDAVIS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 39,'pod_errors' => 0,'total' => 111,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 9121,'unpacked' => 23015},'testers' => {},'uses' => ['Carp','Tk','Tk::Derived','Tk::Frame','strict','vars']},'Tk-SlideShow-0.07.tar.gz' => {'author' => 'OLIBOU','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2201,'pod' => 667,'pod_errors' => 0,'total' => 2868,'with_comments' => 92},'releases' => 7,'requires' => ['Tk-800.024.tar.gz','X11-Protocol-0.51.tar.gz'],'requires_module' => {'Tk' => '800.012','X11::Protocol' => '0.04'},'requires_recursive' => ['Tk-800.024.tar.gz','X11-Protocol-0.51.tar.gz'],'size' => {'packed' => 81923,'unpacked' => 204152},'testers' => {'pass' => 1},'uses' => ['Cwd','Exporter','Tk','Tk::After','Tk::Animation','Tk::DialogBox','Tk::Font','Tk::Xlib','strict','vars']},'Tk-SlideSwitch-1.1.tar.gz' => {'author' => 'LUSOL','description' => 'a 2 position horizontal or vertical switch.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 64,'pod_errors' => 0,'total' => 146,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 2612,'unpacked' => 6242},'testers' => {'pass' => 2},'uses' => ['Tk','Tk::Frame','Tk::widgets','strict']},'Tk-Splash-0.10.tar.gz' => {'author' => 'SREZIC','description' => 'create a splash screen in a compatible way','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 304,'pod' => 153,'pod_errors' => 0,'total' => 457,'with_comments' => 47},'releases' => 1,'size' => {'packed' => 5704,'unpacked' => 16136},'testers' => {'pass' => 1},'uses' => ['DynaLoader','Tk','Tk::Wm','strict','vars']},'Tk-Splashscreen-1.0.tar.gz' => {'author' => 'LUSOL','description' => 'display a Splashscreen during initialization','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 98,'pod_errors' => 0,'total' => 265,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 4035,'unpacked' => 9519},'testers' => {'pass' => 4},'uses' => ['Carp','Exporter','Tie::Watch','Tk','Tk::Toplevel','Tk::widgets','strict']},'Tk-StayOnTop-0.03.tar.gz' => {'author' => 'GBROCK','description' => 'Keep your window in the foreground','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 109,'pod' => 41,'pod_errors' => 0,'total' => 150,'with_comments' => 33},'releases' => 3,'size' => {'packed' => 2648,'unpacked' => 5920},'testers' => {'fail' => 1,'pass' => 1,'tests' => '4'},'uses' => ['Carp','strict','warnings']},'Tk-Stderr-1.2.tar.gz' => {'author' => 'KVAIL','description' => 'capture STDERR into separate window','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 67,'pod_errors' => 0,'total' => 289,'with_comments' => 49},'releases' => 3,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 3702,'unpacked' => 10319},'testers' => {'pass' => 1},'uses' => ['5.006','Tk::Derived','Tk::Frame','Tk::MainWindow','Tk::ROText','strict','vars','warnings']},'Tk-TIFF-0.08.tar.gz' => {'author' => 'SREZIC','description' => 'TIFF loader for Tk::Photo','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14,'pod' => 0,'pod_errors' => 0,'total' => 14,'with_comments' => 0},'releases' => 5,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '800.014'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 34025,'unpacked' => 195490},'testers' => {'pass' => 1},'uses' => ['DynaLoader','Tk','Tk::Photo','vars']},'Tk-TM-0.53.tar.gz' => {'author' => 'MAKAROW','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 4106,'pod' => 1466,'pod_errors' => 8,'total' => 5572,'with_comments' => 387},'releases' => 4,'size' => {'packed' => 45439,'unpacked' => 191649},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['5.000','Carp','Exporter','Tk','Tk::DialogBox','Tk::Tree','strict','vars']},'Tk-TableMatrix-1.01.tar.gz' => {'author' => 'CERNEY','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2998,'pod' => 1431,'pod_errors' => 1,'total' => 4429,'with_comments' => 499},'releases' => 3,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '800.022'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 188613,'unpacked' => 769474},'testers' => {'pass' => 3},'uses' => ['','AutoLoader','Carp','Tk','Tk::Derived','Tk::Widget','strict','vars']},'Tk-Task-1.1.tar.gz' => {'author' => 'KVAIL','description' => 'Repetitive background tasks in Tk','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 665,'pod' => 232,'pod_errors' => 0,'total' => 897,'with_comments' => 155},'releases' => 2,'requires' => ['Tie-StrictHash-1.0.tar.gz'],'requires_module' => {'Tie::StrictHash' => 1},'requires_recursive' => ['Tie-StrictHash-1.0.tar.gz'],'size' => {'packed' => 7518,'unpacked' => 28604},'testers' => {'pass' => 3},'uses' => ['5.005_62','Carp','Tie::StrictHash','Tk','strict','vars']},'Tk-Text-SuperText-0.9.4.tar.gz' => {'author' => 'ALEXIOB','description' => 'An improved text widget for perl/tk','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2155,'pod' => 408,'pod_errors' => 0,'total' => 2563,'with_comments' => 253},'releases' => 8,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk::Text' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 16061,'unpacked' => 59968},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['AutoLoader','Carp','Term::ANSIColor','Tk','Tk::Derived','Tk::Text','strict','vars']},'Tk-TextANSIColor-0.14.tar.gz' => {'author' => 'TJENNESS','description' => 'Tk::Text widget with support for ANSI color escape codes =for pm Tk/TextANSIColor.pm =for category Derived Widgets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 341,'pod' => 115,'pod_errors' => 0,'total' => 456,'with_comments' => 89},'releases' => 5,'requires' => ['ANSIColor-1.07.tar.gz','Test-1.24.tar.gz','Tk-800.024.tar.gz'],'requires_module' => {'Term::ANSIColor' => '1.00','Test' => 0,'Tk' => 0},'requires_recursive' => ['ANSIColor-1.07.tar.gz','File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Tk-800.024.tar.gz'],'size' => {'packed' => 6912,'unpacked' => 19147},'testers' => {'fail' => 1,'pass' => 3,'tests' => '32'},'uses' => ['Term::ANSIColor','Tk','Tk::ROText','Tk::Text','strict','vars']},'Tk-Thumbnail-1.0.tar.gz' => {'author' => 'LUSOL','description' => 'Create a Table of shrunken/expanded images','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 126,'pod' => 63,'pod_errors' => 0,'total' => 189,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 4742,'unpacked' => 15631},'testers' => {'pass' => 2},'uses' => ['Carp','File::Basename','Tk::Derived','Tk::Table','Tk::widgets','strict','subs']},'Tk-ToolBar-0.07.tar.gz' => {'author' => 'AQUMSIEH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 729,'pod' => 183,'pod_errors' => 0,'total' => 912,'with_comments' => 18},'releases' => 6,'requires' => ['Tk-CursorControl-0.2.tar.gz'],'requires_module' => {'Tk::CursorControl' => 0},'requires_recursive' => ['Tk-800.024.tar.gz','Tk-CursorControl-0.2.tar.gz'],'size' => {'packed' => 57178,'unpacked' => 157197},'testers' => {'pass' => 1},'uses' => ['Carp','POSIX','Tk::Balloon','Tk::Frame','Tk::LabEntry','Tk::widgets','strict','vars']},'Tk-Tree-0.05.tar.gz' => {'author' => 'CTDEAN','description' => 'Create and manipulate Tree widgets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 461,'pod' => 179,'pod_errors' => 0,'total' => 640,'with_comments' => 31},'releases' => 5,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '402.002'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 11822,'unpacked' => 39741},'testers' => {'pass' => 2},'uses' => ['5.004','Tk','Tk::Derived','Tk::HList','strict','vars']},'Tk-TreeGraph-1.024.tar.gz' => {'author' => 'DDUMONT','description' => 'Widget to draw a tree in a Canvas','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 945,'pod' => 429,'pod_errors' => 0,'total' => 1374,'with_comments' => 100},'releases' => 10,'size' => {'packed' => 13918,'unpacked' => 67843},'testers' => {'fail' => 1,'pass' => 5,'tests' => '46'},'uses' => ['AutoLoader','Carp','Tk::Canvas','Tk::Derived','Tk::Frame','strict','vars']},'Tk-WaitBox-1.3.tar.gz' => {'author' => 'BPOWERS','description' => 'A Wait dialog, of the "Please Wait" variety','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 191,'pod' => 134,'pod_errors' => 0,'total' => 325,'with_comments' => 43},'releases' => 2,'size' => {'packed' => 4196,'unpacked' => 10189},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['Tk::Toplevel','strict']},'Tk-Wizard-Bases-1.05.tar.gz' => {'author' => 'LGODDARD','description' => 'GUI for step-by-step interactive logical process','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2028,'pod' => 969,'pod_errors' => 0,'total' => 2997,'with_comments' => 193},'releases' => 3,'size' => {'packed' => 79608,'unpacked' => 218265},'testers' => {'fail' => 1,'tests' => '28'},'uses' => ['Carp','Config','Cwd','Exporter','File::Copy','File::Path','File::Spec','HTTP::Request','LWP::UserAgent','OLE','Tk','Tk::DirTree','Tk::ErrorDialog','Tk::LabFrame','Tk::MainWindow','Tk::ProgressBar','Tk::ROText','Win32','Win32::Shortcut','Win32::TieRegistry','strict','vars']},'Tk-Workspace-1.75.tar.gz' => {'author' => 'RKIES','description' => '-Persistent, multi-purpose text processor. (File browser, shell, editor) script. Requires Perl/Tk; optionally Net::FTP.','files' => ['Makefile.PL'],'lines' => {'nonpod' => 3385,'pod' => 644,'pod_errors' => 0,'total' => 4029,'with_comments' => 131},'releases' => 6,'size' => {'packed' => 53276,'unpacked' => 191596},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','Cwd','Env','Exporter','File::Basename','FileHandle','IO::File','IO::Select','IPC::Open2','IPC::Open3','POSIX','Tk','Tk::Button','Tk::Checkbutton','Tk::ColorEditor','Tk::Dialog','Tk::DialogBox','Tk::Entry','Tk::Frame','Tk::LabEntry','Tk::Label','Tk::Listbox','Tk::LoginDialog','Tk::MainWindow','Tk::RemoteFileSelect','Tk::TextUndo','Tk::Toplevel','Tk::widgets','strict','vars']},'Tk-WorldCanvas-1.2.7.tar.gz' => {'author' => 'SKROVAN','description' => 'Autoscaling Canvas widget with zoom, viewAll, viewArea, viewFit, and center. =for category Tk Widget Classes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 996,'pod' => 247,'pod_errors' => 1,'total' => 1243,'with_comments' => 38},'releases' => 10,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '800.013'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 14976,'unpacked' => 61255},'testers' => {'pass' => 3},'uses' => ['Tk','Tk::Canvas','Tk::Derived','strict','vars']},'Tk-XDialogBox-0.01.tar.gz' => {'author' => 'XPIX','description' => 'create and manipulate a dialog screen with added Features. =for pm Tixish/DialogBox.pm =for category Tix Extensions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 195,'pod' => 143,'pod_errors' => 1,'total' => 338,'with_comments' => 25},'releases' => 1,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => 0},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 4293,'unpacked' => 10220},'testers' => {'pass' => 1},'uses' => ['Carp','Tk::Toplevel','strict','vars']},'Tk-XMLViewer-0.15.tar.gz' => {'author' => 'SREZIC','description' => 'Tk widget to display XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 542,'pod' => 118,'pod_errors' => 0,'total' => 660,'with_comments' => 42},'releases' => 5,'requires' => ['Tk-800.024.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Tk' => 0,'XML::Parser' => 0},'requires_recursive' => ['Tk-800.024.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 10066,'unpacked' => 29370},'testers' => {},'uses' => ['Tk','Tk::Derived','Tk::DialogBox','Tk::Pixmap','Tk::ROText','Unicode::String','XML::Parser','strict','vars']},'Tk-autobind-1.2.tar.gz' => {'author' => 'KVAIL','description' => 'Automatic ALT-key bindings for Tk widgets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 65,'pod' => 49,'pod_errors' => 0,'total' => 114,'with_comments' => 24},'releases' => 3,'size' => {'packed' => 2748,'unpacked' => 6687},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.005','Tk','strict','vars']},'Tk-mySplashScreen-1.0.3.tar.gz' => {'author' => 'AHICOX','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 83,'pod_errors' => 0,'total' => 232,'with_comments' => 38},'releases' => 2,'requires' => ['Tk-800.024.tar.gz'],'requires_module' => {'Tk' => '800.024'},'requires_recursive' => ['Tk-800.024.tar.gz'],'size' => {'packed' => 18930,'unpacked' => 23066},'testers' => {'pass' => 1},'uses' => ['Tk::Derived','Tk::MainWindow']},'Tk400.202.tar.gz' => {'author' => 'NI-S','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 19834,'pod' => 3181,'pod_errors' => 0,'total' => 23015,'with_comments' => 2024},'releases' => 1,'size' => {'packed' => 2308666,'unpacked' => 9646810},'testers' => {},'uses' => ['5.002','AutoLoader','Benchmark','Carp','Config','Cwd','DirHandle','DynaLoader','English','Exporter','ExtUtils::MakeMaker','Getopt::Long','HTML::Parse','IO::Handle','LWP::Debug','MIME::QuotedPrint','POSIX','Tk','Tk::$_','Tk::$method','Tk::${need}','Tk::Adjuster','Tk::After','Tk::Bitmap','Tk::Button','Tk::Canvas','Tk::Clipboard','Tk::Config','Tk::Configure','Tk::DSC','Tk::Derived','Tk::Dialog','Tk::DragDrop::Common','Tk::DragDrop::Rect','Tk::DragDrop::SunConst','Tk::DropSite','Tk::Entry','Tk::Frame','Tk::Ghostscript','Tk::HList','Tk::HTML','Tk::HTML::Form','Tk::HTML::Handler','Tk::Image','Tk::JPEG','Tk::LabEntry','Tk::LabRadio','Tk::Label','Tk::Listbox','Tk::MainWindow','Tk::Menu','Tk::Menu::Item','Tk::Menubar','Tk::Menubutton','Tk::NBFrame','Tk::Parse','Tk::Photo','Tk::Pixmap','Tk::Pretty','Tk::ROText','Tk::Radiobutton','Tk::Scrollbar','Tk::Submethods','Tk::Table','Tk::Text','Tk::Text::Tag','Tk::Toplevel','Tk::VStack','Tk::Widget','Tk::Wm','Tk::Xlib','strict','subs','vars']},'Tk402.004.tar.gz' => {'author' => 'NI-S','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 17606,'pod' => 2835,'pod_errors' => 2,'total' => 20441,'with_comments' => 1822},'releases' => 1,'size' => {'packed' => 2532603,'unpacked' => 10744811},'testers' => {'fail' => 1},'uses' => ['5.002','5.004','AutoLoader','Carp','Config','Cwd','Data::Dumper','DirHandle','DynaLoader','English','Exporter','ExtUtils::MakeMaker','File::Basename','IO::Handle','POSIX','Tk','Tk::$_','Tk::$method','Tk::${need}','Tk::Adjuster','Tk::After','Tk::Button','Tk::Canvas','Tk::Clipboard','Tk::CmdLine','Tk::Config','Tk::Configure','Tk::DSC','Tk::Derived','Tk::Dialog','Tk::DragDrop::Common','Tk::DragDrop::Rect','Tk::DragDrop::SunConst','Tk::DropSite','Tk::Entry','Tk::Frame','Tk::HList','Tk::IO','Tk::Image','Tk::LabEntry','Tk::LabRadio','Tk::Label','Tk::Listbox','Tk::MainWindow','Tk::Menu','Tk::Menu::Item','Tk::Menubutton','Tk::NBFrame','Tk::Photo','Tk::Pretty','Tk::Radiobutton','Tk::Scrollbar','Tk::Submethods','Tk::Text','Tk::Text::Tag','Tk::Toplevel','Tk::Widget','Tk::Wm','Tk::Xlib','overload','strict','subs','vars']},'Tk800.015.tar.gz' => {'author' => 'NI-S','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 40550,'pod' => 19809,'pod_errors' => 20,'total' => 60359,'with_comments' => 3874},'releases' => 1,'size' => {'packed' => 3330861,'unpacked' => 14217659},'testers' => {'pass' => 2},'uses' => ['5.002','5.004','5.00404','AutoLoader','Carp','Config','Cwd','Data::Dumper','DirHandle','DynaLoader','English','Exporter','ExtUtils::MakeMaker','File::Basename','IO::Handle','Text::Tabs','Tie::Scalar','Tk','Tk::$_','Tk::$method','Tk::${need}','Tk::Adjuster','Tk::After','Tk::Button','Tk::Canvas','Tk::Clipboard','Tk::CmdLine','Tk::ColorEditor','Tk::Config','Tk::Configure','Tk::Derived','Tk::Dialog','Tk::DialogBox','Tk::DragDrop','Tk::DragDrop::Common','Tk::DragDrop::Rect','Tk::DragDrop::SunConst','Tk::DropSite','Tk::Entry','Tk::FBox','Tk::FloatEntry','Tk::Frame','Tk::HList','Tk::IO','Tk::IconList','Tk::Image','Tk::LabEntry','Tk::LabRadio','Tk::Label','Tk::Listbox','Tk::MainWindow','Tk::MakeDepend','Tk::Menu','Tk::Menu::Button','Tk::Menu::Item','Tk::Menubutton','Tk::NBFrame','Tk::Photo','Tk::Pixmap','Tk::Pretty','Tk::Radiobutton','Tk::Scrollbar','Tk::Submethods','Tk::Text','Tk::Text::Tag','Tk::TextUndo','Tk::Toplevel','Tk::Tree','Tk::Widget','Tk::Wm','Tk::Xlib','Tk::widgets','UNIVERSAL','overload','strict','subs','vars']},'Toolbox-0.52.tar.gz' => {'author' => 'DOCG','description' => 'Simplfy some common tasks in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 520,'pod' => 266,'pod_errors' => 0,'total' => 786,'with_comments' => 19},'releases' => 2,'requires' => ['Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Digest::MD5' => 0,'IO::File' => 0,'MIME::Base64' => 0,'Net::SMTP' => 0,'Socket' => 0,'Sys::Hostname' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10613,'unpacked' => 22360},'testers' => {'pass' => 5,'tests' => '0','unknown' => 3},'uses' => ['Digest::MD5','Exporter','IO::File','MIME::Base64','Net::SMTP','Socket','Sys::Hostname','integer']},'Tools-0.04.tar.gz' => {'author' => 'KANE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1975,'pod' => 1304,'pod_errors' => 0,'total' => 3279,'with_comments' => 144},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 29820,'unpacked' => 106883},'testers' => {'fail' => 5,'pass' => 3,'tests' => '84'},'uses' => ['Carp','Config','DBI','Exporter','Term::ReadLine','strict','vars']},'TransitiveClosure-1.4.tgz' => {'author' => 'ABIGAIL','description' => 'Calculates the transitive closure','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 117,'pod' => 138,'pod_errors' => 0,'total' => 255,'with_comments' => 23},'releases' => 2,'size' => {'packed' => 3686,'unpacked' => 10935},'testers' => {'pass' => 8},'uses' => ['Exporter','strict','vars']},'Tree-DAG_Node-1.04.tar.gz' => {'author' => 'SBURKE','description' => 'base class for trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2071,'pod' => 869,'pod_errors' => 0,'total' => 2940,'with_comments' => 320},'releases' => 7,'size' => {'packed' => 31529,'unpacked' => 100173},'testers' => {'pass' => 32},'uses' => ['5','strict','vars']},'Tree-Fat-1.111.tar.gz' => {'author' => 'JPRIT','description' => 'Embeddable F-Tree algorithm suite','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 166,'pod' => 106,'pod_errors' => 0,'total' => 272,'with_comments' => 6},'releases' => 13,'requires' => ['Test-1.24.tar.gz'],'requires_module' => {'Test' => 1},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 32586,'unpacked' => 106186},'testers' => {'pass' => 7},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Tree-M-0.03.tar.gz' => {'author' => 'MLEHMANN','description' => 'M-trees provide efficient metric searches','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 48,'pod' => 106,'pod_errors' => 0,'total' => 154,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 132806,'unpacked' => 422160},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','DynaLoader']},'Tree-MultiNode-1.0.10.tar.gz' => {'author' => 'KRBURTON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 856,'pod' => 424,'pod_errors' => 0,'total' => 1280,'with_comments' => 30},'releases' => 14,'size' => {'packed' => 10919,'unpacked' => 38319},'testers' => {'pass' => 2},'uses' => ['5.004','Carp','strict','vars']},'Tree-Nary-1.21.tar.gz' => {'author' => 'FSORIANO','description' => 'Perl implementation of N-ary search trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1192,'pod' => 283,'pod_errors' => 0,'total' => 1475,'with_comments' => 88},'releases' => 6,'size' => {'packed' => 11666,'unpacked' => 53351},'testers' => {'pass' => 9},'uses' => ['5.003','Exporter','strict','vars']},'Tree-Nary-Extended-0.01.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 419,'pod' => 138,'pod_errors' => 0,'total' => 557,'with_comments' => 13},'releases' => 1,'requires' => ['DBI-1.37.tar.gz','IO-Extended-0.06.tar.gz','SQL-Generator-0.02.tar.gz','Tree-Nary-1.21.tar.gz'],'requires_module' => {'DBI' => 0,'IO::Extended' => '0.05','SQL::Generator' => 0,'Tree::Nary' => '1.21'},'requires_recursive' => ['Class-Maker-0.5.14.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Error-0.15.tar.gz','IO-Extended-0.06.tar.gz','SQL-Generator-0.02.tar.gz','Tree-Nary-1.21.tar.gz'],'size' => {'packed' => 5236,'unpacked' => 14624},'testers' => {},'uses' => ['5.005_62','DBI','Data::Dumper','SQL::Generator','Tree::Nary','strict','warnings']},'Tree-RedBlack-0.3.tar.gz' => {'author' => 'BHOLZMAN','description' => 'Perl implementation of Red/Black tree, a type of balanced tree.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 434,'pod' => 178,'pod_errors' => 0,'total' => 612,'with_comments' => 3},'releases' => 3,'size' => {'packed' => 5248,'unpacked' => 16279},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['strict','vars']},'Tree-Ternary-0.03.tar.gz' => {'author' => 'MROGASKI','description' => 'Perl implementation of ternary search trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 564,'pod' => 120,'pod_errors' => 0,'total' => 684,'with_comments' => 161},'releases' => 1,'requires' => ['Test-1.24.tar.gz'],'requires_module' => {'Test' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz'],'size' => {'packed' => 8792,'unpacked' => 39264},'testers' => {'pass' => 9},'uses' => ['5','Carp','Exporter','strict','vars']},'Tree-Ternary_XS-0.04.tar.gz' => {'author' => 'LBROCARD','description' => 'XS implementation of ternary search trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 68,'pod' => 101,'pod_errors' => 0,'total' => 169,'with_comments' => 6},'releases' => 3,'size' => {'packed' => 11007,'unpacked' => 38989},'testers' => {'fail' => 2,'pass' => 7,'tests' => '129'},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Tree-Trie-1.0.tar.gz' => {'author' => 'AVIF','description' => 'An implementation of the Trie data structure','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 697,'pod' => 105,'pod_errors' => 0,'total' => 802,'with_comments' => 157},'releases' => 5,'size' => {'packed' => 11424,'unpacked' => 32083},'testers' => {'pass' => 3},'uses' => ['5','strict']},'Tree.tar.gz' => {'author' => 'MSCHWERN','description' => 'Defines a basic binary search tree','files' => [],'lines' => {'nonpod' => 1751,'pod' => 95,'pod_errors' => 0,'total' => 1846,'with_comments' => 459},'releases' => 1,'size' => {'packed' => 20507,'unpacked' => 61880},'testers' => {},'uses' => ['Carp','Exporter','Truth','strict','subs','vars']},'Trinket-0.0.1.tar.gz' => {'author' => 'DEUSX','description' => 'Base class for persistent objects managed by Trinket::Directory','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4569,'pod' => 603,'pod_errors' => 0,'total' => 5172,'with_comments' => 829},'releases' => 1,'size' => {'packed' => 26409,'unpacked' => 133554},'testers' => {'fail' => 2,'tests' => '100'},'uses' => ['BerkeleyDB','Bit::Vector::Overload','Carp','DB_File','Data::Dumper','Exporter','Fcntl','File::Path','IO::File','MIME::Base64','Storable','constant','strict','vars']},'TripleStore-0.03.tar.gz' => {'author' => 'JHIVER','description' => 'An SQL-Free Triple Store API with a Perl Query Language.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2037,'pod' => 199,'pod_errors' => 0,'total' => 2236,'with_comments' => 642},'releases' => 3,'size' => {'packed' => 13287,'unpacked' => 64814},'testers' => {'pass' => 2},'uses' => ['','	','Carp','DBI','strict','vars','warnings']},'Tui-0.4.tar.gz' => {'author' => 'RFLENS','description' => 'Text user interface toolkit','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 4156,'pod' => 2140,'pod_errors' => 0,'total' => 6296,'with_comments' => 519},'releases' => 1,'size' => {'packed' => 22033,'unpacked' => 123500},'testers' => {'pass' => 1},'uses' => ['Curses']},'Tuxedo-Admin-0.08.tar.gz' => {'author' => 'KBURDIS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2736,'pod' => 1923,'pod_errors' => 0,'total' => 4659,'with_comments' => 51},'releases' => 4,'size' => {'packed' => 20947,'unpacked' => 127519},'testers' => {'pass' => 1},'uses' => ['Carp','Data::Dumper','IPC::Open2','strict']},'Tvtoday-1.05.tar.gz' => {'author' => 'HORSHACK','description' => 'Get television-program from german www.tvtoday.de and search for special broadcasts you like','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 402,'pod' => 118,'pod_errors' => 0,'total' => 520,'with_comments' => 74},'releases' => 4,'requires' => ['HTML-TableContentParser-0.13.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Basename' => 0,'HTML::TableContentParser' => '0','LWP::UserAgent' => 0,'URI::Escape' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableContentParser-0.13.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6230,'unpacked' => 14465},'testers' => {'pass' => 5},'uses' => ['5.006','AutoLoader','Exporter','File::Basename','HTML::TableContentParser','LWP::UserAgent','URI::Escape','strict','warnings']},'UDDI-0.03.tar.gz' => {'author' => 'GAAS','description' => 'UDDI client interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 794,'pod' => 111,'pod_errors' => 0,'total' => 905,'with_comments' => 22},'releases' => 3,'requires' => ['XML-Parser-2.31.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.4','XML::Parser' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12345,'unpacked' => 60149},'testers' => {'fail' => 7,'tests' => '5'},'uses' => ['Exporter','LWP::UserAgent','XML::Parser::Expat','strict']},'UDPM-0.88.tar.gz' => {'author' => 'KCK','description' => 'Perl extension for User Dialogs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2843,'pod' => 1351,'pod_errors' => 1,'total' => 4194,'with_comments' => 120},'releases' => 4,'size' => {'packed' => 40095,'unpacked' => 168980},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Cwd','File::Basename','FileHandle','diagnostics','strict','vars','warnings']},'UML-Sequence-0.04.tar.gz' => {'author' => 'PHILCROW','description' => 'This package makes UML sequence diagrams, often by running the code.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1218,'pod' => 310,'pod_errors' => 1,'total' => 1528,'with_comments' => 91},'releases' => 4,'requires' => ['XML-DOM-1.42.tar.gz'],'requires_module' => {'XML::DOM' => '1.25'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 77682,'unpacked' => 179670},'testers' => {'pass' => 1},'uses' => ['5.005_62','Die','Exporter','Getopt::Std','XML::DOM','strict','vars','warnings']},'UML-State-0.02.tar.gz' => {'author' => 'PHILCROW','description' => 'draws state diagrams from simple text files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 429,'pod' => 107,'pod_errors' => 0,'total' => 536,'with_comments' => 46},'releases' => 2,'size' => {'packed' => 55802,'unpacked' => 96490},'testers' => {'pass' => 3},'uses' => ['strict','warnings']},'UNIVERSAL-exports-0.03.tar.gz' => {'author' => 'MSCHWERN','description' => 'Lightweight, universal exporting of variables','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 121,'pod' => 124,'pod_errors' => 0,'total' => 245,'with_comments' => 7},'releases' => 2,'requires' => ['Exporter-Lite-0.01.tar.gz'],'requires_module' => {'Exporter::Lite' => '0.01'},'requires_recursive' => ['Exporter-Lite-0.01.tar.gz'],'size' => {'packed' => 4497,'unpacked' => 11288},'testers' => {'pass' => 39},'uses' => ['Exporter::Lite','strict']},'UNIX-Cal-0.01.tar.gz' => {'author' => 'PIERS','description' => 'Perl wrapper for the original cal UNIX command line tool','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 122,'pod' => 51,'pod_errors' => 0,'total' => 173,'with_comments' => 5},'releases' => 1,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline' => '0.43'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 6635,'unpacked' => 16374},'testers' => {'pass' => 1},'uses' => ['Cwd','strict','vars']},'UPS-Nut-0.04.tar.gz' => {'author' => 'KPETERS','description' => 'a module to talk to a UPS via NUT (Network UPS Tools) upsd','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 880,'pod' => 115,'pod_errors' => 0,'total' => 995,'with_comments' => 209},'releases' => 3,'size' => {'packed' => 22738,'unpacked' => 73706},'testers' => {'pass' => 2},'uses' => ['Carp','FileHandle','IO::Select','IO::Socket','strict','vars']},'URI-1.23.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3266,'pod' => 941,'pod_errors' => 0,'total' => 4207,'with_comments' => 243},'releases' => 32,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::Base64' => 2},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'testers' => {'pass' => 8},'uses' => ['Carp','Cwd','Data::Dumper','Exporter','MIME::Base64','Net::Domain','URI::_foreign','overload','strict','vars']},'URI-Bookmarks-0.92.tar.gz' => {'author' => 'ASPIERS','description' => 'Perl module class encapsulating an entry in a typical bookmark file.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 659,'pod' => 193,'pod_errors' => 0,'total' => 852,'with_comments' => 49},'releases' => 1,'requires' => ['Tree-DAG_Node-1.04.tar.gz'],'requires_module' => {'Tree::DAG_Node' => 0},'requires_recursive' => ['Tree-DAG_Node-1.04.tar.gz'],'size' => {'packed' => 9068,'unpacked' => 41532},'testers' => {'pass' => 13},'uses' => ['5.004','AutoLoader','Carp','Tree::DAG_Node','strict','vars']},'URI-Find-0.13.tar.gz' => {'author' => 'ROSCH','description' => 'Find URIs in arbitrary text','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 331,'pod' => 189,'pod_errors' => 0,'total' => 520,'with_comments' => 43},'releases' => 7,'requires' => ['URI-1.24.tar.gz'],'requires_module' => {'URI' => '1.00','URI::URL' => '5.00'},'requires_recursive' => ['URI-1.24.tar.gz'],'size' => {'packed' => 9855,'unpacked' => 25059},'testers' => {'pass' => 27},'uses' => ['5.005','Exporter','URI','URI::URL','strict','vars']},'URI-Find-Delimited-0.02.tar.gz' => {'author' => 'KAKE','description' => 'Find URIs which may be wrapped in enclosing delimiters.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 123,'pod' => 95,'pod_errors' => 0,'total' => 218,'with_comments' => 14},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','URI-Find-0.13.tar.gz'],'requires_module' => {'Test::More' => 0,'URI::Find' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','URI-Find-0.13.tar.gz'],'size' => {'packed' => 4688,'unpacked' => 15633},'testers' => {'pass' => 4},'uses' => ['URI::Find','strict','vars']},'URI-Find-Schemeless-Stricter-1.00.tar.gz' => {'author' => 'SIMON','description' => 'Find schemeless URIs in arbitrary text.','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 56,'pod' => 41,'pod_errors' => 0,'total' => 97,'with_comments' => 9},'releases' => 1,'requires' => ['URI-Find-0.13.tar.gz'],'requires_module' => {'URI::Find' => 0},'requires_recursive' => ['URI-1.24.tar.gz','URI-Find-0.13.tar.gz'],'size' => {'packed' => 3534,'unpacked' => 6181},'testers' => {'pass' => 8},'uses' => ['5.00600','URI::Find','strict']},'URI-Sequin-1.1.2.tar.gz' => {'author' => 'SARGIE','description' => 'Takes search terms from URLs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 404,'pod' => 72,'pod_errors' => 0,'total' => 476,'with_comments' => 135},'releases' => 3,'size' => {'packed' => 29341,'unpacked' => 152178},'testers' => {'pass' => 7},'uses' => ['5.005','Exporter','strict','vars']},'URIC-2.02.tar.gz' => {'author' => 'LDACHARY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1700,'pod' => 55,'pod_errors' => 0,'total' => 1755,'with_comments' => 228},'releases' => 1,'size' => {'packed' => 109890,'unpacked' => 506578},'testers' => {'fail' => 1},'uses' => ['5.004','DynaLoader','Exporter','Net::Domain','overload','strict','vars']},'UUID-0.03.tar.gz' => {'author' => 'LZAP','description' => 'interface for e2fsprogs UUID (unique idents)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 32,'pod' => 28,'pod_errors' => 0,'total' => 60,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 2633,'unpacked' => 5144},'testers' => {},'uses' => ['5.005','DynaLoader','Exporter','strict','vars','warnings']},'UniLog-0.11.tar.gz' => {'author' => 'TPABA','description' => 'Perl module for unified logging on Unix and Win32 I<Version 0.11>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 557,'pod' => 303,'pod_errors' => 0,'total' => 860,'with_comments' => 33},'releases' => 10,'size' => {'packed' => 9222,'unpacked' => 30226},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','File::Basename','File::Path','IO::File','POSIX','Unix::Syslog','Win32::EventLog','strict','vars']},'Unicode-Collate-0.25.tar.gz' => {'author' => 'SADAHIRO','description' => 'Unicode Collation Algorithm','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1055,'pod' => 485,'pod_errors' => 0,'total' => 1540,'with_comments' => 160},'releases' => 13,'size' => {'packed' => 31234,'unpacked' => 124813},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','File::Spec','constant','strict','warnings']},'Unicode-Collate-Standard-V3_1_1-0.1.tar.gz' => {'author' => 'BBENNETT','description' => 'Thin Perl wrapper to allow easy installation of the Unicode collation database that Unicode::Collate uses to sort Unicode data.','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 37,'pod_errors' => 0,'total' => 76,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 167489,'unpacked' => 883052},'testers' => {'pass' => 2},'uses' => ['Exporter','File::Spec','strict','vars']},'Unicode-Decompose-0.02.tar.gz' => {'author' => 'SIMON','description' => 'Unicode decomposition and normalization','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 47,'pod_errors' => 0,'total' => 180,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 4082,'unpacked' => 8640},'testers' => {'fail' => 2},'uses' => ['5.006','DynaLoader','Exporter','UnicodeCD','lib','strict','utf','warnings']},'Unicode-EastAsianWidth-1.01.tar.gz' => {'author' => 'AUTRIJUS','description' => 'East Asian Width properties','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 771,'pod' => 56,'pod_errors' => 0,'total' => 827,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 7282,'unpacked' => 16518},'testers' => {'pass' => 4},'uses' => ['5.006','Exporter','strict']},'Unicode-IMAPUtf7-1.04.tar.gz' => {'author' => 'FABPOT','description' => 'Perl extension to deal with IMAP UTF7','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 27,'pod_errors' => 0,'total' => 72,'with_comments' => 4},'releases' => 3,'requires' => ['Unicode-String-2.07.tar.gz'],'requires_module' => {'Unicode::String' => 0},'requires_recursive' => ['MIME-Base64-2.20.tar.gz','Unicode-String-2.07.tar.gz'],'size' => {'packed' => 1862,'unpacked' => 3598},'testers' => {'pass' => 3},'uses' => ['AutoLoader','Exporter','Unicode::String','strict','vars']},'Unicode-Japanese-0.18.tar.gz' => {'author' => 'MIKAGE','description' => 'Japanese Character Encoding Handler','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 3144,'pod' => 407,'pod_errors' => 0,'total' => 3551,'with_comments' => 192},'releases' => 10,'size' => {'packed' => 156669,'unpacked' => 991990},'testers' => {'pass' => 7},'uses' => ['Carp','DynaLoader','Encode','bytes','strict','vars']},'Unicode-Lite-0.12.tar.gz' => {'author' => 'AMICHAUER','description' => 'Easy conversion between encodings','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 907,'pod' => 224,'pod_errors' => 0,'total' => 1131,'with_comments' => 422},'releases' => 11,'requires' => ['Unicode-Map-0.112.tar.gz','Unicode-String-2.07.tar.gz','enum-1.016.tar.gz'],'requires_module' => {'Unicode::Map' => '0.11','Unicode::String' => '2.06','enum' => '1.016'},'requires_recursive' => ['MIME-Base64-2.20.tar.gz','Unicode-Map-0.112.tar.gz','Unicode-String-2.07.tar.gz','enum-1.016.tar.gz'],'size' => {'packed' => 8456,'unpacked' => 35559},'testers' => {'pass' => 21},'uses' => ['5.005_03','5.005_62','Carp','Exporter','Unicode::Map','constant','enum','strict','vars','warnings']},'Unicode-Map-0.112.tar.gz' => {'author' => 'MSCHWARTZ','description' => 'maps charsets from and to utf16 unicode','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1079,'pod' => 287,'pod_errors' => 1,'total' => 1366,'with_comments' => 208},'releases' => 6,'size' => {'packed' => 476116,'unpacked' => 709275},'testers' => {'pass' => 26},'uses' => ['Carp','DynaLoader','strict','vars']},'Unicode-Map8-0.12.tar.gz' => {'author' => 'GAAS','description' => 'Convert between most 8bit encodings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 173,'pod' => 133,'pod_errors' => 0,'total' => 306,'with_comments' => 12},'releases' => 11,'requires' => ['Unicode-String-2.07.tar.gz'],'requires_module' => {'Unicode::String' => 2},'requires_recursive' => ['MIME-Base64-2.20.tar.gz','Unicode-String-2.07.tar.gz'],'size' => {'packed' => 102882,'unpacked' => 451016},'testers' => {'pass' => 1},'uses' => ['DynaLoader','Exporter','Unicode::String','strict','vars']},'Unicode-MapUTF8-1.09.tar.gz' => {'author' => 'SNOWHARE','description' => 'Conversions to and from arbitrary charsets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 599,'pod' => 176,'pod_errors' => 0,'total' => 775,'with_comments' => 79},'releases' => 8,'requires' => ['Jcode-0.83.tar.gz','Unicode-Map-0.112.tar.gz','Unicode-Map8-0.12.tar.gz','Unicode-String-2.07.tar.gz'],'requires_module' => {'Jcode' => 0,'Unicode::Map' => 0,'Unicode::Map8' => 0,'Unicode::String' => 0},'requires_recursive' => ['Jcode-0.83.tar.gz','MIME-Base64-2.20.tar.gz','Unicode-Map-0.112.tar.gz','Unicode-Map8-0.12.tar.gz','Unicode-String-2.07.tar.gz'],'size' => {'packed' => 7667,'unpacked' => 36619},'testers' => {'pass' => 13},'uses' => ['Carp','Exporter','Jcode','Unicode::Map','Unicode::Map8','Unicode::String','strict','subs','vars']},'Unicode-Normalize-0.23.tar.gz' => {'author' => 'SADAHIRO','description' => 'Unicode Normalization Forms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 550,'pod' => 216,'pod_errors' => 0,'total' => 766,'with_comments' => 54},'releases' => 18,'size' => {'packed' => 16265,'unpacked' => 66208},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','File::Spec','constant','strict','warnings']},'Unicode-Regex-Set-0.02.tar.gz' => {'author' => 'SADAHIRO','description' => 'Subtraction and Intersection of Character Sets in Unicode Regular Expressions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 290,'pod' => 65,'pod_errors' => 0,'total' => 355,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 5544,'unpacked' => 15786},'testers' => {'pass' => 3},'uses' => ['5.008','Carp','Exporter','constant','strict','vars','warnings']},'Unicode-String-2.07.tar.gz' => {'author' => 'GAAS','description' => 'String manipulation for Unicode strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7506,'pod' => 250,'pod_errors' => 0,'total' => 7756,'with_comments' => 54},'releases' => 8,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::Base64' => 2},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 61102,'unpacked' => 277433},'testers' => {'pass' => 5},'uses' => ['Carp','DynaLoader','Exporter','MIME::Base64','strict','vars']},'Unicode-Transform-0.22.tar.gz' => {'author' => 'SADAHIRO','description' => 'conversion among Unicode Transformation Formats (UTFs)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 113,'pod_errors' => 0,'total' => 182,'with_comments' => 6},'releases' => 2,'size' => {'packed' => 8007,'unpacked' => 29624},'testers' => {'pass' => 2},'uses' => ['5.006','AutoLoader','DynaLoader','Exporter','strict','vars']},'Unicode-Transliterate.0.3.tgz' => {'author' => 'JHIVER','description' => 'Perl wrapper for ICU transliteration services','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 229,'pod' => 63,'pod_errors' => 0,'total' => 292,'with_comments' => 41},'releases' => 1,'size' => {'packed' => 7500,'unpacked' => 28547},'testers' => {},'uses' => ['5.005_62','AutoLoader','Carp','DynaLoader','Exporter','constant','strict','warnings']},'Unicode-Unihan-0.02.tar.gz' => {'author' => 'DANKOGAI','description' => 'The Unihan Data Base 3.2.0','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 412,'pod' => 575,'pod_errors' => 0,'total' => 987,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 4513673,'unpacked' => 12924673},'testers' => {'pass' => 2},'uses' => ['5.006','AnyDBM_File','Carp','Fcntl','strict','warnings']},'Unicode-Wrap-0.03.tar.gz' => {'author' => 'NESTING','description' => 'Unicode Line Breaking','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 364,'pod' => 113,'pod_errors' => 0,'total' => 477,'with_comments' => 28},'releases' => 3,'size' => {'packed' => 7266,'unpacked' => 21524},'testers' => {'pass' => 2},'uses' => ['5.008','Carp','Clone','Exporter','Unicode::UCD','constant','strict','warnings']},'Unix-Conf-0.2.tar.gz' => {'author' => 'KARTHIKK','description' => 'Front end for class methods in various utility modules under the Unix::Conf namespace.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 903,'pod' => 418,'pod_errors' => 0,'total' => 1321,'with_comments' => 124},'releases' => 2,'requires' => ['perl-5.8.0.tar.gz'],'requires_module' => {'Fcntl' => '1.03'},'requires_recursive' => ['perl-5.8.0.tar.gz'],'size' => {'packed' => 11522,'unpacked' => 36771},'testers' => {'pass' => 3},'uses' => ['5.6.0','Fcntl','overload','strict','warnings']},'Unix-Conf-Bind8-0.3.tar.gz' => {'author' => 'KARTHIKK','description' => 'Front end for a suite of classes for manipulating a Bind8 conf and associated zone record files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7899,'pod' => 3031,'pod_errors' => 8,'total' => 10930,'with_comments' => 885},'releases' => 2,'requires' => ['Unix-Conf-0.2.tar.gz'],'requires_module' => {'Unix::Conf' => '0.2'},'requires_recursive' => ['Unix-Conf-0.2.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 78132,'unpacked' => 365378},'testers' => {'fail' => 3,'tests' => '586'},'uses' => ['5.6.0','Exporter','Unix::Conf','Unix::Conf::Bind8::Conf::Parser','Unix::Conf::Bind8::DB::Parser','constant','strict','warnings']},'Unix-ConfigFile-0.06.tar.gz' => {'author' => 'SSNODGRA','description' => 'Abstract interfaces to Unix config files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1225,'pod' => 381,'pod_errors' => 0,'total' => 1606,'with_comments' => 182},'releases' => 2,'size' => {'packed' => 18821,'unpacked' => 65421},'testers' => {'pass' => 9},'uses' => ['5.004','Carp','Exporter','Fcntl','IO::File','Text::ParseWords','Text::Tabs','strict','vars']},'Unix-Login-1.06.tar.gz' => {'author' => 'NWIGER','description' => 'Customizable Unix login prompt / validation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 284,'pod' => 103,'pod_errors' => 0,'total' => 387,'with_comments' => 101},'releases' => 3,'size' => {'packed' => 5895,'unpacked' => 17414},'testers' => {'pass' => 5},'uses' => ['5.004','Carp','Exporter','User::pwent','strict']},'Unix-Processors-2.014.tar.gz' => {'author' => 'WSNYDER','description' => 'Interface to processor (CPU) information','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 95,'pod_errors' => 0,'total' => 214,'with_comments' => 55},'releases' => 13,'size' => {'packed' => 15885,'unpacked' => 49262},'testers' => {'pass' => 3},'uses' => ['Carp','DynaLoader','strict','vars']},'Unix-Syslog-0.99.tar.gz' => {'author' => 'MHARNISCH','description' => 'Interface to syslog functions in a C-library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 166,'pod' => 115,'pod_errors' => 0,'total' => 281,'with_comments' => 13},'releases' => 3,'size' => {'packed' => 12499,'unpacked' => 37537},'testers' => {'fail' => 3,'pass' => 8},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'UnixODBC-0.21.tar.gz' => {'author' => 'RKIES','description' => 'Perl extension for unixODBC.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 3115,'pod' => 1897,'pod_errors' => 0,'total' => 5012,'with_comments' => 222},'releases' => 6,'size' => {'packed' => 153205,'unpacked' => 577031},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','IO::Socket','Net::Daemon','RPC::PlServer','lib','strict','vars','warnings']},'Untaint-0.05.tar.gz' => {'author' => 'KMELTZ','description' => 'Module for laundering tainted data.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 94,'pod' => 123,'pod_errors' => 1,'total' => 217,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 4251,'unpacked' => 13517},'testers' => {},'uses' => ['5.005','Carp','Exporter','Taint','strict','vars']},'Usage-0.10.tar.gz' => {'author' => 'JACKS','description' => 'Type and range checking on subroutine args','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 927,'pod' => 0,'pod_errors' => 0,'total' => 927,'with_comments' => 420},'releases' => 1,'size' => {'packed' => 11425,'unpacked' => 35155},'testers' => {'pass' => 1,'tests' => '0','unknown' => 12},'uses' => ['AutoLoader','Exporter','strict','the']},'Usage-Sub-0.02.tar.gz' => {'author' => 'HASANT','description' => 'Issueing subroutine/method usage','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 109,'pod' => 112,'pod_errors' => 0,'total' => 221,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 4439,'unpacked' => 12837},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','strict','warnings']},'User-1.6.tar.gz' => {'author' => 'TBONE','description' => 'API for locating user information regardless of OS','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 48,'pod' => 71,'pod_errors' => 0,'total' => 119,'with_comments' => 2},'releases' => 7,'size' => {'packed' => 2092,'unpacked' => 3428},'testers' => {'pass' => 25},'uses' => ['Exporter','strict','vars']},'User-Identity-0.04.tar.gz' => {'author' => 'MARKOV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1071,'pod' => 1380,'pod_errors' => 0,'total' => 2451,'with_comments' => 27},'releases' => 4,'requires' => ['Geography-Countries-1.4.tar.gz'],'requires_module' => {'Geography::Countries' => '1.4'},'requires_recursive' => ['Geography-Countries-1.4.tar.gz'],'size' => {'packed' => 16636,'unpacked' => 66234},'testers' => {'pass' => 3},'uses' => ['Carp','List::Util','Scalar::Util','overload','strict','warnings']},'User-Utmp-1.01.tar.gz' => {'author' => 'MPIOTR','description' => 'Perl access to UNIX utmp(x)-style databases','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 89,'pod' => 67,'pod_errors' => 0,'total' => 156,'with_comments' => 10},'releases' => 5,'size' => {'packed' => 7830,'unpacked' => 21833},'testers' => {'fail' => 1,'pass' => 7},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Util-0.05.tar.gz' => {'author' => 'CHOCOLATE','description' => 'Frequently Hacked Functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 862,'pod' => 759,'pod_errors' => 1,'total' => 1621,'with_comments' => 178},'releases' => 5,'requires' => ['Test-Deep-0.06.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Math::Complex' => 0,'Test::Deep' => 0,'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Deep-0.06.tar.gz','Test-Harness-2.29.tar.gz','Test-NoWarnings-0.05.tar.gz','Test-Simple-0.47.tar.gz','Test-Tester-0.06.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 23247,'unpacked' => 67720},'testers' => {'fail' => 1,'pass' => 1,'tests' => '120'},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Errno','Exporter','Fcntl','Math::Complex','POSIX','Scalar::Util','strict','warnings']},'Uttu-0.01.tar.gz' => {'author' => 'JSMITH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2261,'pod' => 1177,'pod_errors' => 5,'total' => 3438,'with_comments' => 159},'releases' => 6,'requires' => ['AppConfig-1.55.tar.gz','Cache-Cache-1.02.tar.gz','HTML-Mason-1.22.tar.gz','Module-Require-0.04.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'AppConfig' => '1.52','Cache::Cache' => '0.99','HTML::Mason' => '1.04','Module::Require' => '0.02','mod_perl' => '1.24'},'requires_recursive' => ['AppConfig-1.55.tar.gz','Cache-Cache-1.02.tar.gz','File-Spec-0.82.tar.gz','HTML-Mason-1.22.tar.gz','Module-Require-0.04.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 30305,'unpacked' => 99746},'testers' => {},'uses' => ['5.005002','Apache','Apache::Constants','Apache::DBI','Apache::ModuleConfig','Apache::Test','Apache::TestRequest','AppConfig','Carp','DBI','Data::Dumper','Exporter','File::Glob','HTML::Mason','HTML::Mason::ApacheHandler','Locale::Maketext','Module::Require','Uttu','lib','mod_perl','strict','vars','warnings']},'Uttu-0.04.tar.gz' => {'author' => 'JSMITH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3758,'pod' => 1950,'pod_errors' => 11,'total' => 5708,'with_comments' => 227},'releases' => 6,'requires' => ['AppConfig-1.55.tar.gz','Cache-Cache-1.02.tar.gz','DBIx-Abstract-1.005.tar.gz','Module-Require-0.04.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'AppConfig' => '1.52','Cache::Cache' => '0.99','DBIx::Abstract' => 1,'Module::Require' => '0.02','mod_perl' => '1.24'},'requires_recursive' => ['AppConfig-1.55.tar.gz','Cache-Cache-1.02.tar.gz','DBI-1.37.tar.gz','DBIx-Abstract-1.005.tar.gz','File-Spec-0.82.tar.gz','Module-Require-0.04.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 49471,'unpacked' => 172608},'testers' => {},'uses' => ['5.005002','5.006','Apache','Apache::AxKit::ConfigReader','Apache::AxKit::Exception','Apache::AxKit::Provider::File','Apache::Constants','Apache::DBI','Apache::ModuleConfig','Apache::Test','Apache::TestRequest','AppConfig','AxKit','Carp','DBI','DBIx::Abstract','Data::Dumper','Exporter','File::Glob','File::Spec','HTML::Mason','HTML::Mason::ApacheHandler','IO::File','Locale::Maketext','Module::Build','Module::Require','Template','Template::Service::Apache','Time::HiRes','Uttu','Uttu::Config','Uttu::Handler::axkit::ConfigReader','Uttu::Handler::axkit::ContentProvider','Uttu::Tools','mod_perl','strict','vars','warnings']},'Uttu-0.06.tar.gz' => {'author' => 'JSMITH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4106,'pod' => 2099,'pod_errors' => 14,'total' => 6205,'with_comments' => 289},'releases' => 6,'requires' => ['AppConfig-1.55.tar.gz','Cache-Cache-1.02.tar.gz','DBIx-Abstract-1.005.tar.gz','Module-Require-0.04.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'AppConfig' => '1.52','Cache::Cache' => '0.99','DBIx::Abstract' => 1,'Module::Require' => '0.02','mod_perl' => '1.24'},'requires_recursive' => ['AppConfig-1.55.tar.gz','Cache-Cache-1.02.tar.gz','DBI-1.37.tar.gz','DBIx-Abstract-1.005.tar.gz','File-Spec-0.82.tar.gz','Module-Require-0.04.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 54356,'unpacked' => 188380},'testers' => {},'uses' => ['5.005002','5.006','Apache','Apache::AxKit::ConfigReader','Apache::AxKit::Exception','Apache::AxKit::Provider::File','Apache::Constants','Apache::DBI','Apache::ModuleConfig','Apache::Test','Apache::TestRequest','Apache::URI','AppConfig','AxKit','Carp','DBI','DBIx::Abstract','Data::Dumper','Exporter','File::Glob','File::Spec','HTML::Mason','HTML::Mason::ApacheHandler','IO::File','Locale::Maketext','Module::Require','ResourcePool','ResourcePool::Factory::DBI','ResourcePool::Factory::Net::LDAP','ResourcePool::LoadBalancer','Template','Template::Service::Apache','Uttu::Config','Uttu::Tools','XML::XPath','XML::XPath::Parser','mod_perl','strict','vars','warnings']},'Uttu-Framework-Uttu-0.01.tar.gz' => {'author' => 'JSMITH','description' => 'framework for Uttu site','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 599,'pod' => 100,'pod_errors' => 1,'total' => 699,'with_comments' => 49},'releases' => 1,'requires' => ['Uttu-0.01.tar.gz'],'requires_module' => {'Uttu::MakeMaker' => '0.01'},'requires_recursive' => ['AppConfig-1.55.tar.gz','Cache-Cache-1.02.tar.gz','File-Spec-0.82.tar.gz','HTML-Mason-1.22.tar.gz','Module-Require-0.04.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Uttu-0.01.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 11464,'unpacked' => 35282},'testers' => {},'uses' => ['Apache::Session::Flex','AppConfig','Error','Quantum::Superpositions','Uttu::Framework','Uttu::Tools','lib','strict','vars']},'VBTK-0.14.tar.gz' => {'author' => 'BSHENRY','description' => 'Virtual Brent Toolkit - A generic toolkit for system monitoring','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 16440,'pod' => 5329,'pod_errors' => 1,'total' => 21769,'with_comments' => 4910},'releases' => 1,'requires' => ['Algorithm-Diff-1.15.tar.gz','DateManip-5.42a.tar.gz','Storable-2.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Algorithm::Diff' => 0,'Date::Manip' => 0,'File::Find' => 0,'Storable' => 0},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','DateManip-5.42a.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 161151,'unpacked' => 732924},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.004','5.6.1','Algorithm::Diff','CGI','Config','DBI','Date::Manip','Exporter','ExtUtils::MakeMaker','File::Basename','File::Find','File::Path','FileHandle','Getopt::Std','HTTP::Cookies','HTTP::Daemon','HTTP::Status','IO::Socket::INET','IPC::Open2','LWP::UserAgent','Mail::POP3Client','Mail::Sendmail','POSIX','Pod::Find','Pod::Html','SNMP','Storable','Sys::Hostname','URI::Escape','VBTK::Objects::Rrd','strict','vars','warnings']},'VCG-0.5.tar.gz' => {'author' => 'TEEJAY','description' => 'Interface to the VCG graphing tool','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 176,'pod' => 126,'pod_errors' => 0,'total' => 302,'with_comments' => 9},'releases' => 5,'requires' => ['IPC-Run-0.75.tar.gz'],'requires_module' => {'IPC::Run' => 0},'requires_recursive' => ['IPC-Run-0.75.tar.gz'],'size' => {'packed' => 4831,'unpacked' => 11779},'testers' => {'pass' => 8},'uses' => ['IPC::Run','strict','vars']},'VCP-0.3.tar.gz' => {'author' => 'RBS','description' => 'Versioned Copy, copying hierarchies of versioned files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9839,'pod' => 2359,'pod_errors' => 5,'total' => 12198,'with_comments' => 1411},'releases' => 20,'requires' => ['Digest-MD5-2.26.tar.gz','File-Temp-0.12.tar.gz','IPC-Run-0.75.tar.gz','MIME-Base64-2.20.tar.gz','PodToHTML-0.04.tar.gz','Regexp-Shellish-0.93.tar.gz','Text-Diff-0.35.tar.gz','XML-AutoWriter-0.37.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Digest::MD5' => 0,'File::Temp' => 0,'IPC::Run' => '0.6','MIME::Base64' => 0,'Pod::Links' => 0,'Regexp::Shellish' => '0.93','Text::Diff' => 0,'XML::Parser' => 0,'XML::ValidWriter' => '0.36'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IPC-Run-0.75.tar.gz','MIME-Base64-2.20.tar.gz','PodToHTML-0.04.tar.gz','Regexp-Shellish-0.93.tar.gz','Text-Diff-0.35.tar.gz','XML-AutoWriter-0.37.tar.gz','XML-Parser-2.31.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 122937,'unpacked' => 447291},'testers' => {},'uses' => ['','Carp','Cwd','Data::Dumper','Digest::MD5','Exporter','Fcntl','File::Basename','File::Path','File::Spec','File::Spec::Unix','File::Temp','Getopt::Long','IPC::Run','MIME::Base64','POSIX','Pod::Usage','Regexp::Shellish','RevML::Doctype::v$doctype_pm','Symbol','Text::Diff','Time::Local','UNIVERSAL','XML::AutoWriter','XML::Doctype','XML::Parser','constant','strict','vars']},'VCS-0.10.tar.gz' => {'author' => 'GMCCAR','description' => 'Library for generic Version Control System access in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1140,'pod' => 569,'pod_errors' => 0,'total' => 1709,'with_comments' => 51},'releases' => 10,'requires' => ['URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Spec::Functions' => 0,'URI' => 0},'requires_recursive' => ['URI-1.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 22668,'unpacked' => 79124},'testers' => {'fail' => 1,'pass' => 10,'tests' => '38'},'uses' => ['Carp','Cwd','File::Basename','File::Spec::Functions','Sort::Versions','URI','VCS::Hms::Dir','VCS::Hms::File','VCS::Hms::Version','strict','vars']},'VCS-CMSynergy-1.14.tar.gz' => {'author' => 'RSCHUPP','description' => 'Perl interface to Telelogic CM Synergy (aka Continuus/CM)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2545,'pod' => 1408,'pod_errors' => 0,'total' => 3953,'with_comments' => 328},'releases' => 7,'size' => {'packed' => 43230,'unpacked' => 147361},'testers' => {},'uses' => ['5.006_000','Carp','Config','Cwd','Data::Dumper','Digest::MD5','Expect','File::Basename','File::Spec','File::Temp','Filesys::CygwinPaths','IO::File','IO::Handle','IO::Pipe','IO::Select','IPC::Open3','Memoize','POSIX','Scalar::Util','strict','vars']},'VCS-Hms-0.03.tar.gz' => {'author' => 'GMCCAR','description' => 'notes for the HMS implementation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 245,'pod' => 29,'pod_errors' => 0,'total' => 274,'with_comments' => 14},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz','VCS-0.10.tar.gz'],'requires_module' => {'Test::More' => 0,'VCS' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','VCS-0.10.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3106,'unpacked' => 8105},'testers' => {'pass' => 2},'uses' => ['Carp','File::Basename','Sort::Versions','strict','vars']},'VCS-LibCVS-1.tar.gz' => {'author' => 'DISSENT','description' => 'Access CVS working directories and repositories.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5757,'pod' => 3016,'pod_errors' => 0,'total' => 8773,'with_comments' => 1601},'releases' => 1,'size' => {'packed' => 53006,'unpacked' => 259415},'testers' => {'fail' => 1,'pass' => 1,'tests' => '103'},'uses' => ['Carp','File::Spec::Unix','FileHandle','IO::Dir','IPC::Open2','Time::Local','VCS::LibCVS::Client::Request::ArgumentUsingRequests','VCS::LibCVS::Client::Request::Requests','VCS::LibCVS::Client::Response::FileUpdateModifyingResponses','VCS::LibCVS::Client::Response::FileUpdatingResponses','VCS::LibCVS::Client::Response::Responses','constant','strict','vars']},'VCS-Lite-0.04.tar.gz' => {'author' => 'IVORW','description' => 'Minimal version control system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 731,'pod' => 162,'pod_errors' => 0,'total' => 893,'with_comments' => 87},'releases' => 3,'requires' => ['Algorithm-Diff-1.15.tar.gz'],'requires_module' => {'Algorithm::Diff' => '1.13'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz'],'size' => {'packed' => 12459,'unpacked' => 44297},'testers' => {'pass' => 2},'uses' => ['Algorithm::Diff','Carp','strict','warnings']},'VCS-Rcs-Parser-0.04.tar.gz' => {'author' => 'ZIYA','description' => 'Perl extension for RCSfile Parsing','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2047,'pod' => 140,'pod_errors' => 0,'total' => 2187,'with_comments' => 518},'releases' => 2,'requires' => ['Parse-Yapp-1.05.tar.gz'],'requires_module' => {'Parse::Yapp' => '1.04'},'requires_recursive' => ['Parse-Yapp-1.05.tar.gz'],'size' => {'packed' => 14768,'unpacked' => 62668},'testers' => {},'uses' => ['5.004','5.6.0','Carp','Data::Dumper','VCS::Rcs::YappRcsParser','strict','vars','warnings']},'VCS-Rcs-Parser-0.06.tar.gz' => {'author' => 'ZIYA','description' => 'Perl extension for RCSfile Parsing','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5117,'pod' => 307,'pod_errors' => 0,'total' => 5424,'with_comments' => 1156},'releases' => 2,'requires' => ['Parse-Yapp-1.05.tar.gz'],'requires_module' => {'Parse::Yapp' => '1.04'},'requires_recursive' => ['Parse-Yapp-1.05.tar.gz'],'size' => {'packed' => 35545,'unpacked' => 145198},'testers' => {'pass' => 2},'uses' => ['5.004','5.6.0','Carp','Data::Dumper','Rcs::Deltatext','Rcs::Parser','VCS::Rcs::Deltatext','constant','strict','vars','warnings']},'VCS-SaVeS-0.12.tar.gz' => {'author' => 'INGY','description' => 'The Standalone Versioning System(tm)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 758,'pod' => 88,'pod_errors' => 0,'total' => 846,'with_comments' => 42},'releases' => 3,'requires' => ['YAML-0.35.tar.gz'],'requires_module' => {'YAML' => '0.35'},'requires_recursive' => ['YAML-0.35.tar.gz'],'size' => {'packed' => 14964,'unpacked' => 48068},'testers' => {'pass' => 5},'uses' => ['5.005','File::Path','VCS::SaVeS::Config','YAML','strict']},'VCS-StarTeam-0.08.zip' => {'author' => 'JOEPHAYES','description' => 'Provides an interface to StarBase\'s StarTeam','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 304,'pod' => 263,'pod_errors' => 0,'total' => 567,'with_comments' => 53},'releases' => 1,'size' => {'packed' => 7834,'unpacked' => 23890},'testers' => {},'uses' => ['5.005_62','Carp','Exporter','strict','warnings']},'VCS-Vss-0.20.tar.gz' => {'author' => 'JTILLMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 274,'pod' => 37,'pod_errors' => 0,'total' => 311,'with_comments' => 15},'releases' => 2,'requires' => ['VCS-0.10.tar.gz','Win32-OLE-0.1403.tar.gz'],'requires_module' => {'VCS' => 0,'Win32::OLE' => 0},'requires_recursive' => ['URI-1.24.tar.gz','VCS-0.10.tar.gz','Win32-OLE-0.1403.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4922,'unpacked' => 12943},'testers' => {},'uses' => ['Carp','File::Basename','Win32::OLE','Win32::OLE::Enum','strict','vars']},'VCS_PVCS-0.02.tar.gz' => {'author' => 'BMIDD','description' => 'Global configuration class for for VCS::PVCS::*.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2489,'pod' => 1077,'pod_errors' => 11,'total' => 3566,'with_comments' => 339},'releases' => 2,'size' => {'packed' => 27239,'unpacked' => 119669},'testers' => {'fail' => 6,'tests' => '10'},'uses' => ['5.003','Carp','Cwd','Exporter','Getopt::Long','strict','vars']},'VFS-Gnome-0.04.tar.gz' => {'author' => 'PIERS','description' => 'Gnome Virtual Filesystem for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 308,'pod' => 131,'pod_errors' => 0,'total' => 439,'with_comments' => 25},'releases' => 1,'size' => {'packed' => 8144,'unpacked' => 29688},'testers' => {},'uses' => ['5.006','Carp','Data::Dumper','DynaLoader','Exporter','strict','vars']},'VMS-FindFile-0.91.tar.gz' => {'author' => 'FORREST','description' => 'Perl extension to return all the file names matching a VMS wildcard file specification.','files' => [],'lines' => {'nonpod' => 59,'pod' => 29,'pod_errors' => 0,'total' => 88,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 8404,'unpacked' => 21664},'testers' => {},'uses' => ['5.004','DynaLoader','strict','vars']},'VMS-FlatFile-0.01.zip' => {'author' => 'PFAUT','description' => 'read and write hashes with VMS::IndexedFile.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 87,'pod' => 160,'pod_errors' => 0,'total' => 247,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 3931,'unpacked' => 7130},'testers' => {},'uses' => ['Data::FixedFormat','strict','vars']},'VMS-IndexedFile-0_02.tar.gz' => {'author' => 'BHUGHES','description' => undef,'files' => [],'lines' => {'nonpod' => 43,'pod' => 0,'pod_errors' => 0,'total' => 43,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 10561,'unpacked' => 36426},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['AutoLoader','DynaLoader','Exporter']},'VMS-Lock-1.02.tar.gz' => {'author' => 'BHUGHES','description' => 'Object interface to $ENQ (VMS lock mgr)','files' => ['Makefile.PL'],'lines' => {'nonpod' => 267,'pod' => 10,'pod_errors' => 1,'total' => 277,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 5394,'unpacked' => 20673},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'VRML-1.04.tar.gz' => {'author' => 'HPALM','description' => 'Specification independent VRML methods (1.0, 2.0, 97)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 4496,'pod' => 1738,'pod_errors' => 1,'total' => 6234,'with_comments' => 322},'releases' => 8,'size' => {'packed' => 71530,'unpacked' => 287170},'testers' => {'pass' => 11},'uses' => ['5.000','Exporter','strict','vars']},'Validate-Net-0.4.tar.gz' => {'author' => 'ADAMK','description' => 'Format validation and more for Net:: related strings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 219,'pod' => 90,'pod_errors' => 0,'total' => 309,'with_comments' => 40},'releases' => 4,'requires' => ['Class-Default-0.2.tar.gz','Class-Inspector-1.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Default' => '0.2','Class::Inspector' => 0,'Test::More' => 0},'requires_recursive' => ['Class-Default-0.2.tar.gz','Class-ISA-0.32.tar.gz','Class-Inspector-1.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 12166,'unpacked' => 32482},'testers' => {'pass' => 1},'uses' => ['Class::Default','vars']},'Variable-Alias-0.01.tar.gz' => {'author' => 'BRENTDAX','description' => 'Make any variable an alias of another','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 130,'pod' => 101,'pod_errors' => 0,'total' => 231,'with_comments' => 2},'releases' => 1,'requires' => ['Switch-2.09.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Switch' => '2.09','Test::More' => '0.46'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Switch-2.09.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 3202,'unpacked' => 7606},'testers' => {'pass' => 3},'uses' => ['5.6.0','Carp','Exporter','Switch','Tie::Array','Tie::Hash','Tie::Scalar','strict','warnings']},'VcsTools-File-1.004.tar.gz' => {'author' => 'DDUMONT','description' => 'Perl class to manage a VCS file.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2933,'pod' => 1004,'pod_errors' => 0,'total' => 3937,'with_comments' => 141},'releases' => 4,'requires' => ['DB_File-1.806.tar.gz','File-chmod-0.31.tar.gz','Getopt-Long-2.33.tar.gz','MLDBM-2.01.tar.gz','Puppet-Body-1.018.tar.gz','Storable-2.07.tar.gz','String-ShellQuote-1.00.tar.gz','Time-Local-1.07.tar.gz','VcsTools-History-1.004.tar.gz'],'requires_module' => {'DB_File' => 0,'File::chmod' => '0.31','Getopt::Long' => 0,'MLDBM' => 0,'Puppet::Body' => '1.013','Storable' => 0,'String::ShellQuote' => 0,'Time::Local' => 0,'VcsTools::History' => '1.007','VcsTools::LogParser' => '1.003','VcsTools::Version' => '1.006'},'requires_recursive' => ['DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','File-chmod-0.31.tar.gz','Getopt-Long-2.33.tar.gz','MLDBM-2.01.tar.gz','PodParser-1.23.tar.gz','Puppet-Body-1.018.tar.gz','Puppet-LogBody-1.002.tar.gz','Storable-2.07.tar.gz','String-ShellQuote-1.00.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Local-1.07.tar.gz','VcsTools-History-1.004.tar.gz'],'size' => {'packed' => 24937,'unpacked' => 128062},'testers' => {'fail' => 3,'pass' => 2},'uses' => ['AutoLoader','Carp','Cwd','Exporter','File::Path','File::chmod','File::stat','FileHandle','IPC::Open3','Puppet::Body','Storable','String::ShellQuote','Sys::Hostname','VcsTools::History','strict','vars']},'VcsTools-History-1.004.tar.gz' => {'author' => 'DDUMONT','description' => 'Perl class to manage a VCS history.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1797,'pod' => 542,'pod_errors' => 0,'total' => 2339,'with_comments' => 213},'releases' => 4,'requires' => ['MLDBM-2.01.tar.gz','Puppet-Body-1.018.tar.gz','Time-Local-1.07.tar.gz'],'requires_module' => {'MLDBM' => 0,'Puppet::Body' => '1.015','Puppet::Storage' => '1.004','Time::Local' => 0},'requires_recursive' => ['DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','MLDBM-2.01.tar.gz','Puppet-Body-1.018.tar.gz','Puppet-LogBody-1.002.tar.gz','Time-Local-1.07.tar.gz'],'size' => {'packed' => 23466,'unpacked' => 92626},'testers' => {'fail' => 4,'pass' => 2,'tests' => '53'},'uses' => ['AutoLoader','Carp','Exporter','Puppet::Body','Puppet::Storage','Time::Local','VcsTools::HistSqlStorage','VcsTools::VerSqlStorage','strict','vars']},'VelocisSQL-1.3.tar.gz' => {'author' => 'VKHERA','description' => 'Perl interface to the Raima Velocis SQL database engine','files' => [],'lines' => {'nonpod' => 102,'pod' => 63,'pod_errors' => 0,'total' => 165,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 5560,'unpacked' => 14362},'testers' => {},'uses' => ['5.003','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Verilog-CodeGen-0.9.4.tar.gz' => {'author' => 'WVDB','description' => 'Object-oriented Verilog code generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 742,'pod' => 341,'pod_errors' => 0,'total' => 1083,'with_comments' => 116},'releases' => 4,'size' => {'packed' => 18817,'unpacked' => 69142},'testers' => {'pass' => 2},'uses' => ['Cwd','DeviceLibs::DesignName','lib','sigtrap','strict','vars']},'Verilog-Perl-2.224.tar.gz' => {'author' => 'WSNYDER','description' => 'Signal and module extraction','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3384,'pod' => 1345,'pod_errors' => 1,'total' => 4729,'with_comments' => 743},'releases' => 26,'size' => {'packed' => 68628,'unpacked' => 267344},'testers' => {'pass' => 1},'uses' => ['5.000','Carp','Class::Struct','Cwd','Data::Dumper','DynaLoader','English','Exporter','File::Basename','File::Spec','FileHandle','IO::File','strict','vars']},'Verilog-Pli-1.6.tar.gz' => {'author' => 'WSNYDER','description' => 'Access to simulator functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 214,'pod' => 139,'pod_errors' => 0,'total' => 353,'with_comments' => 89},'releases' => 6,'size' => {'packed' => 19354,'unpacked' => 57311},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','ExtUtils::MakeMaker','strict','vars']},'Verity-Collection-0.02.tar.gz' => {'author' => 'SRL','description' => 'interface to a local Verity collection.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 162,'pod' => 55,'pod_errors' => 0,'total' => 217,'with_comments' => 15},'releases' => 2,'size' => {'packed' => 12133,'unpacked' => 33015},'testers' => {},'uses' => ['Carp']},'Video-Capture-V4l-0.222.tar.gz' => {'author' => 'MLEHMANN','description' => 'Video4linux framegrabber + vbe interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1278,'pod' => 302,'pod_errors' => 0,'total' => 1580,'with_comments' => 20},'releases' => 6,'size' => {'packed' => 81482,'unpacked' => 281716},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','Fcntl','strict','vars']},'Video-DVDRip-0.50.13.tar.gz' => {'author' => 'JRED','description' => 'GUI for copying DVDs, based on an open Low Level API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 31189,'pod' => 137,'pod_errors' => 0,'total' => 31326,'with_comments' => 1686},'releases' => 42,'requires' => ['Gtk-Perl-0.7009.tar.gz'],'requires_module' => {'Gtk' => '0.7008','Gtk::Gdk::Pixbuf' => 0},'requires_recursive' => ['Gtk-Perl-0.7009.tar.gz','XML-Parser-2.31.tar.gz','XML-Writer-0.4.tar.gz'],'size' => {'packed' => 225065,'unpacked' => 955256},'testers' => {},'uses' => ['','5.005','5.006','Carp','Cwd','Data::Dumper','Event','Exporter','Fcntl','File::Basename','File::Copy','File::Path','FileHandle','Gtk','Gtk::Gdk::Pixbuf','Gtk::Keysyms','IO::Pipe','IO::Socket','POSIX','Socket','Storable','Symbol','Text::Wrap','Time::Local','Video::DVDRip::GUI::CheckedEntry','Video::DVDRip::GUI::Project::BurnTab','Video::DVDRip::GUI::Project::ClipZoomTab','Video::DVDRip::GUI::Project::LoggingTab','Video::DVDRip::GUI::Project::StorageTab','Video::DVDRip::GUI::Project::SubtitleTab','Video::DVDRip::GUI::Project::TitleTab','Video::DVDRip::GUI::Project::TranscodeTab','Video::DVDRip::GUI::Project::TranscodeTabAudio','strict','vars']},'Video-Info-0.993.tar.gz' => {'author' => 'ALLENDAY','description' => 'Retrieve video properties such as: height width codec fps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3066,'pod' => 697,'pod_errors' => 2,'total' => 3763,'with_comments' => 835},'releases' => 8,'requires' => ['Class-MakeMethods-1.006.tar.gz','MP3-Info-1.02.tar.gz','Video-OpenQuicktime-1.02.tar.gz'],'requires_module' => {'Class::MakeMethods::Emulator' => 1,'MP3::Info' => 1,'Video::OpenQuicktime' => 1},'requires_recursive' => ['Class-MakeMethods-1.006.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','MP3-Info-1.02.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Video-OpenQuicktime-1.02.tar.gz'],'size' => {'packed' => 634560,'unpacked' => 1054861},'testers' => {},'uses' => ['5.006','Exporter','IO::File','Video::OpenQuicktime','constant','strict','warnings']},'Video-Info-Quicktime_PL-0.05.tar.gz' => {'author' => 'SHOGE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 338,'pod' => 46,'pod_errors' => 0,'total' => 384,'with_comments' => 43},'releases' => 2,'requires' => ['Class-MakeMethods-1.006.tar.gz','Compress-Zlib-1.22.tar.gz','Digest-MD5-2.26.tar.gz','Video-Info-0.993.tar.gz'],'requires_module' => {'Class::MakeMethods::Emulator' => 1,'Compress::Zlib' => 0,'Digest::MD5' => 0,'Video::Info' => '0.991'},'requires_recursive' => ['Class-MakeMethods-1.006.tar.gz','Compress-Zlib-1.22.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','MP3-Info-1.02.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Video-Info-0.993.tar.gz','Video-OpenQuicktime-1.02.tar.gz'],'size' => {'packed' => 237872,'unpacked' => 546250},'testers' => {},'uses' => ['Compress::Zlib','Video::Info','constant','strict']},'Video-Manip-0.02.tar.gz' => {'author' => 'HVC','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1116,'pod' => 10,'pod_errors' => 1,'total' => 1126,'with_comments' => 68},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz','Math-Round-0.05.tar.gz','TermReadKey-2.21.tar.gz','Time-HiRes-1.49.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'Data::Dumper' => '0','Math::Round' => '0','Term::ReadKey' => '0','Time::HiRes' => '0','XML::Simple' => '0'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Math-Round-0.05.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','XML-Simple-2.08.tar.gz'],'size' => {'packed' => 16089,'unpacked' => 55447},'testers' => {'fail' => 1,'tests' => '3'},'uses' => ['Data::Dumper','Event','Exporter','Math::Round','Term::ReadKey','Time::HiRes','XML::Simple','strict','vars']},'Video-Manip-0.03.tar.gz' => {'author' => 'HVC','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1112,'pod' => 10,'pod_errors' => 1,'total' => 1122,'with_comments' => 68},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz','Math-Round-0.05.tar.gz','TermReadKey-2.21.tar.gz','Time-HiRes-1.49.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'Data::Dumper' => '0','Math::Round' => '0','Term::ReadKey' => '0','Time::HiRes' => '0','XML::Simple' => '0'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Math-Round-0.05.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz','XML-Simple-2.08.tar.gz'],'size' => {'packed' => 10292,'unpacked' => 37353},'testers' => {'pass' => 2},'uses' => ['Data::Dumper','Exporter','Math::Round','Term::ReadKey','Time::HiRes','XML::Simple','strict','vars']},'Video-OpenQuicktime-1.02.tar.gz' => {'author' => 'ALLENDAY','description' => 'An interface to the OpenQuicktime library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 452,'pod' => 61,'pod_errors' => 0,'total' => 513,'with_comments' => 18},'releases' => 3,'requires' => ['Inline-0.44.tar.gz'],'requires_module' => {'Inline::C' => '0.01'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 99819,'unpacked' => 373164},'testers' => {},'uses' => ['Inline']},'VoiceXML-Server-1.6.tar.gz' => {'author' => 'TERRY','description' => '- An easy-to-use VoiceXML server class','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 564,'pod' => 175,'pod_errors' => 0,'total' => 739,'with_comments' => 18},'releases' => 2,'size' => {'packed' => 7802,'unpacked' => 20993},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['HTTP::Daemon','HTTP::Status','LWP::UserAgent','POSIX','diagnostics','strict']},'W3C-LogValidator-0.1.tar.gz' => {'author' => 'OLIVIERT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1356,'pod' => 163,'pod_errors' => 0,'total' => 1519,'with_comments' => 229},'releases' => 3,'requires' => ['Config-General-2.21.tar.gz','DB_File-1.806.tar.gz','File-Temp-0.12.tar.gz','Mail-Sendmail-0.79.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Config::General' => 0,'DB_File' => 0,'Exporter' => 0,'File::Temp' => 0,'LWP::UserAgent' => 0,'Mail::Sendmail' => 0,'Sys::Hostname' => 0,'URI::Escape' => 0},'requires_recursive' => ['Config-General-2.21.tar.gz','DB_File-1.806.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Mail-Sendmail-0.79.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13790,'unpacked' => 48647},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Config::General','DB_File','Exporter','File::Temp','LWP::UserAgent','Mail::Sendmail','Sys::Hostname','URI::Escape','W3C::LogValidator::Config','strict','warnings']},'W3C-LogValidator-0.2.tar.gz' => {'author' => 'OLIVIERT','description' => 'Main module for LogValidator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1415,'pod' => 161,'pod_errors' => 0,'total' => 1576,'with_comments' => 238},'releases' => 3,'requires' => ['Config-General-2.21.tar.gz','DB_File-1.806.tar.gz','File-Temp-0.12.tar.gz','Mail-Sendmail-0.79.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Config::General' => 0,'DB_File' => 0,'Exporter' => 0,'File::Temp' => 0,'LWP::UserAgent' => 0,'Mail::Sendmail' => 0,'Sys::Hostname' => 0,'URI::Escape' => 0},'requires_recursive' => ['Config-General-2.21.tar.gz','DB_File-1.806.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Mail-Sendmail-0.79.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14636,'unpacked' => 50717},'testers' => {'pass' => 2},'uses' => ['Config::General','DB_File','Exporter','File::Temp','LWP::UserAgent','Mail::Sendmail','Sys::Hostname','URI::Escape','strict','warnings']},'WAIT-1.800.tar.gz' => {'author' => 'ULPFR','description' => 'a rewrite of the freeWAIS-sf engine in Perl and XS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6081,'pod' => 428,'pod_errors' => 1,'total' => 6509,'with_comments' => 732},'releases' => 3,'requires' => ['DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','HTML-Parser-3.28.tar.gz','LockFile-Simple-0.2.5.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'requires_module' => {'DB_File' => '1.03','Data::Dumper' => '2.02','HTML::Entities' => 0,'LockFile::Simple' => 0,'Pod::Text' => '1.02','Term::ReadLine' => 0},'requires_recursive' => ['DB_File-1.806.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','LockFile-Simple-0.2.5.tar.gz','PodParser-1.23.tar.gz','perl-5.8.0.tar.gz','podlators-1.27.tar.gz'],'size' => {'packed' => 97889,'unpacked' => 359109},'testers' => {'fail' => 2,'pass' => 4,'tests' => '218'},'uses' => ['$path','Carp','DB_File','DynaLoader','Exporter','Fcntl','File::Basename','File::Path','FileHandle','HTML::Entities','HTML::FormatText','HTML::Parse','IO::Select','IO::Socket','Net::Cmd','Pod::PText','Pod::Parser','Pod::Text','Socket','Sys::Hostname','Term::Cap','Term::Info','Text::Abbrev','Text::German','Text::Tabs','Tie::Hash','Time::ParseDate','WAIT::Config','autouse','diagnostics','sigtrap','strict','subs','vars']},'WAP-SAXDriver-wbxml-2.03.tar.gz' => {'author' => 'PERRAD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 803,'pod' => 214,'pod_errors' => 0,'total' => 1017,'with_comments' => 25},'releases' => 7,'requires' => ['I18N-Charset-1.24.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'I18N::Charset' => '1.15','IO::File' => 0,'IO::String' => 0,'XML::SAX::Base' => '1.00','XML::SAX::Writer' => '0.44'},'requires_recursive' => ['App-Info-0.23.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','I18N-Charset-1.24.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 16125,'unpacked' => 82931},'testers' => {'pass' => 1},'uses' => ['I18N::Charset','IO::File','IO::String','XML::SAX::Base','constant','integer','strict','vars']},'WAP-wmls-1.01.tar.gz' => {'author' => 'PERRAD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10652,'pod' => 0,'pod_errors' => 0,'total' => 10652,'with_comments' => 904},'releases' => 2,'requires' => ['I18N-Charset-1.24.tar.gz','Unicode-Map-0.112.tar.gz','Unicode-String-2.07.tar.gz'],'requires_module' => {'I18N::Charset' => '1.15','Unicode::Map' => 0,'Unicode::String' => 0},'requires_recursive' => ['App-Info-0.23.tar.gz','File-Spec-0.82.tar.gz','I18N-Charset-1.24.tar.gz','IO-String-1.02.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Unicode-Map-0.112.tar.gz','Unicode-String-2.07.tar.gz'],'size' => {'packed' => 40609,'unpacked' => 277961},'testers' => {'fail' => 2,'pass' => 3},'uses' => ['5.004','Carp','I18N::Charset','Math::BigFloat','Math::BigInt','UNIVERSAL','Unicode::String','WAP::wmls::lexer','WAP::wmls::node','WAP::wmls::print','constant','strict','vars']},'WDDX-1.01.tar.gz' => {'author' => 'GUELICH','description' => 'a module for reading and writing WDDX packets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2999,'pod' => 609,'pod_errors' => 0,'total' => 3608,'with_comments' => 299},'releases' => 5,'requires' => ['MIME-Base64-2.20.tar.gz','XML-Parser-2.31.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'MIME::Base64' => 0,'XML::Parser' => 2},'requires_recursive' => ['MIME-Base64-2.20.tar.gz','XML-Parser-2.31.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 26464,'unpacked' => 108712},'testers' => {'fail' => 1,'pass' => 9},'uses' => ['Carp','MIME::Base64','Time::Local','XML::Parser','strict']},'WML-Card-0.02.tar.gz' => {'author' => 'MALVARO','description' => 'WML Deck generator','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 541,'pod' => 108,'pod_errors' => 0,'total' => 649,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 4963,'unpacked' => 15803},'testers' => {'pass' => 10},'uses' => ['Data::Dumper','HTML::Entities','strict','vars']},'WSDL-Generator-0.02.tar.gz' => {'author' => 'PDENIS','description' => 'Generate wsdl file automagically','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 677,'pod' => 300,'pod_errors' => 0,'total' => 977,'with_comments' => 27},'releases' => 2,'requires' => ['Class-Hook-0.01.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Hook' => '0.01','Test::Simple' => '0.01'},'requires_recursive' => ['Class-Hook-0.01.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 9816,'unpacked' => 41005},'testers' => {'pass' => 1},'uses' => ['5.6.0','Carp','Class::Hook','strict','warnings::register']},'WWW-AdManager-0.007.tar.gz' => {'author' => 'AWRIGLEY','description' => 'a perl module to administer and serve online advertising','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1770,'pod' => 195,'pod_errors' => 0,'total' => 1965,'with_comments' => 387},'releases' => 4,'requires' => ['CGI_Lite-1.8.tar.gz','Data-Dumper-2.101.tar.gz','HTML-Parser-3.28.tar.gz','IO-1.20.tar.gz','Image-Size-2.992.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Apache::Constants' => undef,'CGI_Lite' => undef,'Data::Dumper' => undef,'Fcntl' => undef,'File::Path' => undef,'HTML::Entities' => undef,'IO::Dir' => undef,'IO::File' => undef,'Image::Size' => undef,'LWP::Simple' => undef,'URI' => undef},'requires_recursive' => ['CGI_Lite-1.8.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','Image-Size-2.992.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','mod_perl-1.28.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13842,'unpacked' => 59442},'testers' => {'pass' => 1},'uses' => ['Apache::Constants','CGI_Lite','Data::Dumper','Fcntl','File::Path','HTML::Entities','IO::Dir','IO::File','Image::Size','LWP::Simple','TempDir','URI','strict','vars','warnings']},'WWW-AdServer-0.01.tar.gz' => {'author' => 'NWETTERS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1363,'pod' => 464,'pod_errors' => 0,'total' => 1827,'with_comments' => 85},'releases' => 1,'size' => {'packed' => 14789,'unpacked' => 57949},'testers' => {'pass' => 4},'uses' => ['Apache','Apache::Constants','CGI::Cookie','Carp','Exporter','Fcntl','HTTP::Status','constant','strict','vars']},'WWW-Amazon-Wishlist-0.9.tar.gz' => {'author' => 'SIMONW','description' => 'grab all the details from your Amazon wishlist','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 352,'pod' => 92,'pod_errors' => 0,'total' => 444,'with_comments' => 67},'releases' => 9,'requires' => ['Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Getopt::Long' => 0,'HTML::TokeParser' => 0,'LWP' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8129,'unpacked' => 22249},'testers' => {'pass' => 11},'uses' => ['AutoLoader','Carp','Exporter','HTML::TokeParser','LWP::UserAgent','constant','strict','vars']},'WWW-Authenticate-0.6-1.tar.gz' => {'author' => 'BARNINGER','description' => 'Perl extension for authenticating users','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 245,'pod' => 39,'pod_errors' => 0,'total' => 284,'with_comments' => 61},'releases' => 1,'size' => {'packed' => 11879,'unpacked' => 34126},'testers' => {'pass' => 3},'uses' => ['CGI','CGI::Cookie','DBI','Exporter','strict','vars']},'WWW-Automate-0.20.tar.gz' => {'author' => 'SKUD','description' => 'automate interaction with websites','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 323,'pod' => 115,'pod_errors' => 0,'total' => 438,'with_comments' => 15},'releases' => 2,'requires' => ['Clone-0.13.tar.gz','HTML-Parser-3.28.tar.gz','Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Clone' => '0.13','HTML::Form' => '0.03','HTML::TokeParser' => '2.2','HTTP::Request' => '1.2','LWP::UserAgent' => '1.8','Test::More' => '0.34'},'requires_recursive' => ['Clone-0.13.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5240,'unpacked' => 15148},'testers' => {'fail' => 6,'pass' => 1,'tests' => '19'},'uses' => ['Carp','Clone','HTML::Form','HTML::TokeParser','HTTP::Request','LWP::UserAgent']},'WWW-BBSWatch-1.01.tar.gz' => {'author' => 'TAYERS','description' => 'email WWW bulletin board postings','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 223,'pod' => 268,'pod_errors' => 2,'total' => 491,'with_comments' => 7},'releases' => 4,'requires' => ['MIME-Lite-3.01.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::UserAgent' => 0,'MIME::Lite' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6464,'unpacked' => 16533},'testers' => {'pass' => 10},'uses' => ['Fcntl','SDBM_File','constant','strict','vars']},'WWW-B_Rail-0.01.tar.gz' => {'author' => 'BEATNIK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1082,'pod' => 128,'pod_errors' => 0,'total' => 1210,'with_comments' => 0},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::TokeParser' => '2.24','LWP::Simple' => '1.35'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 18936,'unpacked' => 51108},'testers' => {'pass' => 1,'tests' => '0','unknown' => 3},'uses' => ['5.006','Exporter','HTML::TokeParser','LWP::Simple','strict','vars']},'WWW-Babelfish-0.11.tar.gz' => {'author' => 'DURIST','description' => 'Perl extension for translation via babelfish','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 307,'pod' => 70,'pod_errors' => 0,'total' => 377,'with_comments' => 72},'releases' => 11,'requires' => ['HTML-Parser-3.28.tar.gz','IO-String-1.02.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::TokeParser' => 0,'HTTP::Request' => 0,'IO::String' => 0,'LWP::UserAgent' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7049,'unpacked' => 16174},'testers' => {'fail' => 1},'uses' => ['AutoLoader','Exporter','HTML::TokeParser','HTTP::Request::Common','IO::String','LWP::UserAgent','strict','vars']},'WWW-Baseball-NPB-0.03.tar.gz' => {'author' => 'MIYAGAWA','description' => 'Fetches Japanese baseball games information','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 70,'pod_errors' => 0,'total' => 190,'with_comments' => 0},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::Simple' => 0,'Test::More' => '0.32'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9476,'unpacked' => 75666},'testers' => {'pass' => 4},'uses' => ['Carp','LWP::Simple','strict','vars']},'WWW-Blog-Identify-0.03.tar.gz' => {'author' => 'MCEGLOWS','description' => 'Heuristics to identify weblogs from raw HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 164,'pod' => 45,'pod_errors' => 0,'total' => 209,'with_comments' => 24},'releases' => 3,'size' => {'packed' => 4647,'unpacked' => 10290},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','warnings']},'WWW-BookBot-0.12.tar.gz' => {'author' => 'QJZHOU','description' => 'Bot to fetch web e-texts with catalog, books and chapters.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3299,'pod' => 504,'pod_errors' => 0,'total' => 3803,'with_comments' => 451},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz','Encode-1.97.tar.gz','Getopt-Long-2.33.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 'POSIX','Encode' => 'File::Basename','Fcntl' => 'LWP::UserAgent','File::Spec::Functions' => 'File::Path','Getopt::Long' => undef,'HTTP::Cookies' => 'HTTP::Date','HTTP::Request::Common' => 'HTTP::Response','URI' => 'Carp'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','Encode-1.97.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 33607,'unpacked' => 125197},'testers' => {'pass' => 2},'uses' => ['5.008','Carp','Data::Dumper','Encode','Exporter','Fcntl','File::Basename','File::Path','File::Spec::Functions','HTTP::Cookies','HTTP::Date','HTTP::Request::Common','HTTP::Response','LWP::UserAgent','POSIX','Test::More','URI','strict','vars','warnings']},'WWW-Bookmark-Crawler-0.01.tar.gz' => {'author' => 'XERN','description' => 'Personal bookmark search engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 190,'pod' => 91,'pod_errors' => 0,'total' => 281,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 5933,'unpacked' => 12871},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.006','Carp','HTML::LinkExtor','HTML::Parser','HTTP::Request::Common','LWP::UserAgent','OurNet::FuzzyIndex','Set::Scalar','strict','warnings']},'WWW-Bugzilla-0.1.tar.gz' => {'author' => 'MCVELLA','description' => 'Handles submission/update of bugzilla bugs via WWW::Mechanize.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 335,'pod' => 210,'pod_errors' => 0,'total' => 545,'with_comments' => 0},'releases' => 1,'requires' => ['Class-MethodMaker-1.10.tar.gz','File-Spec-0.82.tar.gz','WWW-Mechanize-0.56.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Class::MethodMaker' => '1.08','File::Spec' => '0.82','WWW::Mechanize' => '0.4'},'requires_recursive' => ['Class-MethodMaker-1.10.tar.gz','File-Spec-0.82.tar.gz','WWW-Mechanize-0.56.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14829,'unpacked' => 45894},'testers' => {'pass' => 2},'uses' => ['Carp','File::Spec::Functions','WWW::Mechanize','constant','strict','warnings']},'WWW-Cache-Google-0.04.tar.gz' => {'author' => 'MIYAGAWA','description' => 'URI class for Google cache','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 97,'pod' => 100,'pod_errors' => 0,'total' => 197,'with_comments' => 1},'releases' => 4,'requires' => ['URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::Simple' => 0,'URI' => 0,'URI::Escape' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2732,'unpacked' => 7398},'testers' => {'pass' => 8},'uses' => ['LWP::Simple','URI','URI::Escape','strict','vars']},'WWW-ContentRetrieval-0.092.tar.gz' => {'author' => 'XERN','description' => 'WWW robot plus text analyzer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 675,'pod' => 367,'pod_errors' => 0,'total' => 1042,'with_comments' => 52},'releases' => 15,'requires' => ['Clone-0.13.tar.gz','Digest-MD5-2.26.tar.gz','File-Slurp-2002.1031.tar.gz','IO-stringy-2.108.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Clone' => '0.13','Digest::MD5' => '2.02','File::Slurp' => '2002','IO::Scalar' => '2.104','LWP' => '5.69','URI' => '1.22'},'requires_recursive' => ['Clone-0.13.tar.gz','Digest-MD5-2.26.tar.gz','File-Slurp-2002.1031.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10657,'unpacked' => 32676},'testers' => {'fail' => 4,'pass' => 1,'tests' => '6'},'uses' => ['5.006','Clone','Data::Dumper','Digest::MD5','Exporter','File::Slurp','HTTP::Request::Common','IO::Scalar','LWP::UserAgent','POSIX','URI','strict']},'WWW-Curl-2.0.tar.gz' => {'author' => 'CRISB','description' => 'Perl extension interface for libcurl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 87,'pod' => 74,'pod_errors' => 2,'total' => 161,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 22546,'unpacked' => 101411},'testers' => {'fail' => 1,'tests' => '134'},'uses' => ['AutoLoader','DynaLoader','Exporter','WWW::Curl::easy','strict','vars']},'WWW-Extractor-0.3.tar.gz' => {'author' => 'GNALABS','description' => 'Semi-automated record extraction from WWW','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 549,'pod' => 105,'pod_errors' => 1,'total' => 654,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 5903,'unpacked' => 16782},'testers' => {'tests' => '0','unknown' => 4},'uses' => ['Data::Dumper','English','PDL::Lite','integer','strict']},'WWW-Form-1.09.tar.gz' => {'author' => 'BSCHMAU','description' => 'Simple, extendable OO module for HTML form validation and display','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 979,'pod' => 727,'pod_errors' => 0,'total' => 1706,'with_comments' => 154},'releases' => 10,'size' => {'packed' => 15646,'unpacked' => 56804},'testers' => {'pass' => 2},'uses' => ['Data::Dumper','constant','strict','warnings']},'WWW-Gazetteer-0.22.tar.gz' => {'author' => 'LBROCARD','description' => 'Find location of world towns and cities','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 47,'pod' => 65,'pod_errors' => 0,'total' => 112,'with_comments' => 0},'releases' => 5,'requires' => ['Class-Factory-1.00.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::Factory' => '0.01','Test::Simple' => '0.01'},'requires_recursive' => ['Class-Factory-1.00.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2428,'unpacked' => 7091},'testers' => {'pass' => 3},'uses' => ['Class::Factory','strict','vars']},'WWW-Gazetteer-Calle-0.13.tar.gz' => {'author' => 'LBROCARD','description' => 'Find location of world towns and cities','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 571,'pod' => 71,'pod_errors' => 0,'total' => 642,'with_comments' => 25},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','WWW-Gazetteer-0.22.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::UserAgent' => '0.01','Test::Simple' => '0.01','WWW::Gazetteer' => '0.20'},'requires_recursive' => ['Class-Factory-1.00.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','WWW-Gazetteer-0.22.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7555,'unpacked' => 27327},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['Carp','HTTP::Cookies','LWP::UserAgent','strict','vars']},'WWW-Gazetteer-Getty-0.10.tar.gz' => {'author' => 'LBROCARD','description' => 'Find location of world towns and cities','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 391,'pod' => 69,'pod_errors' => 0,'total' => 460,'with_comments' => 2},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz','WWW-Gazetteer-0.22.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::UserAgent' => '0.01','Test::Simple' => '0.01','WWW::Gazetteer' => '0.20'},'requires_recursive' => ['Class-Factory-1.00.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','WWW-Gazetteer-0.22.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6431,'unpacked' => 20172},'testers' => {'pass' => 3},'uses' => ['Carp','HTTP::Cookies','LWP::UserAgent','strict','vars']},'WWW-Gazetteer-HeavensAbove-0.09.tar.gz' => {'author' => 'BOOK','description' => 'Find location of world towns and cities','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 504,'pod' => 185,'pod_errors' => 0,'total' => 689,'with_comments' => 222},'releases' => 9,'requires' => ['HTML-Tree-3.17.tar.gz','Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::Form' => 0,'HTML::TreeBuilder' => 3,'LWP::UserAgent' => 2,'Test::More' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11688,'unpacked' => 31110},'testers' => {'fail' => 1,'pass' => 8,'tests' => '56'},'uses' => ['Carp','HTML::Form','HTML::TreeBuilder','LWP::UserAgent','strict','vars']},'WWW-Google-News-0.04.tar.gz' => {'author' => 'GMCCAR','description' => 'Access to Google\'s News Service (Not Usenet)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 63,'pod_errors' => 0,'total' => 141,'with_comments' => 5},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3199,'unpacked' => 7474},'testers' => {'fail' => 1,'pass' => 4,'tests' => '13'},'uses' => ['Carp','Data::Dumper','Exporter','LWP','strict','warnings']},'WWW-Hotmail-0.01.tar.gz' => {'author' => 'SIMON','description' => 'Connect to Hotmail and download messages','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 91,'pod' => 40,'pod_errors' => 0,'total' => 131,'with_comments' => 1},'releases' => 1,'requires' => ['Crypt-SSLeay-0.51.tar.gz','Mail-Audit-2.1.tar.gz','WWW-Mechanize-0.56.tar.gz'],'requires_module' => {'Crypt::SSLeay' => 0,'Mail::Audit' => '2.1','WWW::Mechanize' => 0},'requires_recursive' => ['Crypt-SSLeay-0.51.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','MIME-tools-5.411a.tar.gz','Mail-Audit-2.1.tar.gz','MailTools-1.58.tar.gz','WWW-Mechanize-0.56.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3349,'unpacked' => 7204},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','Mail::Audit','WWW::Mechanize','strict','warnings']},'WWW-LEO-0.01.tar.gz' => {'author' => 'ZIEFLE','description' => 'Perl interface to the English-German online dictionary at L<http://dict.leo.org>','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 254,'pod' => 159,'pod_errors' => 0,'total' => 413,'with_comments' => 19},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::TokeParser' => 0,'LWP::UserAgent' => 0,'URI::Escape' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6143,'unpacked' => 16241},'testers' => {'pass' => 3},'uses' => ['5.008','Carp','Exporter','HTML::TokeParser','LWP::UserAgent','URI::Escape','strict','warnings']},'WWW-Link-0.036.tar.gz' => {'author' => 'MIKEDLR','description' => 'maintain information about the state of links','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4204,'pod' => 1218,'pod_errors' => 1,'total' => 5422,'with_comments' => 540},'releases' => 6,'requires' => ['CDB_File-BiIndex-0.030.tar.gz','HTML-Stream-1.54.tar.gz','MLDBM-2.01.tar.gz','Net-Telnet-3.03.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'CDB_File::BiIndex' => '0.026','English' => 0,'Exporter' => 0,'HTML::Stream' => 0,'HTTP::Cookies' => 0,'HTTP::Headers' => 0,'HTTP::Message' => 0,'HTTP::Request' => 0,'HTTP::Response' => 0,'HTTP::Status' => 0,'LWP::UserAgent' => 0,'MLDBM' => 0,'Net::Telnet' => 0,'URI' => 0},'requires_recursive' => ['CDB_File-0.93.tar.gz','CDB_File-BiIndex-0.030.tar.gz','CDB_File-Generator-0.030.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Stream-1.54.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MLDBM-2.01.tar.gz','Net-Telnet-3.03.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 61005,'unpacked' => 204568},'testers' => {'fail' => 1,'pass' => 2,'tests' => '227'},'uses' => ['CGI::Form','Carp','Data::Dumper','English','Exporter','File::Copy','HTML::Stream','HTTP::Cookies','HTTP::Headers','HTTP::Message','HTTP::Request','HTTP::Response','HTTP::Status','LWP::Debug','LWP::UserAgent','Net::Telnet','URI','strict','vars','warnings']},'WWW-MSA-Hadith-1.01.tar.gz' => {'author' => 'SHERZODR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 229,'pod' => 79,'pod_errors' => 0,'total' => 308,'with_comments' => 3},'releases' => 2,'requires' => ['HTML-Tree-3.17.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::TreeBuilder' => 0,'LWP::UserAgent' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3919,'unpacked' => 10242},'testers' => {'pass' => 2},'uses' => ['Carp','HTML::TokeParser','HTML::TreeBuilder','LWP::UserAgent','strict','vars']},'WWW-MakeAShorterLink-1.03.tar.gz' => {'author' => 'DAVECROSS','description' => 'Perl interface to makeashorterlink.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 66,'pod' => 35,'pod_errors' => 0,'total' => 101,'with_comments' => 2},'releases' => 1,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2575,'unpacked' => 4866},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Exporter','LWP','strict','warnings']},'WWW-MapBlast-0.02.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 169,'pod' => 84,'pod_errors' => 1,'total' => 253,'with_comments' => 20},'releases' => 2,'requires' => ['HTML-Parser-3.28.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::TokeParser' => '0.1','HTTP::Request' => '0.1','LWP::UserAgent' => '0.1'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5681,'unpacked' => 11867},'testers' => {'pass' => 5},'uses' => ['HTML::TokeParser','HTTP::Request','LWP::UserAgent','strict','warnings']},'WWW-Mechanize-0.55.tar.gz' => {'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 901,'pod' => 788,'pod_errors' => 0,'total' => 1689,'with_comments' => 27},'releases' => 26,'requires' => ['HTML-Parser-3.28.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'FindBin' => 0,'HTML::Form' => 1,'HTML::HeadParser' => 0,'HTML::TokeParser' => '2.2','HTTP::Daemon' => 0,'HTTP::Request' => '1.3','HTTP::Status' => 0,'LWP' => '5.69','LWP::UserAgent' => '2.003','Test::Builder' => '0.17','Test::More' => '0.34','URI::URL' => 0,'URI::file' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'testers' => {'pass' => 2},'uses' => ['Carp','HTML::Form','HTML::HeadParser','HTML::TokeParser','HTTP::Request','LWP::UserAgent','URI::URL','strict','warnings']},'WWW-Mechanize-FormFiller-0.05.tar.gz' => {'author' => 'CORION','description' => 'framework to automate HTML forms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 784,'pod' => 741,'pod_errors' => 0,'total' => 1525,'with_comments' => 13},'releases' => 4,'requires' => ['Data-Random-0.05.tar.gz','Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Data::Random' => '0.05','HTML::Form' => undef,'Test::More' => undef},'requires_recursive' => ['Data-Random-0.05.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17179,'unpacked' => 118103},'testers' => {'pass' => 3},'uses' => ['Carp','Data::Random','POSIX','strict','vars']},'WWW-Mechanize-Shell-0.28.tar.gz' => {'author' => 'CORION','description' => 'An interactive shell for WWW::Mechanize','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1840,'pod' => 946,'pod_errors' => 1,'total' => 2786,'with_comments' => 78},'releases' => 21,'requires' => ['HTML-TokeParser-Simple-2.1.tar.gz','Hook-LexWrap-0.20.tar.gz','Term-Shell-0.01.tar.gz','URI-1.24.tar.gz','WWW-Mechanize-0.56.tar.gz','WWW-Mechanize-FormFiller-0.05.tar.gz'],'requires_module' => {'HTML::TokeParser::Simple' => 2,'Hook::LexWrap' => '0.2','Term::Shell' => '0.01','URI::URL' => 0,'WWW::Mechanize' => '0.46','WWW::Mechanize::FormFiller' => '0.05'},'requires_recursive' => ['Data-Random-0.05.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-TokeParser-Simple-2.1.tar.gz','Hook-LexWrap-0.20.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Term-Shell-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','WWW-Mechanize-0.56.tar.gz','WWW-Mechanize-FormFiller-0.05.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 48855,'unpacked' => 206662},'testers' => {'fail' => 1,'pass' => 2,'tests' => '726'},'uses' => ['','Carp','Exporter','File::Modified','File::Spec','File::Temp','FindBin','HTML::TableExtract','HTML::TokeParser','HTML::TokeParser::Simple','HTTP::Cookies','Hook::LexWrap','LWP::Simple','Pod::Constants','Term::Shell','URI::URL','WWW::Mechanize','WWW::Mechanize::FormFiller','WWW::Mechanize::FormFiller::Value::Callback','Win32::OLE','strict','vars']},'WWW-Meta-XML-Browser-0.04.tar.gz' => {'author' => 'BBOKSA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 568,'pod' => 268,'pod_errors' => 0,'total' => 836,'with_comments' => 21},'releases' => 2,'requires' => ['Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXSLT-1.53.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Cookies' => '0','HTTP::Request' => '0','LWP::UserAgent' => '0','Time::HiRes' => '0','URI::Escape' => '0','XML::LibXML' => '0','XML::LibXSLT' => undef},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Time-HiRes-1.49.tar.gz','URI-1.24.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8557,'unpacked' => 26590},'testers' => {'pass' => 1},'uses' => ['Exporter','HTTP::Cookies','HTTP::Request','LWP::UserAgent','Time::HiRes','URI::Escape','XML::LibXML','XML::LibXSLT','strict','warnings']},'WWW-NewsIsFree-0.01.tar.gz' => {'author' => 'XERN','description' => 'NewsIsFree Agent','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 93,'pod' => 55,'pod_errors' => 0,'total' => 148,'with_comments' => 1},'releases' => 1,'requires' => ['Digest-MD5-2.26.tar.gz','RPC-XML-0.53.tar.gz'],'requires_module' => {'Digest::MD5' => 0,'RPC::XML::Client' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','RPC-XML-0.53.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2358,'unpacked' => 4980},'testers' => {'pass' => 4},'uses' => ['5.006','Digest::MD5','RPC::XML::Client','strict','warnings']},'WWW-Page-Author-1.2.tar.gz' => {'author' => 'SPOON','description' => 'locates the author of a web page','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 51,'pod_errors' => 0,'total' => 198,'with_comments' => 7},'releases' => 1,'requires' => ['Data-Dumper-2.101.tar.gz','DateManip-5.42a.tar.gz','Email-Find-0.09.tar.gz','Module-Info-0.20.tar.gz','Pod-Coverage-0.11.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => '2.102','Date::Manip' => '5.4','Email::Find' => '0.09','HTTP::Request::Common' => '1.19','LWP::UserAgent' => '2.001','Module::Info' => '0.12','Pod::Coverage' => '0.09','Test::More' => '0.41','URI::URL' => '5.02','constant' => '1.02'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','DateManip-5.42a.tar.gz','Devel-Symdump-2.03.tar.gz','Digest-MD5-2.26.tar.gz','Email-Find-0.09.tar.gz','Email-Valid-0.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MailTools-1.58.tar.gz','Module-Info-0.20.tar.gz','Pod-Coverage-0.11.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3631,'unpacked' => 8949},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Data::Dumper','Email::Find','HTTP::Request::Common','LWP::UserAgent','URI::URL','constant','strict','vars','warnings']},'WWW-Page-Modified-1.2.tar.gz' => {'author' => 'SPOON','description' => 'reports when a page was last modified','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 170,'pod' => 53,'pod_errors' => 0,'total' => 223,'with_comments' => 8},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz','DateManip-5.42a.tar.gz','Module-Info-0.20.tar.gz','Pod-Coverage-0.11.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Data::Dumper' => '2.102','Date::Manip' => '5.4','HTTP::Date' => '1.43','HTTP::Request::Common' => '1.19','LWP::UserAgent' => '2.001','Module::Info' => '0.12','Pod::Coverage' => '0.09','Test::More' => '0.41','URI::URL' => '5.02','constant' => '1.02'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','DateManip-5.42a.tar.gz','Devel-Symdump-2.03.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Module-Info-0.20.tar.gz','Pod-Coverage-0.11.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3874,'unpacked' => 9386},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Data::Dumper','Date::Manip','HTTP::Date','HTTP::Request::Common','LWP::UserAgent','URI::URL','constant','strict','vars','warnings']},'WWW-Poll-0.01.tar.gz' => {'author' => 'MGAMMON','description' => 'Perl extension to build web polls','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 410,'pod' => 98,'pod_errors' => 0,'total' => 508,'with_comments' => 74},'releases' => 1,'size' => {'packed' => 11489,'unpacked' => 29328},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['AutoLoader','Carp','Exporter','constant','strict','vars']},'WWW-Promotion-5.20.tar.gz' => {'author' => 'SNEMAROV','description' => 'WWW::Promotion is a Perl module that allow to submit your site to lot of search engines.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 475,'pod' => 330,'pod_errors' => 0,'total' => 805,'with_comments' => 2},'releases' => 2,'requires' => ['TAPORlib-8.70.tar.gz'],'requires_module' => {'TAPORlib' => '8.5'},'requires_recursive' => ['TAPORlib-8.70.tar.gz'],'size' => {'packed' => 9904,'unpacked' => 54389},'testers' => {'fail' => 1,'tests' => '0','unknown' => 3},'uses' => ['Exporter','TAPORlib','strict','vars']},'WWW-Robot-0.023.tar.gz' => {'author' => 'AWRIGLEY','description' => 'Web traversal engine for robots & agents','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1253,'pod' => 513,'pod_errors' => 0,'total' => 1766,'with_comments' => 217},'releases' => 4,'requires' => ['HTML-Parser-3.28.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::LinkExtor' => 0,'HTML::TreeBuilder' => 0,'HTTP::Request' => 0,'HTTP::Status' => 0,'IO::File' => 0,'LWP::RobotUA' => 0,'URI::URL' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17360,'unpacked' => 62705},'testers' => {'pass' => 2,'tests' => '0','unknown' => 12},'uses' => ['5.002','English','HTML::TreeBuilder','HTTP::Request','HTTP::Status','IO::File','LWP::RobotUA','URI::URL','strict','vars']},'WWW-SMS-0.09.tar.gz' => {'author' => 'EIM','description' => 'sends SMS using service provided by free websites','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 2286,'pod' => 185,'pod_errors' => 0,'total' => 2471,'with_comments' => 649},'releases' => 5,'size' => {'packed' => 21745,'unpacked' => 102837},'testers' => {'pass' => 1},'uses' => ['Carp','Date::Manip','Exporter','HTTP::Cookies','HTTP::Request','HTTP::Request::Common','LWP::UserAgent','Time::Local','Time::localtime','constant','strict','vars']},'WWW-Search-2.41.tar.gz' => {'author' => 'MTHURN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2189,'pod' => 818,'pod_errors' => 0,'total' => 3007,'with_comments' => 310},'releases' => 54,'requires' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tree-3.17.tar.gz','MIME-Lite-3.01.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Basename' => 0,'File::Find' => 0,'File::Spec' => 0,'Getopt::Long' => '2.24','HTML::Parser' => '2.23','HTML::TreeBuilder' => 0,'LWP::UserAgent' => 2,'MIME::Lite' => 0,'Net::Domain' => 0,'POSIX' => 0,'Test::Inline' => 0,'Test::More' => 0,'URI' => 0,'URI::Escape' => 0,'User' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 60321,'unpacked' => 209162},'testers' => {'pass' => 2},'uses' => ['Carp','Config','Cwd','Data::Dumper','Exporter','File::Find','File::Path','File::Spec::Functions','HTML::TreeBuilder','HTTP::Cookies','HTTP::Request','HTTP::Response','HTTP::Status','LWP::MemberMixin','LWP::RobotUA','LWP::UserAgent','Net::Domain','Socket','Test::More','URI','URI::Escape','User','WWW::SearchResult','constant','strict','vars']},'WWW-Search-AcronymFinder-0.01.tar.gz' => {'author' => 'XERN','description' => 'Perl interface to AcronymFinder.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 85,'pod' => 34,'pod_errors' => 0,'total' => 119,'with_comments' => 2},'releases' => 1,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2567,'unpacked' => 5239},'testers' => {'pass' => 4},'uses' => ['5.006','WWW::Search','WWW::SearchResult','strict','warnings']},'WWW-Search-AlltheWeb-1.5.tar.gz' => {'author' => 'JSMYSER','description' => 'Class for searching AlltheWeb','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 153,'pod' => 29,'pod_errors' => 0,'total' => 182,'with_comments' => 8},'releases' => 2,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3137,'unpacked' => 7550},'testers' => {'pass' => 9},'uses' => ['Exporter','WWW::Search','WWW::SearchResult']},'WWW-Search-AltaVista-2.09.tar.gz' => {'author' => 'MTHURN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1345,'pod' => 422,'pod_errors' => 0,'total' => 1767,'with_comments' => 270},'releases' => 9,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search::Test' => '2.11'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15190,'unpacked' => 63999},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','WWW::Search','WWW::Search::Result','WWW::SearchResult','strict','vars']},'WWW-Search-Backends-1.01.tar.gz' => {'author' => 'MTHURN','description' => 'class for searching SFgate/Wais search engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3083,'pod' => 751,'pod_errors' => 0,'total' => 3834,'with_comments' => 395},'releases' => 1,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 24421,'unpacked' => 108025},'testers' => {'pass' => 1,'tests' => '0','unknown' => 6},'uses' => ['Exporter','HTML::Parse','HTML::TreeBuilder','Socket','WWW::Search','WWW::SearchResult','strict','vars']},'WWW-Search-EBayGlobal-3.00.tar.gz' => {'author' => 'NINJA','description' => 'backend for searching www.ebay.co.uk and european eBay sites','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 813,'pod' => 432,'pod_errors' => 0,'total' => 1245,'with_comments' => 164},'releases' => 1,'requires' => ['HTML-Tree-3.17.tar.gz','WWW-Search-2.41.tar.gz'],'requires_module' => {'HTML::TreeBuilder' => '2.27','WWW::Search' => '2.27','WWW::Search::Test' => '2.12'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9595,'unpacked' => 45357},'testers' => {'pass' => 2},'uses' => ['Carp','WWW::Search','WWW::Search::Result']},'WWW-Search-Ebay-2.14.tar.gz' => {'author' => 'MTHURN','description' => 'search auctions on www.ebay.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2611,'pod' => 196,'pod_errors' => 0,'total' => 2807,'with_comments' => 304},'releases' => 11,'size' => {'packed' => 22120,'unpacked' => 76778},'testers' => {'pass' => 1},'uses' => ['$self->{path}::$self->{dispatch}','5.004','Carp','Config','Cwd','Data::Dumper','Exporter','ExtUtils::MM_Unix','ExtUtils::MakeMaker','File::Basename','File::Find','File::Path','File::Spec','FileHandle','LWP::Simple','Module::Install','Module::Install::Base','Net::FTP','Socket','Test::Builder','WWW::Search','WWW::Search::Result','YAML','inc::Module::Install','strict','threads::shared','vars']},'WWW-Search-FirstGov-1.14.tar.gz' => {'author' => 'SUTCH','description' => 'Backend class for searching FirstGov.gov','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 379,'pod' => 297,'pod_errors' => 0,'total' => 676,'with_comments' => 31},'releases' => 10,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search' => '2.33','WWW::Search::Test' => '2.16'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9573,'unpacked' => 26234},'testers' => {'pass' => 2},'uses' => ['Exporter','WWW::Search','WWW::SearchResult','strict']},'WWW-Search-Go-1.3.tar.gz' => {'author' => 'ALIAN','description' => 'Backend class for searching with go.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 136,'pod' => 38,'pod_errors' => 0,'total' => 174,'with_comments' => 26},'releases' => 3,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3910,'unpacked' => 8909},'testers' => {'fail' => 2,'pass' => 5},'uses' => ['Exporter','WWW::Search','WWW::SearchResult','strict','vars']},'WWW-Search-Google-0.21.tar.gz' => {'author' => 'LBROCARD','description' => 'search Google via SOAP','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 68,'pod' => 39,'pod_errors' => 0,'total' => 107,'with_comments' => 2},'releases' => 9,'requires' => ['Net-Google-0.60.tar.gz','Test-Simple-0.47.tar.gz','WWW-Search-2.41.tar.gz'],'requires_module' => {'Net::Google' => '0.52','Test::More' => '0.01','WWW::Search' => '2.35'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','Net-Google-0.60.tar.gz','PodParser-1.23.tar.gz','SOAP-Lite-0.55.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2499,'unpacked' => 5393},'testers' => {},'uses' => ['Carp','Net::Google','WWW::Search','WWW::SearchResult','strict','vars']},'WWW-Search-Googlism-0.02.tar.gz' => {'author' => 'XERN','description' => 'Searching Googlism','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 73,'pod' => 37,'pod_errors' => 0,'total' => 110,'with_comments' => 2},'releases' => 2,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2469,'unpacked' => 5192},'testers' => {'pass' => 2},'uses' => ['5.006','Carp','Exporter','WWW::Search','WWW::SearchResult','strict','warnings']},'WWW-Search-HotBot-2.28.tar.gz' => {'author' => 'MTHURN','description' => 'search on www.hotbot.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 231,'pod' => 186,'pod_errors' => 0,'total' => 417,'with_comments' => 39},'releases' => 12,'requires' => ['Test-Simple-0.47.tar.gz','WWW-Search-2.41.tar.gz'],'requires_module' => {'Test::More' => 0,'WWW::Search::Test' => '2.16'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6447,'unpacked' => 18081},'testers' => {'fail' => 2,'pass' => 6},'uses' => ['Exporter','URI::Escape','WWW::Search','WWW::Search::Result','strict']},'WWW-Search-Jobs-2.01.tar.gz' => {'author' => 'MTHURN','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1858,'pod' => 1548,'pod_errors' => 1,'total' => 3406,'with_comments' => 249},'releases' => 1,'size' => {'packed' => 24409,'unpacked' => 92008},'testers' => {'fail' => 1,'pass' => 4,'tests' => '9'},'uses' => ['Exporter','HTML::TokeParser','WWW::Search','WWW::Search::Scraper','WWW::SearchResult','strict']},'WWW-Search-Jobserve-1.01.tar.gz' => {'author' => 'NINJA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 202,'pod' => 139,'pod_errors' => 1,'total' => 341,'with_comments' => 43},'releases' => 2,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search::Test' => '2.12'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4976,'unpacked' => 12748},'testers' => {'pass' => 2},'uses' => ['WWW::Search','WWW::Search::Result']},'WWW-Search-Lycos-2.17.tar.gz' => {'author' => 'MTHURN','description' => 'search on www.lycos.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 214,'pod' => 114,'pod_errors' => 0,'total' => 328,'with_comments' => 32},'releases' => 7,'requires' => ['HTML-Tree-3.17.tar.gz','WWW-Search-2.41.tar.gz'],'requires_module' => {'HTML::TreeBuilder' => 0,'WWW::Search::Test' => '2.21'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4743,'unpacked' => 12568},'testers' => {'pass' => 2},'uses' => ['Carp','Exporter','HTML::Form','HTML::TreeBuilder','URI::Escape','WWW::Search','WWW::SearchResult']},'WWW-Search-News-1.03.tar.gz' => {'author' => 'MTHURN','description' => 'backend for searching AP News at www.washingtonpost.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 286,'pod' => 96,'pod_errors' => 0,'total' => 382,'with_comments' => 46},'releases' => 4,'requires' => ['URI-1.24.tar.gz','WWW-Search-2.41.tar.gz'],'requires_module' => {'URI' => 0,'WWW::Search::Test' => '2.22'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4876,'unpacked' => 14212},'testers' => {},'uses' => ['URI','WWW::Search','WWW::SearchResult','strict','vars']},'WWW-Search-Nomade-1.3.tar.gz' => {'author' => 'ALIAN','description' => 'class for searching Nomade','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 175,'pod' => 36,'pod_errors' => 0,'total' => 211,'with_comments' => 30},'releases' => 3,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4213,'unpacked' => 10676},'testers' => {'pass' => 3},'uses' => ['Exporter','URI::URL','WWW::Search','WWW::SearchResult','strict']},'WWW-Search-PRWire-1.0.tar.gz' => {'author' => 'JSMYSER','description' => undef,'files' => [],'lines' => {'nonpod' => 162,'pod' => 41,'pod_errors' => 0,'total' => 203,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 3354,'unpacked' => 7973},'testers' => {'fail' => 1,'pass' => 4},'uses' => ['Exporter','WWW::Search','WWW::SearchResult']},'WWW-Search-Pagesjaunes-0.06.tar.gz' => {'author' => 'BRIAC','description' => 'Lookup phones numbers from www.pagesjaunes.fr','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 203,'pod' => 116,'pod_errors' => 0,'total' => 319,'with_comments' => 28},'releases' => 6,'requires' => ['HTML-Parser-3.28.tar.gz','PodParser-1.23.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::Form' => 0,'HTML::TokeParser' => 0,'LWP::UserAgent' => '1.8','Pod::Usage' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6331,'unpacked' => 18193},'testers' => {'pass' => 2},'uses' => ['Carp','HTML::Form','HTML::TokeParser','LWP::UserAgent','locale','strict']},'WWW-Search-PubMed.-1.0.tar.gz' => {'author' => 'JSMYSER','description' => 'class for searching National Library of Medicine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 31,'pod_errors' => 0,'total' => 168,'with_comments' => 15},'releases' => 1,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3017,'unpacked' => 6761},'testers' => {'pass' => 5},'uses' => ['Exporter','WWW::Search','WWW::SearchResult']},'WWW-Search-RpmFind-1.2.tar.gz' => {'author' => 'ALIAN','description' => 'Search interface for rpmfind.net','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 137,'pod' => 39,'pod_errors' => 0,'total' => 176,'with_comments' => 24},'releases' => 2,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5148,'unpacked' => 13064},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['Exporter','WWW::Search','WWW::SearchResult','strict','vars']},'WWW-Search-Teoma-0.01.tar.gz' => {'author' => 'JSCHNEID','description' => 'class for searching www.teoma.com','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 169,'pod' => 34,'pod_errors' => 0,'total' => 203,'with_comments' => 30},'releases' => 1,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search::Test' => '2.11'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3372,'unpacked' => 7253},'testers' => {'pass' => 2},'uses' => ['WWW::Search','WWW::SearchResult','strict']},'WWW-Search-Translator-1.02.tar.gz' => {'author' => 'JSMYSER','description' => 'class for Translating languages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 54,'pod_errors' => 0,'total' => 228,'with_comments' => 20},'releases' => 3,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3694,'unpacked' => 9506},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['Exporter','URI::Escape','WWW::Search','WWW::SearchResult']},'WWW-Search-Tv-Sweden-TvDotNu-1.00.tar.gz' => {'author' => 'CLAESJAC','description' => 'Perl extension for fetching television program from swedish site http://www.tv.nu','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 376,'pod' => 125,'pod_errors' => 0,'total' => 501,'with_comments' => 18},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::Parser' => '3.26','HTTP::Request' => '1.3','LWP::UserAgent' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5520,'unpacked' => 14264},'testers' => {'pass' => 2},'uses' => ['5.008','Exporter','HTML::Parser','HTTP::Request','LWP::UserAgent','strict','warnings']},'WWW-Search-Yahoo-2.34.tar.gz' => {'author' => 'MTHURN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3382,'pod' => 416,'pod_errors' => 0,'total' => 3798,'with_comments' => 464},'releases' => 23,'size' => {'packed' => 30515,'unpacked' => 115748},'testers' => {'fail' => 1,'tests' => '54'},'uses' => ['$self->{path}::$self->{dispatch}','5.004','Carp','Config','Cwd','Data::Dumper','Date::Manip','Exporter','ExtUtils::MM_Unix','ExtUtils::MakeMaker','File::Basename','File::Find','File::Path','File::Spec','FileHandle','HTML::TreeBuilder','LWP::Simple','Module::Install','Module::Install::Base','Net::FTP','Socket','Test::Builder','URI','WWW::Search','WWW::Search::Result','WWW::SearchResult','YAML','constant','inc::Module::Install','strict','threads::shared','vars']},'WWW-Search-YahooNews-1.00.tar.gz' => {'author' => 'JSMYSER','description' => 'backend for searching Yahoo News','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 169,'pod' => 35,'pod_errors' => 0,'total' => 204,'with_comments' => 20},'releases' => 1,'requires' => ['WWW-Search-2.41.tar.gz'],'requires_module' => {'WWW::Search' => 2},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3405,'unpacked' => 7385},'testers' => {'pass' => 6},'uses' => ['Exporter','WWW::Search','WWW::SearchResult']},'WWW-SearchBroker-0.07.tar.gz' => {'author' => 'NATE','description' => 'Parallel metasearcher for Internet-based services (WWW, IMAP, LDAP, etc.)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1008,'pod' => 281,'pod_errors' => 0,'total' => 1289,'with_comments' => 243},'releases' => 4,'requires' => ['Data-Serializer-0.17.tar.gz','DateManip-5.42a.tar.gz','HTML-Tree-3.17.tar.gz','Mail-IMAPClient-2.2.8.tar.gz','NNTPClient-0.37.tar.gz','WWW-Search-2.41.tar.gz','libwww-perl-5.69.tar.gz','perl-ldap-0.29.tar.gz'],'requires_module' => {'Data::Serializer' => '0.17','Date::Manip' => 0,'HTML::TreeBuilder' => 0,'LWP::UserAgent' => 0,'Mail::IMAPClient' => 0,'Net::LDAP' => 0,'News::NNTPClient' => 0,'WWW::Search' => 0},'requires_recursive' => ['Convert-ASN1-0.17.tar.gz','Data-Dumper-2.101.tar.gz','Data-Serializer-0.17.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','Errno-1.09.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','MIME-Lite-3.01.tar.gz','Mail-IMAPClient-2.2.8.tar.gz','NNTPClient-0.37.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Inline-0.15.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','User-1.6.tar.gz','WWW-Search-2.41.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz','perl-ldap-0.29.tar.gz'],'size' => {'packed' => 20784,'unpacked' => 74797},'testers' => {},'uses' => ['Carp','Data::Dumper','Data::Serializer','Date::Manip','Exporter','IO::Select','IO::Socket','Net::hostent','constant','strict','vars','warnings']},'WWW-SherlockSearch-0.14.tar.gz' => {'author' => 'AUTRIJUS','description' => 'Parse and execute Apple Sherlock 2 plugins','files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 1046,'pod' => 117,'pod_errors' => 0,'total' => 1163,'with_comments' => 47},'releases' => 5,'requires' => ['Module-Build-0.19.tar.gz'],'requires_module' => {'Module::Build' => '0.11'},'requires_recursive' => ['Module-Build-0.19.tar.gz'],'size' => {'packed' => 12286,'unpacked' => 45463},'testers' => {'pass' => 1},'uses' => ['Encode','HTML::Entities','HTTP::Cookies','HTTP::Request::Common','LWP','XML::RSS','strict','vars']},'WWW-ShopBot-0.07.tar.gz' => {'author' => 'XERN','description' => 'General framework for shopping bots','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 142,'pod' => 85,'pod_errors' => 0,'total' => 227,'with_comments' => 5},'releases' => 6,'requires' => ['File-Find-Rule-0.10.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'File::Find::Rule' => '0.09','HTTP::Cookies' => '1.30'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Find-Rule-0.10.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3326,'unpacked' => 7181},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Exporter','File::Find::Rule','HTTP::Cookies','WWW::ShopBot::','strict']},'WWW-ShopBot-Driver-0.006.tar.gz' => {'author' => 'XERN','description' => 'Basic class for shopbot drivers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 991,'pod' => 176,'pod_errors' => 0,'total' => 1167,'with_comments' => 24},'releases' => 6,'requires' => ['HTML-Parser-3.28.tar.gz','HTML-TableContentParser-0.13.tar.gz','WWW-Mechanize-0.56.tar.gz','WWW-ShopBot-0.07.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Cwd' => '2.06','HTML::Parser' => '3.27','HTML::TableContentParser' => '0.13','LWP::UserAgent' => '2.003','WWW::Mechanize' => '0.37','WWW::ShopBot' => '0.05'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Find-Rule-0.10.tar.gz','HTML-Parser-3.28.tar.gz','HTML-TableContentParser-0.13.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','WWW-Mechanize-0.56.tar.gz','WWW-ShopBot-0.07.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10434,'unpacked' => 44538},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Dumper','HTML::LinkExtractor','HTML::TableContentParser','LWP::Simple','LWP::UserAgent','WWW::Mechanize','strict']},'WWW-Shorten-1.5.8.tar.gz' => {'author' => 'SPOON','description' => 'Abstract interface to URL shortening sites.','files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 839,'pod' => 612,'pod_errors' => 0,'total' => 1451,'with_comments' => 11},'releases' => 16,'size' => {'packed' => 30641,'unpacked' => 111927},'testers' => {'pass' => 2},'uses' => ['','$file','5.006','Carp','Exporter','LWP','URI','strict','warnings']},'WWW-Shorten-1.82.tar.gz' => {'author' => 'SPOON','description' => 'Abstract interface to URL shortening sites.','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 770,'pod' => 565,'pod_errors' => 0,'total' => 1335,'with_comments' => 9},'releases' => 16,'requires' => ['Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.69','Test::More' => '0.47','URI' => '1.23'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 28432,'unpacked' => 108027},'testers' => {'pass' => 1},'uses' => ['','$file','5.006','Carp','Exporter','LWP','URI','strict','warnings']},'WWW-SimpleRobot-0.07.tar.gz' => {'author' => 'AWRIGLEY','description' => 'a simple web robot for recursively following links on web pages.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 194,'pod' => 63,'pod_errors' => 0,'total' => 257,'with_comments' => 39},'releases' => 6,'requires' => ['HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::LinkExtor' => undef,'LWP::Simple' => undef,'URI' => undef},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6289,'unpacked' => 21121},'testers' => {},'uses' => ['5.005_62','HTML::LinkExtor','LWP::Simple','URI','strict','vars','warnings']},'WWW-Spyder-0.18.tar.gz' => {'author' => 'ASHLEY','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 943,'pod' => 309,'pod_errors' => 0,'total' => 1252,'with_comments' => 160},'releases' => 2,'requires' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Digest::MD5' => '2.14','HTML::Entities' => '1.2','HTML::Parser' => 3,'HTTP::Cookies' => '1.14','LWP::UserAgent' => '1.7','URI::URL' => 5},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17432,'unpacked' => 54649},'testers' => {'pass' => 2},'uses' => ['Carp','Digest::MD5','HTML::Entities','HTML::Parser','HTTP::Cookies','LWP::UserAgent','POSIX','URI::Escape','URI::URL','overload','strict','warnings']},'WWW-Sundance-0.02.tar.gz' => {'author' => 'DSPARLING','description' => 'Get movie schedules/info from Sundance.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 163,'pod' => 46,'pod_errors' => 0,'total' => 209,'with_comments' => 13},'releases' => 2,'size' => {'packed' => 3539,'unpacked' => 8837},'testers' => {'pass' => 2},'uses' => ['Carp','HTML::TokeParser','LWP::Simple','LWP::UserAgent','strict','vars']},'WWW-UsePerl-Journal-0.11.tar.gz' => {'author' => 'IDORU','description' => 'use.perl.org journal tool','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 461,'pod' => 111,'pod_errors' => 0,'total' => 572,'with_comments' => 23},'releases' => 11,'requires' => ['Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::UserAgent' => 0,'Test::Simple' => '0.4','Time::Piece' => '1.07'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-Piece-1.08.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13937,'unpacked' => 38299},'testers' => {'fail' => 1,'pass' => 7,'tests' => '16'},'uses' => ['Carp','Data::Dumper','HTTP::Cookies','HTTP::Request::Common','LWP::UserAgent','Time::Piece','Time::Seconds','constant','strict','warnings']},'WWW-Wikipedia-0.3.tar.gz' => {'author' => 'ESUMMERS','description' => 'Automated interface to the Wikipedia','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 163,'pod' => 125,'pod_errors' => 0,'total' => 288,'with_comments' => 2},'releases' => 3,'requires' => ['HTML-Parser-3.28.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'HTML::Parser' => 1,'LWP::UserAgent' => 1},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3639,'unpacked' => 8455},'testers' => {'pass' => 2},'uses' => ['CGI','Carp','HTML::Parser','LWP::UserAgent','constant','strict','warnings']},'WWW-Yahoo-Groups-1.8.1.tar.gz' => {'author' => 'SPOON','description' => 'automated access to Yahoo! Groups.','files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 754,'pod' => 303,'pod_errors' => 0,'total' => 1057,'with_comments' => 30},'releases' => 16,'size' => {'packed' => 31661,'unpacked' => 97135},'testers' => {'pass' => 1},'uses' => ['Carp','Exception::Class','File::Basename','File::Spec','HTML::Entities','HTTP::Cookies','Locale::Maketext','Locale::Maketext::Lexicon','Module::Build','Params::Validate','WWW::Mechanize','WWW::Yahoo::Groups::Errors','WWW::Yahoo::Groups::Mechanize','strict','vars','warnings']},'WWW-Yahoo-Groups-1.84.tar.gz' => {'author' => 'SPOON','description' => 'automated access to Yahoo! Groups.','files' => ['Makefile.PL','README','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 630,'pod' => 253,'pod_errors' => 0,'total' => 883,'with_comments' => 22},'releases' => 16,'requires' => ['Exception-Class-1.14.tar.gz','HTML-Parser-3.28.tar.gz','Params-Validate-0.64.tar.gz','Test-Simple-0.47.tar.gz','WWW-Mechanize-0.56.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Exception::Class' => '1.14','HTML::Entities' => '1.25','HTTP::Cookies' => '1.30','Params::Validate' => '0.64','Test::More' => '0.47','WWW::Mechanize' => '0.55'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Devel-StackTrace-1.03.tar.gz','Digest-MD5-2.26.tar.gz','Exception-Class-1.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Params-Validate-0.64.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','WWW-Mechanize-0.56.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 26885,'unpacked' => 78276},'testers' => {'pass' => 1},'uses' => ['Carp','Exception::Class','HTML::Entities','HTTP::Cookies','Params::Validate','WWW::Mechanize','strict','vars','warnings']},'WWW-YahooMaps-0.2.tar.gz' => {'author' => 'CSELLEG','description' => 'Create links to Yahoo! Maps','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 183,'pod' => 125,'pod_errors' => 0,'total' => 308,'with_comments' => 12},'releases' => 2,'size' => {'packed' => 3925,'unpacked' => 8846},'testers' => {'pass' => 3},'uses' => ['5.005_62','Exporter','URI::Escape','strict','warnings']},'Wais-2.202.tar.gz' => {'author' => 'ULPFR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 741,'pod' => 326,'pod_errors' => 0,'total' => 1067,'with_comments' => 181},'releases' => 21,'requires' => ['IO-1.20.tar.gz'],'requires_module' => {'IO::Select' => 0},'requires_recursive' => ['IO-1.20.tar.gz'],'size' => {'packed' => 41372,'unpacked' => 150204},'testers' => {},'uses' => ['5.003','Carp','DynaLoader','FileHandle','IO::Select','IO::Socket','vars']},'Wais-2.311.tar.gz' => {'author' => 'ULPFR','description' => 'Interface to the freeWAIS-sf libraries','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 707,'pod' => 326,'pod_errors' => 0,'total' => 1033,'with_comments' => 128},'releases' => 21,'requires' => ['Curses-1.06.tar.gz'],'requires_module' => {'Curses' => 0},'requires_recursive' => ['Curses-1.06.tar.gz'],'size' => {'packed' => 54722,'unpacked' => 197939},'testers' => {},'uses' => ['Carp','DynaLoader','FileHandle','IO::Select','IO::Socket','strict','vars']},'Want-0.05.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 299,'pod' => 386,'pod_errors' => 0,'total' => 685,'with_comments' => 3},'releases' => 6,'testers' => {'pass' => 26},'uses' => ['Carp','DynaLoader','Exporter','strict','v5.6','warnings']},'Watchdog-0.07.tar.gz' => {'author' => 'PSHARPE','description' => 'Watchdog base class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 312,'pod' => 178,'pod_errors' => 0,'total' => 490,'with_comments' => 42},'releases' => 4,'requires' => ['Alias-2.32.tar.gz','Proc-ProcessTable-0.38.tar.gz'],'requires_module' => {'Alias' => 0,'Proc::ProcessTable' => 0},'requires_recursive' => ['Alias-2.32.tar.gz','File-Spec-0.82.tar.gz','Proc-ProcessTable-0.38.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7057,'unpacked' => 24678},'testers' => {'fail' => 1,'pass' => 1,'tests' => '5'},'uses' => ['Alias','DBI','Getopt::Long','HTTP::Request','LWP::UserAgent','Log::Service','Proc::ProcessTable','strict','vars']},'WeSQL-0.53.tar.gz' => {'author' => 'WARD','description' => 'Apache mod_perl module for WeSQL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3578,'pod' => 1421,'pod_errors' => 2,'total' => 4999,'with_comments' => 811},'releases' => 3,'size' => {'packed' => 87534,'unpacked' => 338287},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.006','Apache::Constants','CGI','Exporter','POSIX','lib','strict','warnings']},'WeakRef-0.01.tar.gz' => {'author' => 'LUKKA','description' => '- an API to the Perl weak references','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 39,'pod' => 52,'pod_errors' => 0,'total' => 91,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 3069,'unpacked' => 6407},'testers' => {'pass' => 5},'uses' => ['DynaLoader','Exporter','strict','vars']},'Weather-Bug-0.01.tar.gz' => {'author' => 'ROSULEK','description' => 'Get realtime weather where available','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 100,'pod' => 75,'pod_errors' => 0,'total' => 175,'with_comments' => 0},'releases' => 1,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Request::Common' => 0,'LWP::UserAgent' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2764,'unpacked' => 5784},'testers' => {'tests' => '0','unknown' => 1},'uses' => ['Exporter','HTTP::Request::Common','LWP::UserAgent','strict','warnings']},'Weather-Underground-2.10.tar.gz' => {'author' => 'MNAGUIB','description' => 'Perl extension for retrieving weather information from wunderground.com','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 186,'pod' => 116,'pod_errors' => 0,'total' => 302,'with_comments' => 26},'releases' => 11,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::Simple' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4492,'unpacked' => 11383},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Exporter','LWP::Simple','strict','vars']},'Weaving-Tablet-0.8.2.tar.gz' => {'author' => 'HERVEUS','description' => 'Perl extension for manipulating tablet weaving patterns','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2741,'pod' => 318,'pod_errors' => 0,'total' => 3059,'with_comments' => 37},'releases' => 3,'size' => {'packed' => 32766,'unpacked' => 175675},'testers' => {'fail' => 2},'uses' => ['5.00400','Data::Dumper','Exporter','Tk::ColorEditor','Tk::FileSelect','Tk::FontDialog','Tk::HList','strict','vars']},'Weaving-Tablet-0.8.tar.gz' => {'author' => 'HERVEUS','description' => 'Perl extension for manipulating tablet weaving patterns','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2741,'pod' => 318,'pod_errors' => 0,'total' => 3059,'with_comments' => 37},'releases' => 3,'size' => {'packed' => 32491,'unpacked' => 174708},'testers' => {},'uses' => ['5.00400','Data::Dumper','Exporter','Snartemo','Tk::ColorEditor','Tk::FileSelect','Tk::FontDialog','Tk::HList','strict','vars']},'WebCache-Digest-1.00.tar.gz' => {'author' => 'MHAMILTON','description' => 'Internet Cache Protocol (RFCs 2186 and 2187)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 386,'pod' => 162,'pod_errors' => 0,'total' => 548,'with_comments' => 33},'releases' => 1,'size' => {'packed' => 14363,'unpacked' => 39691},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','IO::Socket','MD5','Sys::Hostname','strict','vars']},'WebCache-ICP-1.00.tar.gz' => {'author' => 'MHAMILTON','description' => 'Internet Cache Protocol client and server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 326,'pod' => 223,'pod_errors' => 0,'total' => 549,'with_comments' => 27},'releases' => 1,'size' => {'packed' => 30721,'unpacked' => 100420},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','Socket','strict','vars']},'WebFS-FileCopy-1.04.tar.gz' => {'author' => 'BZAJAC','description' => 'Get, put, copy, delete files located by URL','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1118,'pod' => 219,'pod_errors' => 2,'total' => 1337,'with_comments' => 133},'releases' => 7,'size' => {'packed' => 22505,'unpacked' => 74496},'testers' => {'fail' => 6,'tests' => '187'},'uses' => ['5.004_04','Carp','Cwd','Exporter','HTTP::Request::Common','HTTP::Response','LWP::Conn::FTP','LWP::Conn::HTTP','LWP::MainLoop','LWP::Request','LWP::UA','LWP::Version','Net::FTP','URI','URI::file','strict','vars']},'WebFetch-0.10.tar.gz' => {'author' => 'IKLUFT','description' => 'Perl module to download and save information from the Web','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4238,'pod' => 1269,'pod_errors' => 1,'total' => 5507,'with_comments' => 677},'releases' => 8,'requires' => ['Data-Dumper-2.101.tar.gz','Date-Calc-5.3.tar.gz','HTML-Parser-3.28.tar.gz','Locale-Codes-2.06.tar.gz','XML-Parser-2.31.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'Date::Calc' => 0,'HTML::LinkExtor' => 0,'HTTP::Request' => 0,'LWP::UserAgent' => 0,'Locale::Country' => 0,'XML::Parser' => 0},'requires_recursive' => ['Bit-Vector-6.3.tar.gz','Data-Dumper-2.101.tar.gz','Date-Calc-5.3.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','Locale-Codes-2.06.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 60499,'unpacked' => 204606},'testers' => {'pass' => 6,'tests' => '0','unknown' => 6},'uses' => ['AutoLoader','Carp','Data::Dumper','Date::Calc','Exporter','Getopt::Long','HTML::LinkExtor','HTTP::Request','LWP::UserAgent','Locale::Country','URI','XML::Parser','strict','vars']},'WebService-Advogato-1.00.tar.gz' => {'author' => 'JALDHAR','description' => 'XML-RPC interface to www.advogato.org','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 84,'pod_errors' => 0,'total' => 219,'with_comments' => 3},'releases' => 1,'requires' => ['RPC-XML-0.53.tar.gz'],'requires_module' => {'RPC::XML' => '0.53'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','RPC-XML-0.53.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3940,'unpacked' => 8767},'testers' => {'pass' => 2},'uses' => ['Carp','RPC::XML','RPC::XML::Client','strict','vars']},'WebService-FreeDB-0.56.tar.gz' => {'author' => 'HMERSCH','description' => 'A String search interface to FreeDB','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 478,'pod' => 135,'pod_errors' => 0,'total' => 613,'with_comments' => 70},'releases' => 8,'requires' => ['Test-Simple-0.47.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP::Simple' => '1.32','Test::More' => '0.45'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8293,'unpacked' => 24434},'testers' => {'pass' => 2,'tests' => '0','unknown' => 3},'uses' => ['Data::Dumper','Exporter','LWP::Simple']},'WebService-Mappoint-0.30.tar.gz' => {'author' => 'CGARCIA','description' => 'Mappoint maps service SOAP access library','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 528,'pod' => 287,'pod_errors' => 0,'total' => 815,'with_comments' => 67},'releases' => 1,'requires' => ['MIME-Base64-2.20.tar.gz','SOAP-Lite-0.55.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'MIME::Base64' => '0','SOAP::Lite' => '0','Test::More' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','SOAP-Lite-0.55.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 8628,'unpacked' => 31754},'testers' => {},'uses' => ['Data::Dumper','FileHandle','SOAP::Lite','fields','strict','vars']},'WebService-weblogUpdates-0.35.tar.gz' => {'author' => 'ASCOPE','description' => 'methods supported by the UserLand weblogUpdates framework.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 721,'pod' => 187,'pod_errors' => 0,'total' => 908,'with_comments' => 31},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Test::More' => '0.41'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7444,'unpacked' => 24937},'testers' => {'pass' => 3},'uses' => ['Carp','Cwd','Exporter','File::Spec','constant','strict']},'WebSphere-Payment-1.21.tar.gz' => {'author' => 'LEMP','description' => 'Interface to IBM WebSphere Payment Manager','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 543,'pod' => 86,'pod_errors' => 0,'total' => 629,'with_comments' => 82},'releases' => 2,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'HTTP::Headers' => '','HTTP::Request' => '','LWP::UserAgent' => ''},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5858,'unpacked' => 25608},'testers' => {'pass' => 2},'uses' => ['HTTP::Headers','HTTP::Request','LWP::UserAgent','strict','vars']},'WebTools-1.27.tar.gz' => {'author' => 'JLISHEV','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 10751,'pod' => 1625,'pod_errors' => 3,'total' => 12376,'with_comments' => 1208},'releases' => 16,'size' => {'packed' => 324570,'unpacked' => 1509944},'testers' => {'pass' => 3},'uses' => ['5.002','Cwd','DBI','Exporter','Fcntl','File::DosGlob','Image::Magick','constant','lib','strict','vars']},'Wetware-llyrisWeb-0.01.tar.gz' => {'author' => 'DRIEUX','description' => 'PM for lyris mailserver support','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 74,'pod_errors' => 0,'total' => 296,'with_comments' => 54},'releases' => 1,'requires' => ['CGI.pm-2.98.tar.gz'],'requires_module' => {'CGI' => '2.3'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz'],'size' => {'packed' => 5036,'unpacked' => 12174},'testers' => {'pass' => 2},'uses' => ['5.006','AutoLoader','CGI','Exporter','strict','vars','warnings']},'Wharf-JDockApp-1.1.tar.gz' => {'author' => 'JETTERO','description' => 'Perl extension for doing Wharf or Window Maker dockapps.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 74,'pod' => 139,'pod_errors' => 0,'total' => 213,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 16949,'unpacked' => 78946},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'Whatif-1.01.tar.gz' => {'author' => 'SIMONW','description' => 'provides rollbacks, second chances and ways to overcomes regrets in code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 128,'pod' => 110,'pod_errors' => 0,'total' => 238,'with_comments' => 11},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 4998,'unpacked' => 9669},'testers' => {'pass' => 6},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'Whitespace-1.02.tgz' => {'author' => 'RVAIDH','description' => 'Detect and cleanup bogus whitespace in files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 319,'pod' => 128,'pod_errors' => 1,'total' => 447,'with_comments' => 33},'releases' => 3,'size' => {'packed' => 4288,'unpacked' => 11265},'testers' => {'pass' => 6},'uses' => ['File::Copy','File::Spec','strict']},'Win32-ADO-0.03.tar.gz' => {'author' => 'MSERGEANT','description' => 'ADO Constants and helper functions','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 390,'pod' => 30,'pod_errors' => 0,'total' => 420,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 3884,'unpacked' => 11543},'testers' => {'pass' => 6},'uses' => ['strict','vars']},'Win32-ANSIConsole-0.01.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 230,'pod' => 162,'pod_errors' => 1,'total' => 392,'with_comments' => 59},'releases' => 1,'requires' => ['libwin32-0.191.zip'],'requires_module' => {'Win32::Console' => '0.03'},'requires_recursive' => ['libwin32-0.191.zip'],'testers' => {},'uses' => ['5.006','Win32::Console','strict','warnings']},'Win32-API-0.41.tar.gz' => {'author' => 'ACALPINI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1763,'pod' => 774,'pod_errors' => 0,'total' => 2537,'with_comments' => 149},'releases' => 3,'size' => {'packed' => 52669,'unpacked' => 291942},'testers' => {'pass' => 1},'uses' => ['Carp','DynaLoader','Exporter','vars']},'Win32-API-OutputDebugString-0.03.tar.gz' => {'author' => 'ALFO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 82,'pod' => 39,'pod_errors' => 0,'total' => 121,'with_comments' => 14},'releases' => 2,'size' => {'packed' => 3317,'unpacked' => 6405},'testers' => {},'uses' => ['5.005_62','AutoLoader','Carp','DynaLoader','Exporter','strict','vars','warnings']},'Win32-ASP-2.15.tar.gz' => {'author' => 'WNODOM','description' => 'Makes PerlScript ASP development easier','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 643,'pod' => 192,'pod_errors' => 0,'total' => 835,'with_comments' => 170},'releases' => 10,'size' => {'packed' => 9093,'unpacked' => 29762},'testers' => {'pass' => 2,'tests' => '0','unknown' => 9},'uses' => ['AutoLoader','Exporter','Win32::OLE::Variant','strict','vars']},'Win32-ASP-DB-0.02.tar.gz' => {'author' => 'TEVERETT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3618,'pod' => 822,'pod_errors' => 2,'total' => 4440,'with_comments' => 292},'releases' => 2,'size' => {'packed' => 43055,'unpacked' => 272013},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['Benchmark','Class::SelfMethods','Error','Error::Unhandled','Win32::OLE::Variant','strict']},'Win32-ASP-Extras-1.01.tar.gz' => {'author' => 'TEVERETT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 211,'pod' => 109,'pod_errors' => 0,'total' => 320,'with_comments' => 23},'releases' => 1,'size' => {'packed' => 5799,'unpacked' => 16936},'testers' => {'pass' => 4},'uses' => ['AutoLoader','Data::Dumper','Exporter','strict','vars']},'Win32-AbsPath-1.0.tar.gz' => {'author' => 'JENDA','description' => 'relative paths to absolute, understands UNCs','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 74,'pod' => 71,'pod_errors' => 0,'total' => 145,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 2262,'unpacked' => 4476},'testers' => {'pass' => 12},'uses' => ['Cwd','Exporter']},'Win32-ActAcc-1.0.zip' => {'author' => 'PBWOLF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3383,'pod' => 1281,'pod_errors' => 14,'total' => 4664,'with_comments' => 145},'releases' => 6,'requires' => ['Win32-OLE-0.1403.tar.gz'],'requires_module' => {'Win32::OLE' => '0.13'},'requires_recursive' => ['Win32-OLE-0.1403.tar.gz'],'size' => {'packed' => 199191,'unpacked' => 448475},'testers' => {},'uses' => ['5.005_62','Carp','Config','Data::Dumper','DynaLoader','Exporter','Win32::ActAcc::AO','Win32::ActAcc::Event','Win32::ActAcc::Iterators','Win32::ActAcc::Menu','Win32::ActAcc::MiscRoles','strict','vars','warnings']},'Win32-Autoglob-1.01.tar.gz' => {'author' => 'SBURKE','description' => '- expand globs in @ARGV when the shell doesn\'t','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 34,'pod' => 63,'pod_errors' => 0,'total' => 97,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2631,'unpacked' => 5648},'testers' => {},'uses' => ['5','strict','vars']},'Win32-Console-ANSI-0.03.tar.gz' => {'author' => 'JLMOREL','description' => 'Emulate ANSI console on Win32 system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 474,'pod' => 259,'pod_errors' => 0,'total' => 733,'with_comments' => 92},'releases' => 2,'size' => {'packed' => 8789,'unpacked' => 28972},'testers' => {},'uses' => ['5.006','Carp','Exporter','Win32::Console','Win32API::Registry','strict','subs','warnings']},'Win32-CtrlGUI-0.30.tar.gz' => {'author' => 'TEVERETT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2763,'pod' => 520,'pod_errors' => 2,'total' => 3283,'with_comments' => 263},'releases' => 6,'size' => {'packed' => 29958,'unpacked' => 119809},'testers' => {'fail' => 1},'uses' => ['Tk','Tk::Dialog','Tk::HList','Tk::ROText','Win32::API','Win32::Setupsup','strict','vars']},'Win32-Daemon-Simple-0.2.2.tar.gz' => {'author' => 'JENDA','description' => 'simplify creating windows services','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 851,'pod' => 413,'pod_errors' => 0,'total' => 1264,'with_comments' => 43},'releases' => 3,'requires' => ['libwin32-0.191.zip'],'requires_module' => {'Win32::Console' => 0},'requires_recursive' => ['libwin32-0.191.zip'],'size' => {'packed' => 12468,'unpacked' => 42073},'testers' => {},'uses' => ['Carp','Exporter','File::Spec','FileHandle','FindBin','Hash::Case::Preserve','POSIX','Win32','Win32::Console','Win32::Daemon','Win32::Registry','Win32::Service','strict','vars']},'Win32-DirSize-1.00.tar.gz' => {'author' => 'ARICH','description' => undef,'files' => [],'lines' => {'nonpod' => 121,'pod' => 110,'pod_errors' => 0,'total' => 231,'with_comments' => 12},'releases' => 3,'size' => {'packed' => 7182,'unpacked' => 21794},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Win32-DriveInfo-0.06.tar.gz' => {'author' => 'MBLAZ','description' => 'drives on Win32 systems','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 283,'pod' => 240,'pod_errors' => 1,'total' => 523,'with_comments' => 23},'releases' => 3,'requires' => ['Win32-API-0.41.tar.gz'],'requires_module' => {'Win32::API' => 0},'requires_recursive' => ['Win32-API-0.41.tar.gz'],'size' => {'packed' => 8175,'unpacked' => 26775},'testers' => {'pass' => 1},'uses' => ['Cwd','Win32::API','strict','vars']},'Win32-Encode-0.5beta.zip' => {'author' => 'KMELTZ','description' => 'Interface to Progressive Network\'s RealAudio','files' => [],'lines' => {'nonpod' => 465,'pod' => 294,'pod_errors' => 0,'total' => 759,'with_comments' => 57},'releases' => 2,'size' => {'packed' => 13593,'unpacked' => 39263},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Carp','Cwd','Win32::Process','Win32::Registry','strict','vars']},'Win32-EventLog-Carp-1.21.tar.gz' => {'author' => 'RRWO','description' => 'For carping in the Windows NT Event Log','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 272,'pod' => 119,'pod_errors' => 0,'total' => 391,'with_comments' => 48},'releases' => 7,'requires' => ['File-Spec-0.82.tar.gz','libwin32-0.191.zip','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'File::Basename' => 0,'File::Spec' => 0,'Win32::EventLog' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','libwin32-0.191.zip','perl-5.8.0.tar.gz'],'size' => {'packed' => 5416,'unpacked' => 13685},'testers' => {},'uses' => ['Carp','Exporter','File::Basename','File::Spec','Win32::EventLog','Win32::EventLog::Message','strict','vars']},'Win32-Exchange_v0.038.tar.gz' => {'author' => 'SMANROSS','description' => 'Exchange SMTP access list maintenance','files' => [],'lines' => {'nonpod' => 2659,'pod' => 0,'pod_errors' => 0,'total' => 2659,'with_comments' => 118},'releases' => 1,'size' => {'packed' => 41032,'unpacked' => 183716},'testers' => {},'uses' => ['Exporter','Win32::OLE','constant','strict','vars']},'Win32-FileOp-0.14.1.tar.gz' => {'author' => 'JENDA','description' => 'file operations + fancy dialogs, INI files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1772,'pod' => 1005,'pod_errors' => 0,'total' => 2777,'with_comments' => 158},'releases' => 8,'requires' => ['Data-Lazy-0.5.tar.gz','Win32-API-0.41.tar.gz','Win32-AbsPath-1.0.tar.gz'],'requires_module' => {'Data::Lazy' => '0.5','Win32::API' => 0,'Win32::AbsPath' => '1.0'},'requires_recursive' => ['Data-Lazy-0.5.tar.gz','Win32-API-0.41.tar.gz','Win32-AbsPath-1.0.tar.gz'],'size' => {'packed' => 24020,'unpacked' => 90534},'testers' => {},'uses' => ['Carp','Cwd','Data::Lazy','Exporter','File::DosGlob','File::Find','File::Path','Tie::Hash','Win32::API','Win32::AbsPath','strict','vars']},'Win32-FileTime-0.04.tar.gz' => {'author' => 'ROBAU','description' => 'Perl module for accessing Win32 file times','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 141,'pod' => 70,'pod_errors' => 0,'total' => 211,'with_comments' => 0},'releases' => 2,'requires' => ['Win32-API-0.41.tar.gz'],'requires_module' => {'Win32::API' => 0},'requires_recursive' => ['Win32-API-0.41.tar.gz'],'size' => {'packed' => 3195,'unpacked' => 10609},'testers' => {},'uses' => ['Carp','Win32::API','Win32API::File','strict','vars']},'Win32-GUI-0.0.558.tar.gz' => {'author' => 'ACALPINI','description' => 'Perl-Win32 Graphical User Interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 9612,'pod' => 8642,'pod_errors' => 110,'total' => 18254,'with_comments' => 993},'releases' => 3,'size' => {'packed' => 415966,'unpacked' => 6293947},'testers' => {},'uses' => ['DynaLoader','Exporter','MIME::Base64']},'Win32-Girder-IEvent-0.03.tar.gz' => {'author' => 'GBROCK','description' => 'Perl API to the Win32 Girder Internet Events Client','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 464,'pod' => 167,'pod_errors' => 0,'total' => 631,'with_comments' => 44},'releases' => 3,'requires' => ['Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz'],'requires_module' => {'Digest::MD5' => 2,'IO::Socket::INET' => '1.25'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz'],'size' => {'packed' => 5854,'unpacked' => 19161},'testers' => {'pass' => 2},'uses' => ['5.6.0','Digest::MD5','Exporter','IO::Socket','IO::Socket::INET','constant','strict','warnings::register']},'Win32-GuiTest-1.3.zip' => {'author' => 'ERNGUI','description' => 'SendKeys, FindWindowLike and more','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 331,'pod' => 353,'pod_errors' => 0,'total' => 684,'with_comments' => 13},'releases' => 11,'size' => {'packed' => 58103,'unpacked' => 110773},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'Win32-IPConfig-0.04.tar.gz' => {'author' => 'JMACFARLA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 888,'pod' => 304,'pod_errors' => 0,'total' => 1192,'with_comments' => 168},'releases' => 4,'size' => {'packed' => 9305,'unpacked' => 42607},'testers' => {},'uses' => ['5.006','Carp','POSIX','Win32::TieRegistry','strict','warnings']},'Win32-IPHelper-0.02.tar.gz' => {'author' => 'LMASARA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1158,'pod' => 398,'pod_errors' => 0,'total' => 1556,'with_comments' => 527},'releases' => 2,'requires' => ['Win32-API-0.41.tar.gz'],'requires_module' => {'Win32::API' => '0.2'},'requires_recursive' => ['Win32-API-0.41.tar.gz'],'size' => {'packed' => 11948,'unpacked' => 65746},'testers' => {},'uses' => ['5.006','Carp','Exporter','Socket','Win32','Win32::API','enum','strict','warnings']},'Win32-InternetExplorer-Window-0.10.tar.gz' => {'author' => 'MZSANFORD','description' => undef,'files' => [],'lines' => {'nonpod' => 193,'pod' => 125,'pod_errors' => 2,'total' => 318,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 3052,'unpacked' => 8501},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Win32::OLE','strict','vars']},'Win32-Locale-0.03.tar.gz' => {'author' => 'SBURKE','description' => 'get the current MSWin locale or language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 278,'pod' => 91,'pod_errors' => 0,'total' => 369,'with_comments' => 166},'releases' => 3,'size' => {'packed' => 7504,'unpacked' => 22194},'testers' => {'pass' => 1},'uses' => ['strict','vars']},'Win32-MCI-Basic-0.01.tar.gz' => {'author' => 'NILSONSFJ','description' => undef,'files' => ['MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 48,'pod_errors' => 1,'total' => 79,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1684,'unpacked' => 3233},'testers' => {},'uses' => ['5.005','Exporter','Win32::API','strict','warnings']},'Win32-MCI-CD-0.02.tar.gz' => {'author' => 'LENNERTO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 289,'pod' => 133,'pod_errors' => 0,'total' => 422,'with_comments' => 25},'releases' => 3,'requires' => ['Win32-API-0.41.tar.gz'],'requires_module' => {'Win32::API' => '0.01'},'requires_recursive' => ['Win32-API-0.41.tar.gz'],'size' => {'packed' => 3849,'unpacked' => 13705},'testers' => {},'uses' => ['5','Carp','Win32::API','strict','warnings']},'Win32-MIDI-0_2.zip' => {'author' => 'CHURCH','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 402,'pod' => 571,'pod_errors' => 0,'total' => 973,'with_comments' => 7},'releases' => 1,'requires' => ['Time-HiRes-1.49.tar.gz'],'requires_module' => {'Time::HiRes' => '1.2'},'requires_recursive' => ['Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 18175,'unpacked' => 56638},'testers' => {},'uses' => ['5.006','DynaLoader','Exporter','Time::HiRes','strict','warnings']},'Win32-MSAgent-0.05.tar.gz' => {'author' => 'JOUKE','description' => 'Interface to Microsoft Agent','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 468,'pod' => 221,'pod_errors' => 0,'total' => 689,'with_comments' => 11},'releases' => 6,'requires' => ['Win32-OLE-0.1403.tar.gz'],'requires_module' => {'Win32::OLE' => 0,'Win32::OLE::Enum' => 0,'Win32::OLE::Variant' => 0},'requires_recursive' => ['Win32-OLE-0.1403.tar.gz'],'size' => {'packed' => 15931,'unpacked' => 47982},'testers' => {},'uses' => ['Win32::OLE','Win32::OLE::Enum','Win32::OLE::Variant','strict','vars','warnings']},'Win32-MSI-DB-1.02.tar.gz' => {'author' => 'PMAREK','description' => undef,'files' => [],'lines' => {'nonpod' => 622,'pod' => 169,'pod_errors' => 0,'total' => 791,'with_comments' => 31},'releases' => 2,'size' => {'packed' => 7375,'unpacked' => 21430},'testers' => {'fail' => 1},'uses' => ['Win32::API']},'Win32-MachineInfo-0.04.tar.gz' => {'author' => 'JMACFARLA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 283,'pod' => 111,'pod_errors' => 0,'total' => 394,'with_comments' => 15},'releases' => 3,'size' => {'packed' => 4853,'unpacked' => 14209},'testers' => {},'uses' => ['5.006','POSIX','Win32::TieRegistry','strict','warnings']},'Win32-MprApi-0.02.tar.gz' => {'author' => 'LMASARA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 372,'pod' => 195,'pod_errors' => 0,'total' => 567,'with_comments' => 175},'releases' => 2,'requires' => ['Win32-API-0.41.tar.gz'],'requires_module' => {'Win32::API' => '0.2'},'requires_recursive' => ['Win32-API-0.41.tar.gz'],'size' => {'packed' => 5948,'unpacked' => 28825},'testers' => {},'uses' => ['5.006','Carp','Exporter','Socket','Win32::API','enum','strict','warnings']},'Win32-MultiMedia-0.01.zip' => {'author' => 'THAMUS','description' => 'An interface for the MCI system on Win32','files' => ['Makefile.PL'],'lines' => {'nonpod' => 1021,'pod' => 525,'pod_errors' => 0,'total' => 1546,'with_comments' => 53},'releases' => 1,'size' => {'packed' => 91044,'unpacked' => 380000},'testers' => {'pass' => 1,'tests' => '0','unknown' => 6},'uses' => ['AutoLoader','DynaLoader','Exporter','constant','strict','vars']},'Win32-NetName-0.3.tar.gz' => {'author' => 'MSOUTHERN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 227,'pod' => 83,'pod_errors' => 0,'total' => 310,'with_comments' => 4},'releases' => 4,'requires' => ['Win32-API-0.41.tar.gz'],'requires_module' => {'Win32::API' => '0.41'},'requires_recursive' => ['Win32-API-0.41.tar.gz'],'size' => {'packed' => 4241,'unpacked' => 10565},'testers' => {},'uses' => ['File::Spec','Win32::API','Win32::Lanman']},'Win32-NetPacket-0.02.tar.gz' => {'author' => 'JLMOREL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 634,'pod' => 553,'pod_errors' => 0,'total' => 1187,'with_comments' => 53},'releases' => 2,'size' => {'packed' => 38285,'unpacked' => 255578},'testers' => {'fail' => 1,'tests' => '31'},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','constant','strict','warnings']},'Win32-NetSend-0.02.tar.gz' => {'author' => 'VSANCHEZ','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 84,'pod' => 82,'pod_errors' => 0,'total' => 166,'with_comments' => 11},'releases' => 3,'requires' => ['Win32-API-0.41.tar.gz'],'requires_module' => {'Win32::API' => '0.01'},'requires_recursive' => ['Win32-API-0.41.tar.gz'],'size' => {'packed' => 2534,'unpacked' => 6795},'testers' => {},'uses' => ['Carp','Fcntl','Win32','Win32::API','strict','warnings']},'Win32-OLE-0.1403.tar.gz' => {'author' => 'JDB','description' => 'Interface to OLE Automation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2275,'pod' => 2403,'pod_errors' => 0,'total' => 4678,'with_comments' => 122},'releases' => 6,'size' => {'packed' => 119639,'unpacked' => 436778},'testers' => {'fail' => 1,'tests' => '102'},'uses' => ['Carp','DynaLoader','Exporter','Win32::OLE::Lite','strict','vars']},'Win32-OLE-OPC-0.92.zip' => {'author' => 'MARTINTO','description' => 'Ole for Process Control Server Interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1237,'pod' => 391,'pod_errors' => 2,'total' => 1628,'with_comments' => 254},'releases' => 2,'size' => {'packed' => 28666,'unpacked' => 98900},'testers' => {},'uses' => ['Carp','Exporter','Sys::Hostname','Win32::OLE','Win32::OLE::Variant','Win32::WinError','strict','vars']},'Win32-Palm-Install-0.1.tar.gz' => {'author' => 'JOHANVDB','description' => 'Simple installer for palm.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 392,'pod' => 141,'pod_errors' => 0,'total' => 533,'with_comments' => 24},'releases' => 3,'size' => {'packed' => 4594,'unpacked' => 13723},'testers' => {},'uses' => ['Carp','File::Basename','File::Copy','Win32API::Registry','strict','vars']},'Win32-Palm-Install-0.3.tar.gz' => {'author' => 'JOHANVDB','description' => 'Simple installer for palm.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 391,'pod' => 141,'pod_errors' => 0,'total' => 532,'with_comments' => 24},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 47184,'unpacked' => 118118},'testers' => {},'uses' => ['Carp','File::Basename','File::Copy','File::Spec','Win32API::Registry','strict','vars']},'Win32-PerfCounter-0.01.tar.gz' => {'author' => 'CRENZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13,'pod' => 73,'pod_errors' => 1,'total' => 86,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 8307,'unpacked' => 21961},'testers' => {},'uses' => ['5.005','Exporter','XSLoader','strict','warnings']},'Win32-PingICMP-0.02.tar.gz' => {'author' => 'TEVERETT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 242,'pod' => 128,'pod_errors' => 0,'total' => 370,'with_comments' => 10},'releases' => 1,'requires' => ['Win32-API-0.41.tar.gz'],'requires_module' => {'Win32::API' => '0'},'requires_recursive' => ['Win32-API-0.41.tar.gz'],'size' => {'packed' => 6164,'unpacked' => 19496},'testers' => {},'uses' => ['Carp','Win32::API','strict','vars']},'Win32-ProcFarm-2.13.tar.gz' => {'author' => 'TEVERETT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1044,'pod' => 541,'pod_errors' => 1,'total' => 1585,'with_comments' => 103},'releases' => 4,'size' => {'packed' => 18371,'unpacked' => 71810},'testers' => {},'uses' => ['Data::Dumper','IO::Socket','Tk','Win32::Process','strict','vars']},'Win32-Process-Info-0.014.tar.gz' => {'author' => 'WYANT','description' => 'Get Win32 process information','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1620,'pod' => 414,'pod_errors' => 0,'total' => 2034,'with_comments' => 363},'releases' => 5,'requires' => ['libwin32-0.191.zip'],'requires_module' => {'Win32' => '0.18'},'requires_recursive' => ['libwin32-0.191.zip'],'size' => {'packed' => 23507,'unpacked' => 74130},'testers' => {},'uses' => ['Carp','File::Basename','File::Spec','Time::Local','UNIVERSAL','Win32','Win32::API','Win32::OLE','Win32::OLE::Const','Win32::OLE::Variant','Win32API::Registry','constant','strict','vars','warnings']},'Win32-RASE-1.01.tar.gz' => {'author' => 'MBLAZ','description' => 'Dialup entries and connections on Win32','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2225,'pod' => 1301,'pod_errors' => 1,'total' => 3526,'with_comments' => 249},'releases' => 1,'requires' => ['Win32-API-0.41.tar.gz','enum-1.016.tar.gz'],'requires_module' => {'Win32::API' => 0,'enum' => '1.014'},'requires_recursive' => ['Win32-API-0.41.tar.gz','enum-1.016.tar.gz'],'size' => {'packed' => 37164,'unpacked' => 129236},'testers' => {'fail' => 1},'uses' => ['5.000','Carp','Exporter','Win32::API','enum','strict','vars']},'Win32-Registry-File-1.10.tar.gz' => {'author' => 'AVATAR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 651,'pod' => 167,'pod_errors' => 0,'total' => 818,'with_comments' => 90},'releases' => 4,'requires' => ['Tie-IxHash-1.21.tar.gz'],'requires_module' => {'Tie::IxHash' => '1.21'},'requires_recursive' => ['Tie-IxHash-1.21.tar.gz'],'size' => {'packed' => 10773,'unpacked' => 33919},'testers' => {'pass' => 2},'uses' => ['AutoLoader','Exporter','Tie::IxHash','strict','vars']},'Win32-RemoteTOD-0.01.tar.gz' => {'author' => 'ARICH','description' => 'Get the time/timezone of remote Win32 server','files' => [],'lines' => {'nonpod' => 43,'pod' => 114,'pod_errors' => 0,'total' => 157,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3256,'unpacked' => 7202},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.006','AutoLoader','DynaLoader','Exporter','strict','warnings']},'Win32-SAPI4-0.01.tar.gz' => {'author' => 'JOUKE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 80,'pod' => 48,'pod_errors' => 0,'total' => 128,'with_comments' => 1},'releases' => 1,'requires' => ['Win32-OLE-0.1403.tar.gz'],'requires_module' => {'Win32::OLE' => 0,'Win32::OLE::Enum' => 0,'Win32::OLE::Variant' => 0},'requires_recursive' => ['Win32-OLE-0.1403.tar.gz'],'size' => {'packed' => 9612,'unpacked' => 26019},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Win32::OLE','vars']},'Win32-Scanner-EZTWAIN-0.01.tar.gz' => {'author' => 'LENNERTO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 185,'pod' => 164,'pod_errors' => 0,'total' => 349,'with_comments' => 46},'releases' => 1,'requires' => ['Win32-API-0.41.tar.gz'],'requires_module' => {'Win32::API' => '0.01'},'requires_recursive' => ['Win32-API-0.41.tar.gz'],'size' => {'packed' => 4149,'unpacked' => 11451},'testers' => {},'uses' => ['5','Carp','Exporter','Win32::API','strict','vars','warnings']},'Win32-Script-0.56.tar.gz' => {'author' => 'MAKAROW','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1513,'pod' => 781,'pod_errors' => 2,'total' => 2294,'with_comments' => 124},'releases' => 3,'size' => {'packed' => 25943,'unpacked' => 79492},'testers' => {'pass' => 2},'uses' => ['5.000','Carp','Cwd','Exporter','File::Compare','File::Copy','Net::Domain','Net::FTP','Net::SMTP','Sys::Hostname','Win32::API','Win32::TieRegistry','strict','vars']},'Win32-SerialPort-0.19.tar.gz' => {'author' => 'BBIRTH','description' => 'Win32 Serial functions/constants/interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4837,'pod' => 1293,'pod_errors' => 3,'total' => 6130,'with_comments' => 270},'releases' => 7,'size' => {'packed' => 120932,'unpacked' => 471766},'testers' => {'fail' => 1,'tests' => '1749'},'uses' => ['AutoLoader','Carp','Exporter','Win32','Win32::API','strict','vars']},'Win32-SharedFileOpen-3.13.tar.gz' => {'author' => 'SHAY','description' => 'Interface to Win32 sopen + fsopen functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 742,'pod' => 746,'pod_errors' => 0,'total' => 1488,'with_comments' => 75},'releases' => 10,'requires' => ['Errno-1.09.tar.gz','IO-1.20.tar.gz','Test-1.24.tar.gz','libwin32-0.191.zip','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Errno' => 0,'Exporter' => 0,'FileHandle' => 0,'IO::File' => 0,'IO::Handle' => 0,'Symbol' => 0,'Test' => 0,'Win32' => 0,'Win32::WinError' => 0},'requires_recursive' => ['Errno-1.09.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','libwin32-0.191.zip','perl-5.8.0.tar.gz'],'size' => {'packed' => 35034,'unpacked' => 144402},'testers' => {},'uses' => ['5.006','Carp','Exporter','Symbol','Win32','Win32::WinError','XSLoader','strict','warnings']},'Win32-ShellExt-0.1.zip' => {'author' => 'JBNIVOIT','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 3145,'pod' => 255,'pod_errors' => 0,'total' => 3400,'with_comments' => 430},'releases' => 1,'requires' => ['Win32-TieRegistry-0.24.zip'],'requires_module' => {'Win32::TieRegistry' => '0.23'},'requires_recursive' => ['Win32-TieRegistry-0.24.zip'],'size' => {'packed' => 116955,'unpacked' => 254636},'testers' => {},'uses' => ['5.006','Archive::Tar','Archive::Zip','Compress::Zlib','Config','Convert::BinHex','Getopt::Std','HTML::LinkExtor','Image::Magick','Image::Size','MD5','MIME::Base64','MP3::Info','PDF','Text::FIGlet','Text::PDF::File','Text::PDF::Utils','Text::Tabs','Text::Trie','URI::URL','Whitespace','Win32::Clipboard','Win32::TieRegistry','Win32API::File','XML::Canonical','constant','strict','warnings']},'Win32-Sound-0.45.zip' => {'author' => 'ACALPINI','description' => 'An extension to play with Windows sounds','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 285,'pod' => 293,'pod_errors' => 0,'total' => 578,'with_comments' => 56},'releases' => 1,'size' => {'packed' => 36254,'unpacked' => 106491},'testers' => {},'uses' => ['DynaLoader','Exporter']},'Win32-SoundRec-0.01.tar.gz' => {'author' => 'JOUKE','description' => 'Record audio on Win32 platforms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 75,'pod_errors' => 0,'total' => 242,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 10089,'unpacked' => 28906},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Win32::API::Prototype','strict','vars','warnings']},'Win32-SystemInfo-0.08.zip' => {'author' => 'CJOHNSTON','description' => 'Memory and Processor information','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 313,'pod' => 221,'pod_errors' => 1,'total' => 534,'with_comments' => 43},'releases' => 8,'requires' => ['Win32-API-0.41.tar.gz','Win32-TieRegistry-0.24.zip'],'requires_module' => {'Win32::API' => '0.4','Win32::TieRegistry' => '0.23'},'requires_recursive' => ['Win32-API-0.41.tar.gz','Win32-TieRegistry-0.24.zip'],'size' => {'packed' => 31653,'unpacked' => 82080},'testers' => {},'uses' => ['5.005_62','Win32::API','Win32::TieRegistry','constant','strict','vars','warnings']},'Win32-TieRegistry-0.24.zip' => {'author' => 'TYEMQ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2378,'pod' => 1442,'pod_errors' => 7,'total' => 3820,'with_comments' => 81},'releases' => 4,'size' => {'packed' => 43247,'unpacked' => 140326},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Tie::Hash','Win32API::Registry','strict','vars']},'Win32-TieRegistry-Dump-0.031.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 44,'pod_errors' => 0,'total' => 94,'with_comments' => 2},'releases' => 5,'requires' => ['Win32-TieRegistry-0.24.zip'],'requires_module' => {'Win32::TieRegistry' => '0.2'},'requires_recursive' => ['Win32-TieRegistry-0.24.zip'],'size' => {'packed' => 2383,'unpacked' => 4507},'testers' => {'pass' => 4},'uses' => ['5.006','Carp','Win32::TieRegistry','strict']},'Win32-TieRegistry-PMVersionInfo-0.2.tar.gz' => {'author' => 'LGODDARD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 185,'pod' => 154,'pod_errors' => 2,'total' => 339,'with_comments' => 15},'releases' => 3,'requires' => ['Win32-TieRegistry-0.24.zip'],'requires_module' => {'Win32::TieRegistry' => '0.2'},'requires_recursive' => ['Win32-TieRegistry-0.24.zip'],'size' => {'packed' => 5481,'unpacked' => 14129},'testers' => {'pass' => 2},'uses' => ['Carp','Win32::TieRegistry','strict']},'Win32-ToolHelp-0.2.tar.gz' => {'author' => 'PRANTL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 214,'pod' => 165,'pod_errors' => 0,'total' => 379,'with_comments' => 19},'releases' => 2,'size' => {'packed' => 8242,'unpacked' => 34742},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Win32-UTCFileTime-1.10.tar.gz' => {'author' => 'SHAY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 711,'pod' => 596,'pod_errors' => 0,'total' => 1307,'with_comments' => 46},'releases' => 2,'requires' => ['Test-1.24.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Exporter' => 0,'Test' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 30595,'unpacked' => 100369},'testers' => {},'uses' => ['5.006','Carp','Exporter','XSLoader','strict','warnings']},'Win32-Wallpaper-0.03.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 34,'pod_errors' => 0,'total' => 106,'with_comments' => 0},'releases' => 4,'testers' => {},'uses' => ['Exporter','File::Spec::Functions','Image::Size','Win32::API','Win32::TieRegistry','constant']},'Win32API-Const-0.011.tar.gz' => {'author' => 'ASPIDER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 155,'pod' => 89,'pod_errors' => 0,'total' => 244,'with_comments' => 27},'releases' => 1,'size' => {'packed' => 59104,'unpacked' => 198160},'testers' => {'fail' => 1,'tests' => '14'},'uses' => ['AutoLoader','Carp','DynaLoader','strict','vars']},'Win32API-File-0.08.zip' => {'author' => 'TYEMQ','description' => 'Win32 file/dir functions/constants','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1409,'pod' => 1443,'pod_errors' => 4,'total' => 2852,'with_comments' => 50},'releases' => 3,'size' => {'packed' => 61457,'unpacked' => 193630},'testers' => {'pass' => 1},'uses' => ['','Carp','Config','DynaLoader','Exporter','ExtUtils::MakeMaker','Fcntl','File::Basename','Win32API::File::cFile.pc','strict','vars']},'Win32API-MIDI-0.04.tar.gz' => {'author' => 'HAYASHI','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 267,'pod' => 326,'pod_errors' => 0,'total' => 593,'with_comments' => 36},'releases' => 2,'size' => {'packed' => 27323,'unpacked' => 125431},'testers' => {},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','strict','warnings']},'Win32API-MIDI-0.05.tar.gz' => {'author' => 'HAYASHI','description' => 'Perl extension for MS Windows 32bit MIDI API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2086,'pod' => 1272,'pod_errors' => 0,'total' => 3358,'with_comments' => 348},'releases' => 2,'size' => {'packed' => 52318,'unpacked' => 217263},'testers' => {'fail' => 1},'uses' => ['5.006','AutoLoader','Carp','DynaLoader','Exporter','Win32API::MIDI::Out','strict','vars','warnings']},'Win32API-Process-0.01.tar.gz' => {'author' => 'PRANTL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 190,'pod' => 233,'pod_errors' => 0,'total' => 423,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 16079,'unpacked' => 59975},'testers' => {},'uses' => ['5.006','DynaLoader','Exporter','strict','warnings']},'Win32API-ProcessStatus-0.01.tar.gz' => {'author' => 'PRANTL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 189,'pod' => 260,'pod_errors' => 0,'total' => 449,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 16799,'unpacked' => 69071},'testers' => {},'uses' => ['5.006','DynaLoader','Exporter','strict','warnings']},'Win32API-Registry-0.23.zip' => {'author' => 'TYEMQ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1151,'pod' => 989,'pod_errors' => 1,'total' => 2140,'with_comments' => 53},'releases' => 6,'size' => {'packed' => 50801,'unpacked' => 167547},'testers' => {},'uses' => ['Carp','Config','DynaLoader','Exporter','ExtUtils::MakeMaker','File::Basename','Win32API::Registry::cRegistry.pc','strict','vars']},'Win32API-Resources-0.06.tar.gz' => {'author' => 'BSTURNER','description' => undef,'files' => [],'lines' => {'nonpod' => 931,'pod' => 401,'pod_errors' => 0,'total' => 1332,'with_comments' => 217},'releases' => 1,'size' => {'packed' => 15452,'unpacked' => 76213},'testers' => {},'uses' => ['Win32','Win32::API','strict']},'Win32API-ToolHelp-0.02.tar.gz' => {'author' => 'PRANTL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 402,'pod' => 673,'pod_errors' => 0,'total' => 1075,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 26491,'unpacked' => 122035},'testers' => {},'uses' => ['5.006','DynaLoader','Exporter','strict','warnings']},'Win32Shortcut-0.03.zip' => {'author' => 'ACALPINI','description' => 'Manipulate Windows Shortcut files','files' => ['README'],'lines' => {'nonpod' => 352,'pod' => 0,'pod_errors' => 0,'total' => 352,'with_comments' => 81},'releases' => 2,'size' => {'packed' => 44819,'unpacked' => 140065},'testers' => {},'uses' => ['DynaLoader','Exporter']},'Winamp-Control-0.2.1.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 103,'pod' => 406,'pod_errors' => 0,'total' => 509,'with_comments' => 8},'releases' => 4,'requires' => ['Class-Maker-0.5.14.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Class::Maker' => 0,'LWP::Simple' => 0,'URI' => 0},'requires_recursive' => ['Class-Maker-0.5.14.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-Extended-0.06.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6346,'unpacked' => 19428},'testers' => {'pass' => 2},'uses' => ['5.006','Class::Maker','LWP::Simple','URI','strict','vars','warnings']},'Wizard-0.1003.tar.gz' => {'author' => 'AMAR','description' => 'A framework for building wizard-style applications.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 4307,'pod' => 891,'pod_errors' => 1,'total' => 5198,'with_comments' => 975},'releases' => 5,'size' => {'packed' => 37128,'unpacked' => 201197},'testers' => {'fail' => 2,'tests' => '35'},'uses' => ['$c_class','$file','5.004','File::Path','strict']},'Wizard-0.1006.tar.gz' => {'author' => 'JWIED','description' => 'A framework for building wizard-style applications.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 4319,'pod' => 918,'pod_errors' => 1,'total' => 5237,'with_comments' => 977},'releases' => 5,'size' => {'packed' => 29732,'unpacked' => 166834},'testers' => {'fail' => 1,'tests' => '37'},'uses' => ['$c_class','$file','5.004','File::Path','strict']},'Wizard-LDAP-0.1004.tar.gz' => {'author' => 'AMAR','description' => 'A package for automatically saved objects, that are stored in a LDAP server\'s directory structure.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1343,'pod' => 38,'pod_errors' => 0,'total' => 1381,'with_comments' => 56},'releases' => 7,'size' => {'packed' => 14759,'unpacked' => 66865},'testers' => {'pass' => 1},'uses' => ['Wizard','strict']},'Wizard-LDAP-0.1006.tar.gz' => {'author' => 'AMAR','description' => 'Administration interface for your LDAP server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1397,'pod' => 180,'pod_errors' => 0,'total' => 1577,'with_comments' => 58},'releases' => 7,'size' => {'packed' => 16992,'unpacked' => 75284},'testers' => {'fail' => 1,'tests' => '5'},'uses' => ['Wizard','strict']},'Wizard-LDAP-0.1008.tar.gz' => {'author' => 'JWIED','description' => 'Administration interface for your LDAP server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1509,'pod' => 572,'pod_errors' => 0,'total' => 2081,'with_comments' => 59},'releases' => 7,'size' => {'packed' => 20681,'unpacked' => 92111},'testers' => {'pass' => 1},'uses' => ['Wizard','strict']},'Wombat-0.7.1.tar.gz' => {'author' => 'IX','description' => 'a Perl servlet container','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13634,'pod' => 6748,'pod_errors' => 0,'total' => 20382,'with_comments' => 378},'releases' => 1,'requires' => ['Digest-1.02.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libservlet-0.9.2.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz'],'requires_module' => {'Digest' => 0,'File::Spec' => 0,'HTTP::Date' => 0,'HTTP::Headers' => 0,'MIME::Base64' => 0,'Servlet' => '0.9.2','URI' => 0,'URI::Escape' => 0,'XML::Parser::PerlSAX' => 0},'requires_recursive' => ['Class-Data-Inheritable-0.02.tar.gz','Devel-StackTrace-1.03.tar.gz','Digest-1.02.tar.gz','Digest-MD5-2.26.tar.gz','Exception-Class-1.14.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libservlet-0.9.2.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 109986,'unpacked' => 671366},'testers' => {'pass' => 2,'tests' => '0','unknown' => 3},'uses' => ['5.006','IO::Handle','Servlet::Http::HttpServlet','Servlet::Http::HttpServletRequest','Servlet::Http::HttpServletResponse','Servlet::Http::HttpSession','Servlet::RequestDispatcher','Servlet::ServletConfig','Servlet::ServletContext','Servlet::ServletRequest','Servlet::ServletResponse','Servlet::Util::Exception','Servlet::Util::Principal','Wombat::Util::XmlMapper::ObjectCreateAction','constant','fields','strict','warnings']},'WordNet-QueryData-1.28.tar.gz' => {'author' => 'JRENNIE','description' => 'direct perl interface to WordNet database','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1023,'pod' => 105,'pod_errors' => 0,'total' => 1128,'with_comments' => 200},'releases' => 20,'size' => {'packed' => 15404,'unpacked' => 56447},'testers' => {},'uses' => ['Carp','Exporter','FileHandle','strict','vars']},'WordNet-Similarity-0.05.tar.gz' => {'author' => 'SID','description' => 'Perl extensions for computing semantic relatedness of word senses defined in WordNet.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8439,'pod' => 1093,'pod_errors' => 0,'total' => 9532,'with_comments' => 1547},'releases' => 3,'requires' => ['WordNet-QueryData-1.28.tar.gz'],'requires_module' => {'WordNet::QueryData' => '1.26'},'requires_recursive' => ['WordNet-QueryData-1.28.tar.gz'],'size' => {'packed' => 745995,'unpacked' => 2424413},'testers' => {},'uses' => ['5.005','BerkeleyDB','Exporter','PDL','db','get','strict','string','vars']},'WordReturn-0.01.tar.gz' => {'author' => 'GRISKEY','description' => 'A Perl module that quickly identifies words and phrases in a document and returns the number of times they appear within that document.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 804,'pod' => 236,'pod_errors' => 0,'total' => 1040,'with_comments' => 165},'releases' => 1,'size' => {'packed' => 17147,'unpacked' => 59771},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'Wx-0.11.tar.gz' => {'author' => 'MBARBON','description' => 'interface to the wxWindows GUI toolkit','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 10636,'pod' => 1735,'pod_errors' => 0,'total' => 12371,'with_comments' => 1596},'releases' => 9,'size' => {'packed' => 249311,'unpacked' => 1173080},'testers' => {'fail' => 1},'uses' => ['$package_to_use','5.004','5.007003','Any_OS','Any_wx_config','Benchmark','Carp','Config','DataObjects','Devel::CoreStack','DynaLoader','Exporter','ExtUtils::Liblist','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Find','File::Path','File::Spec','FindBin','Getopt::Long','POSIX','Symbol','Test::Builder','Test::Harness::Assert','Test::Harness::Iterator','Test::Harness::Straps','Tie::Handle','W32','Wx','Wx::App','Wx::CheckListBox','Wx::DND','Wx::Dialog','Wx::DropSource','Wx::DropTarget','Wx::Event','Wx::FS','Wx::FileDropTarget','Wx::Grid','Wx::Html','Wx::Image','Wx::ImageList','Wx::Locale','Wx::MDI','Wx::Menu','Wx::Panel','Wx::PlFileSystemHandler','Wx::Print','Wx::RadioBox','Wx::Region','Wx::STC','Wx::Sizer','Wx::SplashScreen','Wx::Timer','Wx::XRC','Wx::_Constants','Wx::_Exp','Wx::_Functions','Wx::_Inheritance','Wx::_Ovl','XSLoader','strict','threads','threads::shared','vars','vmsish','wx']},'Wx-0.12.tar.gz' => {'author' => 'MBARBON','description' => 'interface to the wxWindows GUI toolkit','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 10055,'pod' => 1796,'pod_errors' => 1,'total' => 11851,'with_comments' => 1388},'releases' => 9,'size' => {'packed' => 291311,'unpacked' => 1386955},'testers' => {'fail' => 2,'tests' => '445'},'uses' => ['$package_to_use','5.004','5.007003','Benchmark','Carp','Config','Cwd','DataObjects','Devel::CoreStack','DynaLoader','Exporter','ExtUtils::Liblist','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Find','File::Path','File::Spec','FindBin','Getopt::Long','POSIX','Symbol','Test::Builder','Test::Harness::Assert','Test::Harness::Iterator','Test::Harness::Straps','Tie::Handle','Wx','Wx::App','Wx::CheckListBox','Wx::DND','Wx::Dialog','Wx::DocView','Wx::DropSource','Wx::DropTarget','Wx::Event','Wx::FS','Wx::FileDropTarget','Wx::Frame','Wx::Grid','Wx::Help','Wx::Html','Wx::ImageList','Wx::Locale','Wx::MDI','Wx::Menu','Wx::Panel','Wx::PlFileSystemHandler','Wx::Print','Wx::RadioBox','Wx::Region','Wx::STC','Wx::Sizer','Wx::Timer','Wx::XRC','Wx::_Constants','Wx::_Exp','Wx::_Functions','Wx::_Ovl','XSLoader','strict','threads','threads::shared','vars','vmsish','wx']},'Wx-0.13.tar.gz' => {'author' => 'MBARBON','description' => 'interface to the wxWindows GUI toolkit','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 7549,'pod' => 513,'pod_errors' => 2,'total' => 8062,'with_comments' => 1215},'releases' => 9,'requires' => ['Data-Dumper-2.101.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'File::Spec::Functions' => '0.01','Test::Harness' => '2.26','Test::More' => '0.45'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 264660,'unpacked' => 1320036},'testers' => {'pass' => 1},'uses' => ['$file','5.007003','Carp','Config','Data::Dumper','DataObjects','DynaLoader','Exporter','ExtUtils::Liblist','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Basename','File::Find','File::Path','File::Spec::Functions','File::Spec::Unix','FindBin','Getopt::Long','Symbol','Tie::Handle','Wx','Wx::App','Wx::CheckListBox','Wx::DND','Wx::Dialog','Wx::DropSource','Wx::DropTarget','Wx::Event','Wx::FS','Wx::FileDropTarget','Wx::Frame','Wx::Grid','Wx::Html','Wx::MDI','Wx::Menu','Wx::Panel','Wx::PlFileSystemHandler','Wx::Print','Wx::STC','Wx::Sizer','Wx::SplashScreen','Wx::XRC','Wx::_Constants','Wx::_Exp','Wx::_Functions','Wx::_Ovl','Wx::build::Config','Wx::build::Config::Any_OS','Wx::build::Config::Any_wx_config','Wx::build::Config::Win32','Wx::build::MakeMaker','Wx::build::MakeMaker::Any_OS','Wx::build::MakeMaker::Any_wx_config','Wx::build::MakeMaker::Hacks','Wx::build::MakeMaker::Win32','Wx::build::Options','Wx::build::Utils','XSLoader','strict','threads','threads::shared','vars']},'Wx-0.14.tar.gz' => {'author' => 'MBARBON','description' => 'interface to the wxWindows GUI toolkit','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 9563,'pod' => 575,'pod_errors' => 2,'total' => 10138,'with_comments' => 1629},'releases' => 9,'requires' => ['Data-Dumper-2.101.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'File::Spec::Functions' => '0.82','Test::Harness' => '2.26','Test::More' => '0.45'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 286000,'unpacked' => 1415009},'testers' => {},'uses' => ['$file','5.004','5.007003','Carp','Config','Data::Dumper','DynaLoader','Exporter','ExtUtils::Liblist','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Basename','File::Find','File::Path','File::Spec::Functions','File::Spec::Unix','FindBin','Getopt::Long','Symbol','Tie::Handle','Wx','Wx::App','Wx::Calendar','Wx::CheckListBox','Wx::DND','Wx::DateTime','Wx::Dialog','Wx::DropSource','Wx::DropTarget','Wx::Event','Wx::FS','Wx::FileDropTarget','Wx::Frame','Wx::Grid','Wx::Html','Wx::Locale','Wx::MDI','Wx::Menu','Wx::Panel','Wx::PlFileSystemHandler','Wx::Print','Wx::RadioBox','Wx::Region','Wx::STC','Wx::Sizer','Wx::SplashScreen','Wx::Timer','Wx::XRC','Wx::_Constants','Wx::_Exp','Wx::_Functions','Wx::_Ovl','Wx::build::Config','Wx::build::Config::Any_OS','Wx::build::Config::Any_wx_config','Wx::build::Config::Win32','Wx::build::MakeMaker','Wx::build::MakeMaker::Any_OS','Wx::build::MakeMaker::Any_wx_config','Wx::build::MakeMaker::Hacks','Wx::build::MakeMaker::Win32','Wx::build::Utils','XSLoader','strict','threads','threads::shared','vars']},'Wx-0.15.tar.gz' => {'author' => 'MBARBON','description' => 'interface to the wxWindows GUI toolkit','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 9410,'pod' => 717,'pod_errors' => 3,'total' => 10127,'with_comments' => 1621},'releases' => 9,'requires' => ['Data-Dumper-2.101.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'File::Spec::Functions' => '0.82','Test::Harness' => '2.26','Test::More' => '0.45'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 283798,'unpacked' => 1389846},'testers' => {},'uses' => ['$file','5.004','5.007003','Carp','Config','Data::Dumper','DataObjects','DynaLoader','Exporter','ExtUtils::Liblist','ExtUtils::MakeMaker','ExtUtils::Manifest','File::Basename','File::Find','File::Path','File::Spec::Functions','File::Spec::Unix','FindBin','Getopt::Long','Symbol','Tie::Handle','Wx::CheckListBox','Wx::Dialog','Wx::DropTarget','Wx::FileDropTarget','Wx::Frame','Wx::Locale','Wx::Panel','Wx::PlFileSystemHandler','Wx::RadioBox','Wx::Region','Wx::ScrolledWindow','Wx::Timer','Wx::Wx_Exp','Wx::_Constants','Wx::_Functions','Wx::build::Options','XSLoader','strict','threads','threads::shared','vars']},'Wx-ActiveX-0.04.tar.gz' => {'author' => 'GMPASSOS','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 517,'pod' => 782,'pod_errors' => 0,'total' => 1299,'with_comments' => 136},'releases' => 3,'size' => {'packed' => 43278,'unpacked' => 192780},'testers' => {'pass' => 1},'uses' => ['Exporter','Wx','strict','vars']},'Wx-Perl-TreeChecker-1.07.tar.gz' => {'author' => 'SIMONFLK','description' => 'Tree Control with checkbox functionality','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 630,'pod' => 168,'pod_errors' => 0,'total' => 798,'with_comments' => 35},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','Wx-0.15.tar.gz'],'requires_module' => {'Test::More' => '0.45','Wx' => '0.13'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Wx-0.15.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8571,'unpacked' => 32098},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','Wx','Wx::Event','constant','strict','vars']},'Wx-Sample-XS-0.01.tar.gz' => {'author' => 'MBARBON','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 11,'pod' => 0,'pod_errors' => 0,'total' => 11,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 804,'unpacked' => 839},'testers' => {},'uses' => ['DynaLoader','Wx','vars']},'Wx-WidgetMaker-0.01.tar.gz' => {'author' => 'SLANNING','description' => 'CGI.pm-like widget library for wxPerl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 757,'pod' => 439,'pod_errors' => 0,'total' => 1196,'with_comments' => 38},'releases' => 1,'requires' => ['Wx-0.15.tar.gz'],'requires_module' => {'Wx' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Wx-0.15.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9925,'unpacked' => 35458},'testers' => {},'uses' => ['5.006','Carp','Wx','Wx::Panel','constant','fields','named','strict','warnings']},'X-Osd-0.7.tar.gz' => {'author' => 'GOZER','description' => 'Perl glue to libxosd (X OnScreen Display)','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 136,'pod_errors' => 0,'total' => 269,'with_comments' => 13},'releases' => 5,'size' => {'packed' => 6442,'unpacked' => 17648},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars','warnings']},'X10-0.03.tar.gz' => {'author' => 'ROBF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2578,'pod' => 0,'pod_errors' => 0,'total' => 2578,'with_comments' => 118},'releases' => 2,'requires' => ['Astro-SunTime-0.01.tar.gz','Device-SerialPort-0.22.tar.gz','IO-1.20.tar.gz','Storable-2.07.tar.gz','Time-modules-2003.0211.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Astro::SunTime' => '0.01','Device::SerialPort' => 0,'File::Basename' => 0,'FileHandle' => 0,'IO::Select' => 0,'IO::Socket' => 0,'POSIX' => 0,'Storable' => 0,'Time::ParseDate' => 0},'requires_recursive' => ['Astro-SunTime-0.01.tar.gz','Device-SerialPort-0.22.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Time-modules-2003.0211.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15846,'unpacked' => 57408},'testers' => {'pass' => 1},'uses' => ['Astro::SunTime','Data::Dumper','Device::SerialPort','File::Basename','FileHandle','IO::Select','IO::Socket','POSIX','Storable','Time::ParseDate','strict','vars']},'X11-Fvwm-1.0.tar.gz' => {'author' => 'RJRAY','description' => 'interface to the FVWM window manager API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1838,'pod' => 1060,'pod_errors' => 0,'total' => 2898,'with_comments' => 546},'releases' => 5,'size' => {'packed' => 60359,'unpacked' => 229695},'testers' => {},'uses' => ['5.002','5.003','AutoLoader','Carp','Config','DynaLoader','Exporter','IO::File','Tk','X11::Xforms','strict','vars']},'X11-GUITest-0.15.tar.gz' => {'author' => 'CTRONDLP','description' => 'Provides GUI testing/interaction facilities. Developed by Dennis K. Paulsen','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 374,'pod' => 176,'pod_errors' => 0,'total' => 550,'with_comments' => 65},'releases' => 5,'size' => {'packed' => 39255,'unpacked' => 139637},'testers' => {'fail' => 1,'tests' => '18'},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars','warnings']},'X11-IdleTime-0.01.tar.gz' => {'author' => 'AWENDT','description' => 'Get the idle time of X11','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 44,'pod' => 27,'pod_errors' => 0,'total' => 71,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 1884,'unpacked' => 3205},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'X11-Keyboard-1.4.tar.gz' => {'author' => 'ECALDER','description' => 'Keyboard support functions for X11','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 81,'pod' => 71,'pod_errors' => 0,'total' => 152,'with_comments' => 12},'releases' => 1,'requires' => ['X11-Protocol-0.51.tar.gz'],'requires_module' => {'X11::Protocol' => '0.04'},'requires_recursive' => ['X11-Protocol-0.51.tar.gz'],'size' => {'packed' => 3106,'unpacked' => 6860},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['X11::Keysyms','strict','vars','warnings']},'X11-Motif-1.1b3.tar.gz' => {'author' => 'KENFOX','description' => 'X11 library interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13831,'pod' => 0,'pod_errors' => 0,'total' => 13831,'with_comments' => 392},'releases' => 1,'size' => {'packed' => 223641,'unpacked' => 1171874},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['Carp','Cwd','DynaLoader','File::Listing','Net::Domain','Net::FTP','X11::AthenaCons','X11::Toolkit','strict','vars']},'X11-Protocol-0.51.tar.gz' => {'author' => 'SMCCAM','description' => 'Perl module for the X Window System Protocol, version 11','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6136,'pod' => 1291,'pod_errors' => 0,'total' => 7427,'with_comments' => 527},'releases' => 5,'size' => {'packed' => 86381,'unpacked' => 355754},'testers' => {'pass' => 1},'uses' => ['5.000','Carp','Exporter','FileHandle','IO::Socket','Socket','Sys::Hostname','strict','vars']},'X11-SendEvent-1.3.tar.gz' => {'author' => 'ECALDER','description' => 'a module for sending events to X windows','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 124,'pod_errors' => 1,'total' => 284,'with_comments' => 18},'releases' => 1,'requires' => ['X11-Protocol-0.51.tar.gz'],'requires_module' => {'X11::Protocol' => '0.04'},'requires_recursive' => ['X11-Protocol-0.51.tar.gz'],'size' => {'packed' => 4414,'unpacked' => 10162},'testers' => {'fail' => 2},'uses' => ['X11::Keyboard','X11::Protocol','strict','vars','warnings']},'X11-Wcl-0.3.tar.gz' => {'author' => 'JHPB','description' => 'Interface to the Widget Creation Library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 451,'pod' => 147,'pod_errors' => 0,'total' => 598,'with_comments' => 146},'releases' => 4,'size' => {'packed' => 19614,'unpacked' => 80119},'testers' => {},'uses' => ['Carp']},'X12-0.01.tar.gz' => {'author' => 'PRASAD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 630,'pod' => 360,'pod_errors' => 0,'total' => 990,'with_comments' => 44},'releases' => 1,'size' => {'packed' => 18362,'unpacked' => 97127},'testers' => {'pass' => 1},'uses' => ['5.006','5.008','Exporter','X12','strict','warnings']},'X500-DN-0.28.tar.gz' => {'author' => 'RJOOP','description' => 'handle X.500 Relative Distinguished Names','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 210,'pod' => 157,'pod_errors' => 0,'total' => 367,'with_comments' => 18},'releases' => 9,'size' => {'packed' => 5163,'unpacked' => 15994},'testers' => {'fail' => 3,'pass' => 5,'tests' => '54'},'uses' => ['5.6.1','Carp','Parse::RecDescent','strict']},'X500-DN-Parser-1.15.tgz' => {'author' => 'RSAVAGE','description' => 'X500 Distinguished Name parser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 243,'pod' => 77,'pod_errors' => 0,'total' => 320,'with_comments' => 79},'releases' => 2,'size' => {'packed' => 5663,'unpacked' => 19087},'testers' => {'pass' => 1},'uses' => ['Exporter','strict','vars']},'XAO-Base-1.03.tar.gz' => {'author' => 'XAOINC','description' => 'generic interface for caching various data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2436,'pod' => 821,'pod_errors' => 1,'total' => 3257,'with_comments' => 336},'releases' => 4,'requires' => ['Error-0.15.tar.gz','Test-Unit-0.24.tar.gz'],'requires_module' => {'Error' => '0.13','Test::Unit' => '0.14'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','Devel-Symdump-2.03.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Unit-0.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 26173,'unpacked' => 92387},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['5.6.0','Carp','Error','Exporter','Test::Unit::TestCase','XAO::Base','XAO::Cache','XAO::Errors','XAO::Projects','XAO::SimpleHash','XAO::Utils','strict','testcases::base','vars']},'XAO-Base-1.04.tar.gz' => {'author' => 'XAOINC','description' => 'generic interface for caching various data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2445,'pod' => 886,'pod_errors' => 1,'total' => 3331,'with_comments' => 310},'releases' => 4,'requires' => ['Error-0.15.tar.gz','Test-Unit-0.24.tar.gz'],'requires_module' => {'Error' => '0.13','Test::Unit' => '0.14'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','Devel-Symdump-2.03.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Unit-0.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 26888,'unpacked' => 94597},'testers' => {'pass' => 3},'uses' => ['5.6.0','Carp','Error','Exporter','Test::Unit::TestCase','XAO::Base','XAO::Objects','strict','testcases::base','vars']},'XAO-Catalogs-1.01.tar.gz' => {'author' => 'XAOINC','description' => 'XAO catalog exchange module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1027,'pod' => 323,'pod_errors' => 0,'total' => 1350,'with_comments' => 108},'releases' => 1,'requires' => ['Test-Unit-0.24.tar.gz','XAO-FS-1.04.tar.gz','XAO-Web-1.04.tar.gz'],'requires_module' => {'Test::Unit' => '0.14','XAO::FS' => '1.03','XAO::Web' => '1.03'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Devel-Symdump-2.03.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Unit-0.24.tar.gz','Text-FormatTable-1.00.tar.gz','XAO-FS-1.04.tar.gz','XAO-Web-1.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15968,'unpacked' => 52461},'testers' => {'fail' => 1},'uses' => ['CGI','Error','IO::File','Test::Unit::TestCase','XAO::Base','XAO::Errors','XAO::Objects','XAO::Projects','XAO::SimpleHash','XAO::Utils','XML::DOM','constant','strict','testcases::base','vars']},'XAO-Commerce-1.0.tar.gz' => {'author' => 'XAOINC','description' => 'eCommerce Suite','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2335,'pod' => 521,'pod_errors' => 2,'total' => 2856,'with_comments' => 497},'releases' => 2,'requires' => ['Test-Unit-0.24.tar.gz','XAO-FS-1.04.tar.gz','XAO-Web-1.04.tar.gz'],'requires_module' => {'Test::Unit' => '0.14','XAO::FS' => '1.03','XAO::Web' => '1.03'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Devel-Symdump-2.03.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Unit-0.24.tar.gz','Text-FormatTable-1.00.tar.gz','XAO-FS-1.04.tar.gz','XAO-Web-1.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 925360,'unpacked' => 1390779},'testers' => {},'uses' => ['CGI','Digest::MD5','Error','IO::File','Test::Unit::TestCase','XAO::Base','XAO::Errors','XAO::Objects','XAO::Projects','XAO::Utils','XAO::Web','XML::DOM','constant','strict','testcases::base','vars']},'XAO-Commerce-1.01.tar.gz' => {'author' => 'XAOINC','description' => 'eCommerce Suite','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2208,'pod' => 378,'pod_errors' => 1,'total' => 2586,'with_comments' => 453},'releases' => 2,'requires' => ['Test-Unit-0.24.tar.gz','XAO-Catalogs-1.01.tar.gz','XAO-FS-1.04.tar.gz','XAO-Web-1.04.tar.gz'],'requires_module' => {'Test::Unit' => '0.14','XAO::DO::Catalogs' => '1.01','XAO::FS' => '1.04','XAO::Web' => '1.04'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Devel-Symdump-2.03.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Unit-0.24.tar.gz','Text-FormatTable-1.00.tar.gz','XAO-Catalogs-1.01.tar.gz','XAO-FS-1.04.tar.gz','XAO-Web-1.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 924062,'unpacked' => 1384399},'testers' => {'fail' => 1},'uses' => ['CGI','Digest::MD5','Error','IO::File','Test::Unit::TestCase','XAO::Base','XAO::Errors','XAO::Objects','XAO::Projects','XAO::Utils','XAO::Web','XML::DOM','constant','strict','testcases::base','vars']},'XAO-Content-1.0.tar.gz' => {'author' => 'XAOINC','description' => '- Dynamic content management for XAO::Web','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 985,'pod' => 368,'pod_errors' => 1,'total' => 1353,'with_comments' => 27},'releases' => 1,'requires' => ['XAO-FS-1.04.tar.gz','XAO-Web-1.04.tar.gz'],'requires_module' => {'XAO::FS' => '1.03','XAO::Web' => '1.03'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Devel-Symdump-2.03.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Unit-0.24.tar.gz','Text-FormatTable-1.00.tar.gz','XAO-FS-1.04.tar.gz','XAO-Web-1.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 22836,'unpacked' => 83438},'testers' => {},'uses' => ['CGI','Error','IO::File','Test::Unit::TestCase','XAO::Base','XAO::Errors','XAO::Objects','XAO::Projects','XAO::SimpleHash','XAO::Utils','strict','testcases::base','vars']},'XAO-FS-1.03.tar.gz' => {'author' => 'XAOINC','description' => 'XAO Foundation Server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5926,'pod' => 1642,'pod_errors' => 1,'total' => 7568,'with_comments' => 589},'releases' => 4,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Error-0.15.tar.gz','PodParser-1.23.tar.gz','Test-Unit-0.24.tar.gz'],'requires_module' => {'DBD::mysql' => '2.0414','DBI' => '1.13','Error' => '0.14','Pod::Usage' => '1.12','Test::Unit' => '0.14'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Devel-Symdump-2.03.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Unit-0.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 71626,'unpacked' => 292948},'testers' => {'fail' => 1},'uses' => ['Benchmark','DBD::mysql','DBI','Data::Dumper','Error','Test::Unit::TestCase','XAO::Errors','XAO::Objects','XAO::Utils','strict','testcases::base','vars']},'XAO-FS-1.04.tar.gz' => {'author' => 'XAOINC','description' => 'XAO Foundation Server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6311,'pod' => 1596,'pod_errors' => 0,'total' => 7907,'with_comments' => 613},'releases' => 4,'requires' => ['DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Error-0.15.tar.gz','PodParser-1.23.tar.gz','Test-Unit-0.24.tar.gz'],'requires_module' => {'DBD::mysql' => '2.0414','DBI' => '1.13','Error' => '0.14','Pod::Usage' => '1.12','Test::Unit' => '0.14'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Devel-Symdump-2.03.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Unit-0.24.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 79392,'unpacked' => 321575},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['DBI','Data::Dumper','Error','Test::Unit::TestCase','XAO::Errors','XAO::Objects','XAO::Utils','strict','testcases::base','vars']},'XAO-MySQL-1.0.tar.gz' => {'author' => 'XAOINC','description' => 'Fast MySQL driver for XAO::FS','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2228,'pod' => 108,'pod_errors' => 0,'total' => 2336,'with_comments' => 139},'releases' => 1,'requires' => ['Error-0.15.tar.gz','Test-Unit-0.24.tar.gz','XAO-FS-1.04.tar.gz'],'requires_module' => {'Error' => '0.14','Test::Unit' => '0.14','XAO::FS' => '1.04'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Devel-Symdump-2.03.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Unit-0.24.tar.gz','XAO-FS-1.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19663,'unpacked' => 91571},'testers' => {'fail' => 1},'uses' => ['Data::Dumper','Error','Test::Unit::TestCase','XAO::Objects','XAO::Utils','strict','vars']},'XAO-PodView-1.02.tar.gz' => {'author' => 'XAOINC','description' => 'POD files viewer for XAO::Web','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 856,'pod' => 192,'pod_errors' => 0,'total' => 1048,'with_comments' => 149},'releases' => 3,'requires' => ['IO-String-1.02.tar.gz','PodParser-1.23.tar.gz','XAO-Web-1.04.tar.gz'],'requires_module' => {'IO::String' => '1.01','Pod::Parser' => '1.12','XAO::Web' => '1.02'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Devel-Symdump-2.03.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','IO-String-1.02.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Unit-0.24.tar.gz','Text-FormatTable-1.00.tar.gz','XAO-FS-1.04.tar.gz','XAO-Web-1.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12965,'unpacked' => 40522},'testers' => {},'uses' => ['CGI','IO::File','IO::String','Pod::Parser','Test::Unit::TestCase','XAO::Base','XAO::Objects','XAO::Projects','XAO::Utils','XAO::Web','strict','testcases::base','vars']},'XAO-Web-1.04.tar.gz' => {'author' => 'XAOINC','description' => 'XAO Web Developer, dynamic content building suite','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7596,'pod' => 2948,'pod_errors' => 1,'total' => 10544,'with_comments' => 977},'releases' => 5,'requires' => ['Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','MIME-Lite-3.01.tar.gz','Text-FormatTable-1.00.tar.gz','XAO-FS-1.04.tar.gz'],'requires_module' => {'Digest::MD5' => '2.13','Error' => '0.13','MIME::Lite' => '2.117','Text::FormatTable' => '0.01','XAO::FS' => '1.04'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Fields-0.16.tar.gz','Class-Inner-0.1.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Devel-Symdump-2.03.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','MIME-Lite-3.01.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Test-Unit-0.24.tar.gz','Text-FormatTable-1.00.tar.gz','XAO-FS-1.04.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 91869,'unpacked' => 342024},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.005','CGI','Carp','Data::Dumper','Digest::MD5','DynaLoader','Error','Exporter','File::Basename','File::Copy','File::Path','IO::File','MIME::Lite','POSIX','Test::Unit::TestCase','Text::FormatTable','XAO::Base','XAO::Cache','XAO::Errors','XAO::Objects','XAO::Projects','XAO::SimpleHash','XAO::Utils','integer','strict','testcases::base','vars']},'XDR-0.03.tar.gz' => {'author' => 'GORD','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1184,'pod' => 0,'pod_errors' => 0,'total' => 1184,'with_comments' => 319},'releases' => 1,'size' => {'packed' => 34540,'unpacked' => 122076},'testers' => {'pass' => 6},'uses' => ['Carp','strict','vars']},'XML-ASX-0.01.tar.gz' => {'author' => 'ALLENDAY','description' => 'Create ASX (Advanced Streaming XML) files for Windows Media Player','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 422,'pod' => 272,'pod_errors' => 0,'total' => 694,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 5639,'unpacked' => 19678},'testers' => {'pass' => 4},'uses' => ['strict','vars']},'XML-AutoWriter-0.37.tar.gz' => {'author' => 'RBS','description' => 'DOCTYPE based XML output','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 2059,'pod' => 963,'pod_errors' => 3,'total' => 3022,'with_comments' => 184},'releases' => 6,'size' => {'packed' => 27888,'unpacked' => 102302},'testers' => {'fail' => 4,'pass' => 10,'tests' => '182'},'uses' => ['','Carp','Data::Dumper','Fcntl','Symbol','UNIVERSAL','fields','strict','vars']},'XML-BMEcat-0.55.tar.gz' => {'author' => 'FPREICH','description' => 'Perl extension for generating BMEcat-XML','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 966,'pod' => 409,'pod_errors' => 2,'total' => 1375,'with_comments' => 31},'releases' => 2,'size' => {'packed' => 9047,'unpacked' => 36268},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['IO::File','XML::Generator','strict','vars']},'XML-Beautify-0.05.tar.gz' => {'author' => 'TBOLIOLI','description' => 'Beautifies XML output from XML::Writer (soon to do any XML).','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 566,'pod' => 160,'pod_errors' => 0,'total' => 726,'with_comments' => 123},'releases' => 5,'requires' => ['Log-AndError-0.99.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Log::AndError' => '0.99','XML::Parser::Expat' => 2},'requires_recursive' => ['Log-AndError-0.99.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 7685,'unpacked' => 29945},'testers' => {'pass' => 5},'uses' => ['5.005','5.6.0','Log::AndError','Log::AndError::Constants','XML::Parser::Expat','constant','strict','warnings']},'XML-CSV-0.15.tar.gz' => {'author' => 'ISTERIN','description' => 'Transform comma separated values to XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 394,'pod' => 109,'pod_errors' => 0,'total' => 503,'with_comments' => 46},'releases' => 6,'size' => {'packed' => 7419,'unpacked' => 21894},'testers' => {'fail' => 4,'pass' => 4},'uses' => ['5.004','AutoLoader','Carp','DynaLoader','Exporter','Text::CSV_XS','strict','vars']},'XML-Canonical-0.10.tar.gz' => {'author' => 'TJMATHER','description' => 'Perl wrapper to libxml2 Canonical XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 56,'pod' => 65,'pod_errors' => 0,'total' => 121,'with_comments' => 0},'releases' => 6,'requires' => ['XML-GDOME-0.82.tar.gz'],'requires_module' => {'XML::GDOME' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-GDOME-0.82.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6243,'unpacked' => 14346},'testers' => {},'uses' => ['DynaLoader','Exporter','XML::GDOME','strict','vars','warnings']},'XML-Catalog-0.02.tar.gz' => {'author' => 'EBOHLMAN','description' => 'Resolve public identifiers and remap system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 304,'pod' => 64,'pod_errors' => 0,'total' => 368,'with_comments' => 25},'releases' => 2,'size' => {'packed' => 3965,'unpacked' => 12005},'testers' => {'fail' => 3,'pass' => 8},'uses' => ['LWP::Simple','Text::ParseWords','URI::URL','XML::Parser','strict','vars']},'XML-Checker-0.13.tar.gz' => {'author' => 'TJMATHER','description' => 'Validates XML against DTD','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2197,'pod' => 656,'pod_errors' => 0,'total' => 2853,'with_comments' => 195},'releases' => 5,'requires' => ['XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','libxml-perl-0.07.tar.gz'],'requires_module' => {'XML::DOM' => '1.29','XML::Parser' => '2.30','XML::Parser::PerlSAX' => '0.07'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 34012,'unpacked' => 143403},'testers' => {'fail' => 3,'pass' => 2},'uses' => ['LWP::UserAgent','XML::Checker::Parser','XML::DOM','XML::Parser','XML::RegExp','strict','vars','warnings']},'XML-Clean-1.04.tar.gz' => {'author' => 'PKUBANEK','description' => 'XMLized text.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 231,'pod' => 65,'pod_errors' => 0,'total' => 296,'with_comments' => 26},'releases' => 2,'size' => {'packed' => 3811,'unpacked' => 8348},'testers' => {'pass' => 7},'uses' => ['Exporter','strict','vars','warnings']},'XML-Comma-1.17.tar.gz' => {'author' => 'KWINDLA','description' => 'A framework for structured document manipulation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14329,'pod' => 230,'pod_errors' => 0,'total' => 14559,'with_comments' => 3039},'releases' => 6,'requires' => ['Crypt-CBC-2.08.tar.gz','Crypt-Twofish-2.12.tar.gz','Digest-HMAC-1.01.tar.gz','Inline-0.44.tar.gz','Lingua-Stem-0.60.tar.gz','Math-BaseCalc-1.011.tar.gz','PAR-0.69.tar.gz','Proc-ProcessTable-0.38.tar.gz','String-CRC-1.0.tar.gz'],'requires_module' => {'Crypt::CBC' => 0,'Crypt::Twofish' => 0,'Digest::HMAC_MD5' => 0,'Inline' => 0,'Lingua::Stem' => 0,'Math::BaseCalc' => 0,'PAR' => 0,'Proc::ProcessTable' => 0,'String::CRC' => 0},'requires_recursive' => ['Crypt-CBC-2.08.tar.gz','Crypt-Twofish-2.12.tar.gz','Data-Dumper-2.101.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','Math-BaseCalc-1.011.tar.gz','PAR-0.69.tar.gz','Parse-RecDescent-1.94.tar.gz','Proc-ProcessTable-0.38.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Storable-2.07.tar.gz','String-CRC-1.0.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-German-0.03.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 315972,'unpacked' => 953426},'testers' => {'fail' => 3,'tests' => '15'},'uses' => ['Apache::Constants','Apache::Request','Archive::Zip','Carp','Compress::Zlib','Crypt::CBC','Crypt::SSLeay','Crypt::Twofish','DBI','Data::Dumper','Digest::HMAC_MD5','Digest::MD5','Exporter','File::Copy','File::Find','File::Path','File::Spec','File::Temp','HTML::Mason::Resolver','HTTP::Request::Common','LWP::UserAgent','Lingua::Stem','MIME::Base64','Math::BaseCalc','PAR','Parse::RecDescent','Proc::ProcessTable','Storable','Sys::Hostname','Unicode::String','XML::Comma','XML::Comma::AbstractElement','XML::Comma::BlobElement','XML::Comma::Configable','XML::Comma::Configuration','XML::Comma::Def','XML::Comma::DefManager','XML::Comma::Doc','XML::Comma::Element','XML::Comma::Hookable','XML::Comma::Indexing::Clean','XML::Comma::Indexing::Index','XML::Comma::Indexing::Iterator','XML::Comma::Methodable','XML::Comma::NestedElement','XML::Comma::Pkg::ModuleConfiguration','XML::Comma::Pkg::Textsearch::Preprocessor','XML::Comma::Pkg::Textsearch::Preprocessor_En','XML::Comma::SQL::Base','XML::Comma::SQL::DBH_User','XML::Comma::SQL::Lock','XML::Comma::Storage::FileUtil','XML::Comma::Storage::Iterator','XML::Comma::Storage::Location::Abstract_file','XML::Comma::Storage::Location::GMT_3layer_dir','XML::Comma::Storage::Store','XML::Comma::Storage::Util','XML::Comma::Util','XML::Parser::PerlSAX','integer','locale','strict','vars']},'XML-Comma-1.18.tar.gz' => {'author' => 'KWINDLA','description' => 'A framework for structured document manipulation','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 14474,'pod' => 230,'pod_errors' => 0,'total' => 14704,'with_comments' => 3047},'releases' => 6,'requires' => ['Crypt-CBC-2.08.tar.gz','Crypt-Twofish-2.12.tar.gz','Digest-HMAC-1.01.tar.gz','Inline-0.44.tar.gz','Lingua-Stem-0.60.tar.gz','Math-BaseCalc-1.011.tar.gz','PAR-0.69.tar.gz','Proc-ProcessTable-0.38.tar.gz','String-CRC-1.0.tar.gz'],'requires_module' => {'Crypt::CBC' => 0,'Crypt::Twofish' => 0,'Digest::HMAC_MD5' => 0,'Inline' => 0,'Lingua::Stem' => 0,'Math::BaseCalc' => 0,'PAR' => 0,'Proc::ProcessTable' => 0,'String::CRC' => 0},'requires_recursive' => ['Crypt-CBC-2.08.tar.gz','Crypt-Twofish-2.12.tar.gz','Data-Dumper-2.101.tar.gz','Digest-HMAC-1.01.tar.gz','Digest-MD5-2.26.tar.gz','Digest-SHA1-2.04.tar.gz','File-Spec-0.82.tar.gz','Inline-0.44.tar.gz','Lingua-PT-Stemmer-0.01.tar.gz','Lingua-Stem-0.60.tar.gz','Lingua-Stem-It-0.01.tar.gz','Lingua-Stem-Snowball-Da-1.01.tar.gz','Math-BaseCalc-1.011.tar.gz','PAR-0.69.tar.gz','Parse-RecDescent-1.94.tar.gz','Proc-ProcessTable-0.38.tar.gz','Snowball-Norwegian-1.0.tar.gz','Snowball-Swedish-1.01.tar.gz','Storable-2.07.tar.gz','String-CRC-1.0.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-German-0.03.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 322138,'unpacked' => 961386},'testers' => {'fail' => 2,'tests' => '15'},'uses' => ['Apache::Constants','Apache::File','Apache::Request','Apache::Util','Archive::Zip','Carp','Compress::Zlib','Crypt::CBC','Crypt::SSLeay','Crypt::Twofish','DBI','Data::Dumper','Digest::HMAC_MD5','Digest::MD5','Exporter','File::Copy','File::Find','File::Path','File::Spec','File::Temp','HTML::Mason::ComponentSource','HTML::Mason::Resolver','HTTP::Request::Common','LWP::UserAgent','Lingua::Stem','MIME::Base64','Math::BaseCalc','PAR','Parse::RecDescent','Proc::ProcessTable','Storable','Sys::Hostname','Unicode::String','XML::Comma::Bootstrap','XML::Parser::PerlSAX','integer','locale','strict','vars','warnings']},'XML-CommonNS-0.01.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 54,'pod_errors' => 0,'total' => 130,'with_comments' => 3},'releases' => 2,'requires' => ['XML-NamespaceFactory-0.01.tar.gz'],'requires_module' => {'XML::NamespaceFactory' => 0},'requires_recursive' => ['XML-NamespaceFactory-0.01.tar.gz'],'testers' => {'pass' => 2},'uses' => ['XML::NamespaceFactory','strict','vars']},'XML-Conf-0.02.tar.gz' => {'author' => 'SCHOP','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 167,'pod' => 0,'pod_errors' => 0,'total' => 167,'with_comments' => 0},'releases' => 2,'requires' => ['XML-Simple-2.08.tar.gz'],'requires_module' => {'XML::Simple' => '1.04'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz'],'size' => {'packed' => 1995,'unpacked' => 4325},'testers' => {'fail' => 3},'uses' => ['Tie::DeepTied','Tie::Hash','XML::Simple','strict','vars']},'XML-Config-0.2.tar.gz' => {'author' => 'MATTMK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 54,'pod_errors' => 1,'total' => 179,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 8190,'unpacked' => 22226},'testers' => {'pass' => 7},'uses' => ['XML::Parser','vars']},'XML-DB.tar.gz' => {'author' => 'GSEAMAN','description' => 'Abstract class for extension by XML:SimpleDB drivers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2596,'pod' => 1885,'pod_errors' => 0,'total' => 4481,'with_comments' => 72},'releases' => 1,'requires' => ['Getopt-Long-2.33.tar.gz','MIME-Base64-2.20.tar.gz','RPC-XML-0.53.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-XUpdate-LibXML-0.4.0.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Getopt::Long' => 0,'MIME::Base64' => 0,'RPC::XML' => 0,'Term::ReadLine' => 0,'XML::LibXML' => '1.53','XML::LibXML::Common' => '0.12','XML::LibXSLT' => '1.49','XML::Normalize::LibXML' => 0,'XML::XUpdate::LibXML' => '0.3'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','RPC-XML-0.53.tar.gz','URI-1.24.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXML-Iterator-1.00.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-NodeFilter-0.01.tar.gz','XML-Parser-2.31.tar.gz','XML-SAX-0.12.tar.gz','XML-XUpdate-LibXML-0.4.0.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 35683,'unpacked' => 138253},'testers' => {},'uses' => ['Carp','Fcntl','File::Path','Getopt::Long','MIME::Base64','RPC::XML','RPC::XML::Client','Term::ReadLine','XML::LibXML','XML::LibXML::Common','XML::Normalize::LibXML','XML::XUpdate::LibXML','strict','vars']},'XML-DOM-1.42.tar.gz' => {'author' => 'TJMATHER','description' => 'Implements Level 1 of W3\'s DOM','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6483,'pod' => 1768,'pod_errors' => 0,'total' => 8251,'with_comments' => 690},'releases' => 25,'requires' => ['XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz'],'requires_module' => {'LWP::UserAgent' => '0','XML::Parser' => '2.30','XML::Parser::PerlSAX' => '0.07','XML::RegExp' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 116617,'unpacked' => 421062},'testers' => {'fail' => 5,'pass' => 1,'tests' => '129'},'uses' => ['Carp','Exporter','FileHandle','LWP::UserAgent','XML::DOM::DOMException','XML::DOM::NamedNodeMap','XML::DOM::NodeList','XML::Handler::BuildDOM','XML::Parser','XML::RegExp','bytes','strict','vars']},'XML-DOMHandler-1.0.tar.gz' => {'author' => 'ERIKRAY','description' => 'Implements a call-back interface to DOM.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 251,'pod' => 105,'pod_errors' => 1,'total' => 356,'with_comments' => 44},'releases' => 1,'size' => {'packed' => 3708,'unpacked' => 10491},'testers' => {'pass' => 2},'uses' => ['Exporter','strict','vars']},'XML-DT-0.24.1.tar.gz' => {'author' => 'JJOAO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 714,'pod' => 310,'pod_errors' => 0,'total' => 1024,'with_comments' => 134},'releases' => 11,'size' => {'packed' => 22335,'unpacked' => 74318},'testers' => {'pass' => 4},'uses' => ['Data::Dumper','LWP::Simple','XML::LibXML','XML::Parser','bytes','vars']},'XML-DTDParser-1.7.tar.gz' => {'author' => 'JENDA','description' => 'quick and dirty DTD parser Version 1.7','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 268,'pod' => 90,'pod_errors' => 0,'total' => 358,'with_comments' => 19},'releases' => 4,'size' => {'packed' => 6033,'unpacked' => 19898},'testers' => {'pass' => 2},'uses' => ['Exporter','FileHandle','strict']},'XML-Database-0.01.tar.gz' => {'author' => 'ISTERIN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 353,'pod' => 112,'pod_errors' => 0,'total' => 465,'with_comments' => 49},'releases' => 1,'size' => {'packed' => 3884,'unpacked' => 13584},'testers' => {'fail' => 2},'uses' => ['5.006','AutoLoader','Carp','Exporter','File::Copy','File::Path','lib','strict','warnings']},'XML-DifferenceMarkup-0.09.tar.gz' => {'author' => 'VBAR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 903,'pod' => 96,'pod_errors' => 0,'total' => 999,'with_comments' => 97},'releases' => 9,'requires' => ['Algorithm-Diff-1.15.tar.gz','XML-LibXML-1.54.tar.gz'],'requires_module' => {'Algorithm::Diff' => '1.15','XML::LibXML' => '1.52'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12340,'unpacked' => 53973},'testers' => {},'uses' => ['5.006','Algorithm::Diff','Exporter','XML::LibXML','strict','vars','warnings']},'XML-Directory-0.99.tar.gz' => {'author' => 'PCIMPRICH','description' => 'returns a content of directory as XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1262,'pod' => 606,'pod_errors' => 0,'total' => 1868,'with_comments' => 46},'releases' => 22,'size' => {'packed' => 35962,'unpacked' => 288085},'testers' => {'pass' => 8},'uses' => ['5.005_03','Apache::Constants','Carp','Cwd','DirHandle','Exporter','RDF::Notation3','RDF::Notation3::PrefTriples','XML::SAX::Base','strict','vars']},'XML-DocStats-0.01.tar.gz' => {'author' => 'ALDICKEY','description' => 'produce a simple analysis of an XML document','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2179,'pod' => 1164,'pod_errors' => 0,'total' => 3343,'with_comments' => 101},'releases' => 1,'requires' => ['XML-Parser-2.31.tar.gz','libxml-perl-0.07.tar.gz'],'requires_module' => {'XML::Parser' => '2.3','XML::Parser::PerlSAX' => '0.07'},'requires_recursive' => ['XML-Parser-2.31.tar.gz','libxml-perl-0.07.tar.gz'],'size' => {'packed' => 28160,'unpacked' => 95281},'testers' => {'pass' => 4},'uses' => ['Carp','Data::Dumper','XML::Parser','XML::Parser::PerlSAX','strict','vars']},'XML-Driver-HTML-0.06.tar.gz' => {'author' => 'KRAEHE','description' => 'SAX Driver for non wellformed HTML.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 160,'pod' => 126,'pod_errors' => 0,'total' => 286,'with_comments' => 10},'releases' => 3,'requires' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','libxml-perl-0.07.tar.gz'],'requires_module' => {'Digest::MD5' => '2.09','HTML::Parser' => '3.07','HTML::TreeBuilder' => '2.96','IO::File' => '1.06','XML::Handler::YAWriter' => '0.2','XML::Parser::PerlSAX' => '0.06'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','XML-Parser-2.31.tar.gz','libxml-perl-0.07.tar.gz'],'size' => {'packed' => 7000,'unpacked' => 20878},'testers' => {'pass' => 4},'uses' => ['HTML::TreeBuilder','strict','vars']},'XML-Dumper-0.4.tar.gz' => {'author' => 'EISEN','description' => 'Converts XML from/to Perl code','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 293,'pod' => 57,'pod_errors' => 0,'total' => 350,'with_comments' => 34},'releases' => 11,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.16'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 4732,'unpacked' => 12173},'testers' => {'pass' => 13},'uses' => ['Data::Dumper','XML::Parser','strict','vars']},'XML-EP-0.01.tar.gz' => {'author' => 'JWIED','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1033,'pod' => 64,'pod_errors' => 0,'total' => 1097,'with_comments' => 47},'releases' => 1,'requires' => ['CGI.pm-2.98.tar.gz','Data-Dumper-2.101.tar.gz','IO-stringy-2.108.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'CGI' => 0,'Data::Dumper' => 0,'IO::Scalar' => 0,'XML::DOM' => 0,'XML::Parser' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-stringy-2.108.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14512,'unpacked' => 48671},'testers' => {'fail' => 4,'tests' => '30'},'uses' => ['Exporter','XML::DOM','strict','utf','vars']},'XML-EasyOBJ-1.12.tar.gz' => {'author' => 'RHANSON','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 466,'pod' => 327,'pod_errors' => 1,'total' => 793,'with_comments' => 12},'releases' => 4,'size' => {'packed' => 26334,'unpacked' => 91271},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['XML::DOM','strict','vars']},'XML-Edifact-0.46.tar.gz' => {'author' => 'KRAEHE','description' => 'Scripts for translating EDIFACT into XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 634,'pod' => 73,'pod_errors' => 0,'total' => 707,'with_comments' => 39},'releases' => 12,'requires' => ['Digest-MD5-2.26.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Digest::MD5' => '2.09','XML::Parser' => '2.27'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 298794,'unpacked' => 1485431},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','Fcntl','SDBM_File','XML::Edifact::Config','XML::Parser','bytes','strict','vars']},'XML-Encoding-1.01.tar.gz' => {'author' => 'COOPERCL','description' => 'Parses encoding map XML files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 220,'pod' => 50,'pod_errors' => 0,'total' => 270,'with_comments' => 23},'releases' => 2,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.18'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 189564,'unpacked' => 1140643},'testers' => {'fail' => 1,'pass' => 5},'uses' => ['XML::Parser','strict','vars']},'XML-Excel-0.02.tar.gz' => {'author' => 'ISTERIN','description' => 'Transform Excel spreadsheet data into XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 401,'pod' => 109,'pod_errors' => 0,'total' => 510,'with_comments' => 44},'releases' => 2,'requires' => ['Spreadsheet-ParseExcel-0.2602.tar.gz'],'requires_module' => {'Spreadsheet::ParseExcel' => '0.2'},'requires_recursive' => ['IO-stringy-2.108.tar.gz','OLE-Storage_Lite-0.11.tar.gz','Spreadsheet-ParseExcel-0.2602.tar.gz'],'size' => {'packed' => 10605,'unpacked' => 58325},'testers' => {'pass' => 6},'uses' => ['5.004','AutoLoader','Carp','DynaLoader','Exporter','Spreadsheet::ParseExcel','strict','vars']},'XML-FOAF-0.02.tar.gz' => {'author' => 'BTROTT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 236,'pod' => 125,'pod_errors' => 0,'total' => 361,'with_comments' => 10},'releases' => 2,'size' => {'packed' => 5471,'unpacked' => 14412},'testers' => {'pass' => 2},'uses' => ['','Crypt::OpenPGP','HTML::Parser','LWP::Simple','LWP::UserAgent','RDF::Core::Model','RDF::Core::Model::Parser','RDF::Core::Resource','RDF::Core::Storage::Memory','strict','vars']},'XML-Filter-BufferText-1.01.tar.gz' => {'author' => 'RBERJON','description' => 'Filter to put all characters() in one event','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 61,'pod' => 36,'pod_errors' => 0,'total' => 97,'with_comments' => 15},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz'],'requires_module' => {'Test::More' => '0.40','XML::SAX' => '0.04','XML::SAX::Base' => '1.03'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2269,'unpacked' => 5047},'testers' => {'pass' => 2},'uses' => ['XML::SAX::Base','strict','vars']},'XML-Filter-Cache-0.03.tar.gz' => {'author' => 'MSERGEANT','description' => 'a SAX2 recorder/playback mechanism','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 246,'pod' => 67,'pod_errors' => 0,'total' => 313,'with_comments' => 5},'releases' => 3,'requires' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'Digest::MD5' => 2,'File::Spec' => '0.8','Storable' => 1,'XML::SAX' => '0.08','XML::SAX::Writer' => '0.39'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 26556,'unpacked' => 82706},'testers' => {'fail' => 1,'pass' => 2,'tests' => '6'},'uses' => ['Digest::MD5','XML::SAX::Base','strict','vars']},'XML-Filter-DOMFilter-LibXML-0.01.tar.gz' => {'author' => 'PAJAS','description' => 'SAX Filter allowing DOM processing of selected subtrees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 226,'pod' => 88,'pod_errors' => 0,'total' => 314,'with_comments' => 12},'releases' => 1,'requires' => ['XML-LibXML-1.54.tar.gz'],'requires_module' => {'XML::LibXML' => '1.53'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4170,'unpacked' => 10780},'testers' => {'pass' => 1},'uses' => ['5.006','XML::LibXML::SAX::Builder','XML::LibXML::SAX::Parser','strict']},'XML-Filter-DataIndenter-0.1.tar.gz' => {'author' => 'RBS','description' => 'SAX2 Indenter for data oriented XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 180,'pod' => 59,'pod_errors' => 0,'total' => 239,'with_comments' => 5},'releases' => 1,'requires' => ['XML-SAX-0.12.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'XML::SAX::PurePerl' => 0,'XML::SAX::Writer' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3181,'unpacked' => 9275},'testers' => {'fail' => 1},'uses' => ['XML::SAX::Base','XML::SAX::EventMethodMaker','strict']},'XML-Filter-DetectWS-0.01.tar.gz' => {'author' => 'TJMATHER','description' => 'PerlSAX filter detects ignorable whitespace','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 541,'pod' => 86,'pod_errors' => 0,'total' => 627,'with_comments' => 68},'releases' => 1,'requires' => ['XML-Filter-SAXT-0.01.tar.gz'],'requires_module' => {'XML::Filter::SAXT' => 0},'requires_recursive' => ['XML-Filter-SAXT-0.01.tar.gz'],'size' => {'packed' => 5932,'unpacked' => 18598},'testers' => {'pass' => 7},'uses' => ['XML::Filter::SAXT','strict','vars']},'XML-Filter-Digest-0.06.tar.gz' => {'author' => 'KRAEHE','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 268,'pod' => 161,'pod_errors' => 0,'total' => 429,'with_comments' => 15},'releases' => 4,'requires' => ['Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','XML-XPath-1.13.tar.gz','libxml-perl-0.07.tar.gz'],'requires_module' => {'Digest::MD5' => '2.09','IO::File' => 1,'XML::Handler::YAWriter' => '0.1','XML::Parser::PerlSAX' => '0.06','XML::XPath' => '0.51'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','IO-1.20.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','XML-Parser-2.31.tar.gz','XML-XPath-1.13.tar.gz','libxml-perl-0.07.tar.gz'],'size' => {'packed' => 29808,'unpacked' => 137874},'testers' => {'pass' => 3},'uses' => ['XML::Parser::PerlSAX','XML::XPath','XML::XPath::Builder','XML::XPath::Node','XML::XPath::Node::Element','vars']},'XML-Filter-Dispatcher-0.51.tar.gz' => {'author' => 'RBS','description' => 'Path based event dispatching with DOM support','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 8210,'pod' => 1449,'pod_errors' => 1,'total' => 9659,'with_comments' => 1412},'releases' => 13,'requires' => ['XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Machines-0.4.tar.gz'],'requires_module' => {'XML::NamespaceSupport' => 0,'XML::SAX::Base' => 0,'XML::SAX::EventMethodMaker' => 0,'XML::SAX::ParserFactory' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Machines-0.4.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 85056,'unpacked' => 378121},'testers' => {'pass' => 1},'uses' => ['5.004','Carp','Devel::TraceSAX','Exporter','GraphViz','POSIX','UNIVERSAL','XML::Filter::Dispatcher::Ops','XML::Filter::Dispatcher::Parser','XML::Filter::Dispatcher::Runtime','XML::NamespaceSupport','XML::SAX::Base','XML::SAX::EventMethodMaker','constant','strict','vars']},'XML-Filter-Dispatcher-0.52.tar.gz' => {'author' => 'RBS','description' => 'Path based event dispatching with DOM support','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 8511,'pod' => 1502,'pod_errors' => 1,'total' => 10013,'with_comments' => 1459},'releases' => 13,'requires' => ['XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Machines-0.4.tar.gz'],'requires_module' => {'XML::NamespaceSupport' => 0,'XML::SAX::Base' => 0,'XML::SAX::EventMethodMaker' => 0,'XML::SAX::ParserFactory' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Machines-0.4.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 88099,'unpacked' => 389221},'testers' => {'pass' => 1},'uses' => ['5.004','Carp','Devel::TraceSAX','Exporter','GraphViz','POSIX','UNIVERSAL','XML::Filter::Dispatcher::AsHashHandler','XML::Filter::Dispatcher::AsStructHandler','XML::Filter::Dispatcher::Runtime','XML::NamespaceSupport','XML::SAX::Base','XML::SAX::EventMethodMaker','constant','strict','vars']},'XML-Filter-Essex-0.01.tar.gz' => {'author' => 'RBS','description' => 'SAX & DOM pull filtering','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4017,'pod' => 1374,'pod_errors' => 0,'total' => 5391,'with_comments' => 518},'releases' => 1,'requires' => ['IPC-Run-0.75.tar.gz','XML-Filter-Dispatcher-0.52.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'IPC::Run' => 0,'XML::Filter::Dispatcher' => '0.4','XML::SAX::Base' => 0,'XML::SAX::PurePerl' => 0,'XML::SAX::Writer' => '0.42'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IPC-Run-0.75.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-Filter-Dispatcher-0.52.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Machines-0.4.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 42819,'unpacked' => 169177},'testers' => {},'uses' => ['Carp','Exporter','Filter::Util::Call','NEXT','Scalar::Util','Time::HiRes','UNIVERSAL','XML::Filter::Dispatcher','XML::NamespaceSupport','XML::SAX::EventMethodMaker','XML::SAX::PurePerl','XML::SAX::Writer','strict','threads::shared','vars']},'XML-Filter-GenericChunk-0.06.tar.gz' => {'author' => 'PHISH','description' => 'Base Class for SAX Filters parsing WellBallanced Chunks','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 320,'pod' => 229,'pod_errors' => 0,'total' => 549,'with_comments' => 6},'releases' => 1,'requires' => ['XML-LibXML-1.54.tar.gz','XML-SAX-Base-1.02.tar.gz'],'requires_module' => {'XML::LibXML' => '1.4','XML::SAX::Base' => '1.03'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6126,'unpacked' => 18851},'testers' => {'fail' => 1,'pass' => 1,'tests' => '13'},'uses' => ['XML::LibXML','XML::LibXML::SAX::Parser','XML::SAX::Base','strict','warnings']},'XML-Filter-Glossary-0.2.tar.gz' => {'author' => 'ASCOPE','description' => 'SAX2 filter for keyword lookup and replacement','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 415,'pod' => 220,'pod_errors' => 0,'total' => 635,'with_comments' => 24},'releases' => 2,'requires' => ['XML-SAX-0.12.tar.gz','XML-SAX-Machines-0.4.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'XML::SAX' => '0.11','XML::SAX::Machines' => '0.38','XML::SAX::Writer' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Machines-0.4.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19944,'unpacked' => 70844},'testers' => {'pass' => 1},'uses' => ['XML::Filter::Merger','XML::SAX::Base','XML::SAX::ParserFactory','strict','vars']},'XML-Filter-Hekeln-0.06.tar.gz' => {'author' => 'KRAEHE','description' => 'a SAX stream editor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 231,'pod' => 150,'pod_errors' => 0,'total' => 381,'with_comments' => 8},'releases' => 4,'requires' => ['IO-1.20.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','libxml-perl-0.07.tar.gz'],'requires_module' => {'IO::File' => 1,'XML::Handler::YAWriter' => '0.1','XML::Parser::PerlSAX' => '0.06'},'requires_recursive' => ['IO-1.20.tar.gz','XML-Handler-YAWriter-0.23.tar.gz','XML-Parser-2.31.tar.gz','libxml-perl-0.07.tar.gz'],'size' => {'packed' => 8336,'unpacked' => 32807},'testers' => {'pass' => 3},'uses' => ['UNIVERSAL','strict','vars']},'XML-Filter-Mode-0.02.tar.gz' => {'author' => 'RBS','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 125,'pod' => 95,'pod_errors' => 0,'total' => 220,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 3555,'unpacked' => 9206},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['XML::SAX::Base','XML::SAX::EventMethodMaker','strict']},'XML-Filter-NSNormalise-0.04.tar.gz' => {'author' => 'GRANTM','description' => 'SAX filter to normalise namespace prefixes','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 156,'pod' => 95,'pod_errors' => 0,'total' => 251,'with_comments' => 22},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'Test::Simple' => '0.41','XML::NamespaceSupport' => '1.08','XML::SAX' => '0.11','XML::SAX::Writer' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6395,'unpacked' => 23336},'testers' => {'fail' => 1,'pass' => 2,'tests' => '38'},'uses' => ['Carp','XML::SAX::Base','strict','vars','warnings']},'XML-Filter-Namespace-1.03.tar.gz' => {'author' => 'SEMANTICO','description' => 'strip all but a single namespace','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 152,'pod' => 73,'pod_errors' => 0,'total' => 225,'with_comments' => 11},'releases' => 3,'requires' => ['Class-Accessor-0.18.tar.gz','Test-Simple-0.47.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'Class::Accessor' => '0.17','Test::More' => 0,'XML::SAX' => 0,'XML::SAX::Writer' => '0.44'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-Fields-0.16.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5476,'unpacked' => 15132},'testers' => {'pass' => 2},'uses' => ['','Class::Accessor','XML::SAX::Base','strict','vars']},'XML-Filter-PerlTidy-0.02.tar.gz' => {'author' => 'CHOLET','description' => 'SAX filter through Perl::Tidy','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 101,'pod' => 44,'pod_errors' => 0,'total' => 145,'with_comments' => 5},'releases' => 2,'requires' => ['Perl-Tidy-20021130.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'Perl::Tidy' => 0,'XML::Filter::BufferText' => 0,'XML::SAX::Base' => 0,'XML::SAX::Writer' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Perl-Tidy-20021130.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2970,'unpacked' => 6895},'testers' => {'fail' => 1,'tests' => '6'},'uses' => ['Perl::Tidy','XML::Filter::BufferText','XML::SAX::ParserFactory','strict','vars']},'XML-Filter-Reindent-0.03.tar.gz' => {'author' => 'TJMATHER','description' => 'Reformats whitespace for pretty printing XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 232,'pod' => 77,'pod_errors' => 0,'total' => 309,'with_comments' => 21},'releases' => 3,'requires' => ['XML-Filter-DetectWS-0.01.tar.gz'],'requires_module' => {'XML::Filter::DetectWS' => 0},'requires_recursive' => ['XML-Filter-DetectWS-0.01.tar.gz','XML-Filter-SAXT-0.01.tar.gz'],'size' => {'packed' => 4749,'unpacked' => 12039},'testers' => {'pass' => 6},'uses' => ['XML::Filter::DetectWS','strict','vars']},'XML-Filter-SAX1toSAX2-0.03.tar.gz' => {'author' => 'MSERGEANT','description' => 'Convert SAX1 events to SAX2','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 60,'pod_errors' => 0,'total' => 234,'with_comments' => 9},'releases' => 3,'requires' => ['XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'XML::NamespaceSupport' => 0,'XML::SAX::Base' => 0,'XML::SAX::ParserFactory' => 0,'XML::SAX::Writer' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3077,'unpacked' => 9312},'testers' => {'pass' => 2},'uses' => ['XML::NamespaceSupport','XML::SAX::Base','strict','vars']},'XML-Filter-SAXT-0.01.tar.gz' => {'author' => 'TJMATHER','description' => 'Replicates SAX events to SAX event handlers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 119,'pod' => 71,'pod_errors' => 0,'total' => 190,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 2891,'unpacked' => 6316},'testers' => {'pass' => 7},'uses' => ['strict','vars']},'XML-Filter-Sort-0.91.tar.gz' => {'author' => 'GRANTM','description' => 'SAX filter for sorting elements in XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1869,'pod' => 389,'pod_errors' => 0,'total' => 2258,'with_comments' => 369},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'Test::Simple' => '0.41','XML::SAX' => undef,'XML::SAX::Writer' => undef},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 25747,'unpacked' => 115918},'testers' => {'fail' => 1,'pass' => 3,'tests' => '40'},'uses' => ['Carp','File::Path','File::Spec','File::Temp','IO::File','Storable','XML::SAX::Base','constant','strict','vars']},'XML-Filter-TableWrapper-0.02.tar.gz' => {'author' => 'RBS','description' => 'Wrap a table\'s cells in to a certain number of rows','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 124,'pod' => 71,'pod_errors' => 1,'total' => 195,'with_comments' => 0},'releases' => 2,'requires' => ['XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'XML::SAX::Base' => 0,'XML::SAX::Writer' => '0.42'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3204,'unpacked' => 7008},'testers' => {'pass' => 3},'uses' => ['XML::SAX::Base','strict']},'XML-Filter-XInclude-1.0.tar.gz' => {'author' => 'MSERGEANT','description' => 'XInclude as a SAX Filter','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 230,'pod' => 43,'pod_errors' => 0,'total' => 273,'with_comments' => 9},'releases' => 1,'requires' => ['XML-SAX-0.12.tar.gz'],'requires_module' => {'XML::SAX' => '0.05'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7668,'unpacked' => 24053},'testers' => {'fail' => 3,'tests' => '3'},'uses' => ['Cwd','LWP::UserAgent','URI','XML::SAX::Base','constant','strict','vars']},'XML-Filter-XML_Directory_2-Base-1.4.4.tar.gz' => {'author' => 'ASCOPE','description' => 'base class for creating XML::Directory to something else SAX filters.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 373,'pod' => 193,'pod_errors' => 0,'total' => 566,'with_comments' => 12},'releases' => 9,'requires' => ['Digest-MD5-2.26.tar.gz','XML-Directory-0.99.tar.gz','XML-Filter-XML_Directory_Pruner-1.3.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '0','Digest::MD5' => '0','File::Basename' => '0','XML::Directory' => '0.97','XML::Filter::XML_Directory_Pruner' => '1.3','XML::SAX::Base' => '1.03','XML::SAX::Writer' => '0.39'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','MIME-Types-1.06.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Directory-0.99.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-Filter-XML_Directory_Pruner-1.3.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4938,'unpacked' => 15009},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Digest::MD5','Exporter','XML::Filter::XML_Directory_Pruner','strict']},'XML-Filter-XML_Directory_2RSS-0.9.02.tar.gz' => {'author' => 'ASCOPE','description' => 'SAX2 filter for generating RSS from the output of XML::Directory::SAX','files' => ['Makefile.PL'],'lines' => {'nonpod' => 805,'pod' => 394,'pod_errors' => 0,'total' => 1199,'with_comments' => 14},'releases' => 4,'requires' => ['XML-Directory-0.99.tar.gz','XML-Filter-XML_Directory_Pruner-1.3.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'XML::Directory' => '0.95','XML::Filter::XML_Directory_Pruner' => '1.0','XML::SAX::Base' => '1.02','XML::SAX::Writer' => '0.39'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','MIME-Types-1.06.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Directory-0.99.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-Filter-XML_Directory_Pruner-1.3.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6811,'unpacked' => 27285},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','XML::Filter::XML_Directory_2RSS::Items','XML::Filter::XML_Directory_Pruner','strict']},'XML-Filter-XML_Directory_2RSS-0.9.1.tar.gz' => {'author' => 'ASCOPE','description' => 'SAX2 filter for generating RSS from the output of XML::Directory::SAX','files' => ['Makefile.PL'],'lines' => {'nonpod' => 807,'pod' => 392,'pod_errors' => 0,'total' => 1199,'with_comments' => 15},'releases' => 4,'requires' => ['XML-Directory-0.99.tar.gz','XML-Filter-XML_Directory_Pruner-1.3.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'XML::Directory' => '0.96','XML::Filter::XML_Directory_Pruner' => '1.0','XML::SAX::Base' => '1.04','XML::SAX::Writer' => '0.39'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','MIME-Types-1.06.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Directory-0.99.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-Filter-XML_Directory_Pruner-1.3.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6904,'unpacked' => 27582},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','XML::Filter::XML_Directory_2RSS::Base','XML::Filter::XML_Directory_Pruner','strict']},'XML-Filter-XML_Directory_2XHTML-1.3.1.tar.gz' => {'author' => 'ASCOPE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 540,'pod' => 303,'pod_errors' => 0,'total' => 843,'with_comments' => 8},'releases' => 6,'requires' => ['XML-Filter-XML_Directory_2-Base-1.4.4.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => '0','File::Basename' => '0','XML::Filter::XML_Directory_2::Base' => '1.4.4'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','MIME-Types-1.06.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Directory-0.99.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-Filter-XML_Directory_2-Base-1.4.4.tar.gz','XML-Filter-XML_Directory_Pruner-1.3.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6151,'unpacked' => 21439},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Exporter','File::Basename','XML::Filter::XML_Directory_2::Base','constant','strict']},'XML-Filter-XML_Directory_Pruner-1.3.tar.gz' => {'author' => 'ASCOPE','description' => 'SAX2 filter for restricting the output of the XML::Directory::SAX','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 453,'pod' => 179,'pod_errors' => 0,'total' => 632,'with_comments' => 27},'releases' => 4,'requires' => ['MIME-Types-1.06.tar.gz','XML-Directory-0.99.tar.gz','XML-SAX-Base-1.02.tar.gz'],'requires_module' => {'MIME::Types' => '0.4','XML::Directory' => '0.97','XML::SAX::Base' => '1.02'},'requires_recursive' => ['MIME-Types-1.06.tar.gz','XML-Directory-0.99.tar.gz','XML-SAX-Base-1.02.tar.gz'],'size' => {'packed' => 4324,'unpacked' => 15322},'testers' => {'fail' => 3,'pass' => 5},'uses' => ['Exporter','MIME::Types','XML::SAX::Base','strict']},'XML-Filter-XSLT-0.03.tar.gz' => {'author' => 'MSERGEANT','description' => 'XSLT as a SAX Filter','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 104,'pod' => 37,'pod_errors' => 0,'total' => 141,'with_comments' => 11},'releases' => 3,'requires' => ['XML-LibXSLT-1.53.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'XML::LibXSLT' => '1.31','XML::SAX' => '0.03','XML::SAX::Writer' => '0.2'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2363,'unpacked' => 4858},'testers' => {'fail' => 1,'tests' => '5'},'uses' => ['XML::LibXML::SAX::Builder','XML::LibXML::SAX::Parser','XML::LibXSLT','strict','vars']},'XML-GDOME-0.82.tar.gz' => {'author' => 'TJMATHER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1181,'pod' => 1327,'pod_errors' => 0,'total' => 2508,'with_comments' => 16},'releases' => 8,'requires' => ['XML-LibXML-Common-0.13.tar.gz','XML-SAX-0.12.tar.gz'],'requires_module' => {'XML::LibXML::Common' => 0,'XML::SAX' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 45055,'unpacked' => 214776},'testers' => {'fail' => 3,'tests' => '349'},'uses' => ['DynaLoader','Exporter','XML::LibXML::Common','XML::SAX::Base','overload','strict','vars']},'XML-GDOME-XSLT-0.75.tar.gz' => {'author' => 'TJMATHER','description' => 'XSLT using libxslt and XML::GDOME','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 333,'pod' => 136,'pod_errors' => 0,'total' => 469,'with_comments' => 5},'releases' => 1,'requires' => ['XML-GDOME-0.82.tar.gz'],'requires_module' => {'XML::GDOME' => '0.75'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-GDOME-0.82.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17760,'unpacked' => 63105},'testers' => {'fail' => 1,'tests' => '74'},'uses' => ['Carp','Cwd','Driver::BaseClass','DynaLoader','Exporter','IO::File','XML::GDOME','XML::LibXML','XML::LibXSLT','XML::Sablotron','strict','vars']},'XML-GXML-2.2.tar.gz' => {'author' => 'JCARTER','description' => 'XML transformation and XML->HTML conv.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1702,'pod' => 58,'pod_errors' => 0,'total' => 1760,'with_comments' => 504},'releases' => 2,'requires' => ['File-Spec-0.82.tar.gz','XML-Parser-2.31.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Cwd' => 1,'File::Basename' => 1,'File::Path' => 1,'File::Spec' => '0.7','XML::Parser' => 2},'requires_recursive' => ['File-Spec-0.82.tar.gz','XML-Parser-2.31.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 61180,'unpacked' => 181754},'testers' => {'pass' => 5},'uses' => ['Cwd','File::Basename','File::Path','File::Spec','XML::Parser','strict']},'XML-Generator-0.93.tar.gz' => {'author' => 'BHOLZMAN','description' => 'Generates XML documents','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 821,'pod' => 378,'pod_errors' => 0,'total' => 1199,'with_comments' => 70},'releases' => 12,'size' => {'packed' => 15281,'unpacked' => 48329},'testers' => {'pass' => 13},'uses' => ['Carp','XML::DOM','XML::Generator::overload','constant','strict','vars']},'XML-Generator-CGI-0.01.tar.gz' => {'author' => 'MNEYLON','description' => 'Generate SAX2 Events from CGI objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 151,'pod' => 94,'pod_errors' => 0,'total' => 245,'with_comments' => 13},'releases' => 1,'requires' => ['CGI.pm-2.98.tar.gz','XML-SAX-Base-1.02.tar.gz'],'requires_module' => {'CGI' => 0,'XML::SAX::Base' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','File-Spec-0.82.tar.gz','XML-SAX-Base-1.02.tar.gz'],'size' => {'packed' => 3720,'unpacked' => 9520},'testers' => {'pass' => 2},'uses' => ['CGI','XML::SAX::Base','strict','vars']},'XML-Generator-DBI-0.03.tar.gz' => {'author' => 'MSERGEANT','description' => 'Generate SAX events from SQL queries','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 207,'pod' => 157,'pod_errors' => 0,'total' => 364,'with_comments' => 20},'releases' => 3,'requires' => ['MIME-Base64-2.20.tar.gz','XML-SAX-Base-1.02.tar.gz'],'requires_module' => {'MIME::Base64' => 2,'XML::SAX::Base' => 1},'requires_recursive' => ['MIME-Base64-2.20.tar.gz','XML-SAX-Base-1.02.tar.gz'],'size' => {'packed' => 5706,'unpacked' => 14789},'testers' => {'pass' => 3},'uses' => ['Data::Dumper','MIME::Base64','XML::SAX::Base','strict','vars']},'XML-Generator-Pdb-0.1.tar.gz' => {'author' => 'JOHANVDB','description' => 'Generate SAX events from a Palm PDB','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 155,'pod' => 74,'pod_errors' => 0,'total' => 229,'with_comments' => 4},'releases' => 1,'size' => {'packed' => 3588,'unpacked' => 8728},'testers' => {'fail' => 2,'tests' => '1'},'uses' => ['Palm::PDB','Palm::Raw','strict','warnings']},'XML-Generator-PerlData-0.89.tar.gz' => {'author' => 'KHAMPTON','description' => 'Perl extension for generating SAX2 events from nested Perl data structures.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 980,'pod' => 629,'pod_errors' => 1,'total' => 1609,'with_comments' => 32},'releases' => 4,'requires' => ['XML-SAX-Base-1.02.tar.gz'],'requires_module' => {'XML::SAX::Base' => '1.02'},'requires_recursive' => ['XML-SAX-Base-1.02.tar.gz'],'size' => {'packed' => 13763,'unpacked' => 60410},'testers' => {'pass' => 2},'uses' => ['XML::SAX::Base','strict','vars']},'XML-Generator-Win32OLETypeLib-0.01.tar.gz' => {'author' => 'MSERGEANT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 440,'pod' => 22,'pod_errors' => 0,'total' => 462,'with_comments' => 36},'releases' => 1,'requires' => ['Win32-OLE-0.1403.tar.gz'],'requires_module' => {'Win32::OLE' => 0,'Win32::OLE::Const' => 0,'Win32::OLE::TypeInfo' => 0},'requires_recursive' => ['Win32-OLE-0.1403.tar.gz'],'size' => {'packed' => 5391,'unpacked' => 15550},'testers' => {},'uses' => ['Win32::OLE','Win32::OLE::Const','Win32::OLE::TypeInfo','strict','vars']},'XML-Grove-0.05.tar.gz' => {'author' => 'KMACLEOD','description' => 'simple, non-validating XML objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1286,'pod' => 305,'pod_errors' => 0,'total' => 1591,'with_comments' => 152},'releases' => 2,'size' => {'packed' => 17702,'unpacked' => 64136},'testers' => {'pass' => 3},'uses' => ['XML::Grove','XML::Parser','strict','vars']},'XML-Grove-0.46alpha.tar.gz' => {'author' => 'KMACLEOD','description' => 'Perl-style XML objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1548,'pod' => 990,'pod_errors' => 0,'total' => 2538,'with_comments' => 169},'releases' => 3,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.19'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 27336,'unpacked' => 103105},'testers' => {'fail' => 5,'pass' => 5,'tests' => '10'},'uses' => ['5.005','Data::Grove','Data::Grove::Visitor','UNIVERSAL','strict','vars']},'XML-Handler-2Simple-0.1.tar.gz' => {'author' => 'RBS','description' => 'SAX => XML::Simple handler','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 50,'pod' => 50,'pod_errors' => 0,'total' => 100,'with_comments' => 2},'releases' => 1,'requires' => ['XML-Handler-Trees-0.02.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'XML::Handler::Trees' => 0,'XML::Simple' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Handler-Trees-0.02.tar.gz','XML-Simple-2.08.tar.gz'],'size' => {'packed' => 1600,'unpacked' => 2772},'testers' => {},'uses' => ['XML::Handler::Trees','XML::Simple']},'XML-Handler-AxPoint-1.30.tar.gz' => {'author' => 'MSERGEANT','description' => 'AxPoint XML to PDF Slideshow generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1687,'pod' => 217,'pod_errors' => 0,'total' => 1904,'with_comments' => 100},'releases' => 8,'requires' => ['PDFLib-0.12.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'PDFLib' => '0.11','XML::SAX' => '0.09','XML::SAX::Writer' => '0.39'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','PDFLib-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 166315,'unpacked' => 217406},'testers' => {'pass' => 1},'uses' => ['File::Basename','File::Spec','PDFLib','XML::SAX::Writer','strict','vars']},'XML-Handler-Composer-0.01.tar.gz' => {'author' => 'TJMATHER','description' => 'Another XML printer/writer/generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 685,'pod' => 140,'pod_errors' => 0,'total' => 825,'with_comments' => 78},'releases' => 1,'requires' => ['XML-UM-0.01.tar.gz'],'requires_module' => {'XML::UM' => 0},'requires_recursive' => ['XML-Encoding-1.01.tar.gz','XML-Parser-2.31.tar.gz','XML-UM-0.01.tar.gz'],'size' => {'packed' => 7219,'unpacked' => 21379},'testers' => {'pass' => 6},'uses' => ['Carp','XML::UM','strict','utf','vars']},'XML-Handler-Dtd2Html-0.32.tar.gz' => {'author' => 'PERRAD','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1618,'pod' => 40,'pod_errors' => 0,'total' => 1658,'with_comments' => 39},'releases' => 14,'requires' => ['HTML-Template-2.6.tar.gz','XML-Parser-2.31.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Expat-0.37.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'HTML::Template' => 0,'XML::Parser' => '2.31','XML::SAX' => '0.11','XML::SAX::Base' => 1,'XML::SAX::Expat' => '0.37','XML::SAX::Writer' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Template-2.6.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Expat-0.37.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 23496,'unpacked' => 132662},'testers' => {'pass' => 1},'uses' => ['File::Copy','File::Temp','HTML::Template','XML::Handler::Dtd2Html::Document','strict','vars']},'XML-Handler-HTMLWriter-2.01.tar.gz' => {'author' => 'MSERGEANT','description' => 'SAX Handler for writing HTML 4.0','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 373,'pod' => 134,'pod_errors' => 0,'total' => 507,'with_comments' => 5},'releases' => 4,'requires' => ['HTML-Parser-3.28.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'HTML::Entities' => '1.22','XML::SAX::Writer' => '0.44'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7265,'unpacked' => 22508},'testers' => {'fail' => 1,'pass' => 1,'tests' => '63'},'uses' => ['XML::SAX::Writer::XML','strict','vars']},'XML-Handler-Machine2GraphViz-0.2.tar.gz' => {'author' => 'RBS','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 113,'pod' => 48,'pod_errors' => 0,'total' => 161,'with_comments' => 4},'releases' => 2,'requires' => ['GraphViz-1.8.tar.gz','XML-Filter-Dispatcher-0.52.tar.gz','XML-SAX-Machines-0.4.tar.gz'],'requires_module' => {'GraphViz' => 0,'XML::Filter::Dispatcher' => 0,'XML::SAX::Machines' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Graph-0.20101.tar.gz','GraphViz-1.8.tar.gz','Heap-0.50.tar.gz','IPC-Run-0.75.tar.gz','Math-Bezier-0.01.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-Filter-Dispatcher-0.52.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Machines-0.4.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 2221,'unpacked' => 4808},'testers' => {},'uses' => ['Exporter','GraphViz','XML::Filter::Dispatcher','strict']},'XML-Handler-Pdb-0.2.tar.gz' => {'author' => 'JOHANVDB','description' => 'Generate a Palm PDB from XML data','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 175,'pod' => 111,'pod_errors' => 0,'total' => 286,'with_comments' => 10},'releases' => 2,'requires' => ['libxml-perl-0.07.tar.gz'],'requires_module' => {'XML::Handler::Subs' => 0},'requires_recursive' => ['XML-Parser-2.31.tar.gz','libxml-perl-0.07.tar.gz'],'size' => {'packed' => 48070,'unpacked' => 120186},'testers' => {'fail' => 1,'tests' => '1'},'uses' => ['Carp','File::Temp','Palm::PDB','Palm::Raw','XML::Handler::Subs','strict','warnings']},'XML-Handler-PrintEvents-0.01.tar.gz' => {'author' => 'TJMATHER','description' => 'Prints PerlSAX events (for debugging)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 51,'pod' => 21,'pod_errors' => 0,'total' => 72,'with_comments' => 10},'releases' => 1,'requires' => ['XML-Filter-SAXT-0.01.tar.gz'],'requires_module' => {'XML::Filter::SAXT' => 0},'requires_recursive' => ['XML-Filter-SAXT-0.01.tar.gz'],'size' => {'packed' => 1784,'unpacked' => 3117},'testers' => {'pass' => 6},'uses' => ['XML::Filter::SAXT','strict','vars']},'XML-Handler-Trees-0.02.tar.gz' => {'author' => 'EBOHLMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 628,'pod' => 208,'pod_errors' => 0,'total' => 836,'with_comments' => 72},'releases' => 2,'size' => {'packed' => 7684,'unpacked' => 29988},'testers' => {'pass' => 5},'uses' => ['XML::Element','strict','vars']},'XML-Handler-YAWriter-0.23.tar.gz' => {'author' => 'KRAEHE','description' => 'Yet another Perl SAX XML Writer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 323,'pod' => 183,'pod_errors' => 0,'total' => 506,'with_comments' => 10},'releases' => 13,'requires' => ['IO-1.20.tar.gz','libxml-perl-0.07.tar.gz'],'requires_module' => {'IO::File' => '1.06','XML::Parser::PerlSAX' => '0.06'},'requires_recursive' => ['IO-1.20.tar.gz','XML-Parser-2.31.tar.gz','libxml-perl-0.07.tar.gz'],'size' => {'packed' => 25695,'unpacked' => 146019},'testers' => {'pass' => 11},'uses' => ['IO::File','strict','vars']},'XML-IDMEF-0.10.tar.gz' => {'author' => 'ERWAN','description' => 'A module for building/parsing IDMEF messages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2127,'pod' => 482,'pod_errors' => 0,'total' => 2609,'with_comments' => 912},'releases' => 9,'requires' => ['XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::DOM' => '0','XML::Parser' => '0'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 25644,'unpacked' => 93851},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['5.006','Carp','Data::Dumper','Exporter','XML::DOM','constant','strict','warnings']},'XML-LibRSVG-0.01.tar.gz' => {'author' => 'MSERGEANT','description' => 'Interface to gnome\'s librsvg','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 38,'pod' => 29,'pod_errors' => 0,'total' => 67,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 6803,'unpacked' => 19859},'testers' => {'fail' => 1,'pass' => 2,'tests' => '5'},'uses' => ['DynaLoader','strict','vars']},'XML-LibXML-1.40.tar.gz' => {'author' => 'MSERGEANT','description' => 'Interface to the gnome libxml2 library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1370,'pod' => 1357,'pod_errors' => 0,'total' => 2727,'with_comments' => 38},'releases' => 17,'requires' => ['XML-SAX-0.12.tar.gz'],'requires_module' => {'XML::SAX' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 77814,'unpacked' => 333251},'testers' => {'pass' => 2},'uses' => ['Carp','Data::Dumper','DynaLoader','Exporter','IO::Handle','XML::LibXML','XML::SAX::Base','XML::SAX::DocumentLocator','overload','strict','vars']},'XML-LibXML-1.54.tar.gz' => {'author' => 'PHISH','description' => 'Interface to the gnome libxml2 library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4210,'pod' => 2030,'pod_errors' => 0,'total' => 6240,'with_comments' => 153},'releases' => 17,'requires' => ['XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz'],'requires_module' => {'XML::LibXML::Common' => 0,'XML::NamespaceSupport' => '1.07','XML::SAX' => '0.11'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 144632,'unpacked' => 650365},'testers' => {'pass' => 1},'uses' => ['Carp','Data::Dumper','DynaLoader','Exporter','IO::File','IO::Handle','XML::LibXML::Boolean','XML::LibXML::Common','XML::LibXML::Literal','XML::LibXML::NodeList','XML::LibXML::Number','XML::NamespaceSupport','XML::SAX::Base','XML::SAX::DocumentLocator','XML::SAX::Exception','overload','strict','vars']},'XML-LibXML-Common-0.13.tar.gz' => {'author' => 'PHISH','description' => 'Routines and Constants common for XML::LibXML and XML::GDOME','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 239,'pod' => 67,'pod_errors' => 0,'total' => 306,'with_comments' => 22},'releases' => 4,'size' => {'packed' => 12930,'unpacked' => 43696},'testers' => {'pass' => 2},'uses' => ['DynaLoader','Exporter','constant','strict','vars']},'XML-LibXML-Fixup-0.03.tar.gz' => {'author' => 'NWETTERS','description' => 'apply regexes to XML to fix validation and parsing errors','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 238,'pod' => 119,'pod_errors' => 0,'total' => 357,'with_comments' => 20},'releases' => 3,'requires' => ['Test-Simple-0.47.tar.gz','XML-LibXML-1.54.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => undef,'Test::More' => undef,'XML::LibXML' => undef},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6743,'unpacked' => 29692},'testers' => {'pass' => 1},'uses' => ['Carp','XML::LibXML','strict','vars','warnings']},'XML-LibXML-Iterator-1.00.tar.gz' => {'author' => 'PHISH','description' => 'XML::LibXML\'s Tree Iteration Class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 430,'pod' => 208,'pod_errors' => 0,'total' => 638,'with_comments' => 8},'releases' => 1,'requires' => ['XML-LibXML-1.54.tar.gz','XML-NodeFilter-0.01.tar.gz'],'requires_module' => {'XML::LibXML' => '1.52','XML::NodeFilter' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-NodeFilter-0.01.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6156,'unpacked' => 18706},'testers' => {'pass' => 2},'uses' => ['XML::NodeFilter','strict','vars']},'XML-LibXML-XPathContext-0.04.tar.gz' => {'author' => 'ILYAM','description' => 'Perl interface to libxml2\'s xmlXPathContext','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 197,'pod' => 204,'pod_errors' => 0,'total' => 401,'with_comments' => 5},'releases' => 4,'requires' => ['XML-LibXML-1.54.tar.gz'],'requires_module' => {'XML::LibXML' => '1.51'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 46465,'unpacked' => 193144},'testers' => {'pass' => 1},'uses' => ['DynaLoader','XML::LibXML::NodeList','strict','vars']},'XML-LibXSLT-1.52.tar.gz' => {'author' => 'MSERGEANT','description' => 'Interface to the gnome libxslt library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 337,'pod' => 153,'pod_errors' => 0,'total' => 490,'with_comments' => 6},'releases' => 23,'requires' => ['XML-LibXML-1.54.tar.gz'],'requires_module' => {'XML::LibXML' => '0.94'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 22507,'unpacked' => 79692},'testers' => {'fail' => 4,'tests' => '79'},'uses' => ['Carp','Cwd','DynaLoader','Exporter','IO::File','XML::LibXML','XML::LibXSLT','XML::Sablotron','strict','vars']},'XML-LibXSLT-1.53.tar.gz' => {'author' => 'MSERGEANT','description' => 'Interface to the gnome libxslt library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 361,'pod' => 153,'pod_errors' => 0,'total' => 514,'with_comments' => 10},'releases' => 23,'requires' => ['XML-LibXML-1.54.tar.gz'],'requires_module' => {'XML::LibXML' => '0.94'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 23855,'unpacked' => 87735},'testers' => {'pass' => 1},'uses' => ['Carp','Cwd','Driver::BaseClass','DynaLoader','Exporter','IO::File','XML::LibXML','XML::LibXML::Boolean','XML::LibXML::Literal','XML::LibXML::NodeList','XML::LibXML::Number','XML::Sablotron','strict','vars']},'XML-MetaGenerator-0.03.tgz' => {'author' => 'BRUJAH','description' => 'Collects user input, validates input and generates output in a number of ways based on the defined grammar.','files' => ['Makefile.PL'],'lines' => {'nonpod' => 1125,'pod' => 83,'pod_errors' => 0,'total' => 1208,'with_comments' => 83},'releases' => 1,'size' => {'packed' => 11654,'unpacked' => 35981},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['Term::ReadKey','Term::ReadLine','XML::Generator','XML::Parser','strict','vars']},'XML-Mini-1.2.8.tar.gz' => {'author' => 'PDEEGAN','description' => 'Perl implementation of the XML::Mini XML create/parse interface.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2588,'pod' => 1350,'pod_errors' => 0,'total' => 3938,'with_comments' => 102},'releases' => 6,'requires' => ['Data-Dumper-2.101.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => '2.1','FileHandle' => 2},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 35349,'unpacked' => 136366},'testers' => {'pass' => 2},'uses' => ['Data::Dumper','FileHandle','strict','vars']},'XML-NamespaceFactory-0.01.tar.gz' => {'author' => 'RBERJON','description' => 'Simple factory objects for SAX namespaced names','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 69,'pod' => 37,'pod_errors' => 0,'total' => 106,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2091,'unpacked' => 3800},'testers' => {'pass' => 2},'uses' => ['strict','vars']},'XML-NamespaceSupport-1.08.tar.gz' => {'author' => 'RBERJON','description' => 'Generic namespace helpers (ported from SAX2)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 395,'pod' => 179,'pod_errors' => 0,'total' => 574,'with_comments' => 94},'releases' => 10,'size' => {'packed' => 7643,'unpacked' => 27977},'testers' => {'pass' => 25},'uses' => ['constant','strict','vars']},'XML-Node-0.11.tar.gz' => {'author' => 'CHANG-LIU','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 293,'pod' => 76,'pod_errors' => 0,'total' => 369,'with_comments' => 33},'releases' => 5,'size' => {'packed' => 7937,'unpacked' => 26901},'testers' => {'pass' => 9},'uses' => ['Carp','Exporter','XML::Parser','strict','vars']},'XML-NodeFilter-0.01.tar.gz' => {'author' => 'PHISH','description' => 'Generic XML::NodeFilter Class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 334,'pod' => 260,'pod_errors' => 0,'total' => 594,'with_comments' => 40},'releases' => 1,'size' => {'packed' => 6620,'unpacked' => 22690},'testers' => {'pass' => 5},'uses' => ['5.005','Exporter','constant','strict','vars']},'XML-Object-0.03.tar.gz' => {'author' => 'CHOCOLATE','description' => 'Methodical XML Configuration','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 800,'pod' => 967,'pod_errors' => 0,'total' => 1767,'with_comments' => 56},'releases' => 3,'requires' => ['Error-0.15.tar.gz','Test-Simple-0.47.tar.gz','Util-0.05.tar.gz','XML-Parser-2.31.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'Error' => '0.15','Test::More' => 0,'Util' => '0.02','XML::Parser' => 0,'XML::Simple' => '2.08'},'requires_recursive' => ['Error-0.15.tar.gz','File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Deep-0.06.tar.gz','Test-Harness-2.29.tar.gz','Test-NoWarnings-0.05.tar.gz','Test-Simple-0.47.tar.gz','Test-Tester-0.06.tar.gz','Util-0.05.tar.gz','XML-Parser-2.31.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 15784,'unpacked' => 58928},'testers' => {'pass' => 1},'uses' => ['5.008','DBI','Data::Dumper','Error','Error::Simple','Util','XML::Simple','XOE','strict','warnings']},'XML-PYX-0.07.tar.gz' => {'author' => 'MSERGEANT','description' => 'XML to PYX generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 213,'pod' => 38,'pod_errors' => 0,'total' => 251,'with_comments' => 8},'releases' => 7,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.23'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 3750,'unpacked' => 9833},'testers' => {'pass' => 8},'uses' => ['XML::Checker::Parser','XML::Parser','strict','vars']},'XML-Parser-2.31.tar.gz' => {'author' => 'COOPERCL','description' => 'A perl module for parsing XML documents','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1629,'pod' => 688,'pod_errors' => 2,'total' => 2317,'with_comments' => 60},'releases' => 15,'size' => {'packed' => 255106,'unpacked' => 595503},'testers' => {'fail' => 1,'pass' => 59},'uses' => ['5.004','Carp','DynaLoader','IO::File','IO::Handle','strict','vars']},'XML-Parser-EasyTree-0.01.tar.gz' => {'author' => 'EBOHLMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 122,'pod_errors' => 0,'total' => 242,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 3229,'unpacked' => 13712},'testers' => {'pass' => 16},'uses' => ['strict','vars']},'XML-QL-0.07.tar.gz' => {'author' => 'MSERGEANT','description' => 'Implements the XML Query Language','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 407,'pod' => 117,'pod_errors' => 0,'total' => 524,'with_comments' => 54},'releases' => 6,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.20'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 8201,'unpacked' => 25999},'testers' => {'pass' => 5},'uses' => ['Data::Dumper','LWP::UserAgent','XML::Parser','strict','vars']},'XML-Quote-1.02.tar.gz' => {'author' => 'GDSL','description' => 'XML quote/dequote functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 47,'pod' => 80,'pod_errors' => 0,'total' => 127,'with_comments' => 1},'releases' => 3,'size' => {'packed' => 5112,'unpacked' => 16982},'testers' => {'pass' => 8},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'XML-RDB-1.0.tar.gz' => {'author' => 'METZZO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1738,'pod' => 581,'pod_errors' => 0,'total' => 2319,'with_comments' => 571},'releases' => 1,'requires' => ['DBI-1.37.tar.gz','DBIx-DBSchema-0.21.tar.gz','DBIx-Recordset-0.24.tar.gz','DBIx-Sequence-1.4.tar.gz','IO-1.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz'],'requires_module' => {'DBI' => '1.35','DBIx::DBSchema' => '.16','DBIx::Recordset' => '.23','DBIx::Sequence' => '.04','IO::File' => '1.08','URI::Escape' => '3.16','XML::DOM' => '1.29'},'requires_recursive' => ['DBI-1.37.tar.gz','DBIx-DBSchema-0.21.tar.gz','DBIx-Recordset-0.24.tar.gz','DBIx-Sequence-1.4.tar.gz','Digest-MD5-2.26.tar.gz','FreezeThaw-0.43.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 35115,'unpacked' => 115663},'testers' => {},'uses' => ['DBIx::DBSchema','DBIx::Recordset','DBIx::Sequence','Data::Dumper','IO::File','URI::Escape','XML::DOM','constant','strict','vars']},'XML-RDDL-1.02.tar.gz' => {'author' => 'RBERJON','description' => 'Interface to RDDL (http://www.rddl.org/)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 468,'pod' => 271,'pod_errors' => 0,'total' => 739,'with_comments' => 119},'releases' => 5,'requires' => ['XML-SAX-0.12.tar.gz'],'requires_module' => {'XML::SAX' => '0.00'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 6754,'unpacked' => 35258},'testers' => {'pass' => 3},'uses' => ['XML::SAX::Base','strict','vars']},'XML-RSS-1.02.tar.gz' => {'author' => 'KELLAN','description' => 'Parse or create Rich Site Summaries (RSS)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1885,'pod' => 330,'pod_errors' => 0,'total' => 2215,'with_comments' => 383},'releases' => 15,'requires' => ['Test-Manifest-0.91.tar.gz','Test-Simple-0.47.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Test::Manifest' => '0.9','Test::More' => '0','XML::Parser' => '2.23'},'requires_recursive' => ['ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Simple-0.47.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 38454,'unpacked' => 160109},'testers' => {'pass' => 3},'uses' => ['Carp','XML::Parser','strict','vars']},'XML-RSS-Aggregate-0.02.tar.gz' => {'author' => 'AUTRIJUS','description' => 'RSS Aggregator','files' => ['Makefile.PL','README','Build.PL','META.yml','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 90,'pod' => 65,'pod_errors' => 0,'total' => 155,'with_comments' => 8},'releases' => 2,'requires' => ['Module-Build-0.19.tar.gz'],'requires_module' => {'Module::Build' => '0.11'},'requires_recursive' => ['Module-Build-0.19.tar.gz'],'size' => {'packed' => 5028,'unpacked' => 12393},'testers' => {'pass' => 3},'uses' => ['Date::Parse','HTML::Entities','LWP::Simple','XML::RSS','strict']},'XML-RSS-Feed-0.02.tgz' => {'author' => 'JBISBEE','description' => 'Encapsulate RSS XML New Items Watching','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 368,'pod' => 129,'pod_errors' => 0,'total' => 497,'with_comments' => 17},'releases' => 2,'size' => {'packed' => 11330,'unpacked' => 31729},'testers' => {'fail' => 1,'pass' => 1,'tests' => '4'},'uses' => ['Digest::MD5','Exporter','URI','XML::RSS','strict','vars']},'XML-RSS-Parser-0.21.tar.gz' => {'author' => 'TIMA','description' => 'A liberal parser for RSS Feeds.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 108,'pod_errors' => 0,'total' => 269,'with_comments' => 15},'releases' => 2,'size' => {'packed' => 4228,'unpacked' => 9743},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['XML::Parser','strict','vars']},'XML-RSS-Tools-0.12.tar.gz' => {'author' => 'ATRICKETT','description' => 'A tool-kit providing a wrapper around a HTTP client, a RSS parser, and a XSLT engine.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 764,'pod' => 237,'pod_errors' => 0,'total' => 1001,'with_comments' => 142},'releases' => 11,'requires' => ['URI-1.24.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-RSS-1.02.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => '5.6','URI' => '1.21','XML::LibXML' => '1.5','XML::LibXSLT' => '1.5','XML::RSS' => 1},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','ExtUtils-MakeMaker-6.05.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Manifest-0.91.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXSLT-1.53.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-RSS-1.02.tar.gz','XML-SAX-0.12.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 34400,'unpacked' => 112639},'testers' => {'pass' => 2},'uses' => ['5.006','FileHandle','HTTP::GHTTP','HTTP::Lite','URI','XML::LibXML','XML::LibXSLT','XML::RSS','strict','warnings','warnings::register']},'XML-RSSLite-0.11.tgz' => {'author' => 'JPIERCE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 331,'pod' => 131,'pod_errors' => 0,'total' => 462,'with_comments' => 45},'releases' => 3,'size' => {'packed' => 8557,'unpacked' => 24100},'testers' => {'pass' => 6},'uses' => ['strict','vars']},'XML-Records-0.12.tar.gz' => {'author' => 'EBOHLMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 253,'pod' => 142,'pod_errors' => 0,'total' => 395,'with_comments' => 7},'releases' => 4,'requires' => ['XML-TokeParser-0.04.tar.gz'],'requires_module' => {'XML::TokeParser' => '0.03'},'requires_recursive' => ['XML-TokeParser-0.04.tar.gz'],'size' => {'packed' => 7275,'unpacked' => 29585},'testers' => {'pass' => 4},'uses' => ['XML::TokeParser','strict','vars']},'XML-RegExp-0.03.tar.gz' => {'author' => 'TJMATHER','description' => 'Regular expressions for XML tokens','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 54,'pod' => 28,'pod_errors' => 0,'total' => 82,'with_comments' => 7},'releases' => 2,'size' => {'packed' => 3313,'unpacked' => 8141},'testers' => {'pass' => 26},'uses' => ['vars']},'XML-Registry-0.02.tar.gz' => {'author' => 'EISEN','description' => 'Implements a generic XML registry','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 83,'pod' => 45,'pod_errors' => 0,'total' => 128,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 48442,'unpacked' => 168823},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Data::Dumper','strict','vars']},'XML-SAX-0.12.tar.gz' => {'author' => 'MSERGEANT','description' => 'Simple API for XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3438,'pod' => 528,'pod_errors' => 0,'total' => 3966,'with_comments' => 200},'releases' => 12,'requires' => ['File-Temp-0.12.tar.gz','XML-NamespaceSupport-1.08.tar.gz'],'requires_module' => {'File::Temp' => 0,'XML::NamespaceSupport' => '0.03'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-NamespaceSupport-1.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 59537,'unpacked' => 286639},'testers' => {'pass' => 19},'uses' => ['Carp','Encode','Exporter','File::Basename','File::Temp','IO::File','LWP::UserAgent','Symbol','XML::SAX::Exception','XML::SAX::PurePerl::NoUnicodeExt','XML::SAX::PurePerl::Reader::NoUnicodeExt','XML::SAX::PurePerl::Reader::UnicodeExt','XML::SAX::PurePerl::UnicodeExt','constant','overload','strict','utf','vars']},'XML-SAX-Base-1.02.tar.gz' => {'author' => 'KHAMPTON','description' => 'Base class SAX Drivers and Filters','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2478,'pod' => 240,'pod_errors' => 0,'total' => 2718,'with_comments' => 345},'releases' => 3,'size' => {'packed' => 21148,'unpacked' => 185737},'testers' => {'fail' => 1,'pass' => 29},'uses' => ['Carp','XML::SAX::Exception','overload','strict','vars']},'XML-SAX-Builder-0.02.tar.gz' => {'author' => 'SEMANTICO','description' => 'build XML documents using SAX','files' => ['Makefile.PL','README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 370,'pod' => 106,'pod_errors' => 0,'total' => 476,'with_comments' => 25},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'Test::More' => 0,'XML::NamespaceSupport' => 0,'XML::SAX::Writer' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 8527,'unpacked' => 33498},'testers' => {'pass' => 2},'uses' => ['Carp','XML::NamespaceSupport','XML::SAX::Builder::Base','XML::SAX::Writer','strict','warnings']},'XML-SAX-Expat-0.37.tar.gz' => {'author' => 'RBERJON','description' => 'SAX2 Driver for Expat (XML::Parser)','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 531,'pod' => 59,'pod_errors' => 0,'total' => 590,'with_comments' => 148},'releases' => 6,'requires' => ['XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz'],'requires_module' => {'XML::NamespaceSupport' => '0.03','XML::Parser' => '2.27','XML::SAX' => '0.03','XML::SAX::Base' => '1.00'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5329,'unpacked' => 22302},'testers' => {'pass' => 3},'uses' => ['XML::NamespaceSupport','XML::Parser','XML::SAX::Base','strict','vars']},'XML-SAX-Machines-0.4.tar.gz' => {'author' => 'RBS','description' => 'Manage a collection of SAX processors','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3065,'pod' => 1436,'pod_errors' => 0,'total' => 4501,'with_comments' => 401},'releases' => 12,'requires' => ['XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz'],'requires_module' => {'XML::SAX' => '0.05','XML::SAX::Base' => '1.02','XML::SAX::Writer' => '0.4100001'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 42660,'unpacked' => 152200},'testers' => {'pass' => 3},'uses' => ['','Carp','Data::Dumper','Devel::TraceSAX','Exporter','File::Spec','File::Spec::Unix','IO::Handle','Symbol','UNIVERSAL','XML::SAX::Base','XML::SAX::Machines::SiteConfig','XML::SAX::ParserFactory','XML::SAX::Writer','strict','vars']},'XML-SAX-RTF-0.1.tar.gz' => {'author' => 'ERIKRAY','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 549,'pod' => 53,'pod_errors' => 0,'total' => 602,'with_comments' => 93},'releases' => 1,'requires' => ['XML-SAX-0.12.tar.gz'],'requires_module' => {'XML::SAX' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 4763,'unpacked' => 14826},'testers' => {'pass' => 2},'uses' => ['5.005_62','Exporter','XML::SAX::Base','strict','vars']},'XML-SAX-Simple-0.02.tar.gz' => {'author' => 'MSERGEANT','description' => 'SAX version of XML::Simple','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 72,'pod' => 24,'pod_errors' => 0,'total' => 96,'with_comments' => 3},'releases' => 2,'requires' => ['XML-Handler-Trees-0.02.tar.gz','XML-SAX-0.12.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'XML::Handler::Trees' => '0.02','XML::SAX' => '0.02','XML::Simple' => '1.06'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Handler-Trees-0.02.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 16245,'unpacked' => 78318},'testers' => {'pass' => 4},'uses' => ['Data::Dumper','XML::Handler::Trees','XML::SAX','strict','vars']},'XML-SAX-Writer-0.44.tar.gz' => {'author' => 'RBERJON','description' => 'SAX2 Writer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 953,'pod' => 271,'pod_errors' => 5,'total' => 1224,'with_comments' => 273},'releases' => 10,'requires' => ['Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz'],'requires_module' => {'Test::More' => '0.40','Text::Iconv' => '1.2','XML::Filter::BufferText' => '0.01','XML::NamespaceSupport' => '0.03'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 11683,'unpacked' => 49149},'testers' => {'fail' => 2,'pass' => 6,'tests' => '42'},'uses' => ['Text::Iconv','XML::Filter::BufferText','XML::NamespaceSupport','XML::SAX::Exception','strict','vars']},'XML-SAXDriver-CSV-0.07.tar.gz' => {'author' => 'ISTERIN','description' => 'complements XML::CSV, SAX interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 149,'pod' => 74,'pod_errors' => 0,'total' => 223,'with_comments' => 5},'releases' => 7,'requires' => ['Text-CSV_XS-0.23.tar.gz'],'requires_module' => {'Text::CSV_XS' => '0.22'},'requires_recursive' => ['Text-CSV_XS-0.23.tar.gz'],'size' => {'packed' => 4784,'unpacked' => 12329},'testers' => {'fail' => 2,'pass' => 1,'tests' => '4'},'uses' => ['IO::File','Text::CSV_XS','XML::SAX::Base','strict','vars']},'XML-SAXDriver-Excel-0.06.tar.gz' => {'author' => 'ISTERIN','description' => 'complements XML::Excel, SAX interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 240,'pod' => 72,'pod_errors' => 0,'total' => 312,'with_comments' => 25},'releases' => 4,'requires' => ['Spreadsheet-ParseExcel-0.2602.tar.gz'],'requires_module' => {'Spreadsheet::ParseExcel' => '0.24'},'requires_recursive' => ['IO-stringy-2.108.tar.gz','OLE-Storage_Lite-0.11.tar.gz','Spreadsheet-ParseExcel-0.2602.tar.gz'],'size' => {'packed' => 8850,'unpacked' => 51546},'testers' => {'fail' => 2,'pass' => 2,'tests' => '5'},'uses' => ['IO::String','Spreadsheet::ParseExcel','XML::SAX::Base','strict','vars']},'XML-SAXDriver-Sablotron-0.30.tar.gz' => {'author' => 'PAVELH','description' => 'Perl SAX driver for the Sablotron XSLT processor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 241,'pod' => 51,'pod_errors' => 0,'total' => 292,'with_comments' => 52},'releases' => 3,'requires' => ['XML-Sablotron-0.98.tar.gz'],'requires_module' => {'XML::Sablotron' => '0.9'},'requires_recursive' => ['XML-Sablotron-0.98.tar.gz'],'size' => {'packed' => 4024,'unpacked' => 9927},'testers' => {},'uses' => ['XML::SAX::Base','XML::Sablotron','XML::Sablotron::DOM','strict','vars','warnings']},'XML-SAXDriver-vCard-0.05.tar.gz' => {'author' => 'ASCOPE','description' => 'generate SAX2 events for vCard 3.0','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 830,'pod' => 100,'pod_errors' => 0,'total' => 930,'with_comments' => 107},'releases' => 4,'requires' => ['Test-Simple-0.47.tar.gz','XML-SAX-0.12.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'FileHandle' => '0','LWP::Simple' => '0','Test::More' => '0','XML::SAX' => '0.11'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 9207,'unpacked' => 27941},'testers' => {'pass' => 4},'uses' => ['Cwd','Exporter','File::Spec','FileHandle','LWP::Simple','XML::SAX::Base','constant','strict']},'XML-STX-0.41.tar.gz' => {'author' => 'PCIMPRICH','description' => 'a pure Perl STX processor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7091,'pod' => 468,'pod_errors' => 0,'total' => 7559,'with_comments' => 832},'releases' => 8,'requires' => ['Clone-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Clone' => '0.13','POSIX' => 1,'XML::NamespaceSupport' => '1.07','XML::SAX' => '0.1'},'requires_recursive' => ['Clone-0.13.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 56728,'unpacked' => 282867},'testers' => {'pass' => 2},'uses' => ['5.005_02','Carp','Clone','Exporter','XML::NamespaceSupport','XML::SAX::Base','XML::SAX::PurePerl','strict','vars']},'XML-Sablotron-0.98.tar.gz' => {'author' => 'PAVELH','description' => 'a Perl interface to the Sablotron XSLT processor','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2598,'pod' => 2793,'pod_errors' => 0,'total' => 5391,'with_comments' => 404},'releases' => 13,'size' => {'packed' => 52726,'unpacked' => 274537},'testers' => {},'uses' => ['5.005_62','Carp','Devel::Peek','DynaLoader','Exporter','XML::Sablotron::Processor','XML::Sablotron::Situation','constant','fields','strict','vars','warnings']},'XML-Schema-0.07.tar.gz' => {'author' => 'ABW','description' => 'XML Schema modules for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8530,'pod' => 1060,'pod_errors' => 0,'total' => 9590,'with_comments' => 2489},'releases' => 1,'size' => {'packed' => 150769,'unpacked' => 704778},'testers' => {'fail' => 2,'pass' => 1,'tests' => '1441'},'uses' => ['','Exporter','XML::Parser','XML::Schema::Facet::Fixable','XML::Schema::Schedule','XML::Schema::Type::Name','XML::Schema::Type::decimal','XML::Schema::Type::double','XML::Schema::Type::integer','XML::Schema::Type::nonNegativeInteger','XML::Schema::Type::recurringDuration','XML::Schema::Type::string','XML::Schema::Type::timePeriod','XML::Schema::Type::token','constant','overload','strict','typos','vars']},'XML-Schematron-0.98.tar.gz' => {'author' => 'KHAMPTON','description' => 'Perl implementation of the Schematron.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 470,'pod' => 437,'pod_errors' => 0,'total' => 907,'with_comments' => 30},'releases' => 6,'size' => {'packed' => 7103,'unpacked' => 29352},'testers' => {'pass' => 4},'uses' => ['XML::LibXML','XML::LibXSLT','XML::Parser::PerlSAX','XML::Sablotron','XML::XPath','strict','vars']},'XML-SemanticDiff-0.95.tar.gz' => {'author' => 'KHAMPTON','description' => 'Perl extension for comparing XML documents.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 448,'pod' => 144,'pod_errors' => 0,'total' => 592,'with_comments' => 26},'releases' => 4,'requires' => ['Digest-MD5-2.26.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Digest::MD5' => '0','XML::Parser' => '0'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 15566,'unpacked' => 67397},'testers' => {'pass' => 8},'uses' => ['Digest::MD5','XML::Parser','strict','vars']},'XML-Simple-2.08.tar.gz' => {'author' => 'GRANTM','description' => 'Easy API to maintain XML (esp config files)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2175,'pod' => 1326,'pod_errors' => 3,'total' => 3501,'with_comments' => 299},'releases' => 16,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Simple' => '0.41'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 59179,'unpacked' => 222305},'testers' => {'fail' => 1,'pass' => 5,'tests' => '418'},'uses' => ['Carp','Exporter','File::Basename','File::Spec','Storable','XML::Parser','XML::SAX','strict','vars']},'XML-SimpleObject-0.53.tar.gz' => {'author' => 'DBRIAN','description' => 'Perl extension allowing a simple object representation of a parsed XML::Parser tree.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 303,'pod' => 313,'pod_errors' => 2,'total' => 616,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 11621,'unpacked' => 42224},'testers' => {'pass' => 2},'uses' => ['XML::LibXML','XML::Parser','strict','warnings']},'XML-SimpleObject-LibXML-0.59.tar.gz' => {'author' => 'DBRIAN','description' => 'Perl extension allowing a simple(r) object representation of an XML::LibXML DOM object.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 325,'pod' => 226,'pod_errors' => 0,'total' => 551,'with_comments' => 14},'releases' => 1,'requires' => ['XML-LibXML-1.54.tar.gz'],'requires_module' => {'XML::LibXML' => 'XML::LibXML::Common'},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7219,'unpacked' => 24154},'testers' => {'pass' => 1},'uses' => ['XML::LibXML','XML::LibXML::Common','strict']},'XML-Smart-1.3.1.tar.gz' => {'author' => 'GMPASSOS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2474,'pod' => 795,'pod_errors' => 0,'total' => 3269,'with_comments' => 315},'releases' => 5,'requires' => ['Object-MultiType-0.02.tar.gz'],'requires_module' => {'Object::MultiType' => '0.02'},'requires_recursive' => ['Object-MultiType-0.02.tar.gz'],'size' => {'packed' => 25538,'unpacked' => 99994},'testers' => {'pass' => 3},'uses' => ['5.006','Carp','LWP','LWP::UserAgent','Object::MultiType','XML::Parser','re','strict','vars']},'XML-Stream-1.15.tar.gz' => {'author' => 'REATMON','description' => 'Creates and XML Stream connection and parses return data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4886,'pod' => 498,'pod_errors' => 0,'total' => 5384,'with_comments' => 1267},'releases' => 12,'requires' => ['Unicode-String-2.07.tar.gz'],'requires_module' => {'Unicode::String' => '2.06'},'requires_recursive' => ['MIME-Base64-2.20.tar.gz','Unicode-String-2.07.tar.gz'],'size' => {'packed' => 52997,'unpacked' => 241135},'testers' => {'fail' => 5,'pass' => 4,'tests' => '105'},'uses' => ['5.003','Carp','Exporter','FileHandle','HTTP::ProxyAutoConfig','IO::Select','IO::Socket','POSIX','Socket','Sys::Hostname','Unicode::String','XML::Stream::Namespace','XML::Stream::Parser','strict','vars']},'XML-Stream-1.16.tar.gz' => {'author' => 'REATMON','description' => 'Creates and XML Stream connection and parses return data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8082,'pod' => 1591,'pod_errors' => 0,'total' => 9673,'with_comments' => 1295},'releases' => 12,'size' => {'packed' => 73065,'unpacked' => 332626},'testers' => {'pass' => 6},'uses' => ['5.003','5.006_001','5.008_000','Carp','Exporter','FileHandle','HTTP::ProxyAutoConfig','IO::Select','IO::Socket','POSIX','Sys::Hostname','open','strict','vars']},'XML-Template-3.00.tar.gz' => {'author' => 'EMRYS','description' => 'Front end module to XML::Template.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 12063,'pod' => 673,'pod_errors' => 1,'total' => 12736,'with_comments' => 512},'releases' => 5,'requires' => ['CGI.pm-2.98.tar.gz','DBI-Wrap-1.00.tar.gz','Data-Dumper-2.101.tar.gz','IO-String-1.02.tar.gz','MailTools-1.58.tar.gz','Parse-RecDescent-1.94.tar.gz','XML-Parser-2.31.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'CGI' => '2.81','DBI::Wrap' => 1,'Data::Dumper' => '2.12','IO::String' => '1.01','Mail::Mailer' => '1.47','Parse::RecDescent' => '1.8','XML::Parser' => '2.31','XML::Simple' => '1.08'},'requires_recursive' => ['CGI.pm-2.98.tar.gz','DBI-1.37.tar.gz','DBI-Wrap-1.00.tar.gz','Data-Dumper-2.101.tar.gz','File-Spec-0.82.tar.gz','IO-String-1.02.tar.gz','MailTools-1.58.tar.gz','Parse-RecDescent-1.94.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','XML-Parser-2.31.tar.gz','XML-Simple-2.08.tar.gz'],'size' => {'packed' => 54932,'unpacked' => 532289},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['CGI','DBI::Wrap','Data::Dumper','Exporter','File::Basename','File::Path','File::Spec','IO::String','Mail::Mailer','Parse::RecDescent','WWW::Auth','WWW::Auth::DB','XML::Parser','XML::Simple','XML::XPath','constant','strict','vars']},'XML-TiePYX-0.05.tar.gz' => {'author' => 'EBOHLMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 318,'pod' => 167,'pod_errors' => 0,'total' => 485,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 6811,'unpacked' => 25858},'testers' => {'pass' => 2},'uses' => ['Carp','IO::File','Tie::Handle','XML::Catalog','XML::Checker::Parser','XML::Parser','strict','vars']},'XML-TokeParser-0.04.tar.gz' => {'author' => 'EBOHLMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 299,'pod' => 183,'pod_errors' => 0,'total' => 482,'with_comments' => 4},'releases' => 5,'size' => {'packed' => 6476,'unpacked' => 29673},'testers' => {'pass' => 5},'uses' => ['Carp','IO::File','XML::Catalog','XML::Parser','strict','vars']},'XML-TreeBuilder-3.08.tar.gz' => {'author' => 'SBURKE','description' => 'XML elements with the same interface as HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 247,'pod' => 124,'pod_errors' => 0,'total' => 371,'with_comments' => 26},'releases' => 1,'requires' => ['HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'HTML::Element' => '3.08','HTML::Tagset' => '3.02','XML::Parser' => 0},'requires_recursive' => ['HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 4419,'unpacked' => 11910},'testers' => {'pass' => 10},'uses' => ['5','strict','vars']},'XML-Twig-3.10.tar.gz' => {'author' => 'MIROD','description' => 'A module for easy processing of XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7708,'pod' => 2113,'pod_errors' => 0,'total' => 9821,'with_comments' => 1018},'releases' => 19,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.23'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 179676,'unpacked' => 778192},'testers' => {'pass' => 6},'uses' => ['5.004','Carp','Encode','HTML::Entities','LWP','Text::Iconv','Unicode::Map8','Unicode::String','XML::Parser','bytes','constant','strict','vars']},'XML-UM-0.01.tar.gz' => {'author' => 'TJMATHER','description' => 'Convert UTF-8 strings to any encoding','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 399,'pod' => 70,'pod_errors' => 0,'total' => 469,'with_comments' => 120},'releases' => 1,'requires' => ['XML-Encoding-1.01.tar.gz'],'requires_module' => {'XML::Encoding' => 0},'requires_recursive' => ['XML-Encoding-1.01.tar.gz','XML-Parser-2.31.tar.gz'],'size' => {'packed' => 5507,'unpacked' => 13729},'testers' => {'pass' => 6},'uses' => ['Carp','XML::Encoding','vars']},'XML-WMM-ASX-0.30.tar.gz' => {'author' => 'CCZ','description' => undef,'files' => [],'lines' => {'nonpod' => 271,'pod' => 88,'pod_errors' => 0,'total' => 359,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 3601,'unpacked' => 9208},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['strict','vars']},'XML-Writer-0.4.tar.gz' => {'author' => 'DMEGG','description' => 'Module for writing XML documents','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1074,'pod' => 300,'pod_errors' => 0,'total' => 1374,'with_comments' => 191},'releases' => 4,'size' => {'packed' => 11910,'unpacked' => 45549},'testers' => {'fail' => 6,'pass' => 34},'uses' => ['5.004','Carp','IO','strict','vars']},'XML-Writer-String-0.1.tar.gz' => {'author' => 'SOLIVER','description' => 'Module to capture output from XML::Writer','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 45,'pod' => 62,'pod_errors' => 0,'total' => 107,'with_comments' => 0},'releases' => 1,'requires' => ['XML-Writer-0.4.tar.gz'],'requires_module' => {'XML::Writer' => 0},'requires_recursive' => ['XML-Writer-0.4.tar.gz'],'size' => {'packed' => 5426,'unpacked' => 8072},'testers' => {'pass' => 5},'uses' => ['5.004','strict','warnings']},'XML-XForms-Generator-0.62.tar.gz' => {'author' => 'DHAGEMAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1759,'pod' => 317,'pod_errors' => 0,'total' => 2076,'with_comments' => 487},'releases' => 1,'requires' => ['Exporter-Cluster-0.31.tar.gz','XML-LibXML-1.54.tar.gz'],'requires_module' => {'Exporter::Cluster' => 0,'XML::LibXML' => '1.52'},'requires_recursive' => ['Exporter-Cluster-0.31.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 28109,'unpacked' => 154779},'testers' => {'pass' => 1},'uses' => ['5.006','Carp','Exporter','Exporter::Cluster','XML::LibXML','strict','warnings']},'XML-XPath-1.13.tar.gz' => {'author' => 'MSERGEANT','description' => 'a set of modules for parsing and evaluating XPath statements','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5139,'pod' => 694,'pod_errors' => 0,'total' => 5833,'with_comments' => 344},'releases' => 37,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.23'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 39832,'unpacked' => 179577},'testers' => {'pass' => 7},'uses' => ['Carp','Data::Dumper','DynaLoader','Exporter','IO::File','POSIX','XML::Parser','strict','vars']},'XML-XPath-Simple-0.05.tar.gz' => {'author' => 'WHYTEWOLF','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 200,'pod' => 75,'pod_errors' => 0,'total' => 275,'with_comments' => 56},'releases' => 1,'requires' => ['Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Test::More' => '0.18','XML::Simple' => '1.08'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10767,'unpacked' => 31699},'testers' => {'pass' => 3},'uses' => ['Carp','Exporter','XML::Simple','strict','vars']},'XML-XPathScript-0.03.tar.gz' => {'author' => 'MSERGEANT','description' => 'Stand alone XPathScript','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 474,'pod' => 35,'pod_errors' => 0,'total' => 509,'with_comments' => 29},'releases' => 3,'requires' => ['XML-XPath-1.13.tar.gz'],'requires_module' => {'XML::XPath' => 1},'requires_recursive' => ['XML-Parser-2.31.tar.gz','XML-XPath-1.13.tar.gz'],'size' => {'packed' => 5040,'unpacked' => 15138},'testers' => {'pass' => 5},'uses' => ['Exporter','File::Basename','Symbol','XML::Parser','XML::XPath','XML::XPath::Node','XML::XPath::NodeSet','XML::XPath::XMLParser','strict','vars']},'XML-XQL-0.68.tar.gz' => {'author' => 'TJMATHER','description' => 'Performs XQL queries on XML object trees','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7812,'pod' => 1683,'pod_errors' => 0,'total' => 9495,'with_comments' => 985},'releases' => 7,'requires' => ['DateManip-5.42a.tar.gz','Parse-Yapp-1.05.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Date::Manip' => '5.33','LWP::UserAgent' => '0','Parse::Yapp' => '0','XML::DOM' => '1.29','XML::Parser' => '2.30'},'requires_recursive' => ['DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Parse-Yapp-1.05.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 120033,'unpacked' => 454282},'testers' => {'fail' => 1,'tests' => '85'},'uses' => ['Carp','Date::Manip','POSIX','Parse::Yapp::Driver','XML::DOM','XML::RegExp','XML::XQL::Attribute','XML::XQL::BooleanOp','XML::XQL::Date','XML::XQL::Element','XML::XQL::Operator','XML::XQL::Parser','XML::XQL::Plus','fields','strict','vars']},'XML-XSH-1.6.tar.gz' => {'author' => 'PAJAS','description' => 'Powerfull Scripting Language/Shell for XPath-based Editing of XML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 37106,'pod' => 48,'pod_errors' => 0,'total' => 37154,'with_comments' => 604},'releases' => 6,'requires' => ['Parse-RecDescent-1.94.tar.gz','XML-LibXML-1.54.tar.gz','XML-XUpdate-LibXML-0.4.0.tar.gz'],'requires_module' => {'Parse::RecDescent' => '1.79','XML::LibXML' => '1.54','XML::XUpdate::LibXML' => ''},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Parse-RecDescent-1.94.tar.gz','Text-Balanced-1.95.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXML-Iterator-1.00.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-NodeFilter-0.01.tar.gz','XML-SAX-0.12.tar.gz','XML-XUpdate-LibXML-0.4.0.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 158459,'unpacked' => 1890506},'testers' => {},'uses' => ['Carp','Exporter','IO::File','Parse::RecDescent','XML::GDOME','XML::LibXML','XML::LibXSLT','XML::Normalize::LibXML','XML::XUpdate::LibXML','strict','vars']},'XML-XSLT-0.20.tar.gz' => {'author' => 'JOSTEN','description' => 'A perl module for processing XSLT','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1489,'pod' => 241,'pod_errors' => 0,'total' => 1730,'with_comments' => 93},'releases' => 15,'requires' => ['XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::DOM' => '1.25','XML::Parser' => '2.23'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 94811,'unpacked' => 514984},'testers' => {'pass' => 2,'tests' => '0','unknown' => 6},'uses' => ['LWP::UserAgent','XML::DOM','strict','vars']},'XML-XSLT-0.40.tar.gz' => {'author' => 'JSTOWE','description' => 'Process XSL Transformational sheets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2720,'pod' => 375,'pod_errors' => 0,'total' => 3095,'with_comments' => 199},'releases' => 15,'requires' => ['Test-Simple-0.47.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'Test::More' => '0.33','XML::DOM' => '1.25','XML::Parser' => '2.23'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 242962,'unpacked' => 1040416},'testers' => {'fail' => 2,'pass' => 7,'tests' => '77'},'uses' => ['Carp','Cwd','File::Basename','LWP::Simple','URI','XML::DOM','constant','strict','vars']},'XML-XSLT-Wrapper-0.32.tar.gz' => {'author' => 'MULL','description' => 'Consistent interface to XSLT processors','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 893,'pod' => 144,'pod_errors' => 0,'total' => 1037,'with_comments' => 36},'releases' => 1,'size' => {'packed' => 9753,'unpacked' => 47230},'testers' => {'pass' => 2},'uses' => ['Driver::BaseClass','POSIX','XML::LibXML','XML::LibXSLT','XML::Sablotron','XML::XSLT','XML::Xalan::Transformer','lib','vars']},'XML-XUpdate-LibXML-0.4.0.tar.gz' => {'author' => 'PAJAS','description' => 'Simple implementation of XUpdate format','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 496,'pod' => 102,'pod_errors' => 0,'total' => 598,'with_comments' => 13},'releases' => 8,'requires' => ['XML-LibXML-1.54.tar.gz','XML-LibXML-Iterator-1.00.tar.gz'],'requires_module' => {'XML::LibXML' => '1.53','XML::LibXML::Iterator' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-LibXML-Iterator-1.00.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-NodeFilter-0.01.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7015,'unpacked' => 22031},'testers' => {'pass' => 1},'uses' => ['Exporter','XML::LibXML','XML::LibXML::Iterator','strict','vars']},'XML-Xalan-0.44.tar.gz' => {'author' => 'EDPRATOMO','description' => 'Interface to Xalan (Apache XSLT processor)','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 429,'pod' => 631,'pod_errors' => 0,'total' => 1060,'with_comments' => 28},'releases' => 13,'size' => {'packed' => 29177,'unpacked' => 150768},'testers' => {},'uses' => ['Driver::BaseClass','DynaLoader','Exporter','strict','vars']},'XML-Xerces-1.7.0-1.tar.gz' => {'author' => 'JASONS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5458,'pod' => 124,'pod_errors' => 0,'total' => 5582,'with_comments' => 217},'releases' => 1,'size' => {'packed' => 141631,'unpacked' => 1314030},'testers' => {},'uses' => ['Carp','Cwd','DynaLoader','Exporter','strict','vars']},'XML-Ximple-1.02.tar.gz' => {'author' => 'RELIANCE','description' => 'XML in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 353,'pod' => 93,'pod_errors' => 0,'total' => 446,'with_comments' => 76},'releases' => 2,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.3'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 11312,'unpacked' => 32258},'testers' => {'pass' => 6},'uses' => ['Exporter','XML::Parser','strict','warnings']},'XML-YYLex-0.04.tar.gz' => {'author' => 'BOEWE','description' => 'Perl module for using perl-byacc with XML-data','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 409,'pod' => 240,'pod_errors' => 0,'total' => 649,'with_comments' => 87},'releases' => 2,'size' => {'packed' => 7522,'unpacked' => 21329},'testers' => {},'uses' => ['Carp','XML::DOM','XML::Sablotron::DOM','strict','vars']},'XML-miniXQL-0.04.tar.gz' => {'author' => 'MSERGEANT','description' => 'Simplistic XQL-like search using streams','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 448,'pod' => 70,'pod_errors' => 0,'total' => 518,'with_comments' => 44},'releases' => 2,'size' => {'packed' => 11771,'unpacked' => 43226},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['AutoLoader','Exporter','XML::Parser','strict','vars']},'XMLNews-HTMLTemplate-0.01.tar.gz' => {'author' => 'DMEGG','description' => 'A module for converting NITF to HTML.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 734,'pod' => 243,'pod_errors' => 0,'total' => 977,'with_comments' => 204},'releases' => 1,'size' => {'packed' => 8987,'unpacked' => 25706},'testers' => {'fail' => 2,'pass' => 5},'uses' => ['Carp','IO::Handle','XML::Parser','XMLNews::Meta','strict','vars']},'XMLNews-Meta-0.01.tar.gz' => {'author' => 'DMEGG','description' => 'A module for reading and writing XMLNews metadata files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 402,'pod' => 177,'pod_errors' => 1,'total' => 579,'with_comments' => 105},'releases' => 1,'size' => {'packed' => 5632,'unpacked' => 15165},'testers' => {'fail' => 1,'pass' => 7},'uses' => ['Carp','IO','XML::Parser','strict']},'XMail-Ctrl-2.0.tar.gz' => {'author' => 'AARONJJ','description' => 'Crtl access to XMail server','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 443,'pod' => 172,'pod_errors' => 0,'total' => 615,'with_comments' => 90},'releases' => 6,'requires' => ['Digest-MD5-2.26.tar.gz'],'requires_module' => {'Digest::MD5' => '2.2'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz'],'size' => {'packed' => 7536,'unpacked' => 19517},'testers' => {'pass' => 2},'uses' => ['IO::Socket','strict','vars']},'XPC-0.2.tar.gz' => {'author' => 'GREGOR','description' => 'XML Procedure Call','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1437,'pod' => 606,'pod_errors' => 0,'total' => 2043,'with_comments' => 362},'releases' => 2,'requires' => ['Data-Dumper-2.101.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'HTTP::Daemon' => 0,'HTTP::Request' => 0,'HTTP::Status' => 0,'LWP::UserAgent' => 0,'POSIX' => 0,'URI' => 0,'XML::Parser' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 16230,'unpacked' => 69591},'testers' => {'fail' => 1,'pass' => 4,'tests' => '2'},'uses' => ['Data::Dumper','HTTP::Daemon','HTTP::Request','HTTP::Status','LWP::UserAgent','URI','XML::Parser','XML::Writer','strict','vars']},'XPathToXML-0.01.tar.gz' => {'author' => 'KGJERDE','description' => undef,'files' => [],'lines' => {'nonpod' => 262,'pod' => 101,'pod_errors' => 0,'total' => 363,'with_comments' => 50},'releases' => 1,'size' => {'packed' => 2603,'unpacked' => 7349},'testers' => {},'uses' => ['XML::LibXML']},'XSTEST-19960302.tar.gz' => {'author' => 'DMR','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 48,'pod' => 0,'pod_errors' => 0,'total' => 48,'with_comments' => 10},'releases' => 1,'size' => {'packed' => 6342,'unpacked' => 24308},'testers' => {},'uses' => ['5.002','DynaLoader','Exporter','vars']},'XSUB-2.002.tar.gz' => {'author' => 'PMQS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 96,'pod' => 0,'pod_errors' => 0,'total' => 96,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 35386,'unpacked' => 137423},'testers' => {'fail' => 2},'uses' => ['AutoLoader','DynaLoader','Exporter']},'XTM-0.20.tar.gz' => {'author' => 'DRRHO','description' => 'Topic Map management','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2018,'pod' => 1041,'pod_errors' => 0,'total' => 3059,'with_comments' => 194},'releases' => 15,'requires' => ['Data-Dumper-2.101.tar.gz','File-Slurp-2002.1031.tar.gz','IO-1.20.tar.gz','PodParser-1.23.tar.gz','XML-Grove-0.46alpha.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => '2.101','Data::Grove::Visitor' => '0.07','File::Slurp' => '96.042202','File::stat' => 0,'IO::File' => '1.06021','LWP::Simple' => '1.33','Pod::Usage' => '1.14','XML::Grove' => 0,'XML::Parser::PerlSAX' => '0.07'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Slurp-2002.1031.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','URI-1.24.tar.gz','XML-Grove-0.46alpha.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 22350,'unpacked' => 96965},'testers' => {'fail' => 1,'pass' => 4,'tests' => '57'},'uses' => ['5.004','AutoLoader','Carp','Data::Dumper','Data::Grove::Visitor','Exporter','File::Slurp','File::stat','LWP::Simple','POSIX','XML::Grove','XML::Grove::AsString','XML::Grove::Builder','XML::Grove::Path','XML::Parser::PerlSAX','XTM','XTM::Log','XTM::Memory','XTM::XML::Grove2TM','XTM::XML::Latin1Parser','XTM::XML::UTF8','XTM::association','XTM::baseName','XTM::baseNameString','XTM::generic','XTM::instanceOf','XTM::member','XTM::mergeMap','XTM::occurrence','XTM::parameters','XTM::resourceData','XTM::resourceRef','XTM::roleSpec','XTM::scope','XTM::subjectIdentity','XTM::subjectIndicatorRef','XTM::topic','XTM::topicRef','XTM::variant','XTM::variantName','strict','vars']},'XTM-0.25.tar.gz' => {'author' => 'DRRHO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3226,'pod' => 1494,'pod_errors' => 0,'total' => 4720,'with_comments' => 367},'releases' => 15,'requires' => ['Data-Dumper-2.101.tar.gz','File-Slurp-2002.1031.tar.gz','IO-1.20.tar.gz','PodParser-1.23.tar.gz','XML-Grove-0.46alpha.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => '2.101','Data::Grove::Visitor' => '0.07','File::Slurp' => '96.042202','File::stat' => 0,'IO::File' => '1.06021','LWP::Simple' => '1.33','Pod::Usage' => '1.14','XML::Grove' => 0,'XML::Parser::PerlSAX' => '0.07'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Slurp-2002.1031.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','URI-1.24.tar.gz','XML-Grove-0.46alpha.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 50170,'unpacked' => 194438},'testers' => {'fail' => 1,'pass' => 2,'tests' => '97'},'uses' => ['5.004','AutoLoader','Carp','Data::Dumper','Data::Grove::Visitor','Exporter','File::Slurp','File::stat','LWP::Simple','POSIX','URI','URI::file','XML::Grove','XML::Grove::AsString','XML::Grove::Builder','XML::Grove::Path','XML::Parser::PerlSAX','XTM','XTM::Log','XTM::Memory','XTM::PSI','XTM::XML','XTM::association','XTM::baseName','XTM::baseNameString','XTM::generic','XTM::instanceOf','XTM::member','XTM::mergeMap','XTM::occurrence','XTM::parameters','XTM::resourceData','XTM::resourceRef','XTM::roleSpec','XTM::scope','XTM::subjectIdentity','XTM::subjectIndicatorRef','XTM::topic','XTM::topicRef','XTM::variant','XTM::variantName','strict','vars']},'XTM-0.30.tar.gz' => {'author' => 'DRRHO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3861,'pod' => 1554,'pod_errors' => 0,'total' => 5415,'with_comments' => 384},'releases' => 15,'requires' => ['Data-Dumper-2.101.tar.gz','Getopt-Long-2.33.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Test-1.24.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-SAX-0.12.tar.gz','XML-Twig-3.10.tar.gz','XML-Writer-0.4.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => '2.102','File::stat' => 0,'Getopt::Long' => '2.25','IO::File' => '1.08','IO::String' => '1.01','LWP::Simple' => '1.35','Parse::RecDescent' => '1.8','Pod::Usage' => '1.14','Term::ReadLine' => 0,'Test' => '1.15','Test::More' => '0.4','URI' => '1.18','URI::file' => 0,'XML::SAX::ParserFactory' => 1,'XML::Twig' => '3.01','XML::Writer' => '0.4'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','MIME-Base64-2.20.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','URI-1.24.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-SAX-0.12.tar.gz','XML-Twig-3.10.tar.gz','XML-Writer-0.4.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 58370,'unpacked' => 237959},'testers' => {'fail' => 2,'pass' => 2,'tests' => '143'},'uses' => ['AutoLoader','Carp','Data::Dumper','Exporter','File::stat','IO::File','LWP::Simple','POSIX','Parse::RecDescent','URI','URI::file','XML::SAX::Base','XML::SAX::Exception','XML::SAX::ParserFactory','XTM','XTM::AsTMa','XTM::AsTMa::MemoryBuilder','XTM::AsTMa::Parser','XTM::IO','XTM::Log','XTM::Memory','XTM::Namespaces','XTM::PSI','XTM::XML','XTM::XML::MemoryBuilder','XTM::association','XTM::baseName','XTM::baseNameString','XTM::generic','XTM::instanceOf','XTM::member','XTM::mergeMap','XTM::occurrence','XTM::parameters','XTM::resourceData','XTM::resourceRef','XTM::roleSpec','XTM::scope','XTM::subjectIdentity','XTM::subjectIndicatorRef','XTM::topic','XTM::topicRef','XTM::variant','XTM::variantName','strict','vars']},'XTM-0.35.tar.gz' => {'author' => 'DRRHO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 26317,'pod' => 2384,'pod_errors' => 1,'total' => 28701,'with_comments' => 1204},'releases' => 15,'requires' => ['Data-Dumper-2.101.tar.gz','Getopt-Long-2.33.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Test-1.24.tar.gz','Test-Simple-0.47.tar.gz','Text-Iconv-1.2.tar.gz','URI-1.24.tar.gz','XML-SAX-0.12.tar.gz','XML-Twig-3.10.tar.gz','XML-Writer-0.4.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => '2.102','File::stat' => 0,'Getopt::Long' => '2.25','IO::File' => '1.08','IO::String' => '1.01','LWP::Simple' => '1.35','Parse::RecDescent' => '1.8','Pod::Usage' => '1.14','Term::ReadLine' => 0,'Test' => '1.15','Test::More' => '0.4','Text::Iconv' => '1.2','URI' => '1.18','URI::file' => 0,'XML::SAX::ParserFactory' => '1.01','XML::Twig' => '3.01','XML::Writer' => '0.4'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','MIME-Base64-2.20.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-Iconv-1.2.tar.gz','URI-1.24.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-SAX-0.12.tar.gz','XML-Twig-3.10.tar.gz','XML-Writer-0.4.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 144134,'unpacked' => 1300488},'testers' => {'fail' => 2,'pass' => 3,'tests' => '505'},'uses' => ['AutoLoader','Carp','Data::Dumper','Digest::MD5','Exporter','File::stat','IO::File','LWP::Simple','POSIX','Parse::RecDescent','Text::Iconv','UNIVERSAL','URI','URI::file','XML::SAX::Base','XML::SAX::Exception','XML::SAX::ParserFactory','strict','utf','vars']},'XTM-slides-0.2.tar.gz' => {'author' => 'DRRHO','description' => 'Topic Map Slide (STM) to XML (SlideML) conversion','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 223,'pod' => 33,'pod_errors' => 0,'total' => 256,'with_comments' => 29},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz','File-Slurp-2002.1031.tar.gz','PodParser-1.23.tar.gz','Test-Simple-0.47.tar.gz','XTM-0.35.tar.gz'],'requires_module' => {'Data::Dumper' => '2.101','File::Slurp' => '96.042202','Pod::Usage' => '1.14','Test::Simple' => '0.19','XTM' => '0.23'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Slurp-2002.1031.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','MIME-Base64-2.20.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-Iconv-1.2.tar.gz','URI-1.24.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-SAX-0.12.tar.gz','XML-Twig-3.10.tar.gz','XML-Writer-0.4.tar.gz','XTM-0.35.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 17160,'unpacked' => 54881},'testers' => {'fail' => 2,'tests' => '2'},'uses' => ['AutoLoader','Data::Dumper','Exporter','XTM','XTM::Virtual','strict','vars']},'XTM-slides-0.5.tar.gz' => {'author' => 'DRRHO','description' => 'Slide generate from Topic Maps','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 353,'pod' => 116,'pod_errors' => 0,'total' => 469,'with_comments' => 30},'releases' => 3,'requires' => ['Data-Dumper-2.101.tar.gz','File-Slurp-2002.1031.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Writer-0.44.tar.gz','XML-XPath-1.13.tar.gz','XTM-0.35.tar.gz'],'requires_module' => {'Data::Dumper' => '2.102','File::Slurp' => '96.042202','Getopt::Long' => '2.25','Pod::Usage' => '1.14','Test::More' => '0.4','URI::file' => 0,'XML::SAX::ParserFactory' => 1,'XML::SAX::Writer' => '0.39','XML::XPath' => '1.12','XML::XPath::XMLParser' => 0,'XTM::base' => '0.29'},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','Digest-MD5-2.26.tar.gz','File-Slurp-2002.1031.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','IO-String-1.02.tar.gz','MIME-Base64-2.20.tar.gz','Parse-RecDescent-1.94.tar.gz','PodParser-1.23.tar.gz','Test-1.24.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz','Text-Iconv-1.2.tar.gz','URI-1.24.tar.gz','XML-Filter-BufferText-1.01.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-Parser-2.31.tar.gz','XML-SAX-0.12.tar.gz','XML-SAX-Base-1.02.tar.gz','XML-SAX-Writer-0.44.tar.gz','XML-Twig-3.10.tar.gz','XML-Writer-0.4.tar.gz','XML-XPath-1.13.tar.gz','XTM-0.35.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 24876,'unpacked' => 96730},'testers' => {},'uses' => ['AutoLoader','Data::Dumper','Exporter','XML::SAX::Base','XML::SAX::Exception','XTM','XTM::Namespaces','XTM::Virtual','strict','vars']},'Xbase-1.07.tar.gz' => {'author' => 'PRATP','description' => 'Read Xbase files with simple IDX indexes','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 605,'pod' => 208,'pod_errors' => 0,'total' => 813,'with_comments' => 26},'releases' => 1,'size' => {'packed' => 8176,'unpacked' => 23211},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.001','Carp','strict']},'Xcalibur-Rawfile-0.1.tar.gz' => {'author' => 'MSOUTHERN','description' => 'Making use of the Xcalilbur XDK','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 56,'pod_errors' => 0,'total' => 113,'with_comments' => 10},'releases' => 1,'requires' => ['Win32-OLE-0.1403.tar.gz'],'requires_module' => {'Win32::OLE' => undef,'Win32::OLE::Variant' => undef},'requires_recursive' => ['Win32-OLE-0.1403.tar.gz'],'size' => {'packed' => 2341,'unpacked' => 4037},'testers' => {},'uses' => ['5.8.0','Exporter','Win32::OLE','Win32::OLE::Variant']},'Xelig-0.03.tar.gz' => {'author' => 'CHOCOLATE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1475,'pod' => 137,'pod_errors' => 0,'total' => 1612,'with_comments' => 333},'releases' => 3,'requires' => ['Scalar-List-Utils-1.11.tar.gz','Util-0.05.tar.gz','XML-Parser-2.31.tar.gz','XML-Simple-2.08.tar.gz'],'requires_module' => {'Scalar::Util' => 0,'Util' => 0,'XML::Parser' => 0,'XML::Simple' => '1.08'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Scalar-List-Utils-1.11.tar.gz','Test-Deep-0.06.tar.gz','Test-Harness-2.29.tar.gz','Test-NoWarnings-0.05.tar.gz','Test-Simple-0.47.tar.gz','Test-Tester-0.06.tar.gz','Util-0.05.tar.gz','XML-Parser-2.31.tar.gz','XML-Simple-2.08.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21809,'unpacked' => 69043},'testers' => {'pass' => 1},'uses' => ['5.008_000','Carp','Data::Dumper','Exporter','Scalar::Util','Util','XML::Parser::Expat','XML::Simple','Xelig::Template','strict','warnings']},'Xforms4Perl-0.8.4--2.tgz' => {'author' => 'MARTINB','description' => 'provides perl OO acess to XEvent structures','files' => ['README'],'lines' => {'nonpod' => 249,'pod' => 97,'pod_errors' => 0,'total' => 346,'with_comments' => 48},'releases' => 1,'size' => {'packed' => 137863,'unpacked' => 542998},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter']},'Xmms-Perl-0.12.tar.gz' => {'author' => 'DOUGM','description' => 'Interactive remote control shell for xmms','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1967,'pod' => 693,'pod_errors' => 0,'total' => 2660,'with_comments' => 34},'releases' => 7,'requires' => ['ANSIColor-1.07.tar.gz','MP3-Info-1.02.tar.gz','Term-ReadLine-Perl-1.0203.tar.gz'],'requires_module' => {'MPEG::MP3Info' => 0,'Term::ANSIColor' => 0,'Term::ReadLine::Perl' => 0},'requires_recursive' => ['ANSIColor-1.07.tar.gz','File-Spec-0.82.tar.gz','MP3-Info-1.02.tar.gz','Term-ReadLine-Perl-1.0203.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 189600,'unpacked' => 251270},'testers' => {'fail' => 1},'uses' => ['5.005','Audio::CD','Config','File::Basename','File::Find','MPEG::MP3Info','Term::ANSIColor','Text::Abbrev','strict']},'Xmms-Streamcast-0.09.tar.gz' => {'author' => 'CUTTER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 343,'pod' => 0,'pod_errors' => 0,'total' => 343,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 3269,'unpacked' => 9772},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['File::Basename','IO::Handle','MP3::Info','POSIX','Socket','Term::ReadKey','strict']},'YAML-0.35.tar.gz' => {'author' => 'INGY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3115,'pod' => 699,'pod_errors' => 0,'total' => 3814,'with_comments' => 338},'releases' => 4,'size' => {'packed' => 55741,'unpacked' => 182808},'testers' => {'fail' => 1,'pass' => 37,'tests' => '262'},'uses' => ['5.005_64','Carp','Exporter','Test','TestDumper','constant','diagnostics','overload','strict','utf','vars']},'YAML-ConfigFile-0.10.tar.gz' => {'author' => 'SKUD','description' => 'easily read configuration files in YAML format','files' => ['Makefile.PL'],'lines' => {'nonpod' => 43,'pod' => 29,'pod_errors' => 0,'total' => 72,'with_comments' => 4},'releases' => 1,'requires' => ['YAML-0.35.tar.gz'],'requires_module' => {'YAML' => '0.16'},'requires_recursive' => ['YAML-0.35.tar.gz'],'size' => {'packed' => 1636,'unpacked' => 2723},'testers' => {'fail' => 4,'pass' => 1,'tests' => '1'},'uses' => ['YAML','strict','v5.6.0','warnings']},'YAML-LoadFileCached-0.21.tar.gz' => {'author' => 'FLORIAN','description' => 'A wrapper around YAML::LoadFile with caching capabilities.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 66,'pod_errors' => 0,'total' => 144,'with_comments' => 3},'releases' => 3,'requires' => ['YAML-0.35.tar.gz'],'requires_module' => {'YAML' => '0.3'},'requires_recursive' => ['YAML-0.35.tar.gz'],'size' => {'packed' => 3016,'unpacked' => 6276},'testers' => {'pass' => 7},'uses' => ['5.006','Exporter','YAML','strict','warnings']},'YAML-MLDBM-0.10.tar.gz' => {'author' => 'INGY','description' => 'Use tied hash db-s with Python and Ruby','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 52,'pod_errors' => 0,'total' => 257,'with_comments' => 7},'releases' => 1,'size' => {'packed' => 3420,'unpacked' => 8236},'testers' => {'pass' => 1},'uses' => ['Carp','Cwd','Exporter','Fcntl','File::Spec','MLDBM','YAML','strict','vars']},'YAPC-1.01.tar.gz' => {'author' => 'LENZO','description' => 'Yet Another Perl Conference information and documentation','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 80,'pod' => 139,'pod_errors' => 1,'total' => 219,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 4349,'unpacked' => 8713},'testers' => {'pass' => 4},'uses' => ['strict']},'YAPE-HTML-1.11.tar.gz' => {'author' => 'PINYAN','description' => 'Yet Another Parser/Extractor for HTML','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 834,'pod' => 844,'pod_errors' => 1,'total' => 1678,'with_comments' => 7},'releases' => 4,'size' => {'packed' => 19470,'unpacked' => 69759},'testers' => {'pass' => 5},'uses' => ['Carp','strict','vars']},'YAPE-Regex-3.01.tar.gz' => {'author' => 'PINYAN','description' => 'Yet Another Parser/Extractor for Regular Expressions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1217,'pod' => 961,'pod_errors' => 0,'total' => 2178,'with_comments' => 14},'releases' => 7,'requires' => ['Text-Balanced-1.95.tar.gz'],'requires_module' => {'Text::Balanced' => 0},'requires_recursive' => ['Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 15198,'unpacked' => 65743},'testers' => {'pass' => 1},'uses' => ['Carp','Text::Balanced','charnames','strict','vars']},'YAPE-Regex-Explain-3.011.tar.gz' => {'author' => 'PINYAN','description' => 'explanation of a regular expression','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 745,'pod' => 45,'pod_errors' => 0,'total' => 790,'with_comments' => 22},'releases' => 9,'size' => {'packed' => 6592,'unpacked' => 28234},'testers' => {'pass' => 2},'uses' => ['YAPE::Regex','strict','vars']},'Yada-Yada-Yada-0.02.tar.gz' => {'author' => 'TMTM','description' => 'defer coding to later','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 16,'pod' => 31,'pod_errors' => 0,'total' => 47,'with_comments' => 0},'releases' => 1,'requires' => ['Filter-Simple-0.78.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Filter::Simple' => '0.76','Test::Simple' => '0.01'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Filter-Simple-0.78.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Balanced-1.95.tar.gz'],'size' => {'packed' => 1432,'unpacked' => 2044},'testers' => {'pass' => 4},'uses' => ['Carp','Filter::Simple','vars']},'YiJing-0.02.tar.gz' => {'author' => 'AUTRIJUS','description' => 'The Book of Hacking','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 114,'pod' => 609,'pod_errors' => 0,'total' => 723,'with_comments' => 2},'releases' => 2,'size' => {'packed' => 10729,'unpacked' => 23253},'testers' => {'pass' => 3},'uses' => []},'Zobel-0.14.tar.gz' => {'author' => 'DYACOB','description' => '- Specialized Front End to the LiveGe\'ez Package.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2861,'pod' => 282,'pod_errors' => 0,'total' => 3143,'with_comments' => 505},'releases' => 12,'size' => {'packed' => 30006,'unpacked' => 100623},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['5.000','Apache','Apache::Constants','Apache::Request','Apache::URI','Convert::Ethiopic','Convert::Ethiopic::Cstocs','Convert::Ethiopic::System','Convert::Ethiopic::Time','Exporter','HTML::Entities','HTML::Filter','HTTP::Request','HTTP::Response','LWP::Simple','LWP::UserAgent','LiveGeez::CacheAsSERA','LiveGeez::Cgi','LiveGeez::File','LiveGeez::HTML','LiveGeez::Local','LiveGeez::Request','LiveGeez::Services','POSIX','strict','vars']},'Zobel-0.20-100701.tar.gz' => {'author' => 'DYACOB','description' => '- Specialized Front End to the LiveGe\'ez Package.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4611,'pod' => 413,'pod_errors' => 0,'total' => 5024,'with_comments' => 739},'releases' => 1,'size' => {'packed' => 41316,'unpacked' => 150368},'testers' => {'fail' => 1,'tests' => '0','unknown' => 3},'uses' => ['5.000','Apache::Constants','Apache::Cookie','Apache::File','Apache::Request','Apache::URI','Compress::Zlib','Convert::Ethiopic','Convert::Ethiopic::Date','Convert::Ethiopic::Number','Convert::Ethiopic::String','Convert::Ethiopic::System','Exporter','File::Path','HTML::Entities','HTML::Filter','HTML::Parser','HTTP::Request','HTTP::Response','LWP::Simple','LWP::UserAgent','POSIX','URI','diagnostics','strict','vars']},'Zoidberg-0.3c.tar.gz' => {'author' => 'PARDUS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6420,'pod' => 1904,'pod_errors' => 1,'total' => 8324,'with_comments' => 607},'releases' => 1,'size' => {'packed' => 107465,'unpacked' => 299638},'testers' => {'fail' => 1,'tests' => '92'},'uses' => ['Benchmark','Carp','Config','Cwd','Data::Dumper','Devel::GetSymbols','Env','Exporter','File::Glob','File::Spec','IO::File','POSIX','Storable','Term::ANSIColor','Term::ANSIScreen','Term::ReadKey','Tie::Array','Tie::Hash','Zoidberg::Fish::Prompt::string','Zoidberg::FormatedString','Zoidberg::IPC','Zoidberg::StringParse::Syntax','Zoidberg::ZoidParse::scuddle','Zoidberg::stub','strict','utf','vars']},'abbreviation-0.02.tar.gz' => {'author' => 'MIYAGAWA','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 75,'pod' => 38,'pod_errors' => 0,'total' => 113,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 1947,'unpacked' => 3418},'testers' => {'pass' => 3},'uses' => ['Foo','strict','vars']},'again-0.01.tar.gz' => {'author' => 'JUERD','description' => 'Reload modules when they change','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 65,'pod' => 51,'pod_errors' => 0,'total' => 116,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2642,'unpacked' => 6404},'testers' => {'pass' => 7},'uses' => ['Carp']},'base-Glob-0.01.tar.gz' => {'author' => 'CHRIS','description' => 'Establish IS-A relationships based on globbing patterns','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 29,'pod' => 37,'pod_errors' => 0,'total' => 66,'with_comments' => 0},'releases' => 1,'requires' => ['Devel-Symdump-2.03.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Text-Glob-0.05.tar.gz'],'requires_module' => {'Devel::Symdump' => 0,'Sub::Uplevel' => 0,'Text::Glob' => 0},'requires_recursive' => ['Devel-Symdump-2.03.tar.gz','File-Spec-0.82.tar.gz','Sub-Uplevel-0.07-2.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Glob-0.05.tar.gz'],'size' => {'packed' => 1948,'unpacked' => 3200},'testers' => {'pass' => 3},'uses' => ['Devel::Symdump','Sub::Uplevel','Text::Glob','base','strict','vars']},'bbobj-0.5.0.tar.gz' => {'author' => 'DONSHANK','description' => 'Perl extension for common functionality in BigBrother monitoring scripts.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 323,'pod' => 192,'pod_errors' => 2,'total' => 515,'with_comments' => 46},'releases' => 2,'size' => {'packed' => 6045,'unpacked' => 16693},'testers' => {'fail' => 2},'uses' => ['5.006','BigBrother::Object::Config','Date::Manip','strict','warnings']},'beancounter_0.6.2.tar.gz' => {'author' => 'EDD','description' => 'Module for stock portfolio performance functions.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1287,'pod' => 124,'pod_errors' => 0,'total' => 1411,'with_comments' => 236},'releases' => 1,'requires' => ['DBD-Pg-1.22.tar.gz','DBI-1.37.tar.gz','DateManip-5.42a.tar.gz','HTML-Parser-3.28.tar.gz','Statistics-Descriptive-2.6.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'DBD::Pg' => '0.93','DBI' => '1.16','Date::Manip' => '5.35','HTML::Parser' => '2.2','HTTP::Request' => '1.23','LWP::UserAgent' => '1.62','Statistics::Descriptive' => '2.4','Text::ParseWords' => '3.1'},'requires_recursive' => ['DBD-Pg-1.22.tar.gz','DBI-1.37.tar.gz','DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Statistics-Descriptive-2.6.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 59858,'unpacked' => 192415},'testers' => {},'uses' => ['Carp','DBI','Data::Dumper','Date::Manip','English','Exporter','Finance::YahooQuote','POSIX','Statistics::Descriptive','Text::ParseWords','strict']},'bid.tar.gz' => {'author' => 'STRYTOAST','description' => 'Information on an auction bid','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 80,'pod' => 119,'pod_errors' => 0,'total' => 199,'with_comments' => 8},'releases' => 1,'requires' => ['Class-DBI-0.93.tar.gz','Date-Simple-1.03.tar.gz','Test-Simple-0.47.tar.gz','lot.tar.gz'],'requires_module' => {'Auction::Lot' => 1,'Class::DBI' => '0.27','Date::Simple' => '1.03','Test::More' => '0.17'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','Date-Simple-1.03.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','lot.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3742,'unpacked' => 11410},'testers' => {},'uses' => ['Auction::Lot','Class::DBI','Date::Simple','strict','vars']},'bignum-0.13.tar.gz' => {'author' => 'TELS','description' => 'Transparent BigNumber support for Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 734,'pod' => 414,'pod_errors' => 0,'total' => 1148,'with_comments' => 117},'releases' => 8,'requires' => ['Math-BigInt-1.64.tar.gz','Math-BigRat-0.09.tar.gz'],'requires_module' => {'Math::BigFloat' => '1.37','Math::BigInt' => '1.62','Math::BigRat' => '0.09'},'requires_recursive' => ['Math-BigInt-1.64.tar.gz','Math-BigRat-0.09.tar.gz'],'size' => {'packed' => 12018,'unpacked' => 49910},'testers' => {'fail' => 4,'pass' => 7,'tests' => '163'},'uses' => ['5.005','5.005_02','Carp','Exporter','Math::BigFloat','Math::BigInt','Math::BigInt::Lite','Math::BigRat','overload','strict','vars']},'bioperl-0.05.1.tar.gz' => {'author' => 'BIRNEY','description' => 'bioperl sequence object','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 24217,'pod' => 15405,'pod_errors' => 5,'total' => 39622,'with_comments' => 4628},'releases' => 15,'size' => {'packed' => 843148,'unpacked' => 3031372},'testers' => {'pass' => 3},'uses' => ['5.002','5.003','Ace','AutoLoader','Bio::Index::Abstract','Bio::Root::Err','Bio::Root::Global','Bio::Root::IOManager','Bio::Root::Object','Bio::Root::Utilities','Bio::Root::Xref','Bio::Seq','Bio::SeqIO','Bio::SimpleAlign','Bio::Tools::AlignFactory','Bio::Tools::Blast::HSP','Bio::Tools::Blast::HTML','Bio::Tools::Blast::Run::LocalBlast','Bio::Tools::Blast::Run::Webblast','Bio::Tools::Blast::Sbjct','Bio::Tools::SeqAnal','Bio::Tools::WWW','Bio::UnivAln','Carp','DynaLoader','Exporter','Fcntl','File::Basename','FileHandle','IO::File','IO::Socket','POSIX','strict','vars']},'bioperl-0.6.2.tar.gz' => {'author' => 'BIRNEY','description' => 'Sequence object, with features','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 30654,'pod' => 19358,'pod_errors' => 3,'total' => 50012,'with_comments' => 5347},'releases' => 15,'size' => {'packed' => 794360,'unpacked' => 2323083},'testers' => {'pass' => 9},'uses' => ['5.002','Ace','AutoLoader','Bio::Annotation','Bio::Annotation::Comment','Bio::Annotation::DBLink','Bio::Annotation::Reference','Bio::DB::RandomAccessI','Bio::DB::SeqI','Bio::Ext::Align','Bio::Index::Abstract','Bio::Index::AbstractSeq','Bio::LocatableSeq','Bio::PrimarySeq','Bio::PrimarySeqI','Bio::RangeI','Bio::Root::Err','Bio::Root::Global','Bio::Root::IOManager','Bio::Root::Object','Bio::Root::RootI','Bio::Root::Utilities','Bio::Root::Xref','Bio::Search::Hit::Fasta','Bio::Search::Hit::HitI','Bio::Search::Result::ResultI','Bio::Seq','Bio::SeqFeature::FeaturePair','Bio::SeqFeature::Generic','Bio::SeqFeatureI','Bio::SeqI','Bio::SeqIO','Bio::SeqIO::FTHelper','Bio::SeqIO::MultiFile','Bio::SeqIO::StreamI','Bio::SimpleAlign','Bio::Species','Bio::Tools::AlignFactory','Bio::Tools::Blast::Run::LocalBlast','Bio::Tools::Blast::Run::Webblast','Bio::Tools::CodonTable','Bio::Tools::HMMER::Domain','Bio::Tools::HMMER::Set','Bio::Tools::SeqAnal','Bio::Tools::WWW','Bio::UnivAln','Carp','DB_File','Exporter','Fcntl','File::Basename','FileHandle','IO::File','IO::Scalar','IO::Socket','POSIX','SDBM_File','strict','vars']},'bioperl-0.7.0.tar.gz' => {'author' => 'BIRNEY','description' => 'provides a simple framework for writing test scripts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 54114,'pod' => 31119,'pod_errors' => 3,'total' => 85233,'with_comments' => 9068},'releases' => 15,'size' => {'packed' => 1329985,'unpacked' => 4438655},'testers' => {'pass' => 4},'uses' => ['$type','5.002','Ace','AutoLoader','Bio::AlignIO','Bio::Annotation','Bio::Annotation::Comment','Bio::Annotation::DBLink','Bio::Annotation::Reference','Bio::DB::NCBIHelper','Bio::DB::RandomAccessI','Bio::DB::SeqI','Bio::DB::WebDBSeqI','Bio::DBLinkContainerI','Bio::Ext::Align','Bio::Factory::DriverFactory','Bio::Factory::SeqAnalysisParserFactoryI','Bio::Index::Abstract','Bio::Index::AbstractSeq','Bio::LiveSeq::AARange','Bio::LiveSeq::Chain','Bio::LiveSeq::ChainI','Bio::LiveSeq::DNA','Bio::LiveSeq::Exon','Bio::LiveSeq::Gene','Bio::LiveSeq::IO::Loader','Bio::LiveSeq::Intron','Bio::LiveSeq::Prim_Transcript','Bio::LiveSeq::Range','Bio::LiveSeq::Repeat_Region','Bio::LiveSeq::Repeat_Unit','Bio::LiveSeq::SeqI','Bio::LiveSeq::Transcript','Bio::LiveSeq::Translation','Bio::LocatableSeq','Bio::Location::CoordinatePolicyI','Bio::Location::Fuzzy','Bio::Location::FuzzyLocationI','Bio::Location::Simple','Bio::Location::Split','Bio::Location::SplitLocationI','Bio::Location::WidestCoordPolicy','Bio::LocationI','Bio::PrimarySeq','Bio::PrimarySeqI','Bio::RangeI','Bio::Root::Err','Bio::Root::Global','Bio::Root::IO','Bio::Root::IOManager','Bio::Root::Object','Bio::Root::RootI','Bio::Root::Utilities','Bio::Root::Xref','Bio::Seq','Bio::Seq::LargePrimarySeq','Bio::Seq::LargeSeq','Bio::Seq::RichSeq','Bio::Seq::RichSeqI','Bio::SeqAnalysisParserI','Bio::SeqFeature::FeaturePair','Bio::SeqFeature::Gene::Exon','Bio::SeqFeature::Gene::ExonI','Bio::SeqFeature::Gene::Transcript','Bio::SeqFeature::Gene::TranscriptI','Bio::SeqFeature::Generic','Bio::SeqFeature::Similarity','Bio::SeqFeature::SimilarityPair','Bio::SeqFeatureI','Bio::SeqI','Bio::SeqIO','Bio::SeqIO::FTHelper','Bio::SeqIO::MultiFile','Bio::SeqIO::game::featureHandler','Bio::SeqIO::game::idHandler','Bio::SeqIO::game::seqHandler','Bio::SeqIO::gcg','Bio::SimpleAlign','Bio::Species','Bio::Tools::AlignFactory','Bio::Tools::AnalysisResult','Bio::Tools::BPbl2seq','Bio::Tools::BPlite','Bio::Tools::BPlite::HSP','Bio::Tools::BPlite::Iteration','Bio::Tools::BPlite::Sbjct','Bio::Tools::BPpsilite','Bio::Tools::Blast','Bio::Tools::Blast::HSP','Bio::Tools::Blast::HTML','Bio::Tools::Blast::Sbjct','Bio::Tools::CodonTable','Bio::Tools::GFF','Bio::Tools::HMMER::Domain','Bio::Tools::HMMER::Set','Bio::Tools::Prediction::Exon','Bio::Tools::Prediction::Gene','Bio::Tools::SeqAnal','Bio::Tools::SeqStats','Bio::Tools::Sim4::Exon','Bio::Tools::WWW','Bio::Variation::AAChange','Bio::Variation::Allele','Bio::Variation::DNAMutation','Bio::Variation::IO','Bio::Variation::RNAChange','Bio::Variation::SeqDiff','Bio::Variation::VariantI','Carp','DB_File','Exporter','Fcntl','File::Basename','File::Spec','File::Temp','HTML::Parser','HTTP::Request::Common','HTTP::Response','IO','IO::Scalar','IO::String','LWP::UserAgent','POSIX','Symbol','Text::Wrap','XML::Handler::Subs','XML::Node','XML::Parser','XML::Parser::PerlSAX','XML::Writer','integer','overload','srsperl','strict','vars']},'bioperl-1.0.2.tar.gz' => {'author' => 'BIRNEY','description' => 'Functional access to BioPerl for people who don\'t know objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 106064,'pod' => 64853,'pod_errors' => 2,'total' => 170917,'with_comments' => 14655},'releases' => 15,'size' => {'packed' => 2645781,'unpacked' => 9306400},'testers' => {'fail' => 2,'tests' => '1933','unknown' => 3},'uses' => ['$type','5.002','5.004','Ace','Ace::Sequence::Homol','AnyDBM_File','AutoLoader','BMS::Branch','Bio::AlignIO','Bio::AnalysisParserI','Bio::AnalysisResultI','Bio::Annotation::Collection','Bio::Annotation::Comment','Bio::Annotation::DBLink','Bio::Annotation::Reference','Bio::Annotation::SimpleValue','Bio::Annotation::TypeManager','Bio::AnnotationCollectionI','Bio::AnnotationI','Bio::Biblio','Bio::Biblio::Article','Bio::Biblio::BiblioBase','Bio::Biblio::Book','Bio::Biblio::BookArticle','Bio::Biblio::IO','Bio::Biblio::IO::medlinexml','Bio::Biblio::Journal','Bio::Biblio::JournalArticle','Bio::Biblio::MedlineArticle','Bio::Biblio::MedlineBook','Bio::Biblio::MedlineBookArticle','Bio::Biblio::MedlineJournal','Bio::Biblio::MedlineJournalArticle','Bio::Biblio::Organisation','Bio::Biblio::Person','Bio::Biblio::Provider','Bio::Biblio::PubmedArticle','Bio::Biblio::Ref','Bio::DB::BiblioI','Bio::DB::BioFetch','Bio::DB::DBFetch','Bio::DB::EMBL','Bio::DB::Failover','Bio::DB::Fasta','Bio::DB::Flat','Bio::DB::Flat::BDB','Bio::DB::GFF','Bio::DB::GFF::Adaptor::dbi','Bio::DB::GFF::Adaptor::dbi::caching_handle','Bio::DB::GFF::Adaptor::dbi::iterator','Bio::DB::GFF::Adaptor::dbi::mysql','Bio::DB::GFF::Adaptor::memory_iterator','Bio::DB::GFF::Aggregator','Bio::DB::GFF::Featname','Bio::DB::GFF::Feature','Bio::DB::GFF::Homol','Bio::DB::GFF::RelSegment','Bio::DB::GFF::Segment','Bio::DB::GFF::Typename','Bio::DB::GFF::Util::Binning','Bio::DB::GFF::Util::Rearrange','Bio::DB::GenBank','Bio::DB::NCBIHelper','Bio::DB::RandomAccessI','Bio::DB::RefSeq','Bio::DB::SeqI','Bio::DB::SwissProt','Bio::DB::WebDBSeqI','Bio::DB::XEMBLService','Bio::DBLinkContainerI','Bio::Event::EventGeneratorI','Bio::Event::EventHandlerI','Bio::Ext::Align','Bio::Factory::ApplicationFactoryI','Bio::Factory::BlastHitFactory','Bio::Factory::BlastResultFactory','Bio::Factory::DriverFactory','Bio::Factory::HitFactoryI','Bio::Factory::MapFactoryI','Bio::Factory::ResultFactoryI','Bio::Factory::SeqAnalysisParserFactoryI','Bio::Factory::TreeFactoryI','Bio::Graphics::Feature','Bio::Graphics::Glyph','Bio::Graphics::Glyph::Factory','Bio::Graphics::Glyph::arrow','Bio::Graphics::Glyph::ellipse','Bio::Graphics::Glyph::generic','Bio::Graphics::Glyph::graded_segments','Bio::Graphics::Glyph::segmented_keyglyph','Bio::Graphics::Glyph::segments','Bio::Graphics::Glyph::transcript','Bio::Graphics::Glyph::translation','Bio::Graphics::Panel','Bio::Graphics::Util','Bio::Index::Abstract','Bio::Index::AbstractSeq','Bio::LiveSeq::AARange','Bio::LiveSeq::Chain','Bio::LiveSeq::ChainI','Bio::LiveSeq::DNA','Bio::LiveSeq::Exon','Bio::LiveSeq::Gene','Bio::LiveSeq::IO::Loader','Bio::LiveSeq::Intron','Bio::LiveSeq::Mutation','Bio::LiveSeq::Prim_Transcript','Bio::LiveSeq::Range','Bio::LiveSeq::Repeat_Region','Bio::LiveSeq::Repeat_Unit','Bio::LiveSeq::SeqI','Bio::LiveSeq::Transcript','Bio::LiveSeq::Translation','Bio::LocatableSeq','Bio::Location::CoordinatePolicyI','Bio::Location::Fuzzy','Bio::Location::FuzzyLocationI','Bio::Location::Simple','Bio::Location::Split','Bio::Location::SplitLocationI','Bio::Location::WidestCoordPolicy','Bio::LocationI','Bio::Map::CytoPosition','Bio::Map::LinkagePosition','Bio::Map::MapI','Bio::Map::MappableI','Bio::Map::Marker','Bio::Map::MarkerI','Bio::Map::OrderedPosition','Bio::Map::Position','Bio::Map::PositionI','Bio::Map::SimpleMap','Bio::MapIO','Bio::PrimarySeq','Bio::PrimarySeqI','Bio::RangeI','Bio::Root::Err','Bio::Root::Global','Bio::Root::HTTPget','Bio::Root::IO','Bio::Root::IOManager','Bio::Root::Object','Bio::Root::Root','Bio::Root::RootI','Bio::Root::Utilities','Bio::Root::Xref','Bio::Search::BlastUtils','Bio::Search::DatabaseI','Bio::Search::GenericDatabase','Bio::Search::HSP::BlastHSP','Bio::Search::HSP::GenericHSP','Bio::Search::HSP::HSPI','Bio::Search::Hit::BlastHit','Bio::Search::Hit::GenericHit','Bio::Search::Hit::HitI','Bio::Search::Result::BlastResult','Bio::Search::Result::GenericResult','Bio::Search::Result::ResultI','Bio::SearchIO','Bio::SearchIO::EventHandlerI','Bio::SearchIO::SearchResultEventBuilder','Bio::SearchIO::SearchWriterI','Bio::SearchIO::Writer::ResultTableWriter','Bio::Seq','Bio::Seq::LargePrimarySeq','Bio::Seq::LargeSeq','Bio::Seq::PrimaryQual','Bio::Seq::QualI','Bio::Seq::RichSeq','Bio::Seq::RichSeqI','Bio::Seq::SeqWithQuality','Bio::SeqAnalysisParserI','Bio::SeqFeature::FeaturePair','Bio::SeqFeature::Gene::Exon','Bio::SeqFeature::Gene::ExonI','Bio::SeqFeature::Gene::GeneStructureI','Bio::SeqFeature::Gene::Intron','Bio::SeqFeature::Gene::NC_Feature','Bio::SeqFeature::Gene::Poly_A_site','Bio::SeqFeature::Gene::Promoter','Bio::SeqFeature::Gene::Transcript','Bio::SeqFeature::Gene::TranscriptI','Bio::SeqFeature::Gene::UTR','Bio::SeqFeature::Generic','Bio::SeqFeature::Similarity','Bio::SeqFeature::SimilarityPair','Bio::SeqFeatureI','Bio::SeqI','Bio::SeqIO','Bio::SeqIO::FTHelper','Bio::SeqIO::MultiFile','Bio::SeqIO::bsml','Bio::SeqIO::game::featureHandler','Bio::SeqIO::game::idHandler','Bio::SeqIO::game::seqHandler','Bio::SeqIO::gcg','Bio::SeqUtils','Bio::SimpleAlign','Bio::Species','Bio::Structure::Atom','Bio::Structure::Chain','Bio::Structure::Entry','Bio::Structure::IO','Bio::Structure::Model','Bio::Structure::Residue','Bio::Structure::StructureI','Bio::Symbol::Alphabet','Bio::Symbol::AlphabetI','Bio::Symbol::Symbol','Bio::Symbol::SymbolI','Bio::Tools::AlignFactory','Bio::Tools::Alignment::Trim','Bio::Tools::AnalysisResult','Bio::Tools::BPbl2seq','Bio::Tools::BPlite','Bio::Tools::BPlite::HSP','Bio::Tools::BPlite::Iteration','Bio::Tools::BPlite::Sbjct','Bio::Tools::BPpsilite','Bio::Tools::Blast::HSP','Bio::Tools::Blast::HTML','Bio::Tools::Blast::Run::LocalBlast','Bio::Tools::Blast::Run::Webblast','Bio::Tools::Blast::Sbjct','Bio::Tools::CodonTable','Bio::Tools::GFF','Bio::Tools::HMMER::Domain','Bio::Tools::HMMER::Set','Bio::Tools::IUPAC','Bio::Tools::Prediction::Exon','Bio::Tools::Prediction::Gene','Bio::Tools::Run::EMBOSSApplication','Bio::Tools::SeqAnal','Bio::Tools::SeqStats','Bio::Tools::Sim4::Exon','Bio::Tools::StateMachine::AbstractStateMachine','Bio::Tools::StateMachine::IOStateMachine','Bio::Tools::WWW','Bio::Tree::AlleleNode','Bio::Tree::Node','Bio::Tree::NodeI','Bio::Tree::Tree','Bio::Tree::TreeI','Bio::TreeIO','Bio::TreeIO::TreeEventBuilder','Bio::UnivAln','Bio::Variation::AAChange','Bio::Variation::Allele','Bio::Variation::DNAMutation','Bio::Variation::IO','Bio::Variation::RNAChange','Bio::Variation::SeqDiff','Bio::Variation::VariantI','Carp','DBI','DB_File','Data::Dumper','Dumpvalue','Exporter','Fcntl','File::Basename','File::Path','File::Spec','File::Temp','FileHandle','GD','HTML::Parser','HTTP::Request::Common','HTTP::Response','IO','IO::File','IO::Socket','IO::String','LWP','LWP::UserAgent','POSIX','SOAP::Lite','Storable','Symbol','TestInterface','Text::Shellwords','Text::Wrap','Tie::Handle','Tie::IxHash','Tie::RefHash','XML::DOM','XML::Handler::Subs','XML::Parser','XML::Parser::PerlSAX','XML::Twig','XML::Writer','constant','integer','lib','overload','srsperl','strict','vars']},'bioperl-1.0.tar.gz' => {'author' => 'BIRNEY','description' => 'Functional access to BioPerl for people who don\'t know objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 103448,'pod' => 63753,'pod_errors' => 2,'total' => 167201,'with_comments' => 14554},'releases' => 15,'size' => {'packed' => 2547171,'unpacked' => 9072517},'testers' => {},'uses' => ['$type','5.002','5.004','Ace','Ace::Sequence::Homol','AnyDBM_File','AutoLoader','BMS::Branch','Bio::AlignIO','Bio::AnalysisParserI','Bio::AnalysisResultI','Bio::Annotation','Bio::Annotation::Collection','Bio::Annotation::Comment','Bio::Annotation::DBLink','Bio::Annotation::Reference','Bio::Annotation::SimpleValue','Bio::Annotation::TypeManager','Bio::AnnotationCollectionI','Bio::AnnotationI','Bio::Biblio','Bio::Biblio::Article','Bio::Biblio::BiblioBase','Bio::Biblio::Book','Bio::Biblio::BookArticle','Bio::Biblio::IO','Bio::Biblio::IO::medline2ref','Bio::Biblio::IO::medlinexml','Bio::Biblio::Journal','Bio::Biblio::JournalArticle','Bio::Biblio::MedlineArticle','Bio::Biblio::MedlineBook','Bio::Biblio::MedlineBookArticle','Bio::Biblio::MedlineJournal','Bio::Biblio::MedlineJournalArticle','Bio::Biblio::Organisation','Bio::Biblio::Person','Bio::Biblio::Provider','Bio::Biblio::PubmedArticle','Bio::Biblio::Ref','Bio::DB::BiblioI','Bio::DB::DBFetch','Bio::DB::EMBL','Bio::DB::Failover','Bio::DB::Fasta','Bio::DB::Flat','Bio::DB::Flat::BDB','Bio::DB::GFF','Bio::DB::GFF::Adaptor::dbi','Bio::DB::GFF::Adaptor::dbi::caching_handle','Bio::DB::GFF::Adaptor::dbi::iterator','Bio::DB::GFF::Adaptor::dbi::mysql','Bio::DB::GFF::Aggregator','Bio::DB::GFF::Featname','Bio::DB::GFF::Feature','Bio::DB::GFF::Homol','Bio::DB::GFF::RelSegment','Bio::DB::GFF::Segment','Bio::DB::GFF::Typename','Bio::DB::GFF::Util::Binning','Bio::DB::GFF::Util::Rearrange','Bio::DB::GenBank','Bio::DB::NCBIHelper','Bio::DB::RandomAccessI','Bio::DB::RefSeq','Bio::DB::SeqI','Bio::DB::SwissProt','Bio::DB::WebDBSeqI','Bio::DB::XEMBLService','Bio::DBLinkContainerI','Bio::Event::EventGeneratorI','Bio::Event::EventHandlerI','Bio::Ext::Align','Bio::Factory::ApplicationFactoryI','Bio::Factory::BlastHitFactory','Bio::Factory::BlastResultFactory','Bio::Factory::DriverFactory','Bio::Factory::HitFactoryI','Bio::Factory::MapFactoryI','Bio::Factory::ResultFactoryI','Bio::Factory::SeqAnalysisParserFactoryI','Bio::Factory::TreeFactoryI','Bio::Graphics::Feature','Bio::Graphics::Glyph','Bio::Graphics::Glyph::Factory','Bio::Graphics::Glyph::arrow','Bio::Graphics::Glyph::ellipse','Bio::Graphics::Glyph::generic','Bio::Graphics::Glyph::graded_segments','Bio::Graphics::Glyph::segmented_keyglyph','Bio::Graphics::Glyph::transcript','Bio::Graphics::Glyph::transcript2','Bio::Graphics::Panel','Bio::Index::Abstract','Bio::Index::AbstractSeq','Bio::LiveSeq::AARange','Bio::LiveSeq::Chain','Bio::LiveSeq::ChainI','Bio::LiveSeq::DNA','Bio::LiveSeq::Exon','Bio::LiveSeq::Gene','Bio::LiveSeq::IO::Loader','Bio::LiveSeq::Intron','Bio::LiveSeq::Mutation','Bio::LiveSeq::Prim_Transcript','Bio::LiveSeq::Range','Bio::LiveSeq::Repeat_Region','Bio::LiveSeq::Repeat_Unit','Bio::LiveSeq::SeqI','Bio::LiveSeq::Transcript','Bio::LiveSeq::Translation','Bio::LocatableSeq','Bio::Location::CoordinatePolicyI','Bio::Location::Fuzzy','Bio::Location::FuzzyLocationI','Bio::Location::Simple','Bio::Location::Split','Bio::Location::SplitLocationI','Bio::Location::WidestCoordPolicy','Bio::LocationI','Bio::Map::CytoPosition','Bio::Map::LinkagePosition','Bio::Map::MapI','Bio::Map::MappableI','Bio::Map::Marker','Bio::Map::MarkerI','Bio::Map::OrderedPosition','Bio::Map::Position','Bio::Map::PositionI','Bio::Map::SimpleMap','Bio::MapIO','Bio::PrimarySeq','Bio::PrimarySeqI','Bio::RangeI','Bio::Root','Bio::Root::Err','Bio::Root::Exception','Bio::Root::Global','Bio::Root::HTTPget','Bio::Root::IO','Bio::Root::IOManager','Bio::Root::Object','Bio::Root::Root','Bio::Root::RootI','Bio::Root::Utilities','Bio::Root::Xref','Bio::Search::BlastUtils','Bio::Search::DatabaseI','Bio::Search::GenericDatabase','Bio::Search::HSP::BlastHSP','Bio::Search::HSP::GenericHSP','Bio::Search::HSP::HSPI','Bio::Search::Hit::BlastHit','Bio::Search::Hit::GenericHit','Bio::Search::Hit::HitI','Bio::Search::Result::BlastResult','Bio::Search::Result::GenericResult','Bio::Search::Result::ResultI','Bio::SearchIO','Bio::SearchIO::EventHandlerI','Bio::SearchIO::SearchResultEventBuilder','Bio::SearchIO::SearchWriterI','Bio::SearchIO::Writer::ResultTableWriter','Bio::Seq','Bio::Seq::LargePrimarySeq','Bio::Seq::LargeSeq','Bio::Seq::PrimaryQual','Bio::Seq::QualI','Bio::Seq::RichSeq','Bio::Seq::RichSeqI','Bio::Seq::SeqWithQuality','Bio::SeqAnalysisParserI','Bio::SeqFeature::FeaturePair','Bio::SeqFeature::Gene::Exon','Bio::SeqFeature::Gene::ExonI','Bio::SeqFeature::Gene::GeneStructureI','Bio::SeqFeature::Gene::Intron','Bio::SeqFeature::Gene::NC_Feature','Bio::SeqFeature::Gene::Poly_A_site','Bio::SeqFeature::Gene::Promoter','Bio::SeqFeature::Gene::Transcript','Bio::SeqFeature::Gene::TranscriptI','Bio::SeqFeature::Gene::UTR','Bio::SeqFeature::Generic','Bio::SeqFeature::Similarity','Bio::SeqFeature::SimilarityPair','Bio::SeqFeatureI','Bio::SeqI','Bio::SeqIO','Bio::SeqIO::FTHelper','Bio::SeqIO::MultiFile','Bio::SeqIO::bsml','Bio::SeqIO::game::featureHandler','Bio::SeqIO::game::idHandler','Bio::SeqIO::game::seqHandler','Bio::SeqIO::gcg','Bio::SeqUtils','Bio::SimpleAlign','Bio::Species','Bio::Structure::Atom','Bio::Structure::Chain','Bio::Structure::Entry','Bio::Structure::IO','Bio::Structure::Model','Bio::Structure::Residue','Bio::Structure::StructureI','Bio::Symbol::Alphabet','Bio::Symbol::AlphabetI','Bio::Symbol::Symbol','Bio::Symbol::SymbolI','Bio::Tools::AlignFactory','Bio::Tools::Alignment::Trim','Bio::Tools::AnalysisResult','Bio::Tools::BPbl2seq','Bio::Tools::BPlite','Bio::Tools::BPlite::HSP','Bio::Tools::BPlite::Iteration','Bio::Tools::BPlite::Sbjct','Bio::Tools::BPpsilite','Bio::Tools::Blast::HSP','Bio::Tools::Blast::HTML','Bio::Tools::Blast::Run::LocalBlast','Bio::Tools::Blast::Run::Webblast','Bio::Tools::Blast::Sbjct','Bio::Tools::CodonTable','Bio::Tools::GFF','Bio::Tools::HMMER::Domain','Bio::Tools::HMMER::Set','Bio::Tools::IUPAC','Bio::Tools::Prediction::Exon','Bio::Tools::Prediction::Gene','Bio::Tools::Run::EMBOSSApplication','Bio::Tools::SeqAnal','Bio::Tools::SeqStats','Bio::Tools::Sim4::Exon','Bio::Tools::StateMachine::AbstractStateMachine','Bio::Tools::StateMachine::IOStateMachine','Bio::Tools::WWW','Bio::Tree::AlleleNode','Bio::Tree::Node','Bio::Tree::NodeI','Bio::Tree::Tree','Bio::Tree::TreeI','Bio::TreeIO','Bio::TreeIO::TreeEventBuilder','Bio::UnivAln','Bio::Variation::AAChange','Bio::Variation::Allele','Bio::Variation::DNAMutation','Bio::Variation::IO','Bio::Variation::RNAChange','Bio::Variation::SeqDiff','Bio::Variation::VariantI','Carp','DBI','DB_File','Data::Dumper','Dumpvalue','Exporter','Fcntl','File::Basename','File::Path','File::Spec','File::Temp','FileHandle','GD','HTML::Parser','HTTP::Request::Common','HTTP::Response','IO','IO::File','IO::Socket','IO::String','LWP','LWP::UserAgent','POSIX','SOAP::Lite','Storable','Symbol','TestInterface','Text::Shellwords','Text::Wrap','Tie::Handle','Tie::IxHash','Tie::RefHash','XML::DOM','XML::Handler::Subs','XML::Parser','XML::Parser::PerlSAX','XML::Twig','XML::Writer','constant','integer','overload','srsperl','strict','vars']},'bioperl-1.2.1.tar.gz' => {'author' => 'BIRNEY','description' => 'Functional access to BioPerl for people who don\'t know objects','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 142615,'pod' => 89129,'pod_errors' => 2,'total' => 231744,'with_comments' => 19116},'releases' => 15,'size' => {'packed' => 3488040,'unpacked' => 12555654},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['$type','5.002','5.004','Ace','Ace::Sequence::Homol','AnyDBM_File','AutoLoader','BMS::Branch','Bio::Align::AlignI','Bio::Align::PairwiseStatistics','Bio::Align::StatisticsI','Bio::AlignIO','Bio::AnalysisParserI','Bio::AnalysisResultI','Bio::AnnotatableI','Bio::Annotation::Collection','Bio::Annotation::Comment','Bio::Annotation::DBLink','Bio::Annotation::OntologyTerm','Bio::Annotation::Reference','Bio::Annotation::SimpleValue','Bio::Annotation::StructuredValue','Bio::Annotation::TypeManager','Bio::AnnotationCollectionI','Bio::AnnotationI','Bio::Assembly::Contig','Bio::Assembly::IO','Bio::Assembly::Scaffold','Bio::Assembly::ScaffoldI','Bio::Biblio::Article','Bio::Biblio::BiblioBase','Bio::Biblio::Book','Bio::Biblio::BookArticle','Bio::Biblio::IO','Bio::Biblio::IO::medline2ref','Bio::Biblio::Journal','Bio::Biblio::JournalArticle','Bio::Biblio::MedlineArticle','Bio::Biblio::MedlineBook','Bio::Biblio::MedlineBookArticle','Bio::Biblio::MedlineJournal','Bio::Biblio::MedlineJournalArticle','Bio::Biblio::Organisation','Bio::Biblio::Person','Bio::Biblio::Provider','Bio::Biblio::PubmedArticle','Bio::Biblio::Ref','Bio::Cluster::ClusterFactory','Bio::Cluster::FamilyI','Bio::Cluster::UniGene','Bio::Cluster::UniGeneI','Bio::ClusterI','Bio::ClusterIO','Bio::Coordinate::Collection','Bio::Coordinate::ExtrapolatingPair','Bio::Coordinate::Graph','Bio::Coordinate::MapperI','Bio::Coordinate::Pair','Bio::Coordinate::Result','Bio::Coordinate::Result::Gap','Bio::Coordinate::Result::Match','Bio::Coordinate::ResultI','Bio::DB::BioFetch','Bio::DB::DBFetch','Bio::DB::EMBL','Bio::DB::Failover','Bio::DB::Fasta','Bio::DB::Flat','Bio::DB::Flat::BDB','Bio::DB::GFF::Adaptor::ace','Bio::DB::GFF::Adaptor::dbi::iterator','Bio::DB::GFF::Adaptor::dbi::mysqlopt','Bio::DB::GFF::Adaptor::memory_iterator','Bio::DB::GFF::Featname','Bio::DB::GFF::Homol','Bio::DB::GFF::Util::Binning','Bio::DB::GFF::Util::Rearrange','Bio::DB::GenBank','Bio::DB::GenPept','Bio::DB::NCBIHelper','Bio::DB::Query::GenBank','Bio::DB::Query::WebQuery','Bio::DB::QueryI','Bio::DB::RandomAccessI','Bio::DB::RefSeq','Bio::DB::SeqI','Bio::DB::SwissProt','Bio::DB::WebDBSeqI','Bio::DB::XEMBLService','Bio::DBLinkContainerI','Bio::Das::FeatureTypeI','Bio::Das::SegmentI','Bio::DasI','Bio::DescribableI','Bio::Event::EventGeneratorI','Bio::Event::EventHandlerI','Bio::Expression::FeatureI','Bio::Ext::Align','Bio::Factory::ApplicationFactoryI','Bio::Factory::BlastHitFactory','Bio::Factory::BlastResultFactory','Bio::Factory::DriverFactory','Bio::Factory::FTLocationFactory','Bio::Factory::HitFactoryI','Bio::Factory::LocationFactoryI','Bio::Factory::MapFactoryI','Bio::Factory::ObjectBuilderI','Bio::Factory::ObjectFactory','Bio::Factory::ObjectFactoryI','Bio::Factory::ResultFactoryI','Bio::Factory::SeqAnalysisParserFactoryI','Bio::Factory::SequenceFactoryI','Bio::Factory::SequenceProcessorI','Bio::Factory::SequenceStreamI','Bio::Factory::TreeFactoryI','Bio::FeatureHolderI','Bio::Graphics::Feature','Bio::Graphics::Glyph','Bio::Graphics::Glyph::Factory','Bio::Graphics::Glyph::arrow','Bio::Graphics::Glyph::ellipse','Bio::Graphics::Glyph::generic','Bio::Graphics::Glyph::graded_segments','Bio::Graphics::Glyph::segmented_keyglyph','Bio::Graphics::Glyph::segments','Bio::Graphics::Glyph::transcript','Bio::Graphics::Glyph::translation','Bio::Graphics::Panel','Bio::Graphics::Util','Bio::IdentifiableI','Bio::Index::Abstract','Bio::Index::AbstractSeq','Bio::LiveSeq::AARange','Bio::LiveSeq::Chain','Bio::LiveSeq::ChainI','Bio::LiveSeq::DNA','Bio::LiveSeq::Exon','Bio::LiveSeq::Gene','Bio::LiveSeq::IO::Loader','Bio::LiveSeq::Intron','Bio::LiveSeq::Mutation','Bio::LiveSeq::Prim_Transcript','Bio::LiveSeq::Range','Bio::LiveSeq::Repeat_Region','Bio::LiveSeq::Repeat_Unit','Bio::LiveSeq::SeqI','Bio::LiveSeq::Transcript','Bio::LiveSeq::Translation','Bio::LocatableSeq','Bio::Location::Atomic','Bio::Location::CoordinatePolicyI','Bio::Location::Fuzzy','Bio::Location::FuzzyLocationI','Bio::Location::Simple','Bio::Location::Split','Bio::Location::SplitLocationI','Bio::Location::WidestCoordPolicy','Bio::LocationI','Bio::Map::CytoPosition','Bio::Map::LinkagePosition','Bio::Map::MapI','Bio::Map::MappableI','Bio::Map::Marker','Bio::Map::MarkerI','Bio::Map::OrderedPosition','Bio::Map::Position','Bio::Map::PositionI','Bio::Map::SimpleMap','Bio::MapIO','Bio::Matrix::PhylipDist','Bio::Ontology::Ontology','Bio::Ontology::OntologyEngineI','Bio::Ontology::OntologyI','Bio::Ontology::OntologyStore','Bio::Ontology::PathI','Bio::Ontology::Relationship','Bio::Ontology::RelationshipFactory','Bio::Ontology::RelationshipI','Bio::Ontology::RelationshipType','Bio::Ontology::SimpleGOEngine','Bio::Ontology::SimpleOntologyEngine','Bio::Ontology::Term','Bio::Ontology::TermFactory','Bio::Ontology::TermI','Bio::OntologyIO','Bio::OntologyIO::Handlers::InterProHandler','Bio::OntologyIO::dagflat','Bio::Phenotype::Correlate','Bio::Phenotype::Measure','Bio::Phenotype::OMIM::MiniMIMentry','Bio::Phenotype::OMIM::OMIMentry','Bio::Phenotype::OMIM::OMIMentryAllelicVariant','Bio::Phenotype::Phenotype','Bio::Phenotype::PhenotypeI','Bio::PrimarySeq','Bio::PrimarySeqI','Bio::Range','Bio::RangeI','Bio::Root::Err','Bio::Root::Exception','Bio::Root::Global','Bio::Root::HTTPget','Bio::Root::IO','Bio::Root::IOManager','Bio::Root::Object','Bio::Root::Root','Bio::Root::RootI','Bio::Root::Utilities','Bio::Root::Xref','Bio::Search::BlastUtils','Bio::Search::DatabaseI','Bio::Search::GenericDatabase','Bio::Search::HSP::BlastHSP','Bio::Search::HSP::GenericHSP','Bio::Search::HSP::HSPFactory','Bio::Search::HSP::HSPI','Bio::Search::Hit::BlastHit','Bio::Search::Hit::GenericHit','Bio::Search::Hit::HitFactory','Bio::Search::Hit::HitI','Bio::Search::Result::BlastResult','Bio::Search::Result::GenericResult','Bio::Search::Result::ResultFactory','Bio::Search::Result::ResultI','Bio::Search::SearchUtils','Bio::SearchIO','Bio::SearchIO::EventHandlerI','Bio::SearchIO::SearchResultEventBuilder','Bio::SearchIO::SearchWriterI','Bio::SearchIO::Writer::ResultTableWriter','Bio::SearchIO::chado','Bio::Seq','Bio::Seq::LargePrimarySeq','Bio::Seq::PrimaryQual','Bio::Seq::PrimedSeq','Bio::Seq::QualI','Bio::Seq::RichSeq','Bio::Seq::RichSeqI','Bio::Seq::SeqBuilder','Bio::Seq::SeqFactory','Bio::Seq::SeqFastaSpeedFactory','Bio::Seq::TraceI','Bio::SeqAnalysisParserI','Bio::SeqFeature::Collection','Bio::SeqFeature::CollectionI','Bio::SeqFeature::FeaturePair','Bio::SeqFeature::Gene::Exon','Bio::SeqFeature::Gene::ExonI','Bio::SeqFeature::Gene::GeneStructure','Bio::SeqFeature::Gene::GeneStructureI','Bio::SeqFeature::Gene::Intron','Bio::SeqFeature::Gene::NC_Feature','Bio::SeqFeature::Gene::Poly_A_site','Bio::SeqFeature::Gene::Promoter','Bio::SeqFeature::Gene::Transcript','Bio::SeqFeature::Gene::TranscriptI','Bio::SeqFeature::Gene::UTR','Bio::SeqFeature::Generic','Bio::SeqFeature::Primer','Bio::SeqFeature::Similarity','Bio::SeqFeature::SimilarityPair','Bio::SeqFeatureI','Bio::SeqI','Bio::SeqIO','Bio::SeqIO::FTHelper','Bio::SeqIO::MultiFile','Bio::SeqIO::bsml','Bio::SeqIO::chado','Bio::SeqIO::game::featureHandler','Bio::SeqIO::game::idHandler','Bio::SeqIO::game::seqHandler','Bio::SeqIO::gcg','Bio::SeqIO::staden::read','Bio::SeqUtils','Bio::SimpleAlign','Bio::Species','Bio::Structure::Atom','Bio::Structure::Chain','Bio::Structure::Entry','Bio::Structure::IO','Bio::Structure::Model','Bio::Structure::Residue','Bio::Structure::StructureI','Bio::Symbol::Alphabet','Bio::Symbol::AlphabetI','Bio::Symbol::Symbol','Bio::Symbol::SymbolI','Bio::Taxonomy','Bio::Taxonomy::Taxon','Bio::Tools::AlignFactory','Bio::Tools::Alignment::Trim','Bio::Tools::AnalysisResult','Bio::Tools::BPbl2seq','Bio::Tools::BPlite','Bio::Tools::BPlite::HSP','Bio::Tools::BPlite::Iteration','Bio::Tools::BPlite::Sbjct','Bio::Tools::BPpsilite','Bio::Tools::Blast::HSP','Bio::Tools::Blast::HTML','Bio::Tools::Blast::Run::LocalBlast','Bio::Tools::Blast::Run::Webblast','Bio::Tools::Blast::Sbjct','Bio::Tools::CodonTable','Bio::Tools::GFF','Bio::Tools::Genewise','Bio::Tools::HMMER::Domain','Bio::Tools::HMMER::Set','Bio::Tools::IUPAC','Bio::Tools::Phylo::Molphy::Result','Bio::Tools::Phylo::PAML::Result','Bio::Tools::Prediction::Exon','Bio::Tools::Prediction::Gene','Bio::Tools::Run::EMBOSSApplication','Bio::Tools::Run::RemoteBlast','Bio::Tools::Run::WrapperBase','Bio::Tools::SeqAnal','Bio::Tools::SeqStats','Bio::Tools::Sim4::Exon','Bio::Tools::StateMachine::AbstractStateMachine','Bio::Tools::StateMachine::IOStateMachine','Bio::Tools::WWW','Bio::Tree::AlleleNode','Bio::Tree::Node','Bio::Tree::NodeI','Bio::Tree::NodeNHX','Bio::Tree::Tree','Bio::Tree::TreeFunctionsI','Bio::Tree::TreeI','Bio::TreeIO','Bio::TreeIO::TreeEventBuilder','Bio::UnivAln','Bio::Variation::AAChange','Bio::Variation::Allele','Bio::Variation::DNAMutation','Bio::Variation::IO','Bio::Variation::RNAChange','Bio::Variation::SNP','Bio::Variation::SeqDiff','Bio::Variation::VariantI','Carp','DBI','DB_File','Data::Dumper','Data::Stag','Data::Stag::ITextWriter','Data::Stag::SxprWriter','Data::Stag::XMLWriter','Dumpvalue','Exporter','Fcntl','File::Basename','File::Path','File::Spec','File::Temp','FileHandle','GD','Graph::Directed','HTML::Entities','HTML::Parser','HTTP::Request::Common','HTTP::Response','IO','IO::File','IO::Handle','IO::Socket','IO::String','LWP','LWP::UserAgent','POSIX','SOAP::Lite','Storable','Symbol','TestInterface','Text::Shellwords','Text::Wrap','Tie::Handle','Tie::IxHash','Tie::RefHash','URI','URI::Escape','Win32','XML::DOM','XML::Handler::Subs','XML::Parser','XML::Parser::PerlSAX','XML::Twig','XML::Writer','constant','integer','lib','overload','srsperl','strict','vars']},'bioperl-1.2.2.tar.gz' => {'author' => 'BIRNEY','description' => 'Functional access to BioPerl for people who don\'t know objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 144635,'pod' => 90788,'pod_errors' => 2,'total' => 235423,'with_comments' => 19233},'releases' => 15,'size' => {'packed' => 3576685,'unpacked' => 12799399},'testers' => {'pass' => 1},'uses' => ['$type','5.002','5.004','Ace','Ace::Sequence::Homol','AnyDBM_File','AutoLoader','BMS::Branch','Bio::Biblio','Bio::Biblio::IO::medline2ref','Bio::Biblio::IO::medlinexml','Bio::DB::BiblioI','Bio::DB::GFF','Bio::DB::GFF::Adaptor::dbi','Bio::DB::GFF::Adaptor::dbi::caching_handle','Bio::DB::GFF::Adaptor::dbi::mysql','Bio::DB::GFF::Adaptor::dbi::mysqlopt','Bio::DB::GFF::Adaptor::dbi::oracle','Bio::DB::GFF::Aggregator','Bio::DB::GFF::Feature','Bio::DB::GFF::RelSegment','Bio::DB::GFF::Segment','Bio::DB::GFF::Typename','Bio::Ext::Align','Bio::Graphics::Feature','Bio::Graphics::Glyph','Bio::Graphics::Glyph::Factory','Bio::Graphics::Glyph::anchored_arrow','Bio::Graphics::Glyph::arrow','Bio::Graphics::Glyph::ellipse','Bio::Graphics::Glyph::generic','Bio::Graphics::Glyph::graded_segments','Bio::Graphics::Glyph::segmented_keyglyph','Bio::Graphics::Glyph::segments','Bio::Graphics::Glyph::transcript','Bio::Graphics::Glyph::transcript2','Bio::Graphics::Panel','Bio::Root::Exception','Bio::SeqIO::staden::read','Bio::Tools::Blast::HSP','Bio::Tools::Blast::HTML','Bio::Tools::Blast::Run::LocalBlast','Bio::Tools::Blast::Run::Webblast','Bio::Tools::Blast::Sbjct','Bio::Tools::Run::EMBOSSApplication','Bio::UnivAln','Carp','DBI','DB_File','Data::Dumper','Data::Stag','Data::Stag::ITextWriter','Data::Stag::SxprWriter','Data::Stag::XMLWriter','Dumpvalue','Exporter','Fcntl','File::Basename','File::Path','File::Spec','File::Temp','FileHandle','GD','Graph::Directed','HTML::Entities','HTML::Parser','HTTP::Request::Common','HTTP::Response','IO::File','IO::Handle','IO::Socket','IO::String','LWP','LWP::UserAgent','POSIX','SOAP::Lite','Storable','Symbol','Text::Shellwords','Text::Wrap','Tie::Handle','Tie::IxHash','Tie::RefHash','URI','URI::Escape','Win32','XML::DOM','XML::Handler::Subs','XML::Parser','XML::Parser::PerlSAX','XML::Twig','XML::Writer','constant','integer','lib','overload','srsperl','strict','vars']},'bioperl-1.2.tar.gz' => {'author' => 'BIRNEY','description' => 'Functional access to BioPerl for people who don\'t know objects','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 138864,'pod' => 85904,'pod_errors' => 2,'total' => 224768,'with_comments' => 18611},'releases' => 15,'size' => {'packed' => 3425575,'unpacked' => 12245838},'testers' => {},'uses' => ['$type','5.002','5.004','Ace','Ace::Sequence::Homol','AnyDBM_File','AutoLoader','BMS::Branch','Bio::Align::AlignI','Bio::Align::PairwiseStatistics','Bio::Align::StatisticsI','Bio::AlignIO','Bio::AnalysisParserI','Bio::AnalysisResultI','Bio::AnnotatableI','Bio::Annotation::Collection','Bio::Annotation::Comment','Bio::Annotation::DBLink','Bio::Annotation::OntologyTerm','Bio::Annotation::Reference','Bio::Annotation::SimpleValue','Bio::Annotation::StructuredValue','Bio::Annotation::TypeManager','Bio::AnnotationCollectionI','Bio::AnnotationI','Bio::Assembly::Contig','Bio::Assembly::IO','Bio::Assembly::Scaffold','Bio::Assembly::ScaffoldI','Bio::Biblio','Bio::Biblio::Article','Bio::Biblio::BiblioBase','Bio::Biblio::Book','Bio::Biblio::BookArticle','Bio::Biblio::IO','Bio::Biblio::IO::medline2ref','Bio::Biblio::IO::medlinexml','Bio::Biblio::Journal','Bio::Biblio::JournalArticle','Bio::Biblio::MedlineArticle','Bio::Biblio::MedlineBook','Bio::Biblio::MedlineBookArticle','Bio::Biblio::MedlineJournal','Bio::Biblio::MedlineJournalArticle','Bio::Biblio::Organisation','Bio::Biblio::Person','Bio::Biblio::Provider','Bio::Biblio::PubmedArticle','Bio::Biblio::Ref','Bio::Cluster::ClusterFactory','Bio::Cluster::FamilyI','Bio::Cluster::UniGene','Bio::Cluster::UniGeneI','Bio::ClusterI','Bio::ClusterIO','Bio::Coordinate::Collection','Bio::Coordinate::ExtrapolatingPair','Bio::Coordinate::Graph','Bio::Coordinate::MapperI','Bio::Coordinate::Pair','Bio::Coordinate::Result','Bio::Coordinate::Result::Gap','Bio::Coordinate::Result::Match','Bio::DB::BiblioI','Bio::DB::BioFetch','Bio::DB::DBFetch','Bio::DB::EMBL','Bio::DB::Failover','Bio::DB::Fasta','Bio::DB::Flat','Bio::DB::Flat::BDB','Bio::DB::GFF','Bio::DB::GFF::Adaptor::ace','Bio::DB::GFF::Adaptor::dbi','Bio::DB::GFF::Adaptor::dbi::caching_handle','Bio::DB::GFF::Adaptor::dbi::iterator','Bio::DB::GFF::Adaptor::dbi::mysql','Bio::DB::GFF::Adaptor::dbi::mysqlopt','Bio::DB::GFF::Adaptor::dbi::oracle','Bio::DB::GFF::Adaptor::memory_iterator','Bio::DB::GFF::Aggregator','Bio::DB::GFF::Featname','Bio::DB::GFF::Feature','Bio::DB::GFF::Homol','Bio::DB::GFF::RelSegment','Bio::DB::GFF::Segment','Bio::DB::GFF::Typename','Bio::DB::GFF::Util::Binning','Bio::DB::GFF::Util::Rearrange','Bio::DB::GenBank','Bio::DB::GenPept','Bio::DB::NCBIHelper','Bio::DB::Query::GenBank','Bio::DB::Query::WebQuery','Bio::DB::QueryI','Bio::DB::RandomAccessI','Bio::DB::RefSeq','Bio::DB::SeqI','Bio::DB::SwissProt','Bio::DB::WebDBSeqI','Bio::DB::XEMBLService','Bio::DBLinkContainerI','Bio::Das::FeatureTypeI','Bio::Das::SegmentI','Bio::DasI','Bio::DescribableI','Bio::Event::EventGeneratorI','Bio::Event::EventHandlerI','Bio::Expression::FeatureI','Bio::Ext::Align','Bio::Factory::ApplicationFactoryI','Bio::Factory::BlastHitFactory','Bio::Factory::BlastResultFactory','Bio::Factory::DriverFactory','Bio::Factory::FTLocationFactory','Bio::Factory::HitFactoryI','Bio::Factory::LocationFactoryI','Bio::Factory::MapFactoryI','Bio::Factory::ObjectBuilderI','Bio::Factory::ObjectFactoryI','Bio::Factory::ResultFactoryI','Bio::Factory::SeqAnalysisParserFactoryI','Bio::Factory::SequenceFactoryI','Bio::Factory::SequenceProcessorI','Bio::Factory::SequenceStreamI','Bio::Factory::TreeFactoryI','Bio::FeatureHolderI','Bio::Graphics::Feature','Bio::Graphics::Glyph','Bio::Graphics::Glyph::Factory','Bio::Graphics::Glyph::arrow','Bio::Graphics::Glyph::ellipse','Bio::Graphics::Glyph::generic','Bio::Graphics::Glyph::graded_segments','Bio::Graphics::Glyph::segmented_keyglyph','Bio::Graphics::Glyph::segments','Bio::Graphics::Glyph::transcript','Bio::Graphics::Glyph::translation','Bio::Graphics::Panel','Bio::Graphics::Util','Bio::IdentifiableI','Bio::Index::Abstract','Bio::Index::AbstractSeq','Bio::LiveSeq::AARange','Bio::LiveSeq::Chain','Bio::LiveSeq::ChainI','Bio::LiveSeq::DNA','Bio::LiveSeq::Exon','Bio::LiveSeq::Gene','Bio::LiveSeq::IO::Loader','Bio::LiveSeq::Intron','Bio::LiveSeq::Mutation','Bio::LiveSeq::Prim_Transcript','Bio::LiveSeq::Range','Bio::LiveSeq::Repeat_Region','Bio::LiveSeq::Repeat_Unit','Bio::LiveSeq::SeqI','Bio::LiveSeq::Transcript','Bio::LiveSeq::Translation','Bio::LocatableSeq','Bio::Location::Atomic','Bio::Location::CoordinatePolicyI','Bio::Location::Fuzzy','Bio::Location::FuzzyLocationI','Bio::Location::Simple','Bio::Location::Split','Bio::Location::SplitLocationI','Bio::Location::WidestCoordPolicy','Bio::LocationI','Bio::Map::CytoPosition','Bio::Map::LinkagePosition','Bio::Map::MapI','Bio::Map::MappableI','Bio::Map::Marker','Bio::Map::MarkerI','Bio::Map::OrderedPosition','Bio::Map::Position','Bio::Map::PositionI','Bio::Map::SimpleMap','Bio::MapIO','Bio::Matrix::PhylipDist','Bio::Ontology::GOterm','Bio::Ontology::OntologyEngineI','Bio::Ontology::Relationship','Bio::Ontology::RelationshipI','Bio::Ontology::RelationshipType','Bio::Ontology::SimpleGOEngine','Bio::Ontology::Term','Bio::Ontology::TermI','Bio::Phenotype::Correlate','Bio::Phenotype::Measure','Bio::Phenotype::OMIM::MiniMIMentry','Bio::Phenotype::OMIM::OMIMentry','Bio::Phenotype::OMIM::OMIMentryAllelicVariant','Bio::Phenotype::Phenotype','Bio::Phenotype::PhenotypeI','Bio::PrimarySeq','Bio::PrimarySeqI','Bio::Range','Bio::RangeI','Bio::Root::Err','Bio::Root::Exception','Bio::Root::Global','Bio::Root::HTTPget','Bio::Root::IO','Bio::Root::IOManager','Bio::Root::Object','Bio::Root::Root','Bio::Root::RootI','Bio::Root::Utilities','Bio::Root::Xref','Bio::Search::BlastUtils','Bio::Search::DatabaseI','Bio::Search::GenericDatabase','Bio::Search::HSP::BlastHSP','Bio::Search::HSP::GenericHSP','Bio::Search::HSP::HSPFactory','Bio::Search::HSP::HSPI','Bio::Search::Hit::BlastHit','Bio::Search::Hit::GenericHit','Bio::Search::Hit::HitFactory','Bio::Search::Hit::HitI','Bio::Search::Result::BlastResult','Bio::Search::Result::GenericResult','Bio::Search::Result::ResultFactory','Bio::Search::Result::ResultI','Bio::Search::SearchUtils','Bio::SearchIO','Bio::SearchIO::EventHandlerI','Bio::SearchIO::SearchResultEventBuilder','Bio::SearchIO::SearchWriterI','Bio::SearchIO::Writer::ResultTableWriter','Bio::SearchIO::chado','Bio::Seq','Bio::Seq::LargePrimarySeq','Bio::Seq::PrimaryQual','Bio::Seq::PrimedSeq','Bio::Seq::QualI','Bio::Seq::RichSeq','Bio::Seq::RichSeqI','Bio::Seq::SeqBuilder','Bio::Seq::SeqFactory','Bio::Seq::SeqFastaSpeedFactory','Bio::Seq::TraceI','Bio::SeqAnalysisParserI','Bio::SeqFeature::Collection','Bio::SeqFeature::CollectionI','Bio::SeqFeature::FeaturePair','Bio::SeqFeature::Gene::Exon','Bio::SeqFeature::Gene::ExonI','Bio::SeqFeature::Gene::GeneStructure','Bio::SeqFeature::Gene::GeneStructureI','Bio::SeqFeature::Gene::Intron','Bio::SeqFeature::Gene::NC_Feature','Bio::SeqFeature::Gene::Poly_A_site','Bio::SeqFeature::Gene::Promoter','Bio::SeqFeature::Gene::Transcript','Bio::SeqFeature::Gene::TranscriptI','Bio::SeqFeature::Gene::UTR','Bio::SeqFeature::Generic','Bio::SeqFeature::Primer','Bio::SeqFeature::Similarity','Bio::SeqFeature::SimilarityPair','Bio::SeqFeatureI','Bio::SeqI','Bio::SeqIO','Bio::SeqIO::FTHelper','Bio::SeqIO::MultiFile','Bio::SeqIO::bsml','Bio::SeqIO::chado','Bio::SeqIO::game::featureHandler','Bio::SeqIO::game::idHandler','Bio::SeqIO::game::seqHandler','Bio::SeqIO::gcg','Bio::SeqIO::staden::read','Bio::SeqUtils','Bio::SimpleAlign','Bio::Species','Bio::Structure::Atom','Bio::Structure::Chain','Bio::Structure::Entry','Bio::Structure::IO','Bio::Structure::Model','Bio::Structure::Residue','Bio::Structure::StructureI','Bio::Symbol::Alphabet','Bio::Symbol::AlphabetI','Bio::Symbol::Symbol','Bio::Symbol::SymbolI','Bio::Taxonomy','Bio::Taxonomy::Taxon','Bio::Tools::AlignFactory','Bio::Tools::Alignment::Trim','Bio::Tools::AnalysisResult','Bio::Tools::BPbl2seq','Bio::Tools::BPlite','Bio::Tools::BPlite::HSP','Bio::Tools::BPlite::Iteration','Bio::Tools::BPlite::Sbjct','Bio::Tools::BPpsilite','Bio::Tools::Blast::HSP','Bio::Tools::Blast::HTML','Bio::Tools::Blast::Run::LocalBlast','Bio::Tools::Blast::Run::Webblast','Bio::Tools::Blast::Sbjct','Bio::Tools::CodonTable','Bio::Tools::GFF','Bio::Tools::Genewise','Bio::Tools::HMMER::Domain','Bio::Tools::HMMER::Set','Bio::Tools::IUPAC','Bio::Tools::Phylo::Molphy::Result','Bio::Tools::Phylo::PAML::Result','Bio::Tools::Prediction::Exon','Bio::Tools::Prediction::Gene','Bio::Tools::Run::EMBOSSApplication','Bio::Tools::Run::RemoteBlast','Bio::Tools::Run::WrapperBase','Bio::Tools::SeqAnal','Bio::Tools::SeqStats','Bio::Tools::Sim4::Exon','Bio::Tools::StateMachine::AbstractStateMachine','Bio::Tools::StateMachine::IOStateMachine','Bio::Tools::WWW','Bio::Tree::AlleleNode','Bio::Tree::Node','Bio::Tree::NodeI','Bio::Tree::NodeNHX','Bio::Tree::Tree','Bio::Tree::TreeFunctionsI','Bio::Tree::TreeI','Bio::TreeIO','Bio::TreeIO::TreeEventBuilder','Bio::UnivAln','Bio::Variation::AAChange','Bio::Variation::Allele','Bio::Variation::DNAMutation','Bio::Variation::IO','Bio::Variation::RNAChange','Bio::Variation::SNP','Bio::Variation::SeqDiff','Bio::Variation::VariantI','Carp','DBI','DB_File','Data::Dumper','Data::Stag','Data::Stag::ITextWriter','Data::Stag::SxprWriter','Data::Stag::XMLWriter','Dumpvalue','Exporter','Fcntl','File::Basename','File::Path','File::Spec','File::Temp','FileHandle','GD','Graph::Directed','HTML::Entities','HTML::Parser','HTTP::Request::Common','HTTP::Response','IO','IO::File','IO::Handle','IO::Socket','IO::String','LWP','LWP::UserAgent','POSIX','SOAP::Lite','Storable','Symbol','TestInterface','Text::Shellwords','Text::Wrap','Tie::Handle','Tie::IxHash','Tie::RefHash','URI','URI::Escape','Win32','XML::DOM','XML::Handler::Subs','XML::Parser','XML::Parser::PerlSAX','XML::Twig','XML::Writer','constant','integer','lib','overload','srsperl','strict','vars']},'bioperl-db-0.1.tar.gz' => {'author' => 'BIRNEY','description' => 'provides a simple framework for writing test scripts','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6267,'pod' => 3314,'pod_errors' => 0,'total' => 9581,'with_comments' => 509},'releases' => 1,'size' => {'packed' => 158173,'unpacked' => 625119},'testers' => {'fail' => 2,'tests' => '152'},'uses' => ['Bio::Annotation::Comment','Bio::Annotation::DBLink','Bio::Annotation::Reference','Bio::DB::SeqI','Bio::Location::Simple','Bio::Location::Split','Bio::PrimarySeqI','Bio::Root::RootI','Bio::SeqFeature::Generic','Bio::SeqI','Bio::Species','Carp','DBI','Exporter','Sys::Hostname','strict','vars']},'bioperl-ext-0.6.tar.gz' => {'author' => 'BIRNEY','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 51,'pod' => 0,'pod_errors' => 0,'total' => 51,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 181017,'unpacked' => 1226182},'testers' => {'pass' => 5},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'bioperl-gui-0.7.tar.gz' => {'author' => 'BIRNEY','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4490,'pod' => 536,'pod_errors' => 0,'total' => 5026,'with_comments' => 1056},'releases' => 1,'size' => {'packed' => 110325,'unpacked' => 374130},'testers' => {'fail' => 2,'pass' => 1},'uses' => ['Bio::SeqI','Bio::Tk::BioTkPerl8_1','Carp','DBI','Exporter','Storable','Tk','Tk::Canvas','Tk::Frame','Tk::Text','Tk::Widget','Tk::widgets','XML::Simple','strict','vars']},'bioperl-run-1.2.2.tar.gz' => {'author' => 'BIRNEY','description' => 'Object for identifying low complexity regions in a given protein seequence.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 156423,'pod' => 42559,'pod_errors' => 0,'total' => 198982,'with_comments' => 8798},'releases' => 1,'size' => {'packed' => 811989,'unpacked' => 5111464},'testers' => {'pass' => 1},'uses' => ['5.005_62','Algorithm::Diff','Bio::AlignIO','Bio::AlignIO::fasta','Bio::AnalysisI','Bio::Annotation::DBLink','Bio::Cluster::SequenceFamily','Bio::Factory::AnalysisI','Bio::Factory::ApplicationFactoryI','Bio::Matrix::PhylipDist','Bio::Root::IO','Bio::Root::Root','Bio::Search::HSP::GenericHSP','Bio::SearchIO','Bio::Seq','Bio::SeqFeature::FeaturePair','Bio::SeqFeature::Gene::Exon','Bio::SeqFeature::Gene::GeneStructure','Bio::SeqFeature::Gene::Transcript','Bio::SeqFeature::Generic','Bio::SeqIO','Bio::SimpleAlign','Bio::Species','Bio::Tools::AnalysisResult','Bio::Tools::Coil','Bio::Tools::Eponine','Bio::Tools::FootPrinter','Bio::Tools::Genewise','Bio::Tools::Genscan','Bio::Tools::Phylo::Molphy','Bio::Tools::Phylo::PAML','Bio::Tools::Phylo::Phylip::ProtDist','Bio::Tools::Prints','Bio::Tools::Profile','Bio::Tools::Promoterwise','Bio::Tools::RepeatMasker','Bio::Tools::Run::WrapperBase','Bio::Tools::Seg','Bio::Tools::Signalp','Bio::Tools::Sim4::Results','Bio::Tools::Tmhmm','Bio::TreeIO','Cwd','Data::Dumper','File::Copy','HTTP::Request::Common','IO::String','LWP::UserAgent','POSIX','XML::Parser::PerlSAX','XML::Twig','strict','vars']},'bitflags-0.10.tar.gz' => {'author' => 'PINYAN','description' => 'Perl module for generating bit flags','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 44,'pod' => 38,'pod_errors' => 0,'total' => 82,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2053,'unpacked' => 3596},'testers' => {'pass' => 7},'uses' => ['Carp','strict']},'c_plus_plus-0.1.tar.gz' => {'author' => 'ILYAZ','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 20,'pod' => 0,'pod_errors' => 0,'total' => 20,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 3465,'unpacked' => 8401},'testers' => {'fail' => 1},'uses' => ['DynaLoader','Exporter']},'capitalization-0.01.tar.gz' => {'author' => 'MIYAGAWA','description' => 'no capitalization on method names','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 57,'pod' => 32,'pod_errors' => 0,'total' => 89,'with_comments' => 0},'releases' => 1,'requires' => ['Devel-Symdump-2.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Devel::Symdump' => 0,'Test::More' => '0.32'},'requires_recursive' => ['Devel-Symdump-2.03.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 1503,'unpacked' => 2155},'testers' => {'pass' => 8},'uses' => ['Devel::Symdump','strict','vars']},'chronos-1.1.6.1.tar.gz' => {'author' => 'SIMONP','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 4608,'pod' => 0,'pod_errors' => 0,'total' => 4608,'with_comments' => 643},'releases' => 9,'size' => {'packed' => 75087,'unpacked' => 269111},'testers' => {},'uses' => ['Apache::Constants','Apache::DBI','Apache::Request','Date::Calc','Date::Calendar','Date::Calendar::Profiles','Exporter','HTML::Entities','POSIX','URI::Find::Schemeless','strict']},'compatlib-1.2.tar.gz' => {'author' => 'SPP','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 31,'pod' => 0,'pod_errors' => 0,'total' => 31,'with_comments' => 0},'releases' => 3,'size' => {'packed' => 20749,'unpacked' => 59866},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Exporter','File::Basename']},'conjury-1.004.tar.gz' => {'author' => 'JWOODYATT','description' => 'Generic software construction toolset','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 3722,'pod' => 693,'pod_errors' => 3,'total' => 4415,'with_comments' => 189},'releases' => 1,'size' => {'packed' => 34359,'unpacked' => 156054},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.005','Carp','Config','Cwd','Digest::MD5','File::Basename','File::Copy','File::Path','File::Spec','Getopt::Long','strict','subs','vars']},'coroutine0-0.02.tar.gz' => {'author' => 'DAVIDNICO','description' => 'a working but ugly coroutine generator','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 120,'pod' => 88,'pod_errors' => 0,'total' => 208,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 3738,'unpacked' => 7169},'testers' => {'pass' => 2},'uses' => ['5.000','Carp','strict','vars']},'csv2txt-2.0.tar.gz' => {'author' => 'SANFACE','description' => 'Version 2.0 13th December 2002','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 88,'pod' => 32,'pod_errors' => 0,'total' => 120,'with_comments' => 18},'releases' => 2,'size' => {'packed' => 25373,'unpacked' => 78002},'testers' => {},'uses' => ['strict','vars']},'ctflags-0.03.tar.gz' => {'author' => 'SALVA','description' => 'Perl extension for compile time flags configuration','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 775,'pod' => 503,'pod_errors' => 0,'total' => 1278,'with_comments' => 69},'releases' => 2,'size' => {'packed' => 11304,'unpacked' => 37717},'testers' => {'pass' => 8},'uses' => ['5.006','Carp','Exporter','constant','strict','warnings']},'cvswebedit-v2.0b1.tar.gz' => {'author' => 'MRJC','description' => undef,'files' => [],'lines' => {'nonpod' => 4266,'pod' => 1799,'pod_errors' => 0,'total' => 6065,'with_comments' => 732},'releases' => 1,'size' => {'packed' => 120740,'unpacked' => 400725},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.000','5.001','CGI','CGI::Base','CGI::BasePlus','CGI::Carp','CGI::MiniSvr','CGI::Request','Carp','Cwd','Exporter','FileHandle','SelfLoader','Socket','URI::Escape','sigtrap','strict']},'cyrillic-1.05.tar.gz' => {'author' => 'JNEYSTADT','description' => 'Heuristics to detect coded character sets','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4683,'pod' => 81,'pod_errors' => 0,'total' => 4764,'with_comments' => 32},'releases' => 24,'requires' => ['Unicode-Map8-0.12.tar.gz','Unicode-String-2.07.tar.gz'],'requires_module' => {'Unicode::Map8' => 0,'Unicode::String' => 0},'requires_recursive' => ['MIME-Base64-2.20.tar.gz','Unicode-Map8-0.12.tar.gz','Unicode-String-2.07.tar.gz'],'size' => {'packed' => 24636,'unpacked' => 75733},'testers' => {'pass' => 7,'tests' => '0','unknown' => 3},'uses' => ['Unicode::Map8','Unicode::String']},'cyrillic-2.09.tar.gz' => {'author' => 'AMICHAUER','description' => 'Library for fast and easy cyrillic text manipulation','files' => ['Makefile.PL'],'lines' => {'nonpod' => 208,'pod' => 216,'pod_errors' => 1,'total' => 424,'with_comments' => 3},'releases' => 24,'size' => {'packed' => 8926,'unpacked' => 23101},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.005_02','strict','vars']},'dTemplate-2.3.tar.gz' => {'author' => 'DLUX','description' => 'Fast and flexible templating system','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 412,'pod' => 617,'pod_errors' => 0,'total' => 1029,'with_comments' => 26},'releases' => 13,'size' => {'packed' => 20043,'unpacked' => 78095},'testers' => {'fail' => 1},'uses' => ['DynaLoader','HTML::Entities','URI::Escape','locale','strict','vars']},'dapple-0.21.tar.gz' => {'author' => 'GNAT','description' => 'Perl module for reading and writing DAAP structures =head2 SYNOPSIS use Net::DAAP::DMAP qw(:all); $hash_ref = dmap_to_hash_ref($dmap); # crude $array_ref = dmap_to_array_ref($dmap); # crude $array_ref = dmap_unpack($dmap); # knows about data types $node = dmap_seek($array_ref, $path); $flattened = dmap_flatten($array_ref); # convert to path = data format $xml = dmap_to_xml($dmap); # convert to XML fragment update_content_codes($unpacked_content_codes_response);','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1175,'pod' => 318,'pod_errors' => 0,'total' => 1493,'with_comments' => 25},'releases' => 2,'requires' => ['libwww-perl-5.69.tar.gz'],'requires_module' => {'LWP' => 0},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14279,'unpacked' => 51718},'testers' => {'fail' => 1,'pass' => 3,'tests' => '1'},'uses' => ['Carp','Exporter','LWP','Math::BigInt','sigtrap','strict']},'dateheader-1.0.tar.gz' => {'author' => 'DAVIDNICO','description' => 'RFC2822-compliant "Date:" header with current gmtime','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 58,'pod' => 43,'pod_errors' => 0,'total' => 101,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 2164,'unpacked' => 3636},'testers' => {'pass' => 1},'uses' => ['5.00000','strict','vars']},'dbMan-0.31.tar.gz' => {'author' => 'MILSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6084,'pod' => 30,'pod_errors' => 2,'total' => 6114,'with_comments' => 171},'releases' => 19,'size' => {'packed' => 122595,'unpacked' => 293084},'testers' => {},'uses' => ['$dir::$_','DBI','Data::ShowTable','FileHandle','Locale::gettext','POSIX','Struct::Compare','Term::ReadLine','Term::Size','Text::CSV_XS','Text::FormatTable','Time::HiRes','Tk','Tk::ROText','locale','strict','vars']},'dbd_rdb-1_16.tgz' => {'author' => 'ASTILLER','description' => undef,'files' => [],'lines' => {'nonpod' => 285,'pod' => 164,'pod_errors' => 0,'total' => 449,'with_comments' => 31},'releases' => 1,'size' => {'packed' => 24610,'unpacked' => 97473},'testers' => {'fail' => 1},'uses' => ['5.005','DBI','strict','vars']},'dbsh-0.01.tar.gz' => {'author' => 'MILSO','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 126,'pod' => 0,'pod_errors' => 0,'total' => 126,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 4048,'unpacked' => 9872},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['DBI','DBIx::SystemCatalog','Tk','vars']},'deltax-modules-3.06.tar.gz' => {'author' => 'JSPICAK','description' => 'Perl module for parsing pages for masser _____ / \\ _____ ______ ______ ___________ / \\ / \\\\__ \\ / ___// ___// __ \\_ __ \\ / Y \\/ __ \\_\\___ \\ \\___ \\\\ ___/| | \\/ \\____|__ (____ /____ >____ >\\___ >__| \\/ \\/ \\/ \\/ \\/ project','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3181,'pod' => 1270,'pod_errors' => 0,'total' => 4451,'with_comments' => 412},'releases' => 7,'requires' => ['DBI-1.37.tar.gz','Time-HiRes-1.49.tar.gz'],'requires_module' => {'DBI' => 0,'Time::HiRes' => 0},'requires_recursive' => ['DBI-1.37.tar.gz','Time-HiRes-1.49.tar.gz'],'size' => {'packed' => 33859,'unpacked' => 135882},'testers' => {'fail' => 1,'pass' => 1,'tests' => '99'},'uses' => ['Carp','DBI','Exporter','Fcntl','IPC::SharedCache','Time::HiRes','strict','vars']},'ePortal-3.2.tar.gz' => {'author' => 'RUSAKOV','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 13282,'pod' => 2401,'pod_errors' => 1,'total' => 15683,'with_comments' => 3871},'releases' => 1,'requires' => ['CGI.pm-2.98.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Date-Calc-5.3.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','HTML-Mason-1.22.tar.gz','Image-Size-2.992.tar.gz','MD5-2.02.tar.gz','Mail-Sendmail-0.79.tar.gz','Params-Validate-0.64.tar.gz','Storable-2.07.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','mod_perl-1.28.tar.gz'],'requires_module' => {'CGI' => '2.81','DBD::mysql' => 0,'DBI' => '1.28','Data::Dumper' => 0,'Date::Calc' => 5,'Digest::MD5' => '2.13','Error' => 0,'HTML::Mason' => '1.16','Image::Size' => '2.99','MD5' => 0,'Mail::Sendmail' => '0.78','Params::Validate' => '0.24','Storable' => 0,'Text::Wrap' => 0,'mod_perl' => '1.26'},'requires_recursive' => ['Attribute-Handlers-0.78.tar.gz','Bit-Vector-6.3.tar.gz','CGI.pm-2.98.tar.gz','DBD-mysql-2.9002.tar.gz','DBI-1.37.tar.gz','Data-Dumper-2.101.tar.gz','Date-Calc-5.3.tar.gz','Digest-MD5-2.26.tar.gz','Error-0.15.tar.gz','File-Spec-0.82.tar.gz','HTML-Mason-1.22.tar.gz','Image-Size-2.992.tar.gz','MD5-2.02.tar.gz','Mail-Sendmail-0.79.tar.gz','Params-Validate-0.64.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','Text-Tabs+Wrap-2001.0929.tar.gz','mod_perl-1.28.tar.gz'],'size' => {'packed' => 231984,'unpacked' => 955854},'testers' => {},'uses' => ['5.004','5.6.0','5.6.1','Apache','Apache::Constants','Apache::Cookie','Apache::Request','Apache::Util','CGI','Carp','DBI','Data::Dumper','Error','Exporter','Fcntl','Getopt::Long','HTML::Mason::ApacheHandler','Image::Size','MD5','Net::LDAP','POSIX','Params::Validate','Pod::Usage','Storable','Time::localtime','Unicode::Map8','Unicode::String','integer','locale','strict','vars']},'eSTAR-RTML-1.7.0.tar.gz' => {'author' => 'AALLAN','description' => 'Object Orientatied interface to create and parse RTML messages','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1582,'pod' => 551,'pod_errors' => 0,'total' => 2133,'with_comments' => 285},'releases' => 1,'size' => {'packed' => 22388,'unpacked' => 120601},'testers' => {'pass' => 1},'uses' => ['Carp','Data::Dumper','File::Spec','Net::Domain','Socket','XML::Parser','XML::Writer','XML::Writer::String','strict','vars']},'ebx-0.87.tar.gz' => {'author' => 'CLKAO','description' => 'Synchronize OurNet::BBS Objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 696,'pod' => 187,'pod_errors' => 0,'total' => 883,'with_comments' => 51},'releases' => 7,'requires' => ['Compress-Zlib-1.22.tar.gz','Crypt-Rijndael-0.05.tar.gz','MIME-Base64-2.20.tar.gz','OurNet-BBS-1.65.tar.gz','Storable-2.07.tar.gz','TermReadKey-2.21.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Compress::Zlib' => '1.08','Crypt::Rijndael' => '0.04','Getopt::Std' => '1.02','MIME::Base64' => '2.11','OurNet::BBS' => '1.62','Storable' => '1.011','Term::ReadKey' => '2.14'},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','Crypt-Rijndael-0.05.tar.gz','File-Spec-0.82.tar.gz','MIME-Base64-2.20.tar.gz','OurNet-BBS-1.65.tar.gz','Storable-2.07.tar.gz','TermReadKey-2.21.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 25154,'unpacked' => 100836},'testers' => {'pass' => 1},'uses' => ['5.006','Crypt::Rijndael','Digest::MD5','GnuPG::Interface','IO::Handle','Mail::Address','OurNet::BBS','Storable','constant','fields','integer','strict']},'ec-1.25.tar.gz' => {'author' => 'RKIES','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 876,'pod' => 96,'pod_errors' => 0,'total' => 972,'with_comments' => 26},'releases' => 12,'requires' => ['MIME-Base64-2.20.tar.gz'],'requires_module' => {'MIME::Base64' => undef},'requires_recursive' => ['MIME-Base64-2.20.tar.gz'],'size' => {'packed' => 70323,'unpacked' => 189525},'testers' => {'pass' => 1,'tests' => '0','unknown' => 3},'uses' => ['Carp','Cwd','File::Basename','MIME::Base64','Tk','Tk::Button','Tk::Canvas','Tk::Derived','Tk::Dialog','Tk::DialogBox','Tk::Entry','Tk::LabEntry','Tk::Label','Tk::Listbox','Tk::Pixmap','Tk::Toplevel','Tk::widgets','strict','vars']},'enum-1.016.tar.gz' => {'author' => 'ZENIN','description' => 'resemble enumerated types in C','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 204,'pod' => 183,'pod_errors' => 0,'total' => 387,'with_comments' => 27},'releases' => 9,'size' => {'packed' => 5847,'unpacked' => 18229},'testers' => {'pass' => 22},'uses' => ['Carp','strict','vars']},'enum-fields-1.0.tar.gz' => {'author' => 'DMLLOYD','description' => 'Perl extension for defining constants for use in Array-based objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 134,'pod' => 114,'pod_errors' => 0,'total' => 248,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 3636,'unpacked' => 11010},'testers' => {'pass' => 3},'uses' => ['5.00503','Carp','strict','vars']},'eperl-2.2.13.tar.gz' => {'author' => 'RSE','description' => 'Fast emulated Embedded Perl (ePerl)','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1155,'pod' => 844,'pod_errors' => 0,'total' => 1999,'with_comments' => 230},'releases' => 14,'size' => {'packed' => 198806,'unpacked' => 653708},'testers' => {'fail' => 2},'uses' => ['Apache::Constants','Apache::Debug','AutoLoader','Carp','Cwd','DynaLoader','Exporter','File::Basename','Safe','strict','vars']},'esmith-1.70.tar.gz' => {'author' => 'SKUD','description' => '- a CPAN packaging of e-smith API modules','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 3187,'pod' => 601,'pod_errors' => 0,'total' => 3788,'with_comments' => 354},'releases' => 1,'size' => {'packed' => 23266,'unpacked' => 86821},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Errno','Exporter','Fcntl','File::Basename','File::stat','FileHandle','MIME::Base64','POSIX','Sys::Syslog','Text::Template','Time::HiRes','strict','v5.6.0','vars','warnings']},'etext.1.6.3.zip' => {'author' => 'ILYAZ','description' => 'TeX typesetting language input parser','files' => [],'lines' => {'nonpod' => 1833,'pod' => 783,'pod_errors' => 0,'total' => 2616,'with_comments' => 251},'releases' => 1,'size' => {'packed' => 376943,'unpacked' => 1564452},'testers' => {},'uses' => ['5.002','Carp','Exporter','strict','vars']},'ex-constant-vars-0.01.tar.gz' => {'author' => 'CTWETEN','description' => 'Perl pragma to create readonly variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 118,'pod' => 103,'pod_errors' => 0,'total' => 221,'with_comments' => 2},'releases' => 1,'size' => {'packed' => 3637,'unpacked' => 9366},'testers' => {'pass' => 9},'uses' => ['5.006','Carp','Exporter','strict','warnings']},'ex-lib-zip-0.03.tar.gz' => {'author' => 'NWCLARK','description' => 'Perl extension to let you C<use> things direct from zip files.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 180,'pod' => 30,'pod_errors' => 0,'total' => 210,'with_comments' => 18},'releases' => 3,'requires' => ['PerlIO-gzip-0.15.tar.gz','PerlIO-subfile-0.07.tar.gz'],'requires_module' => {'PerlIO::gzip' => '0.07','PerlIO::subfile' => '0.02'},'requires_recursive' => ['PerlIO-gzip-0.15.tar.gz','PerlIO-subfile-0.07.tar.gz'],'size' => {'packed' => 15771,'unpacked' => 37779},'testers' => {'pass' => 2},'uses' => ['5.007001','Carp','PerlIO::gzip','PerlIO::subfile','strict','warnings']},'ex-newest-0.02.tar.gz' => {'author' => 'RGARCIA','description' => 'look for newest versions of modules installed several times','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 107,'pod' => 27,'pod_errors' => 0,'total' => 134,'with_comments' => 8},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::Simple' => '0.19'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 2920,'unpacked' => 5705},'testers' => {'fail' => 3,'pass' => 2,'tests' => '18'},'uses' => ['ExtUtils::MM_Unix','lib','strict','v5.7.2','warnings']},'ex-override-1.1.tar.gz' => {'author' => 'CWEST','description' => 'perl pragma to override core functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 78,'pod' => 101,'pod_errors' => 0,'total' => 179,'with_comments' => 1},'releases' => 2,'size' => {'packed' => 3894,'unpacked' => 11936},'testers' => {'pass' => 2},'uses' => ['Carp','strict','vars','warnings']},'examples.tar.gz' => {'author' => 'SRIRAM','description' => undef,'files' => [],'lines' => {'nonpod' => 2185,'pod' => 13,'pod_errors' => 0,'total' => 2198,'with_comments' => 333},'releases' => 1,'size' => {'packed' => 43370,'unpacked' => 154473},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['Benchmark','Carp','DBI','DynaLoader','Exporter','FreezeThaw','IO::Select','IO::Socket','POSIX','Symbol','strict','vars']},'extensible_report_generator_1.13.zip' => {'author' => 'PHOENIXL','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 3089,'pod' => 0,'pod_errors' => 0,'total' => 3089,'with_comments' => 1210},'releases' => 1,'size' => {'packed' => 18583,'unpacked' => 68068},'testers' => {},'uses' => ['1','5.000','erg_line_formatter','erg_report_generator','erg_report_summary']},'extproc_perl-1.02.tar.gz' => {'author' => 'JHORWITZ','description' => 'Perl interface to the Oracle Perl External Procedure Library','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 122,'pod' => 172,'pod_errors' => 0,'total' => 294,'with_comments' => 9},'releases' => 10,'size' => {'packed' => 24553,'unpacked' => 76582},'testers' => {},'uses' => ['5.005_62','DynaLoader','Exporter','strict','warnings']},'fameperl-2.1.3.tar.gz' => {'author' => 'TRIAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 796,'pod' => 310,'pod_errors' => 0,'total' => 1106,'with_comments' => 168},'releases' => 1,'size' => {'packed' => 36778,'unpacked' => 122683},'testers' => {'fail' => 1},'uses' => ['Carp','DynaLoader','Exporter','strict']},'finance-yahooquote_0.20.tar.gz' => {'author' => 'EDD','description' => 'Get stock quotes from Yahoo! Finance','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 302,'pod' => 214,'pod_errors' => 0,'total' => 516,'with_comments' => 71},'releases' => 1,'requires' => ['HTML-Parser-3.28.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'HTML::Parser' => '2.2','HTTP::Request' => '1.23','LWP::UserAgent' => '1.62','Text::ParseWords' => '3.1'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 21127,'unpacked' => 64231},'testers' => {'pass' => 2},'uses' => ['5.005','Exporter','HTTP::Request::Common','LWP','Text::ParseWords','strict','vars']},'fldbm-0.01.tar.gz' => {'author' => 'MJFLICK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 34,'pod_errors' => 0,'total' => 208,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 2546,'unpacked' => 6474},'testers' => {'pass' => 2},'uses' => ['5.008','strict','warnings']},'font_ft2_0.1.0.tgz' => {'author' => 'CAFFIEND','description' => 'Perl extension for FreeType 2','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 378,'pod' => 298,'pod_errors' => 0,'total' => 676,'with_comments' => 38},'releases' => 1,'size' => {'packed' => 29862,'unpacked' => 402128},'testers' => {'fail' => 1},'uses' => ['5.005_62','AutoLoader','Carp','DynaLoader','Exporter','FT2','strict','warnings']},'forks-0.03.tar.gz' => {'author' => 'ELIZABETH','description' => 'drop-in replacement for Perl threads using fork()','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2201,'pod' => 297,'pod_errors' => 0,'total' => 2498,'with_comments' => 970},'releases' => 3,'requires' => ['Storable-2.07.tar.gz','Test-Simple-0.47.tar.gz','load-0.05.tar.gz'],'requires_module' => {'Storable' => 0,'Test::More' => 0,'load' => '0.03'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','load-0.05.tar.gz'],'size' => {'packed' => 26436,'unpacked' => 99763},'testers' => {'pass' => 2},'uses' => ['1','IO::Socket','POSIX','Storable','XSLoader','load','strict']},'former-0.2beta.tar.gz' => {'author' => 'GEHIC','description' => '- Perl module to read and write Windows-like config files','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 216,'pod' => 48,'pod_errors' => 1,'total' => 264,'with_comments' => 41},'releases' => 1,'size' => {'packed' => 11021,'unpacked' => 32725},'testers' => {},'uses' => ['Carp','strict']},'foundation-0.03.tar.gz' => {'author' => 'MSCHWERN','description' => 'Inheritance without objects','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 79,'pod' => 64,'pod_errors' => 0,'total' => 143,'with_comments' => 5},'releases' => 3,'size' => {'packed' => 3431,'unpacked' => 7747},'testers' => {'pass' => 6},'uses' => ['Exporter','strict','vars']},'frogbak.tar.gz' => {'author' => 'MUIR','description' => undef,'files' => [],'lines' => {'nonpod' => 699,'pod' => 0,'pod_errors' => 0,'total' => 699,'with_comments' => 161},'releases' => 1,'size' => {'packed' => 39877,'unpacked' => 129407},'testers' => {},'uses' => ['5.000','Carp','Exporter']},'gcrypt-0.3.tar.gz' => {'author' => 'ROBBE','description' => 'Perl interface to the GNU Crypto library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 76,'pod' => 132,'pod_errors' => 0,'total' => 208,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 11505,'unpacked' => 30691},'testers' => {},'uses' => ['5.006','AutoLoader','Exporter','XSLoader','strict','warnings']},'gettext-1.00.tar.gz' => {'author' => 'PVANDRY','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 48,'pod' => 34,'pod_errors' => 0,'total' => 82,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 3761,'unpacked' => 8269},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','DynaLoader','Exporter']},'gettext-1.01.tar.gz' => {'author' => 'PVANDRY','description' => 'Multilanguage messages','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 51,'pod' => 40,'pod_errors' => 0,'total' => 91,'with_comments' => 0},'releases' => 2,'size' => {'packed' => 3924,'unpacked' => 8654},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['Carp','DynaLoader','Exporter']},'glist-0.9.17a10.tar.gz' => {'author' => 'ASKSH','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 5377,'pod' => 70,'pod_errors' => 7,'total' => 5447,'with_comments' => 841},'releases' => 1,'size' => {'packed' => 84558,'unpacked' => 343852},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['Carp','Crypt::TripleDES','DBI','DB_File','English','Exporter','Fcntl','File::Copy','IO::Handle','POSIX','Queue','Socket','Version','less','strict','vars']},'gmuck-1.07.tar.gz' => {'author' => 'SCOP','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1182,'pod' => 332,'pod_errors' => 0,'total' => 1514,'with_comments' => 107},'releases' => 5,'requires' => ['Getopt-Long-2.33.tar.gz','HTML-Tagset-3.03.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Carp' => 0,'Getopt::Long' => 0,'HTML::Tagset' => '3.03'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Tagset-3.03.tar.gz','PodParser-1.23.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 19593,'unpacked' => 66323},'testers' => {'pass' => 5},'uses' => ['5.00503','Carp','Regex::PreSuf','strict','vars']},'grepmail-4.80.tar.gz' => {'author' => 'DCOPPIT','description' => 'A fast mailbox reader','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 233,'pod' => 47,'pod_errors' => 0,'total' => 280,'with_comments' => 13},'releases' => 40,'requires' => ['TimeDate-1.16.tar.gz'],'requires_module' => {'Date::Parse' => 0},'requires_recursive' => ['TimeDate-1.16.tar.gz'],'size' => {'packed' => 714739,'unpacked' => 2611976},'testers' => {'fail' => 2,'pass' => 1,'tests' => '222'},'uses' => ['Exporter','strict','vars']},'hp200lx-db-0.09.tar.gz' => {'author' => 'GGONTER','description' => 'Perl module to access HP-200 LX database files','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4238,'pod' => 83,'pod_errors' => 0,'total' => 4321,'with_comments' => 916},'releases' => 4,'size' => {'packed' => 56083,'unpacked' => 194352},'testers' => {'pass' => 9},'uses' => ['Exporter','Tk','strict','vars']},'html2latex-1.1.tar.gz' => {'author' => 'PETER','description' => 'Creates a Latex file from an HTML file.','files' => ['README'],'lines' => {'nonpod' => 1126,'pod' => 332,'pod_errors' => 0,'total' => 1458,'with_comments' => 305},'releases' => 1,'size' => {'packed' => 48439,'unpacked' => 121506},'testers' => {'fail' => 3,'pass' => 2,'tests' => '2'},'uses' => ['Carp','Data::Dumper','File::Basename','File::Path','FileHandle','HTML::TreeBuilder','Image::Magick','LWP::Simple','URI','XML::Simple','diagnostics','strict','vars','warnings']},'htpl-3.14.tar.gz' => {'author' => 'SCHOP','description' => 'Apache mod_perl driver for HTPL.','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 5200,'pod' => 95,'pod_errors' => 1,'total' => 5295,'with_comments' => 163},'releases' => 42,'size' => {'packed' => 161713,'unpacked' => 640407},'testers' => {},'uses' => ['5.004','AutoLoader','CGI','Carp','Compress::Zlib','Config','Crypt::Blowfish','Crypt::CBC','Cwd','DBI','DB_File','Data::ACL','Date::Language','DynaLoader','Exporter','Fcntl','File::FTS','File::Recurse','File::Spec','Filter::Util::Call','FreezeThaw','HTML::Entities','HTML::LinkExtor','HTML::Tagset','HTML::TokeParser','HTTP::Request','HTTP::Request::Common','IO::Socket::INET','Image::Size','IniConf','LWP::MediaType','LWP::Simple','LWP::UserAgent','Locale::Hebrew','Locale::Hebrew::Calendar','MLDBM','Mail::Address','Net::DNS','Net::Finger','Net::LDAP','Net::Ping','Net::SMTP','POSIX','SQL::Eval','SQL::Statement','Set::NestedGroups','Shell','Socket','Storable','Symbol','Sys::Hostname','Tcl','Text::ParseWords','Text::Tabs','Text::Wrap','Tie::Cache','Tie::Hash','Time::HiRes','Time::Local','URI::Escape','URI::URL','XML::Simple','strict','subs','vars']},'http-headers-useragent-1.00.tar.gz' => {'author' => 'JNEYSTADT','description' => 'Routine to detect web browser platform from User-Agent HTTP Header','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 27,'pod' => 34,'pod_errors' => 0,'total' => 61,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 1370,'unpacked' => 3223},'testers' => {'tests' => '0','unknown' => 15},'uses' => []},'i2c-0.1.tar.gz' => {'author' => 'IGERLACH','description' => 'Perl extension fuer diverse i2c devices. Version 0.1 / 2.12.2000','files' => ['README'],'lines' => {'nonpod' => 166,'pod' => 849,'pod_errors' => 0,'total' => 1015,'with_comments' => 24},'releases' => 1,'size' => {'packed' => 161269,'unpacked' => 528381},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'iPerl-0.6.tar.gz' => {'author' => 'PFEIFFER','description' => 'Bring text-docs to life via embedded Perl','files' => ['README'],'lines' => {'nonpod' => 1042,'pod' => 439,'pod_errors' => 0,'total' => 1481,'with_comments' => 27},'releases' => 3,'size' => {'packed' => 41530,'unpacked' => 123456},'testers' => {},'uses' => ['5.004','Exporter']},'if-0.01000001.tar.gz' => {'author' => 'ILYAZ','description' => 'C<use> a Perl module if a condition holds','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 21,'pod' => 27,'pod_errors' => 0,'total' => 48,'with_comments' => 3},'releases' => 1,'size' => {'packed' => 1292,'unpacked' => 2077},'testers' => {'pass' => 6},'uses' => []},'import-1_01.tgz' => {'author' => 'MIKEKING','description' => 'import all modules with a package prefix, aliasing it away. \'import\' acts as a pragma that performs a \'use\' on all modules that can be found with the given package prefix. Any modules found have a \'use\' statement performed, and the fully qualified package name is aliased to one without the given prefix. The functionality is similar to Java\'s \'import\' statement. See import.pod for details.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 151,'pod' => 145,'pod_errors' => 0,'total' => 296,'with_comments' => 54},'releases' => 1,'size' => {'packed' => 4843,'unpacked' => 13203},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','Cwd','DirHandle','strict']},'interface-0.02.tar.gz' => {'author' => 'SWALTERS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 174,'pod' => 120,'pod_errors' => 0,'total' => 294,'with_comments' => 12},'releases' => 3,'size' => {'packed' => 6018,'unpacked' => 17477},'testers' => {'pass' => 2},'uses' => ['5.006','strict','warnings']},'io-page-0.02.tar.gz' => {'author' => 'RMITZ','description' => 'Pipe STDOUT to a pager if STDOUT is a TTY','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 54,'pod' => 25,'pod_errors' => 0,'total' => 79,'with_comments' => 3},'releases' => 2,'size' => {'packed' => 1642,'unpacked' => 2621},'testers' => {'pass' => 6},'uses' => ['strict','vars']},'iodbc_ext_0_1.tar.gz' => {'author' => 'JMAHAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 627,'pod' => 899,'pod_errors' => 0,'total' => 1526,'with_comments' => 41},'releases' => 1,'size' => {'packed' => 21865,'unpacked' => 88668},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'jp_beta_1.tar.gz' => {'author' => 'SBALA','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 7,'pod' => 0,'pod_errors' => 0,'total' => 7,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 355559,'unpacked' => 1138244},'testers' => {},'uses' => []},'kif-1.02.tar.gz' => {'author' => 'MUNROER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1583,'pod' => 0,'pod_errors' => 0,'total' => 1583,'with_comments' => 275},'releases' => 3,'requires' => ['Getopt-Long-2.33.tar.gz','StanzaFile-1.05.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Basename' => '2.71','File::Copy' => '2.05','File::stat' => 1,'FileHandle' => '2.01','Getopt::Long' => '2.32','StanzaFile' => 1},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz','StanzaFile-1.05.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 12706,'unpacked' => 55055},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.8.0','Build','Carp','File::Basename','File::Copy','File::stat','FileHandle','StanzaFile::Grub','StanzaFile::Lilo','strict','vars']},'kif-2.01.tar.gz' => {'author' => 'MUNROER','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1570,'pod' => 0,'pod_errors' => 0,'total' => 1570,'with_comments' => 280},'releases' => 3,'requires' => ['Getopt-Long-2.33.tar.gz','StanzaFile-1.05.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'File::Basename' => '2.6','File::Copy' => '2.03','File::stat' => 1,'FileHandle' => 2,'Getopt::Long' => '2.25','StanzaFile' => 1},'requires_recursive' => ['File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz','StanzaFile-1.05.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 13333,'unpacked' => 57346},'testers' => {'pass' => 1},'uses' => ['Carp','File::Basename','File::Copy','File::stat','FileHandle','StanzaFile::Grub','StanzaFile::Lilo','strict','vars']},'libao-perl_0.03-1.tar.gz' => {'author' => 'FOOF','description' => 'Perl extension for ao cross-platform audio library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 80,'pod' => 66,'pod_errors' => 0,'total' => 146,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 14513,'unpacked' => 43114},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'libapreq-1.2.tar.gz' => {'author' => 'JOESUF','description' => 'CGI.pm functionality using API methods','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 339,'pod' => 786,'pod_errors' => 0,'total' => 1125,'with_comments' => 4},'releases' => 5,'size' => {'packed' => 277549,'unpacked' => 1088659},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Config','strict']},'libnet-1.0703.tar.gz' => {'author' => 'GBARR','description' => 'CCSO Nameserver Client class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 5467,'pod' => 1932,'pod_errors' => 0,'total' => 7399,'with_comments' => 266},'releases' => 34,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'IO::Socket' => '1.05','Socket' => '1.3'},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 64719,'unpacked' => 216430},'testers' => {'pass' => 14,'tests' => '0','unknown' => 3},'uses' => ['5.001','5.002','AutoLoader','Carp','Exporter','File::Basename','FileHandle','IO::Handle','IO::Select','IO::Socket','Net::Cmd','Net::Config','Net::Domain','Net::FTP::A','Net::FTP::I','Net::FTP::dataconn','Net::Netrc','POSIX','Socket','Time::Local','happy','integer','strict','sys::syscall.ph','syscall.ph','vars']},'libnet-1.16.tar.gz' => {'author' => 'GBARR','description' => 'Support for .netrc files','files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 4993,'pod' => 1752,'pod_errors' => 8,'total' => 6745,'with_comments' => 255},'releases' => 34,'requires' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'IO::Socket' => '1.05','Socket' => '1.3'},'requires_recursive' => ['IO-1.20.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 70437,'unpacked' => 232589},'testers' => {'pass' => 6},'uses' => ['5.001','Authen::SASL','AutoLoader','Carp','Convert::EBCDIC','Errno','Exporter','Fcntl','File::Basename','FileHandle','IO::Select','IO::Socket','MIME::Base64','Mac::InternetConfig','POSIX','Socket','Symbol','Time::Local','happy','strict','sys::syscall.ph','syscall.ph','vars']},'libplot-perl-2.1.6.2b.tar.gz' => {'author' => 'JLAPEYRE','description' => 'Binding for C libplotter plotting library','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 197,'pod' => 82,'pod_errors' => 0,'total' => 279,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 13426,'unpacked' => 53765},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'libservlet-0.9.1.tar.gz' => {'author' => 'IX','description' => 'Perl Servlet API v2.3','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3309,'pod' => 4351,'pod_errors' => 3,'total' => 7660,'with_comments' => 64},'releases' => 2,'requires' => ['Exception-Class-1.14.tar.gz'],'requires_module' => {'Exception::Class' => 0},'requires_recursive' => ['Class-Data-Inheritable-0.02.tar.gz','Devel-StackTrace-1.03.tar.gz','Exception-Class-1.14.tar.gz','File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 79634,'unpacked' => 389738},'testers' => {},'uses' => ['5.006','Exception::Class::Base','Servlet::GenericServlet','Servlet::Http::HttpServletResponseWrapper','Servlet::Http::HttpSessionEvent','Servlet::ServletContextEvent','Servlet::ServletException','Servlet::ServletRequestWrapper','Servlet::ServletResponseWrapper','Servlet::Util::Event','Servlet::Util::Exception','constant','fields','strict','warnings']},'libservlet-0.9.2.tar.gz' => {'author' => 'IX','description' => 'Perl Servlet API v2.3','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3367,'pod' => 4390,'pod_errors' => 3,'total' => 7757,'with_comments' => 67},'releases' => 2,'requires' => ['Exception-Class-1.14.tar.gz','IO-1.20.tar.gz'],'requires_module' => {'Exception::Class' => 0,'IO::Handle' => 0},'requires_recursive' => ['Class-Data-Inheritable-0.02.tar.gz','Devel-StackTrace-1.03.tar.gz','Exception-Class-1.14.tar.gz','File-Spec-0.82.tar.gz','IO-1.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 90015,'unpacked' => 435668},'testers' => {'pass' => 5},'uses' => ['5.006','Exception::Class::Base','IO::Handle','Servlet::Config','Servlet::ServletRequest','Servlet::ServletResponse','constant','fields','strict','warnings']},'libsirc-0.12.tar.gz' => {'author' => 'ROSCH','description' => 'view URLs with an external browser','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2233,'pod' => 557,'pod_errors' => 0,'total' => 2790,'with_comments' => 251},'releases' => 6,'size' => {'packed' => 24037,'unpacked' => 74990},'testers' => {'pass' => 2},'uses' => ['Data::Dumper','Tie::Hash','strict','subs','vars']},'libwin32-0.191.tar.gz' => {'author' => 'GSAR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 15986,'pod' => 12439,'pod_errors' => 12,'total' => 28425,'with_comments' => 1317},'releases' => 26,'size' => {'packed' => 676576,'unpacked' => 2910839},'testers' => {},'uses' => ['','AutoLoader','Carp','Config','Data::Dumper','DynaLoader','Exporter','ExtUtils::MakeMaker','Fcntl','File::Basename','Tie::Hash','Win32::IPC','Win32::OLE','Win32::OLE::Lite','Win32::OLE::Variant','Win32::TieRegistry','Win32::WinError','Win32API::File::cFile.pc','Win32API::Registry','Win32API::Registry::cRegistry.pc','constant','strict','vars']},'libwin32-0.191.zip' => {'author' => 'GSAR','description' => 'Use Win32 mutex objects for IPC','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 15986,'pod' => 12439,'pod_errors' => 12,'total' => 28425,'with_comments' => 1317},'releases' => 26,'size' => {'packed' => 765570,'unpacked' => 2910839},'testers' => {},'uses' => ['','AutoLoader','Carp','Config','Data::Dumper','DynaLoader','Exporter','ExtUtils::MakeMaker','Fcntl','File::Basename','Tie::Hash','Win32::OLE','Win32::OLE::Lite','Win32::OLE::Variant','Win32::TieRegistry','Win32API::File::cFile.pc','Win32API::Registry','Win32API::Registry::cRegistry.pc','constant','strict','vars']},'libwww-perl-5.10.tar.gz' => {'author' => 'GAAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 12456,'pod' => 3755,'pod_errors' => 0,'total' => 16211,'with_comments' => 1619},'releases' => 51,'size' => {'packed' => 196319,'unpacked' => 633916},'testers' => {'fail' => 2,'tests' => '376'},'uses' => ['5.002','AnyDBM_File','AutoLoader','Carp','Config','Cwd','Exporter','Fcntl','HTML::Element','HTML::Entities','HTML::FormatText','HTML::Formatter','HTML::HeadParser','HTML::Parser','HTML::TreeBuilder','HTTP::Date','HTTP::Headers','HTTP::Message','HTTP::Request','HTTP::Response','HTTP::Status','LWP','LWP::Debug','LWP::MediaTypes','LWP::MemberMixin','LWP::Protocol','LWP::Socket','LWP::UserAgent','MD5','MIME::Base64','Net::FTP','Socket','Symbol','Sys::Hostname','Tk','URI::Escape','URI::URL','URI::URL::$scheme','URI::URL::_generic','URI::URL::file','URI::URL::http','WWW::RobotRules','overload','strict','vars']},'libwww-perl-5.53.tar.gz' => {'author' => 'GAAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 8956,'pod' => 2713,'pod_errors' => 0,'total' => 11669,'with_comments' => 880},'releases' => 51,'requires' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'Digest::MD5' => 0,'HTML::HeadParser' => 0,'MIME::Base64' => '2.1','Net::FTP' => '2.4','URI' => '1.10'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 157267,'unpacked' => 500610},'testers' => {'fail' => 4,'pass' => 6,'tests' => '287'},'uses' => ['5.002','5.004','AnyDBM_File','Carp','Data::Dumper','Exporter','Fcntl','File::Basename','HTML::Entities','HTML::HeadParser','HTML::TokeParser','HTTP::Date','HTTP::GHTTP','HTTP::Headers','HTTP::Headers::Util','HTTP::Message','HTTP::Request','HTTP::Request::Common','HTTP::Response','HTTP::Status','IO::Select','IO::Socket','IO::Socket::INET','IO::Socket::SSL','LWP','LWP::Debug','LWP::MediaTypes','LWP::MemberMixin','LWP::Protocol','LWP::Protocol::http','LWP::UserAgent','MD5','MIME::Base64','Mail::Internet','Net::FTP','Net::HTTP','Net::NNTP','Net::SSL','Symbol','Sys::Hostname','Time::Local','URI','URI::Escape','WWW::RobotRules','strict','vars']},'libwww-perl-5.69.tar.gz' => {'author' => 'GAAS','description' => 'Functions that generate HTTP::Requests','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 11598,'pod' => 4112,'pod_errors' => 0,'total' => 15710,'with_comments' => 1106},'releases' => 51,'requires' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz'],'requires_module' => {'Digest::MD5' => 0,'HTML::HeadParser' => 0,'MIME::Base64' => '2.1','Net::FTP' => '2.58','URI' => '1.10'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 205846,'unpacked' => 667659},'testers' => {'fail' => 1,'pass' => 19,'tests' => '362'},'uses' => ['5','5.002','5.004','5.005','AnyDBM_File','Authen::NTLM','Carp','Compress::Zlib','Data::Dumper','Digest::MD5','Exporter','Fcntl','File::Basename','HTML::Entities','HTML::HeadParser','HTML::TokeParser','HTTP::GHTTP','IO::Select','IO::Socket','IO::Socket::SSL','MIME::Base64','Mail::Internet','Net::FTP','Net::NNTP','Net::SSL','Symbol','Sys::Hostname','Time::Local','URI','URI::Escape','strict','vars']},'libxml-enno-1.02.tar.gz' => {'author' => 'ENNO','description' => 'Convert UTF-8 strings to any encoding supported by XML::Encoding','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 18838,'pod' => 5175,'pod_errors' => 0,'total' => 24013,'with_comments' => 2121},'releases' => 4,'requires' => ['DateManip-5.42a.tar.gz','Parse-Yapp-1.05.tar.gz','XML-Parser-2.31.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz'],'requires_module' => {'Date::Manip' => '5.33','LWP::UserAgent' => '0','Parse::Yapp' => '0','XML::Parser' => '2.19','XML::Parser::PerlSAX' => '0.07'},'requires_recursive' => ['DateManip-5.42a.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Parse-Yapp-1.05.tar.gz','URI-1.24.tar.gz','XML-Parser-2.31.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 369163,'unpacked' => 1288061},'testers' => {'fail' => 8,'tests' => '259'},'uses' => ['Carp','Date::Manip','Exporter','FileHandle','LWP::UserAgent','POSIX','Parse::Yapp::Driver','XML::Checker','XML::DOM','XML::DOM::DOMException','XML::DOM::NamedNodeMap','XML::DOM::NodeList','XML::Encoding','XML::Filter::DetectWS','XML::Filter::SAXT','XML::Handler::DOM','XML::Parser','XML::RegExp','XML::UM','XML::XQL','XML::XQL::Attribute','XML::XQL::BooleanOp','XML::XQL::Element','XML::XQL::Operator','XML::XQL::Plus','fields','strict','utf','vars']},'libxml-perl-0.07.tar.gz' => {'author' => 'KMACLEOD','description' => '- support for deeply nested structures','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3556,'pod' => 1964,'pod_errors' => 0,'total' => 5520,'with_comments' => 327},'releases' => 6,'requires' => ['XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::Parser' => '2.19'},'requires_recursive' => ['XML-Parser-2.31.tar.gz'],'size' => {'packed' => 53197,'unpacked' => 217792},'testers' => {'fail' => 15,'pass' => 8,'tests' => '45'},'uses' => ['5.005','Carp','Data::Grove','IO::File','UNIVERSAL','XML::Grove::Builder','XML::Parser','strict','vars']},'llg-1.07.tar.gz' => {'author' => 'YVESP','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 1171,'pod' => 923,'pod_errors' => 4,'total' => 2094,'with_comments' => 131},'releases' => 1,'size' => {'packed' => 20365,'unpacked' => 68395},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['5.001','Carp','English','Tk','Tk::Dialog','Tk::ErrorDialog','strict']},'load-0.05.tar.gz' => {'author' => 'ELIZABETH','description' => 'control when subroutines will be loaded','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 474,'pod' => 211,'pod_errors' => 0,'total' => 685,'with_comments' => 126},'releases' => 8,'size' => {'packed' => 9179,'unpacked' => 26512},'testers' => {'pass' => 7},'uses' => []},'log.tar.gz' => {'author' => 'STRYTOAST','description' => 'information gleaned from the output of a Quake2 DM log','files' => [],'lines' => {'nonpod' => 148,'pod' => 74,'pod_errors' => 0,'total' => 222,'with_comments' => 16},'releases' => 1,'size' => {'packed' => 2912,'unpacked' => 7641},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['strict','vars']},'loose-0.01.tar.gz' => {'author' => 'MSCHWERN','description' => 'Perl pragma to allow unsafe constructs','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 53,'pod' => 23,'pod_errors' => 0,'total' => 76,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 2194,'unpacked' => 4040},'testers' => {'pass' => 3},'uses' => ['Exporter','strict','vars']},'lot.tar.gz' => {'author' => 'STRYTOAST','description' => 'Information on an item in an auction','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 83,'pod' => 101,'pod_errors' => 0,'total' => 184,'with_comments' => 10},'releases' => 1,'requires' => ['Class-DBI-0.93.tar.gz','Date-Simple-1.03.tar.gz','Test-Simple-0.47.tar.gz'],'requires_module' => {'Class::DBI' => '0.27','Date::Simple' => '1.03','Test::More' => '0.17'},'requires_recursive' => ['Carp-Assert-0.17.tar.gz','Class-Accessor-0.18.tar.gz','Class-DBI-0.93.tar.gz','Class-Data-Inheritable-0.02.tar.gz','Class-Fields-0.16.tar.gz','Class-Trigger-0.08.tar.gz','Class-WhiteHole-0.04.tar.gz','DBI-1.37.tar.gz','Date-Simple-1.03.tar.gz','File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','IO-stringy-2.108.tar.gz','Ima-DBI-0.29.tar.gz','Storable-2.07.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 3579,'unpacked' => 9552},'testers' => {},'uses' => ['Class::DBI','Date::Simple','strict','vars']},'mixin-0.04.tar.gz' => {'author' => 'MSCHWERN','description' => 'Mix-in inheritance, an alternative to multiple inheritance','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1772,'pod' => 1187,'pod_errors' => 0,'total' => 2959,'with_comments' => 64},'releases' => 4,'size' => {'packed' => 23133,'unpacked' => 70604},'testers' => {'pass' => 8},'uses' => ['Carp','base','strict','vars']},'mmds-1.902.tar.gz' => {'author' => 'JV','description' => undef,'files' => [],'lines' => {'nonpod' => 5032,'pod' => 207,'pod_errors' => 0,'total' => 5239,'with_comments' => 593},'releases' => 1,'size' => {'packed' => 409322,'unpacked' => 807096},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Carp','Data::Dumper','constant','strict','warnings']},'mod_perl-1.27.tar.gz' => {'author' => 'DOUGM','description' => 'Utilities for <Perl> sections','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 6450,'pod' => 4767,'pod_errors' => 10,'total' => 11217,'with_comments' => 221},'releases' => 43,'size' => {'packed' => 372525,'unpacked' => 1096733},'testers' => {'fail' => 3,'pass' => 7},'uses' => ['$file','..::lib::Apache::MyConfig','5.003_97','Apache','Apache::Constants','Apache::Constants::Exports','Apache::ExtUtils','Apache::MyConfig','Apache::PerlSections','Apache::Symbol','Apache::Table','B::Graph','B::Xref','BSD::Resource','Carp','Config','Cwd','Exporter','ExtUtils::Embed','ExtUtils::MakeMaker','ExtUtils::testlib','File::Basename','IO::File','IO::Socket','LWP::UserAgent','MIME::Base64','Opcode','Test::Harness','URI::URL','lib','mod_perl','mod_perl_hooks','strict','subs','vars']},'mod_perl-1.28.tar.gz' => {'author' => 'GOZER','description' => 'Utilities for <Perl> sections','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 6540,'pod' => 4825,'pod_errors' => 10,'total' => 11365,'with_comments' => 235},'releases' => 43,'size' => {'packed' => 375986,'unpacked' => 1113102},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['$file','..::lib::Apache::MyConfig','5.003_97','Apache::MyConfig','B::Graph','B::Xref','BSD::Resource','Carp','Config','Cwd','Exporter','ExtUtils::Embed','ExtUtils::MakeMaker','ExtUtils::testlib','File::Basename','IO::File','IO::Socket','LWP::UserAgent','MIME::Base64','Opcode','Test::Harness','URI::URL','lib','mod_perl_hooks','strict','subs','vars']},'modules-0.04.tar.gz' => {'author' => 'MUENALAN','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 84,'pod' => 75,'pod_errors' => 0,'total' => 159,'with_comments' => 1},'releases' => 5,'size' => {'packed' => 3045,'unpacked' => 6233},'testers' => {'pass' => 6},'uses' => ['CPAN','Carp']},'mqs-header-0.01.tar.gz' => {'author' => 'STOUGARD','description' => 'Perl extension for header management of files, to use with mqs::spool module','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 118,'pod' => 37,'pod_errors' => 0,'total' => 155,'with_comments' => 11},'releases' => 1,'size' => {'packed' => 2940,'unpacked' => 6766},'testers' => {'pass' => 3},'uses' => ['5.006','AutoLoader','DynaLoader','Exporter','strict','warnings']},'mqs-spool-0.03.tar.gz' => {'author' => 'STOUGARD','description' => 'Perl extension for management of spools','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 222,'pod' => 60,'pod_errors' => 0,'total' => 282,'with_comments' => 21},'releases' => 3,'size' => {'packed' => 4700,'unpacked' => 12481},'testers' => {'pass' => 2},'uses' => ['5.005_62','AutoLoader','Cwd','DynaLoader','Exporter','POSIX','strict','warnings']},'mssql-1.008.zip' => {'author' => 'SOMMAR','description' => undef,'files' => [],'lines' => {'nonpod' => 3556,'pod' => 1863,'pod_errors' => 0,'total' => 5419,'with_comments' => 693},'releases' => 4,'size' => {'packed' => 176811,'unpacked' => 603183},'testers' => {},'uses' => ['5.003','Carp','DynaLoader','Exporter','strict','vars']},'namespace-0.05.tar.gz' => {'author' => 'AMICHAUER','description' => 'Perl pragma to use like C++ namespace alias','files' => ['Makefile.PL'],'lines' => {'nonpod' => 62,'pod' => 69,'pod_errors' => 0,'total' => 131,'with_comments' => 0},'releases' => 4,'size' => {'packed' => 2060,'unpacked' => 5648},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['strict']},'new.spirit-2.0.11.tar.gz' => {'author' => 'JRED','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 13275,'pod' => 0,'pod_errors' => 0,'total' => 13275,'with_comments' => 2012},'releases' => 7,'size' => {'packed' => 222587,'unpacked' => 580900},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['$db_module','CIPP','Carp','Config','Cwd','DBI','Data::Dumper','Fcntl','File::Basename','File::Copy','File::Find','File::Path','FileHandle','IPC::Open2','Text::Wrap','Time::Local','strict','vars']},'nsapi_perl-0.24.tar.gz' => {'author' => 'BSUGARS','description' => 'framework for integrating Perl and Netscape servers','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 1263,'pod' => 1264,'pod_errors' => 1,'total' => 2527,'with_comments' => 181},'releases' => 8,'size' => {'packed' => 46047,'unpacked' => 154457},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','File::Basename','strict','subs','vars']},'only-0.26.tar.gz' => {'author' => 'INGY','description' => 'Load specific module versions; Install many','files' => ['Makefile.PL','README','META.yml','MANIFEST'],'lines' => {'nonpod' => 2953,'pod' => 433,'pod_errors' => 0,'total' => 3386,'with_comments' => 140},'releases' => 5,'size' => {'packed' => 28584,'unpacked' => 93723},'testers' => {'pass' => 3},'uses' => ['$self->{path}::$self->{dispatch}','5.004','5.006001','Carp','Config','Cwd','Data::Dumper','Exporter','ExtUtils::Install','ExtUtils::MM_Unix','ExtUtils::MakeMaker','File::Basename','File::Find','File::Path','File::Spec','FileHandle','Module::Install::Base','Net::FTP','Socket','Test::Builder','Test::More','lib','only::config','strict','threads::shared','vars']},'optimize-0.03.tar.gz' => {'author' => 'ABERGMAN','description' => 'Pragma for hinting optimizations on variables','files' => ['Makefile.PL','README','Build.PL','MANIFEST'],'lines' => {'nonpod' => 277,'pod' => 64,'pod_errors' => 0,'total' => 341,'with_comments' => 25},'releases' => 3,'size' => {'packed' => 4806,'unpacked' => 11751},'testers' => {'fail' => 4,'pass' => 2,'tests' => '30'},'uses' => ['Attribute::Handlers','B','B::Generate','B::Utils','Carp','Hook::Scope','constant','optimize::$_','strict']},'optimizer-0.05.tar.gz' => {'author' => 'ABERGMAN','description' => 'Write your own Perl optimizer, in Perl','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 177,'pod' => 69,'pod_errors' => 0,'total' => 246,'with_comments' => 16},'releases' => 5,'size' => {'packed' => 11379,'unpacked' => 36340},'testers' => {'fail' => 1,'tests' => '21'},'uses' => ['5.7.2','B','B::Generate','Carp','DynaLoader','strict','warnings']},'pBLADE-0.10.tar.gz' => {'author' => 'PRATZLAFF','description' => 'Perl interface to the BLADE library.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 161,'pod' => 95,'pod_errors' => 0,'total' => 256,'with_comments' => 3},'releases' => 6,'size' => {'packed' => 11683,'unpacked' => 45708},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'pRPC-modules-0.1005.tar.gz' => {'author' => 'JWIED','description' => 'Perl extension for writing pRPC servers','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1136,'pod' => 658,'pod_errors' => 0,'total' => 1794,'with_comments' => 221},'releases' => 5,'size' => {'packed' => 19186,'unpacked' => 73947},'testers' => {'pass' => 2},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'parrot-0.0.10.tar.gz' => {'author' => 'SFINK','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 41990,'pod' => 13761,'pod_errors' => 18,'total' => 55751,'with_comments' => 5023},'releases' => 9,'size' => {'packed' => 7157339,'unpacked' => 32296993},'testers' => {'fail' => 3,'tests' => '658'},'uses' => ['5.004','5.005','5.005_03','5.005_62','5.006','AutoLoader','COMP_parsefuncs','Carp','Data::Dumper','Digest::MD5','DynaLoader','Env','Exporter','FileHandle','FindBin','Miniperl::Generator','Miniperl::Parser','Miniperl::Tokenizer','P6C::Addcontext','P6C::Builtins','P6C::Context','P6C::IMCC','P6C::IMCC::Binop','P6C::IMCC::guard','P6C::IMCC::hype','P6C::IMCC::prefix','P6C::IMCC::rule','P6C::Nodes','P6C::Parser','P6C::Tree::String','P6C::Util','Parrot::Config','Parrot::Op','Parrot::OpTrans','Parrot::OpTrans::C','Parrot::OpTrans::CPrederef','Parrot::PackFile::ConstTable','Parrot::PackFile::Constant','Parrot::PackFile::FixupTable','Parrot::PakFile2','Parrot::String','Parrot::Test','Parrot::Types','Parse::BNF','Parse::RecDescent','Regex','Regex::CodeGen','Regex::CodeGen::Pasm','Regex::CodeGen::Rx','Regex::Grammar','Regex::Ops::List','Regex::Ops::Tree','Regex::Optimize','Regex::Parse','Regex::PreOptimize','Regex::Rewrite','Scheme::Generator','Scheme::Parser','Scheme::Tokenizer','SelfLoader','Symbol','Test::Builder','Test::More','Text::Balanced','charnames','config::$_','constant','integer','lib','strict','subs','vars','warnings','warnings::register']},'parrot-0.0.3.tar.gz' => {'author' => 'SIMON','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 6079,'pod' => 2987,'pod_errors' => 0,'total' => 9066,'with_comments' => 777},'releases' => 9,'size' => {'packed' => 193166,'unpacked' => 777570},'testers' => {},'uses' => ['5.004','Carp','Data::Dumper','Exporter','FileHandle','Getopt::Long','Parrot::Config','Parrot::Op','Parrot::OpLib::core','Parrot::PMC','Parrot::Types','Scheme::Parser','Scheme::Tokenizer','Symbol','Test::More','Test::Simple','Test::Utils','lib','strict','vars']},'parrot-0.0.4.tar.gz' => {'author' => 'SIMON','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 10573,'pod' => 7435,'pod_errors' => 7,'total' => 18008,'with_comments' => 1063},'releases' => 9,'size' => {'packed' => 443787,'unpacked' => 1786413},'testers' => {},'uses' => ['5.004','Carp','Data::Dumper','Env','Exporter','FileHandle','Getopt::Long','IO::File','Miniperl::Generator','Miniperl::Parser','Miniperl::Tokenizer','Parrot::Config','Parrot::OpLib::core','Parrot::Opcode','Parrot::PMC','Parrot::PackFile','Parrot::PackFile::ConstTable','Parrot::PackFile::Constant','Parrot::PackFile::FixupTable','Parrot::String','Parrot::Types','Scheme::Generator','Symbol','Test::Builder','Test::More','constant','lib','strict','vars','warnings']},'parrot-0.0.5.tar.gz' => {'author' => 'JGOFF','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 13832,'pod' => 7416,'pod_errors' => 0,'total' => 21248,'with_comments' => 1520},'releases' => 9,'size' => {'packed' => 537416,'unpacked' => 2127950},'testers' => {},'uses' => ['5.004','Carp','Data::Dumper','Env','Exporter','FileHandle','Getopt::Long','IO::File','Miniperl::Generator','Miniperl::Parser','Miniperl::Tokenizer','Parrot::Config','Parrot::Jit::alphaGeneric','Parrot::Jit::i386Generic','Parrot::Jit::sun4Generic','Parrot::Op','Parrot::OpLib::core','Parrot::OpTrans','Parrot::OpTrans::C','Parrot::Opcode','Parrot::PMC','Parrot::PackFile','Parrot::PackFile::ConstTable','Parrot::PackFile::Constant','Parrot::PackFile::FixupTable','Parrot::String','Parrot::Types','Regex::CodeGen','Regex::CodeGen::Pasm','Regex::CodeGen::Re','Regex::CodeGen::Rx','Regex::Generate','Regex::Grammar','Regex::Optimize','Regex::Parse','Regex::PreOptimize','Regex::Rewrite','Regex::Rewrite::Rx','Regex::Rewrite::Stackless','Scheme::Generator','Scheme::Parser','Scheme::Tokenizer','Symbol','Test::Builder','Test::More','constant','lib','strict','vars','warnings']},'parrot-0.0.8.1.tgz' => {'author' => 'JGOFF','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 30212,'pod' => 11128,'pod_errors' => 4,'total' => 41340,'with_comments' => 3300},'releases' => 9,'size' => {'packed' => 6781987,'unpacked' => 30889416},'testers' => {},'uses' => ['5.004','5.005','5.005_03','5.005_62','5.006','AutoLoader','Carp','Data::Dumper','DynaLoader','Env','Exporter','FileHandle','FindBin','Miniperl::Generator','Miniperl::Parser','Miniperl::Tokenizer','P6C::Addcontext','P6C::Nodes','Parrot::Config','Parrot::Op','Parrot::OpTrans','Parrot::OpTrans::C','Parrot::PackFile::ConstTable','Parrot::PackFile::Constant','Parrot::PackFile::FixupTable','Parrot::String','Parrot::Test','Parse::BNF','Parse::RecDescent','Scheme::Generator','Scheme::Parser','Scheme::Tokenizer','SelfLoader','Test::Builder','Test::More','Text::Balanced','config::$_','constant','lib','strict','vars','warnings','warnings::register']},'parrot-0.0.9.tar.gz' => {'author' => 'SFINK','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 38359,'pod' => 12844,'pod_errors' => 11,'total' => 51203,'with_comments' => 4592},'releases' => 9,'size' => {'packed' => 7022118,'unpacked' => 31763681},'testers' => {'fail' => 1},'uses' => ['5.004','5.005','5.005_03','5.005_62','5.006','AutoLoader','Carp','Data::Dumper','Digest::MD5','DynaLoader','Env','Exporter','FileHandle','FindBin','Jako::Compiler','Jako::Construct','Jako::Construct::Block','Jako::Construct::Block::Conditional','Jako::Construct::Block::Conditional::Else','Jako::Construct::Block::Conditional::If','Jako::Construct::Block::Conditional::Unless','Jako::Construct::Block::Loop','Jako::Construct::Block::Loop::Continue','Jako::Construct::Block::Loop::Until','Jako::Construct::Block::Loop::While','Jako::Construct::Block::Sub','Jako::Construct::Declaration','Jako::Construct::Declaration::Constant','Jako::Construct::Declaration::Sub','Jako::Construct::Declaration::Variable','Jako::Construct::Expression','Jako::Construct::Expression::Call','Jako::Construct::Expression::Value','Jako::Construct::Expression::Value::Identifier','Jako::Construct::Expression::Value::Literal','Jako::Construct::Label','Jako::Construct::Statement','Jako::Construct::Statement::Arithmetic','Jako::Construct::Statement::Assign','Jako::Construct::Statement::Bitwise','Jako::Construct::Statement::Call','Jako::Construct::Statement::Decrement','Jako::Construct::Statement::Goto','Jako::Construct::Statement::Increment','Jako::Construct::Statement::LoopControl','Jako::Construct::Statement::Return','Jako::Construct::Type','Jako::Construct::Type::Integer','Jako::Construct::Type::Number','Jako::Construct::Type::Object','Jako::Construct::Type::String','Jako::Processor','Jako::Symbol','Jako::Token','Miniperl::Generator','Miniperl::Parser','Miniperl::Tokenizer','P6C::Addcontext','P6C::Builtins','P6C::Context','P6C::IMCC','P6C::IMCC::Binop','P6C::IMCC::guard','P6C::IMCC::hype','P6C::IMCC::prefix','P6C::IMCC::rule','P6C::Nodes','P6C::Parser','P6C::Util','Parrot::Config','Parrot::Op','Parrot::OpTrans','Parrot::OpTrans::C','Parrot::PackFile::ConstTable','Parrot::PackFile::Constant','Parrot::PackFile::FixupTable','Parrot::PakFile2','Parrot::String','Parrot::Test','Parrot::Types','Parse::BNF','Parse::RecDescent','Regex','Regex::CodeGen','Regex::CodeGen::IMCC','Regex::CodeGen::Pasm','Regex::CodeGen::Rx','Regex::Grammar','Regex::Ops::List','Regex::Ops::Tree','Regex::Optimize','Regex::Parse','Regex::PreOptimize','Regex::Rewrite','Regex::State','Scheme::Builtins','Scheme::Generator','Scheme::Parser','Scheme::Tokenizer','SelfLoader','Symbol','Test::Builder','Test::More','Text::Balanced','config::$_','constant','integer','lib','strict','vars','warnings','warnings::register']},'parrot-0_0_7.tgz' => {'author' => 'JGOFF','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 21742,'pod' => 9976,'pod_errors' => 1,'total' => 31718,'with_comments' => 2116},'releases' => 1,'size' => {'packed' => 770925,'unpacked' => 3106432},'testers' => {},'uses' => ['5.004','5.005','5.005_62','AutoLoader','Carp','Data::Dumper','DynaLoader','Env','Exporter','FileHandle','Miniperl::Generator','Miniperl::Parser','Miniperl::Tokenizer','P6C::Addcontext','P6C::Builtins','P6C::Context','P6C::IMCC','P6C::Nodes','P6C::Parser','P6C::Util','Parrot::Config','Parrot::Op','Parrot::OpTrans','Parrot::OpTrans::C','Parrot::PackFile::ConstTable','Parrot::PackFile::Constant','Parrot::PackFile::FixupTable','Parrot::PakFile2','Parrot::String','Parrot::Types','Parse::RecDescent','Regex::CodeGen','Regex::CodeGen::Pasm','Regex::CodeGen::Rx','Regex::Generate','Regex::Grammar','Regex::Ops::List','Regex::Ops::Tree','Regex::Optimize','Regex::Parse','Regex::PreOptimize','Regex::Rewrite','Regex::Rewrite::Stackless','Scheme::Generator','Scheme::Parser','Scheme::Tokenizer','SelfLoader','Test::Builder','Test::More','Text::Balanced','config::$_','constant','lib','strict','vars','warnings']},'payroll-0.4.tar.gz' => {'author' => 'JAMESP','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4053,'pod' => 806,'pod_errors' => 0,'total' => 4859,'with_comments' => 284},'releases' => 2,'requires' => ['File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-SAX-0.12.tar.gz'],'requires_module' => {'File::Temp' => undef,'XML::LibXML' => undef,'XML::SAX' => undef},'requires_recursive' => ['File-Spec-0.82.tar.gz','File-Temp-0.12.tar.gz','XML-LibXML-1.54.tar.gz','XML-LibXML-Common-0.13.tar.gz','XML-NamespaceSupport-1.08.tar.gz','XML-SAX-0.12.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 48504,'unpacked' => 284063},'testers' => {'pass' => 1},'uses' => ['Exporter','XML::LibXML','constant','strict','vars']},'pcsc-perl-1.0.8.tar.gz' => {'author' => 'TCHINCHOW','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 693,'pod' => 345,'pod_errors' => 0,'total' => 1038,'with_comments' => 178},'releases' => 3,'size' => {'packed' => 31857,'unpacked' => 132595},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'pcsc-perl-1.2.2.tar.gz' => {'author' => 'WHOM','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 913,'pod' => 704,'pod_errors' => 1,'total' => 1617,'with_comments' => 171},'releases' => 3,'size' => {'packed' => 38616,'unpacked' => 160724},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars','warnings']},'pee-1.07.tar.gz' => {'author' => 'DREADY','description' => undef,'files' => ['Makefile.PL'],'lines' => {'nonpod' => 264,'pod' => 0,'pod_errors' => 0,'total' => 264,'with_comments' => 58},'releases' => 1,'size' => {'packed' => 11744,'unpacked' => 31226},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['strict','vars']},'perl-5.6.1.tar.gz' => {'author' => 'GSAR','description' => 'Simple way to add/delete directories in @INC','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 106796,'pod' => 94950,'pod_errors' => 29,'total' => 201746,'with_comments' => 9858},'releases' => 9,'size' => {'packed' => 5983695,'unpacked' => 22531730},'testers' => {},'uses' => ['','5.000','5.001','5.002','5.003','5.003_11','5.003_26','5.003_90','5.004','5.005','5.005_64','5.006','Apache','AutoLoader','AutoSplit','B','B::Asmdata','B::Assembler','B::Bblock','B::C','B::Stackobj','B::Terse','Benchmark','ByteLoader','CGI','CGI::Cookie','CGI::Util','CPAN','CPAN::Config','CPAN::FirstTime','CPAN::MyConfig','CPAN::Nox','Carp','Carp::Heavy','Class::Struct','Config','Cwd','DB','Data::Dumper','Devel::CoreStack','Devel::Peek','Devel::SelfStubber','Devel::Symdump','DirHandle','DynaLoader','Errno','Exporter','Exporter::Heavy','ExtUtils::Liblist','ExtUtils::MM_Cygwin','ExtUtils::MM_MacOS','ExtUtils::MM_Unix','ExtUtils::MM_VMS','ExtUtils::MM_Win32','ExtUtils::MakeMaker','ExtUtils::Manifest','ExtUtils::Miniperl','ExtUtils::Mksymlists','ExtUtils::Packlist','ExtUtils::XSSymSet','FCGI','Fcntl','File::Basename','File::Compare','File::Copy','File::Find','File::Path','File::Spec','File::Spec::$module','File::Spec::Functions','File::Spec::Unix','File::stat','FileHandle','Foo','Getopt::Long','Getopt::Std','HTTP::Date','I18N::Collate','IO::','IO::File','IO::Handle','IO::Pipe','IO::Seekable','IO::Select','IO::Socket','IO::Socket::INET','IPC::Open3','IPC::SysV','JNI','JNI::Config','JPL::AutoLoader','JPL::Class','LWP::UserAgent','Mac::Files','Mac::MoreFiles','Math::BigInt','Math::Complex','Net::Ping','OS2::DLL','Opcode','POSIX','ParseWords','Pod::Functions','Pod::InputObjects','Pod::ParseUtils','Pod::Parser','Pod::PlainText','Pod::Select','Pod::Text','SelectSaver','SelfLoader','Socket','Symbol','Sys::Hostname','Term::ANSIColor','Term::Cap','Term::ReadLine','Term::ReadLine::Gnu','Term::ReadLine::Perl','Test::Harness','Text::ParseWords','Text::Tabs','Text::Wrap','Thread','Tie::Array','Tie::Hash','Time::tm','VMS::Filespec','XSLoader','constant','diagnostics','fields','happy','integer','is','locale','overload','re','strict','subs','sys::syscall.ph','sys::systeminfo.ph','syscall.ph','utf','vars','vmsish','warnings','warnings::register']},'perl-5.7.1.tar.gz' => {'author' => 'JHI','description' => 'warn of errors (from perspective of caller) cluck - warn of errors with stack backtrace (not exported by default) croak - die of errors (from perspective of caller) confess - die of errors with stack backtrace','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 114314,'pod' => 100956,'pod_errors' => 28,'total' => 215270,'with_comments' => 10307},'releases' => 9,'size' => {'packed' => 7069918,'unpacked' => 27321368},'testers' => {},'uses' => ['','5','5.000','5.001','5.002','5.003','5.003_11','5.003_26','5.003_90','5.004','5.005','5.005_64','5.006','5.6.0','Apache','AutoLoader','AutoSplit','B','B::Asmdata','B::Assembler','B::Bblock','B::C','B::Stackobj','B::Terse','Benchmark','ByteLoader','CGI','CGI::Cookie','CGI::Util','CPAN','CPAN::Config','CPAN::FirstTime','CPAN::MyConfig','CPAN::Nox','Carp','Carp::Heavy','Class::Struct','Config','Cwd','DB','Data::Dumper','Devel::CoreStack','Devel::Peek','Devel::SelfStubber','Devel::Symdump','Digest::Perl::MD5','DirHandle','DynaLoader','Encode','Encode::Encoding','Errno','Exporter','Exporter::Heavy','ExtUtils::Liblist','ExtUtils::MM_Cygwin','ExtUtils::MM_MacOS','ExtUtils::MM_Unix','ExtUtils::MM_VMS','ExtUtils::MM_Win32','ExtUtils::MakeMaker','ExtUtils::Manifest','ExtUtils::Miniperl','ExtUtils::Mksymlists','ExtUtils::Packlist','ExtUtils::XSSymSet','FCGI','Fcntl','File::Basename','File::Compare','File::Copy','File::Find','File::Path','File::Spec','File::Spec::$module','File::Spec::Functions','File::Spec::Unix','File::stat','FileHandle','Filter::Util::Call','Foo','Getopt::Long','Getopt::Std','HTTP::Date','I18N::Collate','IO::','IO::File','IO::Handle','IO::Pipe','IO::Seekable','IO::Select','IO::Socket','IO::Socket::INET','IPC::Open3','IPC::SysV','JNI','JNI::Config','JPL::AutoLoader','JPL::Class','LWP::UserAgent','Locale::Constants','Mac::Files','Mac::MoreFiles','Math::BigInt','Math::Complex','Net::Ping','Net::Ping::External','OS2::DLL','Opcode','POSIX','ParseWords','Pod::InputObjects','Pod::ParseUtils','Pod::Parser','Pod::PlainText','Pod::Select','Pod::Text','SelectSaver','SelfLoader','Socket','Symbol','Sys::Hostname','Term::ANSIColor','Term::Cap','Term::ReadLine','Term::ReadLine::Gnu','Term::ReadLine::Perl','Test::Harness','Text::Balanced','Text::ParseWords','Text::Tabs','Text::Wrap','Thread','Tie::Array','Tie::Hash','Time::tm','VMS::Filespec','XSLoader','bytes','constant','diagnostics','fields','happy','integer','is','lib','locale','overload','re','strict','subs','sys::syscall.ph','sys::systeminfo.ph','syscall.ph','utf','v5.6','vars','vmsish','warnings','warnings::register']},'perl-5.7.2.tar.gz' => {'author' => 'JHI','description' => 'Establish IS-A relationship with base class at compile time','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 134510,'pod' => 113675,'pod_errors' => 28,'total' => 248185,'with_comments' => 12660},'releases' => 9,'size' => {'packed' => 7775184,'unpacked' => 30015449},'testers' => {},'uses' => ['','$name','5','5.000','5.001','5.002','5.003','5.003_11','5.003_90','5.004','5.005','5.00556','5.005_64','5.006','5.6.0','Apache','Attribute::Handlers','AutoLoader','AutoSplit','B','B::Asmdata','B::Assembler','B::Bblock','B::C','B::Debug','B::Stackobj','B::Terse','Benchmark','ByteLoader','CGI','CGI::Cookie','CGI::Util','CPAN','CPAN::Config','CPAN::FirstTime','CPAN::MyConfig','CPAN::Nox','Carp','Carp::Heavy','Class::Struct','Config','Cwd','DB','Data::Dumper','Devel::CoreStack','Devel::Peek','Devel::SelfStubber','Devel::Symdump','Digest::Perl::MD5','DirHandle','DynaLoader','Encode','Encode::Encoding','Errno','Exporter','Exporter::Heavy','ExtUtils::Liblist','ExtUtils::MM_Cygwin','ExtUtils::MM_MacOS','ExtUtils::MM_NW5','ExtUtils::MM_Unix','ExtUtils::MM_VMS','ExtUtils::MM_Win32','ExtUtils::MakeMaker','ExtUtils::Manifest','ExtUtils::Miniperl','ExtUtils::Mksymlists','ExtUtils::Packlist','ExtUtils::XSSymSet','FCGI','Fcntl','File::Basename','File::Compare','File::Copy','File::Find','File::Path','File::Spec','File::Spec::$module','File::Spec::Functions','File::Spec::Unix','File::stat','FileHandle','Filter::Util::Call','Foo','Getopt::Long','Getopt::Std','HTML::TreeBuilder','HTTP::Date','I18N::Collate','I18N::Langinfo','IO::','IO::File','IO::Handle','IO::Pipe','IO::Seekable','IO::Select','IO::Socket','IO::Socket::INET','IPC::Open3','IPC::SysV','JNI','JNI::Config','JPL::AutoLoader','JPL::Class','LWP::Simple','LWP::UserAgent','List::Util','Locale::Constants','Mac::Files','Mac::MoreFiles','Math::BigInt','Math::Complex','NDBM_File','Net::Cmd','Net::Config','Net::Domain','Net::FTP::A','Net::FTP::I','Net::FTP::dataconn','Net::Netrc','Net::Ping','Net::Ping::External','OS2::DLL','Opcode','POSIX','ParseWords','Pod::InputObjects','Pod::ParseUtils','Pod::Parser','Pod::PlainText','Pod::Select','Pod::Text','SDBM_File','Search::Dict','SelectSaver','SelfLoader','Socket','Symbol','Sys::Hostname','Term::ANSIColor','Term::Cap','Term::ReadLine','Term::ReadLine::Gnu','Term::ReadLine::Perl','Test::Harness','Test::Simple','Text::Balanced','Text::ParseWords','Text::Tabs','Text::Wrap','Thread','Tie::Array','Tie::Hash','Time::Local','Time::Seconds','Time::tm','VMS::Filespec','XSLoader','bytes','constant','diagnostics','fields','happy','integer','is','lib','locale','overload','re','strict','subs','sys::syscall.ph','sys::systeminfo.ph','syscall.ph','utf','v5.6','vars','vmsish','warnings','warnings::register']},'perl-5.7.3.tar.gz' => {'author' => 'JHI','description' => 'Establish IS-A relationship with base class at compile time','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 152816,'pod' => 130072,'pod_errors' => 41,'total' => 282888,'with_comments' => 14478},'releases' => 9,'size' => {'packed' => 9096782,'unpacked' => 35264559},'testers' => {},'uses' => ['','$name','5','5.000','5.001','5.002','5.003_11','5.003_90','5.004','5.00404','5.005','5.00556','5.006','5.006_00','5.006_001','5.7.2','Apache','Attribute::Handlers','AutoLoader','AutoSplit','B','B::Asmdata','B::Assembler','B::Bblock','B::C','B::Debug','B::Deparse','B::Stackobj','B::Terse','Benchmark','ByteLoader','CGI','CGI::Cookie','CGI::Util','CPAN','CPAN::Config','CPAN::FirstTime','CPAN::MyConfig','CPAN::Nox','Carp','Carp::Heavy','Class::Struct','Config','Convert::EBCDIC','Cwd','DB','Data::Dumper','Devel::CoreStack','Devel::Peek','Devel::SelfStubber','Devel::Symdump','Digest::Perl::MD5','DirHandle','DynaLoader','Encode','Encode::CN','Encode::CN::HZ','Encode::Encoding','Encode::JP','Encode::JP::H2Z','Encode::Unicode','Encode::ucs2_le','Errno','Exporter','Exporter::Heavy','ExtUtils::Liblist','ExtUtils::MM_BeOS','ExtUtils::MM_Cygwin','ExtUtils::MM_MacOS','ExtUtils::MM_NW5','ExtUtils::MM_Unix','ExtUtils::MM_VMS','ExtUtils::MM_Win32','ExtUtils::MakeMaker','ExtUtils::Manifest','ExtUtils::Miniperl','ExtUtils::Mksymlists','ExtUtils::Packlist','ExtUtils::XSSymSet','FCGI','Fcntl','File::Basename','File::Compare','File::Copy','File::Find','File::Path','File::Spec','File::Spec::$module','File::Spec::Functions','File::Spec::Unix','File::stat','FileHandle','Filter::Util::Call','Foo','Getopt::Long','Getopt::Std','HTML::TreeBuilder','HTTP::Date','I18N::Collate','IO::','IO::File','IO::Handle','IO::Pipe','IO::Seekable','IO::Select','IO::Socket','IO::Socket::INET','IPC::Open3','IPC::SysV','JNI','JNI::Config','JPL::AutoLoader','JPL::Class','Jcode::Constants','LWP::Simple','LWP::UserAgent','List::Util','Locale::Constants','MIME::Base64','Mac::Files','Mac::InternetConfig','Mac::MoreFiles','Math::BigInt','Math::Complex','NDBM_File','Net::Cmd','Net::Config','Net::FTP::A','Net::FTP::I','Net::FTP::dataconn','Net::Netrc','Net::Ping','Net::Ping::External','OS2::DLL','OS2::Process::Const','Opcode','POSIX','ParseWords','Pod::InputObjects','Pod::ParseLink','Pod::ParseUtils','Pod::Parser','Pod::PlainText','Pod::Select','Pod::Text','SDBM_File','Scalar::Util','Search::Dict','SelectSaver','SelfLoader','Socket','Symbol','Sys::Hostname','Term::ANSIColor','Term::Cap','Term::ReadLine','Term::ReadLine::Gnu','Term::ReadLine::Perl','Test::Builder','Test::Harness','Test::Harness::Assert','Test::Harness::Iterator','Test::Harness::Straps','Text::Balanced','Text::ParseWords','Text::Tabs','Text::Wrap','Thread','Tie::Array','Tie::Hash','Time::Local','Time::tm','Unicode::Normalize','VMS::Filespec','XSLoader','bytes','constant','diagnostics','fields','happy','integer','is','lib','locale','overload','re','strict','subs','sys::syscall.ph','sys::systeminfo.ph','syscall.ph','threads::Shared','utf','vars','vmsish','warnings','warnings::register']},'perl-5.8.0-RC1.tgz' => {'author' => 'JHI','description' => 'warn of errors (from perspective of caller) cluck - warn of errors with stack backtrace (not exported by default) croak - die of errors (from perspective of caller) confess - die of errors with stack backtrace shortmess - return the message that carp and croak produce longmess - return the message that cluck and confess produce','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 160293,'pod' => 136440,'pod_errors' => 44,'total' => 296733,'with_comments' => 15410},'releases' => 2,'size' => {'packed' => 10913451,'unpacked' => 45019911},'testers' => {},'uses' => ['','$name','5','5.000','5.001','5.002','5.003_11','5.003_90','5.004','5.00404','5.005','5.00503','5.00556','5.005_02','5.005_03','5.006','5.006_00','5.006_001','5.007003','5.007_003','Apache','Attribute::Handlers','Authen::SASL','AutoLoader','AutoSplit','B','B::Asmdata','B::Assembler','B::Bblock','B::C','B::Debug','B::Deparse','B::Stackobj','B::Terse','Benchmark','ByteLoader','CGI','CGI::Cookie','CGI::Util','CPAN','CPAN::Config','CPAN::FirstTime','CPAN::MyConfig','CPAN::Nox','Carp','Carp::Heavy','Class::Struct','Config','Convert::EBCDIC','Cwd','DB','Data::Dumper','Devel::CoreStack','Devel::Peek','Devel::SelfStubber','Digest::Perl::MD5','DirHandle','DynaLoader','Encode','Encode::Alias','Encode::CJKConstants','Encode::CN::2022_CN','Encode::CN::HZ','Encode::Config','Encode::Encoding','Encode::JP::H2Z','Encode::JP::JIS7','Encode::KR::2022_KR','Encode::Unicode','Errno','Exporter','Exporter::Heavy','ExtUtils::Liblist','ExtUtils::Liblist::Kid','ExtUtils::MM','ExtUtils::MM_Any','ExtUtils::MM_Unix','ExtUtils::MM_Win32','ExtUtils::MY','ExtUtils::MakeMaker','ExtUtils::Manifest','ExtUtils::Miniperl','ExtUtils::Mksymlists','ExtUtils::Packlist','ExtUtils::XSSymSet','FCGI','Fcntl','File::Basename','File::Compare','File::Copy','File::Find','File::Path','File::Spec','File::Spec::$module','File::Spec::Functions','File::Spec::Unix','File::stat','FileHandle','Filter::Util::Call','Foo','Getopt::Long','Getopt::Std','HTML::TreeBuilder','HTTP::Date','I18N::Collate','I18N::Langinfo','IO::','IO::File','IO::Handle','IO::Pipe','IO::Seekable','IO::Select','IO::Socket','IO::Socket::INET','IPC::Open3','IPC::SysV','JNI','JNI::Config','JPL::AutoLoader','JPL::Class','LWP::Simple','LWP::UserAgent','List::Util','Locale::Constants','MIME::Base64','Mac::Files','Mac::InternetConfig','Math::BigFloat','Math::BigFloat::Trace','Math::BigInt','Math::BigInt::Lite','Math::BigInt::Trace','Math::BigRat','Math::Complex','NDBM_File','Net::Cmd','Net::Config','Net::FTP::A','Net::FTP::I','Net::FTP::dataconn','Net::Netrc','Net::Ping','Net::Ping::External','OS2::DLL','OS2::Process::Const','Opcode','POSIX','ParseWords','Pod::InputObjects','Pod::ParseLink','Pod::ParseUtils','Pod::Parser','Pod::PlainText','Pod::Select','Pod::Text','SDBM_File','Scalar::Util','Search::Dict','SelectSaver','SelfLoader','Socket','Symbol','Sys::Hostname','Term::ANSIColor','Term::Cap','Term::ReadLine','Term::ReadLine::Gnu','Term::ReadLine::Perl','Test::Builder','Test::Harness','Test::Harness::Assert','Test::Harness::Iterator','Test::Harness::Straps','Text::Balanced','Text::ParseWords','Text::Tabs','Text::Wrap','Thread','Tie::Array','Tie::Hash','Time::Local','Time::tm','Unicode::UCD','VMS::Filespec','XSLoader','bytes','constant','diagnostics','fields','happy','integer','is','locale','overload','re','strict','subs','sys::syscall.ph','sys::systeminfo.ph','syscall.ph','threads::Shared','threads::shared','threads::shared::queue','threads::shared::semaphore','utf','vars','vmsish','warnings','warnings::register']},'perl-5.8.0-RC2.tgz' => {'author' => 'JHI','description' => 'warn of errors (from perspective of caller) cluck - warn of errors with stack backtrace (not exported by default) croak - die of errors (from perspective of caller) confess - die of errors with stack backtrace shortmess - return the message that carp and croak produce longmess - return the message that cluck and confess produce','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 160779,'pod' => 136980,'pod_errors' => 44,'total' => 297759,'with_comments' => 15417},'releases' => 2,'size' => {'packed' => 10975492,'unpacked' => 45308363},'testers' => {},'uses' => ['','$file','$name','5','5.000','5.001','5.002','5.003_11','5.003_90','5.004','5.00404','5.005','5.00503','5.00556','5.005_02','5.005_03','5.006','5.006_00','5.006_001','5.007003','5.007_003','5.008','Apache','Attribute::Handlers','Authen::SASL','AutoLoader','AutoSplit','B','B::Asmdata','B::Assembler','B::Bblock','B::C','B::Debug','B::Deparse','B::Stackobj','B::Terse','Benchmark','ByteLoader','CGI','CGI::Cookie','CGI::Util','CPAN','CPAN::Config','CPAN::FirstTime','CPAN::MyConfig','CPAN::Nox','Carp','Carp::Heavy','Class::Struct','Config','Convert::EBCDIC','Cwd','DB','Data::Dumper','Devel::CoreStack','Devel::Peek','Devel::SelfStubber','Digest::Perl::MD5','DirHandle','DynaLoader','Encode','Encode::Alias','Encode::CJKConstants','Encode::CN::2022_CN','Encode::CN::HZ','Encode::Config','Encode::Encoding','Encode::JP::H2Z','Encode::JP::JIS7','Encode::KR::2022_KR','Encode::Unicode','Errno','Exporter','Exporter::Heavy','ExtUtils::Liblist','ExtUtils::Liblist::Kid','ExtUtils::MM','ExtUtils::MM_Any','ExtUtils::MM_Unix','ExtUtils::MM_Win32','ExtUtils::MY','ExtUtils::MakeMaker','ExtUtils::Manifest','ExtUtils::Miniperl','ExtUtils::Mksymlists','ExtUtils::Packlist','ExtUtils::XSSymSet','FCGI','Fcntl','File::Basename','File::Compare','File::Copy','File::Find','File::Path','File::Spec','File::Spec::$module','File::Spec::Functions','File::Spec::Unix','File::stat','FileHandle','Filter::Util::Call','Foo','Getopt::Long','Getopt::Std','HTML::TreeBuilder','HTTP::Date','I18N::Collate','I18N::Langinfo','IO::','IO::File','IO::Handle','IO::Pipe','IO::Seekable','IO::Select','IO::Socket','IO::Socket::INET','IPC::Open3','IPC::SysV','JNI','JNI::Config','JPL::AutoLoader','JPL::Class','LWP::Simple','LWP::UserAgent','List::Util','Locale::Constants','MIME::Base64','Mac::Files','Mac::InternetConfig','Math::BigFloat','Math::BigFloat::Trace','Math::BigInt','Math::BigInt::Lite','Math::BigInt::Trace','Math::BigRat','Math::Complex','NDBM_File','Net::Cmd','Net::Config','Net::FTP::A','Net::FTP::I','Net::FTP::dataconn','Net::Netrc','Net::Ping','Net::Ping::External','OS2::DLL','OS2::Process::Const','Opcode','POSIX','ParseWords','Pod::InputObjects','Pod::ParseLink','Pod::ParseUtils','Pod::Parser','Pod::PlainText','Pod::Select','Pod::Text','SDBM_File','Scalar::Util','Search::Dict','SelectSaver','SelfLoader','Socket','Symbol','Sys::Hostname','Term::ANSIColor','Term::Cap','Term::ReadLine','Term::ReadLine::Gnu','Term::ReadLine::Perl','Test::Builder','Test::Harness','Test::Harness::Assert','Test::Harness::Iterator','Test::Harness::Straps','Text::Balanced','Text::ParseWords','Text::Tabs','Text::Wrap','Thread','Tie::Array','Tie::Hash','Time::Local','Time::tm','Unicode::UCD','VMS::Filespec','XSLoader','bytes','constant','diagnostics','fields','happy','integer','is','locale','overload','re','strict','subs','sys::syscall.ph','sys::systeminfo.ph','syscall.ph','threads::Shared','threads::shared','utf','vars','vmsish','warnings','warnings::register']},'perl-5.8.0.tar.gz' => {'author' => 'JHI','description' => 'Establish IS-A relationship with base class at compile time','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 161015,'pod' => 137344,'pod_errors' => 43,'total' => 298359,'with_comments' => 15480},'releases' => 9,'size' => {'packed' => 11023084,'unpacked' => 45518734},'testers' => {},'uses' => ['','$file','$name','5','5.000','5.001','5.002','5.003_11','5.003_90','5.004','5.00404','5.005','5.00503','5.00556','5.005_02','5.005_03','5.006','5.006_00','5.006_001','5.007003','5.007_003','5.008','Apache','Attribute::Handlers','Authen::SASL','CGI','CGI::Cookie','CGI::Util','CPAN','CPAN::Config','CPAN::FirstTime','CPAN::MyConfig','CPAN::Nox','Carp::Heavy','Config','Convert::EBCDIC','DB','Data::Dumper','Devel::CoreStack','Devel::Peek','Digest::Perl::MD5','DynaLoader','Encode','Encode::Alias','Encode::CJKConstants','Encode::CN::2022_CN','Encode::CN::HZ','Encode::Config','Encode::Encoding','Encode::JP::H2Z','Encode::JP::JIS7','Encode::KR::2022_KR','Encode::Unicode','Errno','ExtUtils::Liblist','ExtUtils::Liblist::Kid','ExtUtils::MM','ExtUtils::MM_Any','ExtUtils::MM_Unix','ExtUtils::MM_Win32','ExtUtils::MY','ExtUtils::MakeMaker','ExtUtils::Manifest','ExtUtils::Miniperl','ExtUtils::Mksymlists','ExtUtils::Packlist','FCGI','File::Spec','File::Spec::$module','Filter::Util::Call','Foo','Getopt::Long','HTML::TreeBuilder','HTTP::Date','I18N::Langinfo','IO::','IO::File','IO::Handle','IO::Pipe','IO::Seekable','IO::Select','IO::Socket','IO::Socket::INET','IPC::SysV','JNI::Config','LWP::Simple','LWP::UserAgent','List::Util','Locale::Constants','MIME::Base64','Mac::Files','Mac::InternetConfig','Math::BigFloat','Math::BigFloat::Trace','Math::BigInt','Math::BigInt::Lite','Math::BigInt::Trace','Math::BigRat','Net::Cmd','Net::Config','Net::FTP::A','Net::FTP::I','Net::FTP::dataconn','Net::Netrc','Net::Ping','Net::Ping::External','OS2::Process::Const','ParseWords','Pod::InputObjects','Pod::ParseLink','Pod::ParseUtils','Pod::Parser','Pod::PlainText','Pod::Select','Pod::Text','Scalar::Util','Term::ANSIColor','Term::Cap','Term::ReadLine::Gnu','Term::ReadLine::Perl','Test::Builder','Test::Harness','Test::Harness::Assert','Test::Harness::Iterator','Test::Harness::Straps','Text::Balanced','Text::Tabs','Text::Wrap','Time::Local','Unicode::UCD','XSLoader','fields','happy','is','sys::syscall.ph','sys::systeminfo.ph','syscall.ph','threads::Shared','utf']},'perl-5.8.1-RC2.tar.gz' => {'author' => 'JHI','description' => 'Establish IS-A relationship with base class at compile time','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 172138,'pod' => 144808,'pod_errors' => 87,'total' => 316946,'with_comments' => 17210},'releases' => 2,'size' => {'packed' => 11668523,'unpacked' => 48618742},'testers' => {},'uses' => ['','$file','$name','5','5.000','5.001','5.002','5.003_11','5.003_90','5.004','5.00404','5.005','5.00503','5.00556','5.005_02','5.005_03','5.006','5.006_00','5.006_001','5.007003','5.007_003','5.008','APR::Pool','Apache','Apache::RequestIO','Apache::RequestRec','Apache::RequestUtil','Apache::Response','Attribute::Handlers','Authen::SASL','AutoLoader','AutoSplit','B','B::Asmdata','B::Assembler','B::Bblock','B::C','B::Concise','B::Debug','B::Deparse','B::Stackobj','Benchmark','ByteLoader','CGI','CGI::Cookie','CGI::Util','CPAN','CPAN::Config','CPAN::FirstTime','CPAN::MyConfig','CPAN::Nox','Carp','Carp::Heavy','Class::Struct','Config','Convert::EBCDIC','Cwd','DB','Data::Dumper','Devel::CoreStack','Devel::Peek','Devel::SelfStubber','Digest::Perl::MD5','DirHandle','DynaLoader','Encode','Encode::Alias','Encode::CJKConstants','Encode::CN::2022_CN','Encode::CN::HZ','Encode::Config','Encode::Encoding','Encode::JP::H2Z','Encode::JP::JIS7','Encode::KR::2022_KR','Encode::Unicode','Errno','Exporter','Exporter::Heavy','ExtUtils::Install','ExtUtils::Liblist','ExtUtils::Liblist::Kid','ExtUtils::MM','ExtUtils::MM_Any','ExtUtils::MM_Unix','ExtUtils::MM_Win32','ExtUtils::MY','ExtUtils::MakeMaker','ExtUtils::Manifest','ExtUtils::Miniperl','ExtUtils::Mksymlists','ExtUtils::Packlist','ExtUtils::XSSymSet','FCGI','Fcntl','File::Basename','File::Compare','File::Copy','File::Find','File::Path','File::Spec','File::Spec::$module','File::Spec::Functions','File::Spec::Unix','File::Temp','File::stat','FileHandle','Filter::Util::Call','Foo','Getopt::Long','Getopt::Std','HTML::TreeBuilder','HTTP::Date','I18N::Collate','I18N::Langinfo','IO::','IO::File','IO::Handle','IO::Pipe','IO::Seekable','IO::Select','IO::Socket','IO::Socket::INET','IPC::Open3','IPC::SysV','JNI','JNI::Config','JPL::AutoLoader','JPL::Class','LWP::Simple','LWP::UserAgent','List::Util','Locale::Constants','Locale::Maketext::GutsLoader','MIME::Base64','Mac::Files','Mac::InternetConfig','Math::BigFloat','Math::BigFloat::Trace','Math::BigInt','Math::BigInt::Lite','Math::BigInt::Trace','Math::BigRat','Math::Complex','ModPerl::Util','NDBM_File','Net::Cmd','Net::Config','Net::FTP::A','Net::FTP::I','Net::FTP::dataconn','Net::Netrc','Net::Ping','Net::Ping::External','OS2::DLL','OS2::Process::Const','Opcode','POSIX','ParseWords','Pod::Checker','Pod::InputObjects','Pod::Man','Pod::ParseLink','Pod::ParseUtils','Pod::Parser','Pod::Perldoc::BaseTo','Pod::Perldoc::GetOptsOO','Pod::Perldoc::ToPod','Pod::PlainText','Pod::Select','Pod::Simple::RTF','Pod::Simple::XMLOutStream','Pod::Text','Pod::Usage','SDBM_File','Scalar::Util','Search::Dict','SelectSaver','SelfLoader','Socket','Symbol','Sys::Hostname','Term::ANSIColor','Term::Cap','Term::ReadLine','Term::ReadLine::Gnu','Term::ReadLine::Perl','Test::Builder','Test::Harness','Test::Harness::Assert','Test::Harness::Iterator','Test::Harness::Straps','Text::Balanced','Text::ParseWords','Text::Tabs','Text::Wrap','Thread','Tie::Array','Tie::Hash','Time::Local','Time::tm','Tk','Tk::ErrorDialog','Tk::FcyEntry','Tk::Pod','Unicode::UCD','VMS::Filespec','XSLoader','asm::socket.ph','blib','bytes','constant','diagnostics','encoding','fields','happy','integer','is','lib','locale','mod_perl','overload','re','strict','subs','sys::syscall.ph','sys::systeminfo.ph','syscall.ph','threads::Shared','threads::shared','utf','vars','vmsish','wait.ph','warnings','warnings::register']},'perl-GPS-0.12.tar.gz' => {'author' => 'JOAOP','description' => 'Access to the Serial port for the GPS::* modules','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 877,'pod' => 151,'pod_errors' => 0,'total' => 1028,'with_comments' => 70},'releases' => 1,'size' => {'packed' => 29590,'unpacked' => 77214},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','Exporter','FileHandle','Math::Trig','POSIX','strict','vars']},'perl-GPSData-0.02.tar.gz' => {'author' => 'NFMNUNES','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1092,'pod' => 339,'pod_errors' => 0,'total' => 1431,'with_comments' => 98},'releases' => 4,'requires' => ['DateManip-5.42a.tar.gz'],'requires_module' => {'Date::Manip' => 'Test::More'},'requires_recursive' => ['DateManip-5.42a.tar.gz'],'size' => {'packed' => 9891,'unpacked' => 42453},'testers' => {'pass' => 2},'uses' => ['DBI','Data::Dumper','Date::Manip','Geo::GPS::Data::Ellipsoid','Geo::GPS::Data::Storage','Geo::GPS::Data::Storage::MySQL','Geo::GPS::Data::Storage::RAM','Geo::GPS::Data::Waypoint','strict']},'perl-GPSData-0.04.tar.gz' => {'author' => 'NFMNUNES','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1932,'pod' => 731,'pod_errors' => 1,'total' => 2663,'with_comments' => 139},'releases' => 4,'requires' => ['DateManip-5.42a.tar.gz'],'requires_module' => {'Date::Manip' => 'Test::More'},'requires_recursive' => ['DateManip-5.42a.tar.gz'],'size' => {'packed' => 23359,'unpacked' => 104455},'testers' => {'pass' => 2},'uses' => ['DBI','Date::Manip','strict']},'perl-ldap-0.15.tar.gz' => {'author' => 'GBARR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4131,'pod' => 1996,'pod_errors' => 1,'total' => 6127,'with_comments' => 473},'releases' => 26,'size' => {'packed' => 83159,'unpacked' => 372556},'testers' => {'pass' => 5},'uses' => ['Carp','Convert::BER','Digest::HMAC_MD5','Exporter','IO::Select','IO::Socket','LWP::Protocol','MIME::Base64','Net::LDAP','Net::LDAP::Bind','Net::LDAP::Constant','Net::LDAP::Entry','Net::LDAP::Extension','Net::LDAP::Filter','Net::LDAP::LDIF','Net::LDAP::Message','Net::LDAP::Schema','Net::LDAP::Search','SelectSaver','Symbol','UNIVERSAL','strict','vars']},'perl-ldap-0.251.tar.gz' => {'author' => 'GBARR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7108,'pod' => 4773,'pod_errors' => 0,'total' => 11881,'with_comments' => 493},'releases' => 26,'requires' => ['Convert-ASN1-0.17.tar.gz'],'requires_module' => {'Convert::ASN1' => '0.07'},'requires_recursive' => ['Convert-ASN1-0.17.tar.gz'],'size' => {'packed' => 256693,'unpacked' => 1043613},'testers' => {'pass' => 12},'uses' => ['Carp','Convert::ASN1','Convert::ASN1::Debug','Exporter','IO::Select','IO::Socket','IO::Socket::SSL','LWP::Protocol','MIME::Base64','Net::LDAP','Net::LDAP::ASN','Net::LDAP::Bind','Net::LDAP::Constant','Net::LDAP::Control','Net::LDAP::Entry','Net::LDAP::Extension','Net::LDAP::Filter','Net::LDAP::LDIF','Net::LDAP::Message','Net::LDAP::Schema','Net::LDAP::Search','Net::LDAP::Util','Net::LDAPS','SelectSaver','Symbol','XML::Parser','strict','vars']},'perl-ldap-0.28.tar.gz' => {'author' => 'GBARR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 7677,'pod' => 5146,'pod_errors' => 1,'total' => 12823,'with_comments' => 463},'releases' => 26,'requires' => ['Convert-ASN1-0.17.tar.gz'],'requires_module' => {'Convert::ASN1' => '0.07'},'requires_recursive' => ['Convert-ASN1-0.17.tar.gz'],'size' => {'packed' => 214038,'unpacked' => 883057},'testers' => {'pass' => 3},'uses' => ['Carp','Convert::ASN1','Convert::ASN1::Debug','Exporter','IO::Select','IO::Socket','IO::Socket::SSL','IO::Socket::UNIX','LWP::Protocol','MIME::Base64','Net::LDAP','Net::LDAP::ASN','Net::LDAP::Bind','Net::LDAP::Constant','Net::LDAP::Control','Net::LDAP::Entry','Net::LDAP::Extension','Net::LDAP::Filter','Net::LDAP::LDIF','Net::LDAP::Message','Net::LDAP::RootDSE','Net::LDAP::Schema','Net::LDAP::Search','Net::LDAP::Util','SelectSaver','Symbol','XML::SAX::Base','XML::SAX::Writer','strict','vars']},'perl-ldap-0.29.tar.gz' => {'author' => 'GBARR','description' => undef,'files' => ['Makefile.PL','README','SIGNATURE','MANIFEST'],'lines' => {'nonpod' => 7692,'pod' => 5123,'pod_errors' => 1,'total' => 12815,'with_comments' => 463},'releases' => 26,'requires' => ['Convert-ASN1-0.17.tar.gz'],'requires_module' => {'Convert::ASN1' => '0.07'},'requires_recursive' => ['Convert-ASN1-0.17.tar.gz'],'size' => {'packed' => 220461,'unpacked' => 892411},'testers' => {'pass' => 2},'uses' => ['Carp','Convert::ASN1','Convert::ASN1::Debug','Exporter','IO::Select','IO::Socket','IO::Socket::SSL','IO::Socket::UNIX','LWP::Protocol','MIME::Base64','Net::LDAP::Bind','SelectSaver','Symbol','Tie::Hash','XML::SAX::Base','XML::SAX::Writer','strict','vars']},'perl-lisp-0.05.tar.gz' => {'author' => 'GAAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1139,'pod' => 72,'pod_errors' => 0,'total' => 1211,'with_comments' => 71},'releases' => 5,'size' => {'packed' => 14784,'unpacked' => 44254},'testers' => {'pass' => 4},'uses' => ['Carp','Data::Dumper','Exporter','strict','vars']},'perl-vgalib-0.4.tgz' => {'author' => 'SCOTTVR','description' => 'Perl extension for svgalib-1.2.11','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 255,'pod' => 196,'pod_errors' => 0,'total' => 451,'with_comments' => 8},'releases' => 1,'size' => {'packed' => 8105,'unpacked' => 33561},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','strict','vars']},'perl5-byacc-patches-0.6.tar.gz' => {'author' => 'JAKE','description' => 'a class to encapsulate a filehandle as a stream;','files' => ['README'],'lines' => {'nonpod' => 75,'pod' => 44,'pod_errors' => 2,'total' => 119,'with_comments' => 4},'releases' => 2,'size' => {'packed' => 10732,'unpacked' => 39030},'testers' => {'tests' => '0','unknown' => 6},'uses' => []},'perl5.00402-bindist04-msvcAlpha.tar.gz' => {'author' => 'BMIDD','description' => 'load various IO modules','files' => ['README'],'lines' => {'nonpod' => 111050,'pod' => 66455,'pod_errors' => 9,'total' => 177505,'with_comments' => 11520},'releases' => 1,'size' => {'packed' => 7921598,'unpacked' => 25857507},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['$file','5','5.000','5.001','5.002','5.003','5.003_11','5.003_90','5.003_96','5.004','AnyDBM_File','AutoLoader','AutoSplit','Benchmark','Bit::Vector','CGI','CPAN','CPAN::Config','CPAN::FirstTime','CPAN::MyConfig','CPAN::Nox','CPAN::WAIT','Carp','Class::Struct','Config','Cwd','DBI','Data::Dumper','Date::DateCalc','Devel::CoreStack','Devel::SelfStubber','Devel::Symdump','DirHandle','DynaLoader','English','Exporter','ExtUtils::Liblist','ExtUtils::MM_Mac','ExtUtils::MM_Unix','ExtUtils::MM_VMS','ExtUtils::MM_Win32','ExtUtils::MakeMaker','ExtUtils::Manifest','ExtUtils::Miniperl','ExtUtils::Mksymlists','ExtUtils::XSSymSet','FCGI','Fcntl','File::Basename','File::Compare','File::Copy','File::Find','File::Path','FileHandle','Getopt::Long','Getopt::Std','HTML::Element','HTML::Entities','HTML::FormatText','HTML::Formatter','HTML::HeadParser','HTML::Parse','HTML::Parser','HTML::TreeBuilder','HTTP::Date','HTTP::Headers','HTTP::Message','HTTP::Request','HTTP::Response','HTTP::Status','I18N::Collate','IO::File','IO::Handle','IO::Pipe','IO::Seekable','IO::Select','IO::Socket','IPC::Open3','LWP','LWP::Debug','LWP::MediaTypes','LWP::MemberMixin','LWP::Protocol','LWP::Protocol::http','LWP::SecureSocket','LWP::Socket','LWP::UserAgent','MD5','MIME::Base64','MIME::QuotedPrint','Math::BigInt','Math::Complex','Net::Cmd','Net::Config','Net::Domain','Net::FTP','Net::Netrc','Net::SSLeay','Opcode','POSIX','ParseWords','Pod::Functions','SelectSaver','SelfLoader','Socket','Symbol','Sys::Hostname','Term::Cap','Term::ReadLine','Term::ReadLine::Gnu','Term::ReadLine::Perl','Test::Harness','Text::Tabs','Text::Wrap','Tie::Hash','Time::Local','Time::tm','Tk','Tk::$_','Tk::$method','Tk::${need}','Tk::Adjuster','Tk::After','Tk::Bitmap','Tk::Button','Tk::Canvas','Tk::Clipboard','Tk::CmdLine','Tk::Config','Tk::Configure','Tk::DSC','Tk::Derived','Tk::Dialog','Tk::DragDrop::Common','Tk::DragDrop::Rect','Tk::DragDrop::SunConst','Tk::DropSite','Tk::Entry','Tk::Frame','Tk::Ghostscript','Tk::HList','Tk::HTML','Tk::HTML::Form','Tk::HTML::Handler','Tk::IO','Tk::Image','Tk::JPEG','Tk::LabEntry','Tk::LabRadio','Tk::Label','Tk::Listbox','Tk::MainWindow','Tk::Menu','Tk::Menu::Item','Tk::Menubar','Tk::Menubutton','Tk::NBFrame','Tk::Parse','Tk::Photo','Tk::Pixmap','Tk::Pretty','Tk::ROText','Tk::Radiobutton','Tk::Scrollbar','Tk::Submethods','Tk::Table','Tk::Text','Tk::Text::Tag','Tk::Toplevel','Tk::VStack','Tk::Widget','Tk::Wm','Tk::Xlib','URI::Escape','URI::URL','URI::URL::$scheme','URI::URL::_generic','URI::URL::_login','URI::URL::file','URI::URL::http','VMS::Filespec','WWW::RobotRules','Win32','Win32::IPC','Win32::ODBC','Win32::WinError','constant','happy','integer','is','lib','overload','package','strict','subs','sys::syscall.ph','syscall.ph','vars','vmsish']},'perlSGML.1997Sep18.tar.gz' => {'author' => 'EHOOD','description' => undef,'files' => ['MANIFEST'],'lines' => {'nonpod' => 6592,'pod' => 0,'pod_errors' => 0,'total' => 6592,'with_comments' => 3211},'releases' => 1,'size' => {'packed' => 366480,'unpacked' => 1758421},'testers' => {'tests' => '0','unknown' => 18},'uses' => ['Config','Exporter','FileHandle','Getopt::Long','SGML::ISO8859::S$set','vars']},'perl_archie.1.5.tar.gz' => {'author' => 'GBOSS','description' => 'Archie queries via Prospero ARDP protocol','files' => [],'lines' => {'nonpod' => 636,'pod' => 64,'pod_errors' => 0,'total' => 700,'with_comments' => 170},'releases' => 1,'size' => {'packed' => 10508,'unpacked' => 38543},'testers' => {'fail' => 1},'uses' => ['Socket']},'perldap-1.4.tar.gz' => {'author' => 'LEIFHED','description' => 'Perl methods for LDAP C API calls','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 3973,'pod' => 2921,'pod_errors' => 1,'total' => 6894,'with_comments' => 574},'releases' => 1,'size' => {'packed' => 89766,'unpacked' => 364452},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','Tie::Hash','integer','strict','vars']},'perlhbm-0.01.tar.gz' => {'author' => 'AZUL','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 28,'pod' => 0,'pod_errors' => 0,'total' => 28,'with_comments' => 1},'releases' => 1,'size' => {'packed' => 20174,'unpacked' => 46887},'testers' => {},'uses' => ['5.002','AutoLoader','DynaLoader','Exporter','strict','vars']},'perlindex-1.301.tar.gz' => {'author' => 'ULPFR','description' => 'English language stemming','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 129,'pod' => 35,'pod_errors' => 0,'total' => 164,'with_comments' => 45},'releases' => 3,'size' => {'packed' => 10785,'unpacked' => 27443},'testers' => {'pass' => 3},'uses' => []},'perlipq-1.25.tar.gz' => {'author' => 'JMORRIS','description' => 'IPTables userspace packet queuing','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 188,'pod' => 181,'pod_errors' => 1,'total' => 369,'with_comments' => 27},'releases' => 3,'size' => {'packed' => 14744,'unpacked' => 41805},'testers' => {},'uses' => ['AutoLoader','Carp','DynaLoader','Exporter','Socket','strict','vars']},'perlmenu.v4.0.tar.gz' => {'author' => 'SKUNZ','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 2368,'pod' => 0,'pod_errors' => 0,'total' => 2368,'with_comments' => 890},'releases' => 1,'size' => {'packed' => 84536,'unpacked' => 299113},'testers' => {},'uses' => ['Curses','Exporter','Term::Cap']},'perlrpcgen-0.71a.tar.gz' => {'author' => 'JAKE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2687,'pod' => 229,'pod_errors' => 0,'total' => 2916,'with_comments' => 162},'releases' => 2,'size' => {'packed' => 37428,'unpacked' => 143567},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['AutoLoader','Dict::Client','Dict::Constants','Dict::Data','DynaLoader','Exporter','Tie::Hash','perlrpcgen::RPCL','strict']},'persist-0.3.1.tar.gz' => {'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2785,'pod' => 1524,'pod_errors' => 0,'total' => 4309,'with_comments' => 182},'releases' => 2,'testers' => {'pass' => 1},'uses' => ['5.008','5.8.0','Carp','DBI','Date::Calc','Exporter','Parse::RecDescent','constant','strict','warnings']},'pgk_xs-0.05.tar.gz' => {'author' => 'OESTERHOL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 445,'pod' => 154,'pod_errors' => 0,'total' => 599,'with_comments' => 15},'releases' => 1,'size' => {'packed' => 7518,'unpacked' => 27107},'testers' => {'pass' => 2},'uses' => ['5.005','DynaLoader','strict','vars']},'pgsql_perl5-1.9.0.tar.gz' => {'author' => 'MERGL','description' => 'PostgreSQL SQL database interface','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 205,'pod' => 341,'pod_errors' => 0,'total' => 546,'with_comments' => 12},'releases' => 7,'size' => {'packed' => 16860,'unpacked' => 54909},'testers' => {},'uses' => ['5.003','AutoLoader','Carp','DynaLoader','Exporter','strict','vars']},'pod2lyx-0.25.tar.gz' => {'author' => 'RICHARDJ','description' => 'A pod to LyX format conversion class','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1011,'pod' => 0,'pod_errors' => 0,'total' => 1011,'with_comments' => 479},'releases' => 3,'requires' => ['File-Spec-0.82.tar.gz'],'requires_module' => {'File::Spec' => 0},'requires_recursive' => ['File-Spec-0.82.tar.gz'],'size' => {'packed' => 18424,'unpacked' => 65124},'testers' => {'pass' => 6,'tests' => '0','unknown' => 9},'uses' => ['5.004','Carp','Pod::Parser','Text::Tabs','locale','strict','vars']},'podlators-1.27.tar.gz' => {'author' => 'RRA','description' => 'converter to man page','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2606,'pod' => 786,'pod_errors' => 1,'total' => 3392,'with_comments' => 798},'releases' => 32,'requires' => ['File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz'],'requires_module' => {'File::Spec' => '0.8','Pod::Parser' => '1.13'},'requires_recursive' => ['File-Spec-0.82.tar.gz','PodParser-1.23.tar.gz'],'size' => {'packed' => 71373,'unpacked' => 262237},'testers' => {'pass' => 5},'uses' => ['5.004','5.005','Carp','Exporter','File::Basename','Term::ANSIColor','Term::Cap','strict','subs','vars']},'poest-0.20030407.tar.gz' => {'author' => 'CWEST','description' => 'Details of Writing a POEST Configurator','files' => ['README','Build.PL','META.yml','MANIFEST'],'lines' => {'nonpod' => 591,'pod' => 604,'pod_errors' => 0,'total' => 1195,'with_comments' => 7},'releases' => 4,'size' => {'packed' => 24471,'unpacked' => 72253},'testers' => {'pass' => 2},'uses' => ['Carp','Config::General','POE','strict','vars']},'pop-0.07.tar.gz' => {'author' => 'BHOLZMAN','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 1728,'pod' => 134,'pod_errors' => 0,'total' => 1862,'with_comments' => 110},'releases' => 5,'size' => {'packed' => 34702,'unpacked' => 122648},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['5.005','Carp','DBI','Devel::WeakRef','Exporter','File::lockf','POSIX','SelectSaver','Symbol','Tie::Array','Tie::Hash','XML::Parser','strict','vars']},'ppt-0.12.tar.gz' => {'author' => 'SDAGUE','description' => 'A bundle for install perl power tools via CPAN','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10,'pod' => 23,'pod_errors' => 0,'total' => 33,'with_comments' => 0},'releases' => 2,'requires' => ['Algorithm-Diff-1.15.tar.gz'],'requires_module' => {'Algorithm::Diff' => '1.1'},'requires_recursive' => ['Algorithm-Diff-1.15.tar.gz'],'size' => {'packed' => 233358,'unpacked' => 740181},'testers' => {},'uses' => []},'psh-1.8.tar.gz' => {'author' => 'GREGOR','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 10436,'pod' => 2877,'pod_errors' => 53,'total' => 13313,'with_comments' => 1355},'releases' => 16,'requires' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Cwd' => '0','File::Spec' => '0'},'requires_recursive' => ['File-Spec-0.82.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 119989,'unpacked' => 372434},'testers' => {'pass' => 6},'uses' => ['Archive::Tar','BSD::Resource','Carp','Config','Cwd','Data::Dumper','Env','Env::Array','Exporter','Getopt::Std','POSIX','Pod::Text','Psh::StrategyBunch','Sys::Hostname','Term::ReadKey','Term::ReadLine','Term::Size','Win32','Win32::Console','Win32::NetAdmin','Win32::Process','Win32::TieRegistry','locale','strict','vars']},'ptkFAQ-0_03.tar.gz' => {'author' => 'PVHP','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1806,'pod' => 367,'pod_errors' => 0,'total' => 2173,'with_comments' => 314},'releases' => 1,'size' => {'packed' => 798332,'unpacked' => 2434208},'testers' => {'tests' => '0','unknown' => 3},'uses' => ['5.001','Carp','Cwd','DynaLoader','English','Exporter','FileDialog','Tk','Tk::Dialog','Tk::FileSelect','Tk::LabEntry','Tk::ScrlListbox','Tk::Toplevel','strict','vars']},'punctuation-0.02.tar.gz' => {'author' => 'MJD','description' => 'Forbid uses of punctuation variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 39,'pod_errors' => 0,'total' => 116,'with_comments' => 6},'releases' => 1,'requires' => ['B-Utils-0.04.tar.gz'],'requires_module' => {'B::Utils' => '0.03'},'requires_recursive' => ['B-Utils-0.04.tar.gz'],'size' => {'packed' => 2251,'unpacked' => 4588},'testers' => {'pass' => 3,'tests' => '0','unknown' => 3},'uses' => ['B::Utils','Carp']},'pyperl-1.0.tar.gz' => {'author' => 'GAAS','description' => 'Wrapper for python objects','files' => ['README','MANIFEST'],'lines' => {'nonpod' => 593,'pod' => 790,'pod_errors' => 0,'total' => 1383,'with_comments' => 35},'releases' => 1,'size' => {'packed' => 62089,'unpacked' => 209490},'testers' => {'fail' => 1,'pass' => 1},'uses' => ['Carp','Data::Dump','DynaLoader','Exporter','strict','vars']},'qtpl_perl-0.5.tgz' => {'author' => 'AVP','description' => 'Parse text files from saved templates and substitutes variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 518,'pod' => 237,'pod_errors' => 0,'total' => 755,'with_comments' => 93},'releases' => 1,'size' => {'packed' => 21041,'unpacked' => 64272},'testers' => {'pass' => 1},'uses' => ['Carp','File::Basename','strict']},'randompass-0.01.tar.gz' => {'author' => 'MJFLICK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 42,'pod' => 19,'pod_errors' => 0,'total' => 61,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 1795,'unpacked' => 2816},'testers' => {'pass' => 1},'uses' => ['5.008','Exporter','strict','vars','warnings']},'release-0.23.tar.gz' => {'author' => 'PETDANCE','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 561,'pod' => 93,'pod_errors' => 0,'total' => 654,'with_comments' => 22},'releases' => 13,'requires' => ['CGI.pm-2.98.tar.gz','ConfigReader-Simple-1.16.tar.gz','File-Spec-0.82.tar.gz','Test-Simple-0.47.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'CGI' => 0,'ConfigReader::Simple' => 0,'File::Spec' => 0,'HTTP::Cookies' => 0,'HTTP::Request' => 0,'LWP::UserAgent' => 0,'Net::FTP' => 0,'Test::More' => 0},'requires_recursive' => ['CGI.pm-2.98.tar.gz','ConfigReader-Simple-1.16.tar.gz','Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 10643,'unpacked' => 29703},'testers' => {'pass' => 2},'uses' => ['CGI','Config','ConfigReader::Simple','File::Spec','HTTP::Cookies','HTTP::Request','LWP::UserAgent','Net::FTP','strict']},'releasesystem-1.00.tar.gz' => {'author' => 'KGREENE','description' => 'Perl extension for managing IMS Release Manager packages','files' => ['README'],'lines' => {'nonpod' => 3656,'pod' => 799,'pod_errors' => 0,'total' => 4455,'with_comments' => 1358},'releases' => 1,'size' => {'packed' => 439628,'unpacked' => 1303082},'testers' => {'fail' => 1},'uses' => ['5.002','5.004','Archive::Tar','AutoLoader','Carp','Cwd','Digest::MD5','Exporter','Fcntl','File::Basename','File::Copy','File::Path','HTTP::Request::Common','IMS::DBConnect','IO::File','IPC::Open3','LWP::UserAgent','Mail::Header','Mail::Internet','Net::Domain','Symbol','URI::URL','strict','subs','vars']},'rlib-0.02.tar.gz' => {'author' => 'GBARR','description' => 'manipulate @INC at compile time with relative paths','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 61,'pod' => 31,'pod_errors' => 0,'total' => 92,'with_comments' => 5},'releases' => 2,'size' => {'packed' => 1766,'unpacked' => 3673},'testers' => {'pass' => 3},'uses' => ['Cwd','File::Basename','File::Spec','FindBin','VMS::Filespec','strict','vars']},'rms.zip' => {'author' => 'JCTEBBAL','description' => undef,'files' => [],'lines' => {'nonpod' => 57,'pod' => 355,'pod_errors' => 0,'total' => 412,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 18652,'unpacked' => 66222},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'router-lg-0.98a.tar.gz' => {'author' => 'CHRISJ','description' => 'Looking Glass','files' => [],'lines' => {'nonpod' => 1013,'pod' => 266,'pod_errors' => 0,'total' => 1279,'with_comments' => 176},'releases' => 1,'size' => {'packed' => 16277,'unpacked' => 59904},'testers' => {'pass' => 5},'uses' => ['IO::Socket']},'rubyisms-1.0.tar.gz' => {'author' => 'SIMON','description' => 'Steal some features from Ruby','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 135,'pod' => 132,'pod_errors' => 0,'total' => 267,'with_comments' => 9},'releases' => 1,'size' => {'packed' => 5122,'unpacked' => 14854},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','strict','warnings']},'savevars-0.07.tar.gz' => {'author' => 'SREZIC','description' => 'Perl pragma to auto-load and save global variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 141,'pod' => 59,'pod_errors' => 0,'total' => 200,'with_comments' => 13},'releases' => 5,'requires' => ['Data-Dumper-2.101.tar.gz'],'requires_module' => {'Data::Dumper' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz'],'size' => {'packed' => 3805,'unpacked' => 8282},'testers' => {'pass' => 4},'uses' => ['Carp','Data::Dumper','Safe']},'sdf-2.001beta1.tar.gz' => {'author' => 'IANC','description' => 'converter to SDF','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 433,'pod' => 0,'pod_errors' => 0,'total' => 433,'with_comments' => 74},'releases' => 1,'size' => {'packed' => 788018,'unpacked' => 3120619},'testers' => {'fail' => 1,'pass' => 1,'tests' => '100'},'uses' => ['Exporter','strict']},'shishi-0.0.1.tar.gz' => {'author' => 'SIMON','description' => 'Perl wrapper for the C<shishi> parsing library','files' => ['README'],'lines' => {'nonpod' => 165,'pod' => 148,'pod_errors' => 0,'total' => 313,'with_comments' => 13},'releases' => 1,'size' => {'packed' => 13532,'unpacked' => 46421},'testers' => {},'uses' => ['5.006','Carp','DynaLoader','Errno','Exporter','strict','warnings']},'shufflestat-0.0.3.tar.gz' => {'author' => 'ASKSH','description' => undef,'files' => [],'lines' => {'nonpod' => 567,'pod' => 153,'pod_errors' => 0,'total' => 720,'with_comments' => 91},'releases' => 1,'size' => {'packed' => 15988,'unpacked' => 49491},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['5.6.0','BerkeleyDB','Exporter','strict']},'sitemapper-1.019.tar.gz' => {'author' => 'AWRIGLEY','description' => 'functions for generating a site map for a given site URL.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 644,'pod' => 262,'pod_errors' => 0,'total' => 906,'with_comments' => 168},'releases' => 12,'requires' => ['Digest-MD5-2.26.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Summary-0.017.tar.gz','IO-1.20.tar.gz','PodParser-1.23.tar.gz','TermReadKey-2.21.tar.gz','TimeDate-1.16.tar.gz','Tk-800.024.tar.gz','URI-1.24.tar.gz','WWW-Robot-0.023.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Date::Format' => 0,'Digest::MD5' => 0,'Getopt::Long' => 0,'HTML::Entities' => 0,'HTML::Summary' => 0,'IO::File' => 0,'LWP::UserAgent' => 0,'Pod::Usage' => 0,'Term::ReadKey' => 0,'Tk' => 0,'URI::URL' => 0,'WWW::Robot' => '0.021'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','File-Spec-0.82.tar.gz','Getopt-Long-2.33.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Summary-0.017.tar.gz','HTML-Tagset-3.03.tar.gz','HTML-Tree-3.17.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','PodParser-1.23.tar.gz','TermReadKey-2.21.tar.gz','TimeDate-1.16.tar.gz','Tk-800.024.tar.gz','URI-1.24.tar.gz','WWW-Robot-0.023.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 33208,'unpacked' => 154344},'testers' => {'pass' => 7},'uses' => ['5.003','Digest::MD5','HTML::Summary','HTML::TreeBuilder','LWP::UserAgent','Term::ReadKey','WWW::Robot','strict','vars']},'smg.zip' => {'author' => 'JCTEBBAL','description' => 'Perl extension for screen management','files' => [],'lines' => {'nonpod' => 344,'pod' => 1399,'pod_errors' => 0,'total' => 1743,'with_comments' => 6},'releases' => 1,'size' => {'packed' => 25948,'unpacked' => 114893},'testers' => {},'uses' => ['AutoLoader','DynaLoader','Exporter','strict','vars']},'smime-0.7.tgz' => {'author' => 'SAMPO','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 194,'pod' => 0,'pod_errors' => 0,'total' => 194,'with_comments' => 39},'releases' => 1,'size' => {'packed' => 59413,'unpacked' => 218603},'testers' => {},'uses' => ['Socket','integer']},'sol-inst-0.90a.tar.gz' => {'author' => 'CHRISJ','description' => 'Perl module to obtain basic Solaris Package Info','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1133,'pod' => 376,'pod_errors' => 0,'total' => 1509,'with_comments' => 166},'releases' => 1,'size' => {'packed' => 9692,'unpacked' => 32517},'testers' => {'pass' => 11},'uses' => ['strict','vars']},'sparky-public-1.06.tar.gz' => {'author' => 'JLHOLT','description' => 'support functions for Sparky data collector and profiler','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 379,'pod' => 137,'pod_errors' => 0,'total' => 516,'with_comments' => 56},'releases' => 1,'size' => {'packed' => 6491,'unpacked' => 17323},'testers' => {},'uses' => ['5.005_62','Carp','Date::Format','Date::Parse','Exporter','Term::ReadKey','Time::HiRes','constant','strict','warnings']},'speech_pm_1.0.tgz' => {'author' => 'RCALEY','description' => 'Communicate with a festival server process.','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 854,'pod' => 334,'pod_errors' => 0,'total' => 1188,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 11640,'unpacked' => 38955},'testers' => {'fail' => 9},'uses' => ['Exporter','Socket','strict','vars']},'spent-0.1.tar.gz' => {'author' => 'SAMSK','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 75,'pod' => 0,'pod_errors' => 0,'total' => 75,'with_comments' => 20},'releases' => 1,'size' => {'packed' => 10531,'unpacked' => 28278},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Exporter','integer','strict','vars']},'strict-ModuleName-0.04.tar.gz' => {'author' => 'SBURKE','description' => '- verify that current package name matches filename','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 195,'pod' => 54,'pod_errors' => 0,'total' => 249,'with_comments' => 11},'releases' => 2,'size' => {'packed' => 4645,'unpacked' => 12018},'testers' => {'pass' => 1},'uses' => ['5','Carp','strict','vars']},'sub-curry-0.04.zip' => {'author' => 'DAVIDH','description' => 'Cute module to curry functions','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 77,'pod' => 62,'pod_errors' => 0,'total' => 139,'with_comments' => 2},'releases' => 3,'size' => {'packed' => 2670,'unpacked' => 4092},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Exporter','strict','vars']},'swig1.1p5.tar.gz' => {'author' => 'DBEAZLEY','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 143,'pod' => 0,'pod_errors' => 0,'total' => 143,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 2058195,'unpacked' => 5904152},'testers' => {'tests' => '0','unknown' => 15},'uses' => ['DynaLoader','Exporter','strict','vars']},'sybperl-2.15.tar.gz' => {'author' => 'MEWP','description' => 'Simple front end to the Sybase BCP API','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 4040,'pod' => 2608,'pod_errors' => 2,'total' => 6648,'with_comments' => 344},'releases' => 14,'size' => {'packed' => 181902,'unpacked' => 722668},'testers' => {},'uses' => ['5.002','AutoLoader','Carp','Exporter','Sybase::CTlib','Sybase::DBlib','Tk','Tk::Dialog','strict','vars']},'tagged-0.1.tar.gz' => {'author' => 'THOGEE','description' => 'Perl extension reading tags of mp3 files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1264,'pod' => 340,'pod_errors' => 1,'total' => 1604,'with_comments' => 123},'releases' => 6,'requires' => ['Compress-Zlib-1.22.tar.gz'],'requires_module' => {'Compress::Zlib' => 0},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz'],'size' => {'packed' => 21724,'unpacked' => 64102},'testers' => {'pass' => 6},'uses' => ['Compress::Zlib','strict','vars']},'tagged-0.40.tar.gz' => {'author' => 'THOGEE','description' => 'Module for reading tags of MP3 audio files','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1746,'pod' => 603,'pod_errors' => 3,'total' => 2349,'with_comments' => 155},'releases' => 6,'requires' => ['Compress-Zlib-1.22.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Compress::Zlib' => 0,'File::Basename' => 0},'requires_recursive' => ['Compress-Zlib-1.22.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 41163,'unpacked' => 137708},'testers' => {'pass' => 6},'uses' => ['Compress::Zlib','Fcntl','File::Basename','strict','vars']},'test' => {'files' => [],'lines' => {'nonpod' => 0,'pod' => 0,'pod_errors' => 0,'total' => 0,'with_comments' => 0},'releases' => 2,'testers' => {},'uses' => []},'tinyperl-1.0-580-win32.zip' => {'author' => 'GMPASSOS','description' => undef,'files' => ['README','MANIFEST'],'lines' => {'nonpod' => 3551,'pod' => 0,'pod_errors' => 0,'total' => 3551,'with_comments' => 386},'releases' => 1,'size' => {'packed' => 861769,'unpacked' => 963207},'testers' => {},'uses' => ['5.003','DynaLoader','File::Basename','File::Path','File::Spec','LibZip::MyFile','LibZip::MyZlib','strict','vars']},'tkjuke-2.0.6.tar.gz' => {'author' => 'LUSOL','description' => 'execute non-blocking system commands','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 667,'pod' => 226,'pod_errors' => 0,'total' => 893,'with_comments' => 59},'releases' => 5,'size' => {'packed' => 87664,'unpacked' => 153180},'testers' => {'pass' => 1},'uses' => ['Carp','Exporter','IO::Handle','Proc::Killfam','Tk::Derived','Tk::Frame','Tk::widgets','strict','subs','vars']},'traceFunc-0.1.tar.gz' => {'author' => 'JOEHIL','description' => 'Trace funcs by using object destructions','files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 165,'pod' => 132,'pod_errors' => 0,'total' => 297,'with_comments' => 5},'releases' => 1,'size' => {'packed' => 3796,'unpacked' => 8207},'testers' => {},'uses' => ['5.002','FileHandle','strict','vars']},'tux_perl-0.01.tar.gz' => {'author' => 'YALE','description' => 'Perl extension for Tux webserver','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 516,'pod' => 541,'pod_errors' => 1,'total' => 1057,'with_comments' => 41},'releases' => 1,'size' => {'packed' => 28593,'unpacked' => 91120},'testers' => {},'uses' => ['5.008','AutoLoader','Carp','Exporter','XSLoader','constant','strict','vars','warnings']},'txt2html-2.03.tar.gz' => {'author' => 'RUBYKAT','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2675,'pod' => 586,'pod_errors' => 3,'total' => 3261,'with_comments' => 327},'releases' => 4,'requires' => ['Data-Dumper-2.101.tar.gz','ExtUtils-configPL-1.1.tar.gz','Filter-1.29.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'requires_module' => {'Data::Dumper' => 0,'ExtUtils::configPL' => 0,'File::Basename' => 0,'Filter::Util::Call' => 0,'Getopt::Long' => 0,'Pod::Usage' => 0,'Test::More' => 0},'requires_recursive' => ['Data-Dumper-2.101.tar.gz','ExtUtils-configPL-1.1.tar.gz','File-Spec-0.82.tar.gz','Filter-1.29.tar.gz','Getopt-Long-2.33.tar.gz','PodParser-1.23.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 56880,'unpacked' => 186525},'testers' => {'pass' => 1},'uses' => ['5.005_03','Data::Dumper','Exporter','constant','strict','vars']},'types-0.05.tar.gz' => {'author' => 'ABERGMAN','description' => 'Perl pragma for strict type checking','files' => ['Makefile.PL','README','Build.PL','MANIFEST'],'lines' => {'nonpod' => 502,'pod' => 69,'pod_errors' => 0,'total' => 571,'with_comments' => 42},'releases' => 4,'size' => {'packed' => 7209,'unpacked' => 21777},'testers' => {'fail' => 5,'tests' => '35'},'uses' => ['5.008','B','B::Utils','Data::Dumper','constant','float','int','number','optimize','strict','warnings']},'ubertext-0.95.tar.gz' => {'author' => 'CHRISJ','description' => 'Customizable Template Engine','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 2475,'pod' => 1041,'pod_errors' => 0,'total' => 3516,'with_comments' => 321},'releases' => 1,'size' => {'packed' => 20875,'unpacked' => 79793},'testers' => {'pass' => 2},'uses' => ['Text::Wrap','strict','vars','warnings']},'uninit-1.00.tar.gz' => {'author' => 'SIMON','description' => 'Warn about uninitialized variables','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 35,'pod' => 25,'pod_errors' => 0,'total' => 60,'with_comments' => 0},'releases' => 1,'size' => {'packed' => 2149,'unpacked' => 3578},'testers' => {'pass' => 5},'uses' => ['B']},'uny2k-19.101.tar.gz' => {'author' => 'MSCHWERN','description' => 'Removes y2k fixes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 48,'pod_errors' => 2,'total' => 181,'with_comments' => 1},'releases' => 2,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.08'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 3655,'unpacked' => 7956},'testers' => {'fail' => 1,'pass' => 2},'uses' => ['Carp','fields','vars']},'vague-1.3.tar.gz' => {'author' => 'PKENT','description' => 'Perl pragma to reduce precision in your programming constructs','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 147,'pod' => 78,'pod_errors' => 0,'total' => 225,'with_comments' => 22},'releases' => 1,'size' => {'packed' => 6282,'unpacked' => 16722},'testers' => {'pass' => 6},'uses' => ['Exporter','vars']},'variable-1.1.tgz' => {'author' => 'ABIGAIL','description' => undef,'files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 133,'pod' => 88,'pod_errors' => 0,'total' => 221,'with_comments' => 12},'releases' => 1,'size' => {'packed' => 3762,'unpacked' => 7979},'testers' => {'pass' => 5},'uses' => ['5.6.0','Carp','strict','vars','warnings::register']},'version-0.29.tar.gz' => {'author' => 'JPEACOCK','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 257,'pod' => 330,'pod_errors' => 0,'total' => 587,'with_comments' => 16},'releases' => 11,'requires' => ['Test-Simple-0.47.tar.gz'],'requires_module' => {'Test::More' => '0.45'},'requires_recursive' => ['File-Spec-0.82.tar.gz','Test-Harness-2.29.tar.gz','Test-Simple-0.47.tar.gz'],'size' => {'packed' => 14805,'unpacked' => 50357},'testers' => {'pass' => 8},'uses' => ['5.005_03','DynaLoader','Exporter','strict','vars']},'vpopmail-0.08.tar.gz' => {'author' => 'SSCANLON','description' => 'Perl extension for the vpopmail package','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 312,'pod' => 56,'pod_errors' => 0,'total' => 368,'with_comments' => 13},'releases' => 5,'size' => {'packed' => 13798,'unpacked' => 42350},'testers' => {},'uses' => ['Carp','DynaLoader','Exporter','File::stat','FileHandle','strict','vars']},'vsDB-1.4.3.tar.gz' => {'author' => 'JHINKLE','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 889,'pod' => 272,'pod_errors' => 0,'total' => 1161,'with_comments' => 147},'releases' => 3,'size' => {'packed' => 15765,'unpacked' => 54364},'testers' => {'pass' => 4},'uses' => ['5.000']},'vstadaf-0.01.tar.gz' => {'author' => 'TOSTI','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 1603,'pod' => 0,'pod_errors' => 0,'total' => 1603,'with_comments' => 140},'releases' => 1,'size' => {'packed' => 10492,'unpacked' => 40041},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['5.004','FreezeThaw','Time::CTime','Time::ParseDate','Tk','Tk::Balloon','Tk::Checkbutton','Tk::DialogBox','Tk::FireButton','Tk::Frame','Tk::Label','Tk::Menubutton','Tk::Optionmenu','Tk::Pod','Tk::ProgressBar','Tk::ROText','Tk::WaitBox','XBase::Base','strict','vars']},'w3mir-1.0.10.tar.gz' => {'author' => 'JANL','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 1523,'pod' => 0,'pod_errors' => 0,'total' => 1523,'with_comments' => 556},'releases' => 9,'size' => {'packed' => 82791,'unpacked' => 243081},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['5.002','HTTP::Date','MIME::Base64','Socket','Sys::Hostname','URI::URL','strict','vars']},'web-1.44.tar.gz' => {'author' => 'XWOLF','description' => 'A set of useful routines for many webworking purposes','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 1159,'pod' => 371,'pod_errors' => 0,'total' => 1530,'with_comments' => 162},'releases' => 4,'size' => {'packed' => 18027,'unpacked' => 56525},'testers' => {},'uses' => ['5.001','Time::Local','vars']},'webchat-0.05.tar.gz' => {'author' => 'GAAS','description' => undef,'files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 95,'pod' => 0,'pod_errors' => 0,'total' => 95,'with_comments' => 3},'releases' => 8,'requires' => ['Data-Dump-0.04.tar.gz','HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Data::Dump' => '0.01','HTML::Parser' => '2.21','LWP' => '5.47','URI' => '1.00'},'requires_recursive' => ['Data-Dump-0.04.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 5279,'unpacked' => 12503},'testers' => {'pass' => 1,'tests' => '0','unknown' => 9},'uses' => ['Exporter','HTML::TokeParser','URI','strict','vars']},'webchat-0.64.tar.gz' => {'author' => 'SIMONW','description' => 'support module for web chat script.','files' => ['Makefile.PL','README','MANIFEST'],'lines' => {'nonpod' => 332,'pod' => 74,'pod_errors' => 0,'total' => 406,'with_comments' => 26},'releases' => 8,'requires' => ['Data-Dump-0.04.tar.gz','HTML-Parser-3.28.tar.gz','URI-1.24.tar.gz','libwww-perl-5.69.tar.gz'],'requires_module' => {'Data::Dump' => '0.01','HTML::Parser' => '2.21','LWP' => '5.47','URI' => '1.00'},'requires_recursive' => ['Data-Dump-0.04.tar.gz','Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 7880,'unpacked' => 22893},'testers' => {'pass' => 5},'uses' => ['Config','Data::Dump','Exporter','HTML::TokeParser','LWP::Debug','URI','WWW::Chat','strict','vars']},'win32-guidgen-0.02.zip' => {'author' => 'JOEPHAYES','description' => 'Generates GUIDs','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 81,'pod' => 56,'pod_errors' => 0,'total' => 137,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 3890,'unpacked' => 6208},'testers' => {},'uses' => ['5.005_62','Carp','Exporter','Win32::API','strict','warnings']},'wing-0.9.tar.gz' => {'author' => 'MICB','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 5754,'pod' => 0,'pod_errors' => 0,'total' => 5754,'with_comments' => 931},'releases' => 4,'size' => {'packed' => 81447,'unpacked' => 259171},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['Apache::Constants','CrackLib','DBI','Exporter','Fcntl','HTTP::Date','IO::File','IO::Handle','IO::Socket','MIME::Base64','MIME::Parser','Mail::Header','Outline','SQL','Socket','Wing::Abook','Wing::Portal','strict','vars']},'xanton+xiri-0.63.tar.gz' => {'author' => 'ASKSH','description' => undef,'files' => [],'lines' => {'nonpod' => 36,'pod' => 0,'pod_errors' => 0,'total' => 36,'with_comments' => 19},'releases' => 1,'size' => {'packed' => 19317,'unpacked' => 60846},'testers' => {'tests' => '0','unknown' => 21},'uses' => ['strict']},'xdbfdump-0.03.tar.gz' => {'author' => 'TOSTI','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 1143,'pod' => 0,'pod_errors' => 0,'total' => 1143,'with_comments' => 111},'releases' => 1,'size' => {'packed' => 7156,'unpacked' => 27549},'testers' => {'tests' => '0','unknown' => 6},'uses' => ['DBI','FreezeThaw','Tk','Tk::Application','Tk::Balloon','Tk::Checkbutton','Tk::CmdLine','Tk::DialogBox','Tk::Frame','Tk::Label','Tk::Menubutton','Tk::Optionmenu','Tk::ProgressBar','Tk::ROText','Tk::WaitBox','XBase','strict']},'xisofs-1.3.tar.gz' => {'author' => 'SHERWOOD','description' => undef,'files' => ['README'],'lines' => {'nonpod' => 3425,'pod' => 83,'pod_errors' => 0,'total' => 3508,'with_comments' => 382},'releases' => 2,'size' => {'packed' => 34157,'unpacked' => 152900},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['Carp','Fcntl','FileHandle','Tk','Tk::BrowseEntry','Tk::Dialog','strict']},'xml-rax-0.01.tar.gz' => {'author' => 'RHANSON','description' => undef,'files' => [],'lines' => {'nonpod' => 290,'pod' => 35,'pod_errors' => 0,'total' => 325,'with_comments' => 18},'releases' => 1,'size' => {'packed' => 3481,'unpacked' => 8611},'testers' => {'pass' => 7},'uses' => ['FileHandle','XML::Parser','strict','vars']},'xslt-parser-0.13.tar.gz' => {'author' => 'JOSTEN','description' => undef,'files' => ['Makefile.PL','README'],'lines' => {'nonpod' => 600,'pod' => 0,'pod_errors' => 0,'total' => 600,'with_comments' => 68},'releases' => 3,'requires' => ['XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz'],'requires_module' => {'XML::DOM' => '1.25','XML::Parser' => '2.26'},'requires_recursive' => ['Digest-MD5-2.26.tar.gz','HTML-Parser-3.28.tar.gz','HTML-Tagset-3.03.tar.gz','IO-1.20.tar.gz','MIME-Base64-2.20.tar.gz','URI-1.24.tar.gz','XML-DOM-1.42.tar.gz','XML-Parser-2.31.tar.gz','XML-RegExp-0.03.tar.gz','libnet-1.16.tar.gz','libwww-perl-5.69.tar.gz','libxml-perl-0.07.tar.gz','perl-5.8.0.tar.gz'],'size' => {'packed' => 14750,'unpacked' => 69742},'testers' => {'tests' => '0','unknown' => 12},'uses' => ['XML::DOM','XML::XSLTParser','strict','vars']},'xxx2lout-1.35.tar.gz' => {'author' => 'SUMMER','description' => 'Module providing txt2lout, htmlentity2lout and pod2lout functions','files' => ['README'],'lines' => {'nonpod' => 798,'pod' => 243,'pod_errors' => 1,'total' => 1041,'with_comments' => 149},'releases' => 16,'size' => {'packed' => 21956,'unpacked' => 76593},'testers' => {'tests' => '0','unknown' => 9},'uses' => ['HTML::Parser','Text::Wrap','strict','vars']},'your-0.01.tar.gz' => {'author' => 'MSCHWERN','description' => 'Perl pragma to declare use of other package\'s variables','files' => ['Makefile.PL','MANIFEST'],'lines' => {'nonpod' => 686,'pod' => 463,'pod_errors' => 0,'total' => 1149,'with_comments' => 38},'releases' => 1,'size' => {'packed' => 11411,'unpacked' => 30003},'testers' => {'pass' => 11},'uses' => ['5.004','Carp','strict','vars']}};

  return $cpants;
}


1;

__END__

=head1 NAME

Module::CPANTS - CPAN Module Testing

=head1 SYNOPSIS

  use Module::CPANTS;
  my $c = Module::CPANTS->new();
  my $cpants = $c->data;

=head1 DESCRIPTION

This is an initial stab at providing automated testing metrics for the
modules on CPAN. Alpha release and all that. It's just out there to
test the waters.

CPANTS was initially described by Michael Schwern a long time ago in:
http://archive.develooper.com/perl-qa@perl.org/msg00148.html
It is highly recommended that you read that.

The idea is to have automated module testing reporting back all sorts
of metadata about the modules on CPAN.

The current interface is a large hash. The keys in the hash are
distributions. For example, the information available for
Acme-Colour-0.20.tar.gz is accessible using:

  my $dist = 'Acme-Colour-0.20.tar.gz';
  my $data = $cpants->{$dist};

The actual information currently returned is as follows:

  'Acme-Colour-0.20.tar.gz' => {
    'author' => 'LBROCARD',
    'description' => 'additive and subtractive human-readable colours',
    'files' => [
      'Makefile.PL',
      'README',
      'MANIFEST'
    ],
    'lines' => {
      'nonpod' => 170,
      'pod' => 95,
      'pod_errors' => 0,
      'total' => 265,
      'with_comments' => 8,
    },
    'releases' => '5',
    'requires' => [
      'Graphics-ColorNames-0.32.tar.gz',
      'Scalar-List-Utils-1.11.tar.gz',
      'Test-Simple-0.47.tar.gz'
    ],
    'requires_module' => {
      'Graphics::ColorNames' => 0,
      'List::Util' => 0,
      'Test::Simple' => 0
    },
    'requires_recursive' => [
      'File-Spec-0.82.tar.gz',
      'Graphics-ColorNames-0.32.tar.gz',
      'Scalar-List-Utils-1.11.tar.gz',
      'Test-Harness-2.28.tar.gz',
      'Test-Simple-0.47.tar.gz'
    ],
    'size' => {
      'packed' => 3883,
      'unpacked' => 13078
    },
    'testers' => {
      'fail' => 1,
      'pass' => 5
    },
    'uses' => [
      'Graphics::ColorNames',
      'List::Util',
      'strict',
      'vars'
    ]
  }

The "author" field is the PAUSE ID of the author of the distribution.

The "description" field is the description listed in the CPAN modules
list for the distribibution.

The "lines" field shows the number of POD lines (documentation),
number of POD errors reported by Pod::Simple::Checker, non-POD lines
(code), lines with comments, and total lines in all the modules in a
distribution.

The "files" field is a listref containing interesting files which were
found. The following files are deemed interesting at the moment: 
Makefile.PL, README, Build.PL, META.yml, SIGNATURE, MANIFEST.

The "releases" field contains the total number of releases to CPAN
that distribution has.

The "requires_module" field is a hashref containing the module
prerequisites listed in the Makefile.PL for the distribution.

The "requires" field is a listref containing all the distributions
containing the module prerequisite listed in the Makefile.PL for the
distribution.

The "requires_recursive" is the same as "requires" but lists the
recursive dependencies. This should be all the distributions that the
distribution needs to run.

The "size" contains two fields: the packed and unpacked size of the
distribution in bytes.

The "testers" field contains the number of passes and fails reported
by the CPAN testers (http://testers.cpan.org/). The "tests" subfield
returns the number of tests in that distribution (this is only
available for a limited number of distributions at the moment).

More data is to be added soon. A kwalitee rating may be added soon.

Note that CPANPLUS is very useful for relating modules to
distributions.

=head1 AUTHOR

Leon Brocard <acme@astray.com>

=head1 LICENSE

This code is distributed under the same license as Perl.

